/**
 * Copyright (c) 2022, Salesforce, Inc.,
 * All rights reserved.
 * For full license text, see the LICENSE.txt file
 */

/*
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce-experience-platform-emu/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { register, withDefaultLuvio } from 'force/ldsEngine';
import { print, visit, parse, astResolver } from 'force/ldsGraphqlParser';
import { createInstrumentedAdapter, createLDSAdapter, createGraphQLWireAdapterConstructor, createGraphQLImperativeAdapter } from 'force/ldsBindings';
export { refresh as refreshGraphQL } from 'force/ldsBindings';
import { serializeStructuredKey, resolveLink, deepFreeze, buildNetworkSnapshotCachePolicy as buildNetworkSnapshotCachePolicy$2, StoreKeyMap, createResourceParams as createResourceParams$2, StoreKeySet } from 'force/luvioEngine';
import { getRequestedFieldsForType, buildFieldState, buildQueryTypeStringKey, createFragmentMap, mergeSelectionSets, serializeFieldArguments, deepMerge, getOperationFromDocument } from 'force/luvioGraphql';
import { createIngestRecordWithFields } from 'force/ldsAdaptersUiapi';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys$1, create: ObjectCreate$1 } = Object;
const { stringify: JSONStringify } = JSON;
const { isArray: ArrayIsArray } = Array;
const { push: ArrayPrototypePush } = Array.prototype;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys$1(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const snapshotRefreshOptions = {
    overrides: {
        headers: {
            'Cache-Control': 'no-cache',
        },
    }
};
/**
 * A deterministic JSON stringify implementation. Heavily adapted from https://github.com/epoberezkin/fast-json-stable-stringify.
 * This is needed because insertion order for JSON.stringify(object) affects output:
 * JSON.stringify({a: 1, b: 2})
 *      "{"a":1,"b":2}"
 * JSON.stringify({b: 2, a: 1})
 *      "{"b":2,"a":1}"
 * @param data Data to be JSON-stringified.
 * @returns JSON.stringified value with consistent ordering of keys.
 */
function stableJSONStringify(node) {
    // This is for Date values.
    if (node && node.toJSON && typeof node.toJSON === 'function') {
        // eslint-disable-next-line no-param-reassign
        node = node.toJSON();
    }
    if (node === undefined) {
        return;
    }
    if (typeof node === 'number') {
        return isFinite(node) ? '' + node : 'null';
    }
    if (typeof node !== 'object') {
        return JSONStringify(node);
    }
    let i;
    let out;
    if (ArrayIsArray(node)) {
        out = '[';
        for (i = 0; i < node.length; i++) {
            if (i) {
                out += ',';
            }
            out += stableJSONStringify(node[i]) || 'null';
        }
        return out + ']';
    }
    if (node === null) {
        return 'null';
    }
    const keys = ObjectKeys$1(node).sort();
    out = '';
    for (i = 0; i < keys.length; i++) {
        const key = keys[i];
        const value = stableJSONStringify(node[key]);
        if (!value) {
            continue;
        }
        if (out) {
            out += ',';
        }
        out += JSONStringify(key) + ':' + value;
    }
    return '{' + out + '}';
}
function getFetchResponseStatusText(status) {
    switch (status) {
        case 200:
            return 'OK';
        case 201:
            return 'Created';
        case 304:
            return 'Not Modified';
        case 404:
            return 'Not Found';
        case 400:
            return 'Bad Request';
        case 500:
            return 'Server Error';
        default:
            return `Unexpected HTTP Status Code: ${status}`;
    }
}
function generateParamConfigMetadata(name, required, resourceType, typeCheckShape, isArrayShape = false, coerceFn) {
    return {
        name,
        required,
        resourceType,
        typeCheckShape,
        isArrayShape,
        coerceFn,
    };
}
function buildAdapterValidationConfig(displayName, paramsMeta) {
    const required = paramsMeta.filter(p => p.required).map(p => p.name);
    const optional = paramsMeta.filter(p => !p.required).map(p => p.name);
    return {
        displayName,
        parameters: {
            required,
            optional,
        }
    };
}
const keyPrefix = 'UiApi';

const { keys: ObjectKeys, create: ObjectCreate, assign: ObjectAssign } = Object;
function equalsObject(a, b, equalsProp) {
    const aKeys = ObjectKeys(a).sort();
    const bKeys = ObjectKeys(b).sort();
    const aKeysLength = aKeys.length;
    const bKeysLength = bKeys.length;
    if (aKeysLength !== bKeysLength) {
        return false;
    }
    for (let i = 0; i < aKeys.length; i++) {
        const key = aKeys[i];
        if (key !== bKeys[i]) {
            return false;
        }
        if (equalsProp(a[key], b[key]) === false) {
            return false;
        }
    }
    return true;
}
function createLink$1(ref) {
    return {
        __ref: serializeStructuredKey(ref),
    };
}
function assignMetadataLink(entry, metadataKey) {
    entry['__metadata'] = createLink$1(metadataKey);
}

const PAGINATION_VERSION = "0.111.0";
const paginationStoreMetadata = {
    ttl: Number.MAX_SAFE_INTEGER,
    namespace: '',
    representationName: '',
    version: PAGINATION_VERSION
};
function createPaginationMetadata(startOffset, edges) {
    const paginationMetadata = {};
    for (let i = 0; i < edges.length; i++) {
        const cursor = edges[i].cursor;
        Object.assign(paginationMetadata, {
            [cursor]: startOffset + i,
        });
    }
    return paginationMetadata;
}
function createPageInfo(edges, startOffset, endOffset, maxOffset, metadata) {
    if (edges === undefined) {
        return undefined;
    }
    const listIsIncomplete = (metadata?.__END__ === undefined);
    const hasNextPage = listIsIncomplete || (endOffset !== undefined && maxOffset !== undefined && (endOffset - 1 < maxOffset));
    const hasPreviousPage = startOffset !== undefined && startOffset > 0;
    let startCursor = null;
    let endCursor = null;
    if (edges.length && metadata !== undefined) {
        const startOffsetIsDefined = startOffset !== undefined;
        const endOffsetIsDefined = endOffset !== undefined;
        Object.keys(metadata)
            .forEach((token) => {
            const index = metadata[token];
            if (startOffsetIsDefined && index === startOffset) {
                startCursor = token;
            }
            if (endOffsetIsDefined && index === endOffset - 1) {
                endCursor = token;
            }
        });
    }
    return {
        startCursor,
        endCursor,
        hasNextPage,
        hasPreviousPage,
        __typename: 'PageInfo',
    };
}
function findMaxOffset(metadata) {
    if (metadata === undefined)
        return -1;
    const endOfList = metadata["__END__"];
    if (endOfList !== undefined) {
        return endOfList > 0 ? endOfList - 1 : 0; // Cursor based pagination in gql is off by one :)
    }
    // end is included in the above case.
    return Object.values(metadata)
        .reduce((acc, value) => Math.max(value ?? -1, acc), -1);
}
function getPageTokenAndOffset(paginationMetadata, token) {
    if (token === undefined) {
        const startToken = tokenFromOffset(paginationMetadata, 0);
        if (startToken === undefined) {
            return;
        }
        return [startToken, 0];
    }
    const startOffset = offsetFromToken(paginationMetadata, token);
    if (startOffset < 0) {
        return;
    }
    return [token, startOffset];
}
function hasGraphQLPaginationFields(data) {
    return (data !== null &&
        data !== undefined &&
        data.pageInfo !== undefined &&
        data.pageInfo !== null &&
        data.pageInfo.endCursor !== undefined &&
        data.pageInfo.startCursor !== undefined &&
        data.edges !== null &&
        data.edges !== undefined);
}
function mergeMetadata(existingMetadata, incomingMetadata) {
    if (existingMetadata === undefined) {
        return incomingMetadata;
    }
    return {
        ...existingMetadata,
        ...incomingMetadata,
    };
}
function getNextPageToken(paginationMetadata, pageEndOffset) {
    const listEndOffset = paginationMetadata.__END__;
    if (listEndOffset === undefined || pageEndOffset < listEndOffset) {
        return tokenFromOffset(paginationMetadata, pageEndOffset);
    }
    return null;
}
function offsetFromToken(paginationMetadata, token) {
    if (token === undefined || token === null) {
        return 0;
    }
    const offset = paginationMetadata[token];
    return offset === undefined ? -1 : offset;
}
function pageEndOffset(paginationMetadata, startOffset, pageSize) {
    const listEndOffset = paginationMetadata.__END__;
    const nextPageOffset = startOffset + pageSize;
    if (listEndOffset === undefined) {
        return nextPageOffset;
    }
    return Math.min(nextPageOffset, listEndOffset);
}
function tokenFromOffset(paginationMetadata, offset) {
    const tokens = Object.keys(paginationMetadata);
    for (let i = 0, len = tokens.length; i < len; i++) {
        const token = tokens[i];
        if (paginationMetadata[token] === offset &&
            token !== '__END__') {
            return token;
        }
    }
}
function tokenForAtMost(paginationMetadata, maxOffset) {
    const tokens = Object.keys(paginationMetadata);
    let tokenResult = undefined;
    let offsetResult = -1;
    for (let i = 0, len = tokens.length; i < len; i++) {
        const token = tokens[i];
        const offset = paginationMetadata[token];
        if (token === '__END__' || offset === undefined) {
            continue;
        }
        if (offset === maxOffset) {
            return [token, offset];
        }
        if (offset < maxOffset && offset > offsetResult) {
            tokenResult = token;
            offsetResult = offset;
        }
    }
    return [tokenResult, offsetResult];
}
function trimEdges(edges, startOffset, endOffset) {
    const trimmedEdges = [];
    if (edges !== undefined) {
        for (let i = startOffset; i < endOffset; i++) {
            if (edges[i] === undefined) {
                return undefined;
            }
            trimmedEdges[i - startOffset] = edges[i];
        }
    }
    return trimmedEdges;
}
function optimizePagination(metadata, firstArgName, afterArgName, variables) {
    if (typeof metadata === 'object' && metadata !== null) {
        const requestedAfterCursor = variables[afterArgName];
        const afterCursorOffset = offsetFromToken(metadata, requestedAfterCursor);
        // optimize only if after cursor is unspecified in the request or it's already loaded in metadata
        if (afterCursorOffset >= 0) {
            const requestedItems = variables[firstArgName];
            const atMostOffset = afterCursorOffset + requestedItems; // The largest offset we care about for this page.
            const lastTokenAndOffset = tokenForAtMost(metadata, atMostOffset);
            if (lastTokenAndOffset !== undefined) {
                const [token, offset] = lastTokenAndOffset;
                const isSubpage = atMostOffset === offset; // We already have all the cursors we seem to need
                const isExactPagination = atMostOffset === offset + requestedItems; // Using the last cursor we have to paginate
                if (!(isSubpage || isExactPagination)) { // If we're asking for more than we have, only request what we're missing.
                    const existingItems = afterCursorOffset === 0 ? offset + 1 : offset - afterCursorOffset;
                    const itemsToRequest = requestedItems - existingItems;
                    variables[firstArgName + '_original'] = requestedItems;
                    variables[firstArgName] = itemsToRequest;
                    variables[afterArgName + '_original'] = requestedAfterCursor;
                    variables[afterArgName] = token;
                }
            }
        }
    }
}
function revertPaginationOptimization(variables) {
    if (variables) {
        const toBeRemoved = [];
        for (const key in variables) {
            if (key.endsWith('_original')) {
                const origKey = key.substring(0, key.length - '_original'.length);
                if (Object.prototype.hasOwnProperty.call(variables, origKey)) {
                    variables[origKey] = variables[key];
                    toBeRemoved.push(key);
                }
            }
        }
        toBeRemoved.forEach((k) => delete variables[k]);
    }
}

const name$1k = 'DoubleValue';
const VERSION$1y = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$1p(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1k(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1p(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1p(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1l,
        isMappedFieldImport: isMappedField$1k,
        getFieldType: getFieldType$1C,
        ingestFieldByType: ingestFieldByType$1k,
        createLink: createLink,
        mergeData: mergeData$1k,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DoubleValue",
            version: VERSION$1y,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1k(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1C(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1l(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Double': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1l(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1k, getFieldType$1C, selectType$1l, parentRecordId);
}
function buildSelectionForNode$1l(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1l, buildSelectionForField$1l, parentRecordId);
}
function select$1y(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1l, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1s(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1p(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1k
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1C(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Double'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1k(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Double': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1k(field) {
    return false;
}
function isFragmentApplicable$1l(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "DoubleValue", typename);
}
function getInContextFragmentType$1C(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1j = 'LongValue';
const VERSION$1x = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$1o(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1j(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1o(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1o(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1k,
        isMappedFieldImport: isMappedField$1j,
        getFieldType: getFieldType$1B,
        ingestFieldByType: ingestFieldByType$1j,
        createLink: createLink,
        mergeData: mergeData$1j,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LongValue",
            version: VERSION$1x,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1j(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1B(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1k(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Long': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1k(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1j, getFieldType$1B, selectType$1k, parentRecordId);
}
function buildSelectionForNode$1k(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1k, buildSelectionForField$1k, parentRecordId);
}
function select$1x(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1k, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1r(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1o(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1j
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1B(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1j(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Long': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1j(field) {
    return false;
}
function isFragmentApplicable$1k(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LongValue", typename);
}
function getInContextFragmentType$1B(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1i = 'PercentValue';
const VERSION$1w = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$1n(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1i(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1n(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1n(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1j,
        isMappedFieldImport: isMappedField$1i,
        getFieldType: getFieldType$1A,
        ingestFieldByType: ingestFieldByType$1i,
        createLink: createLink,
        mergeData: mergeData$1i,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PercentValue",
            version: VERSION$1w,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1i(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1A(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1j(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Percent': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1j(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1i, getFieldType$1A, selectType$1j, parentRecordId);
}
function buildSelectionForNode$1j(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1j, buildSelectionForField$1j, parentRecordId);
}
function select$1w(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1j, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1q(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1n(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1i
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1A(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Percent'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1i(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Percent': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1i(field) {
    return false;
}
function isFragmentApplicable$1j(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "PercentValue", typename);
}
function getInContextFragmentType$1A(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1h = 'PercentAggregate';
const VERSION$1v = '93eeee533428dc68b3aa891a971948e4';
function keyBuilder$1m(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1h(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1m(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1m(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1i,
        isMappedFieldImport: isMappedField$1h,
        getFieldType: getFieldType$1z,
        ingestFieldByType: ingestFieldByType$1h,
        createLink: createLink,
        mergeData: mergeData$1h,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PercentAggregate",
            version: VERSION$1v,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1h(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1z(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1i(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Percent': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'PercentValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1w, select$1w, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1i(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1h, getFieldType$1z, selectType$1i, parentRecordId);
}
function buildSelectionForNode$1i(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1i, buildSelectionForField$1i, parentRecordId);
}
function select$1v(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1i, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$1f() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$1p(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1m(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1h
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$1i) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$1z(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'PercentValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1q(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'PercentValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1q(cacheKeySink, requestedField, minState);
                break;
            }
            case 'PercentValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1q(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$1z(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Percent'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'PercentValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'PercentValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'PercentValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1h(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Percent': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'PercentValue': {
            const PercentValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1n(requestedField, PercentValueState);
            break;
        }
    }
}
function isMappedField$1h(field) {
    return false;
}
function isFragmentApplicable$1i(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "PercentAggregate", typename);
}
function getInContextFragmentType$1z(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1g = 'IntValue';
const VERSION$1u = 'b71c94771478332a178ced0d71731d38';
function keyBuilder$1l(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1g(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1l(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1l(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1h,
        isMappedFieldImport: isMappedField$1g,
        getFieldType: getFieldType$1y,
        ingestFieldByType: ingestFieldByType$1g,
        createLink: createLink,
        mergeData: mergeData$1g,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "IntValue",
            version: VERSION$1u,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1g(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1y(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1h(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1h(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1g, getFieldType$1y, selectType$1h, parentRecordId);
}
function buildSelectionForNode$1h(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1h, buildSelectionForField$1h, parentRecordId);
}
function select$1u(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1h, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1o(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1l(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1g
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1y(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1g(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1g(field) {
    return false;
}
function isFragmentApplicable$1h(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "IntValue", typename);
}
function getInContextFragmentType$1y(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1f = 'StringValue';
const VERSION$1t = 'fb807e77bb467eb909318cafa7f3b4e0';
function keyBuilder$1k(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1f(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1k(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1k(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1g,
        isMappedFieldImport: isMappedField$1f,
        getFieldType: getFieldType$1x,
        ingestFieldByType: ingestFieldByType$1f,
        createLink: createLink,
        mergeData: mergeData$1f,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "StringValue",
            version: VERSION$1t,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1f(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1x(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1g(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1g(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1f, getFieldType$1x, selectType$1g, parentRecordId);
}
function buildSelectionForNode$1g(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1g, buildSelectionForField$1g, parentRecordId);
}
function select$1t(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1g, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1n(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1k(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1f
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1x(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1f(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1f(field) {
    return false;
}
function isFragmentApplicable$1g(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "StringValue", typename);
}
function getInContextFragmentType$1x(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1e = 'StringAggregate';
const VERSION$1s = 'cd64595f5647f1e5a246a7ac13aa702e';
function keyBuilder$1j(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1e(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1j(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1j(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1f,
        isMappedFieldImport: isMappedField$1e,
        getFieldType: getFieldType$1w,
        ingestFieldByType: ingestFieldByType$1e,
        createLink: createLink,
        mergeData: mergeData$1e,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "StringAggregate",
            version: VERSION$1s,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1e(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1w(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1f(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'StringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1t, select$1t, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1f(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1e, getFieldType$1w, selectType$1f, parentRecordId);
}
function buildSelectionForNode$1f(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1f, buildSelectionForField$1f, parentRecordId);
}
function select$1s(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1f, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$1e() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$1m(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1j(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1e
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$1f) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$1w(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'StringValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'StringValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$1w(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1e(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'StringValue': {
            const StringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1k(requestedField, StringValueState);
            break;
        }
    }
}
function isMappedField$1e(field) {
    return false;
}
function isFragmentApplicable$1f(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "StringAggregate", typename);
}
function getInContextFragmentType$1w(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1d = 'IDValue';
const VERSION$1r = '8a917704b9367cdf6322663e4a5f015c';
function keyBuilder$1i(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1d(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1i(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1i(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1e,
        isMappedFieldImport: isMappedField$1d,
        getFieldType: getFieldType$1v,
        ingestFieldByType: ingestFieldByType$1d,
        createLink: createLink,
        mergeData: mergeData$1d,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "IDValue",
            version: VERSION$1r,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1d(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1v(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1e(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1e(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1d, getFieldType$1v, selectType$1e, parentRecordId);
}
function buildSelectionForNode$1e(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1e, buildSelectionForField$1e, parentRecordId);
}
function select$1r(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1e, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1l(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1i(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1d
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1v(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1d(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1d(field) {
    return false;
}
function isFragmentApplicable$1e(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "IDValue", typename);
}
function getInContextFragmentType$1v(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1c = 'DateTimeValue';
const VERSION$1q = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$1h(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1c(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1h(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1h(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1d,
        isMappedFieldImport: isMappedField$1c,
        getFieldType: getFieldType$1u,
        ingestFieldByType: ingestFieldByType$1c,
        createLink: createLink,
        mergeData: mergeData$1c,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DateTimeValue",
            version: VERSION$1q,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1c(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1u(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1d(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DateTime': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1d(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1c, getFieldType$1u, selectType$1d, parentRecordId);
}
function buildSelectionForNode$1d(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1d, buildSelectionForField$1d, parentRecordId);
}
function select$1q(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1d, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1k(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1h(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1c
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1u(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'DateTime'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1c(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DateTime': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1c(field) {
    return false;
}
function isFragmentApplicable$1d(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "DateTimeValue", typename);
}
function getInContextFragmentType$1u(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1b = 'BooleanValue';
const VERSION$1p = '8b2f0c1b2312044b6c60b3bf506054a2';
function keyBuilder$1g(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1b(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1g(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1g(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1c,
        isMappedFieldImport: isMappedField$1b,
        getFieldType: getFieldType$1t,
        ingestFieldByType: ingestFieldByType$1b,
        createLink: createLink,
        mergeData: mergeData$1b,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "BooleanValue",
            version: VERSION$1p,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1b(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1t(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1c(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1c(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1b, getFieldType$1t, selectType$1c, parentRecordId);
}
function buildSelectionForNode$1c(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1c, buildSelectionForField$1c, parentRecordId);
}
function select$1p(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1c, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1j(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1g(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1b
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1t(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1b(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1b(field) {
    return false;
}
function isFragmentApplicable$1c(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "BooleanValue", typename);
}
function getInContextFragmentType$1t(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1a = 'TimeValue';
const VERSION$1o = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$1f(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1a(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1f(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1f(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1b,
        isMappedFieldImport: isMappedField$1a,
        getFieldType: getFieldType$1s,
        ingestFieldByType: ingestFieldByType$1a,
        createLink: createLink,
        mergeData: mergeData$1a,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "TimeValue",
            version: VERSION$1o,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1a(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1s(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1b(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Time': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1b(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1a, getFieldType$1s, selectType$1b, parentRecordId);
}
function buildSelectionForNode$1b(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1b, buildSelectionForField$1b, parentRecordId);
}
function select$1o(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1b, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1i(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1f(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1a
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1s(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Time'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1a(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Time': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$1a(field) {
    return false;
}
function isFragmentApplicable$1b(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "TimeValue", typename);
}
function getInContextFragmentType$1s(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$19 = 'DateValue';
const VERSION$1n = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$1e(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$19(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1e(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1e(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1a,
        isMappedFieldImport: isMappedField$19,
        getFieldType: getFieldType$1r,
        ingestFieldByType: ingestFieldByType$19,
        createLink: createLink,
        mergeData: mergeData$19,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DateValue",
            version: VERSION$1n,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$19(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1r(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1a(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Date': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1a(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$19, getFieldType$1r, selectType$1a, parentRecordId);
}
function buildSelectionForNode$1a(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1a, buildSelectionForField$1a, parentRecordId);
}
function select$1n(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1a, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1h(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1e(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$19
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1r(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Date'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$19(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Date': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$19(field) {
    return false;
}
function isFragmentApplicable$1a(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "DateValue", typename);
}
function getInContextFragmentType$1r(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$18 = 'TextAreaValue';
const VERSION$1m = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$1d(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$18(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1d(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1d(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$19,
        isMappedFieldImport: isMappedField$18,
        getFieldType: getFieldType$1q,
        ingestFieldByType: ingestFieldByType$18,
        createLink: createLink,
        mergeData: mergeData$18,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "TextAreaValue",
            version: VERSION$1m,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$18(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1q(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$19(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'TextArea': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$19(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$18, getFieldType$1q, selectType$19, parentRecordId);
}
function buildSelectionForNode$19(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$19, buildSelectionForField$19, parentRecordId);
}
function select$1m(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$19, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1g(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1d(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$18
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1q(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'TextArea'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$18(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'TextArea': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$18(field) {
    return false;
}
function isFragmentApplicable$19(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "TextAreaValue", typename);
}
function getInContextFragmentType$1q(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$17 = 'LongTextAreaValue';
const VERSION$1l = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$1c(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$17(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1c(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1c(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$18,
        isMappedFieldImport: isMappedField$17,
        getFieldType: getFieldType$1p,
        ingestFieldByType: ingestFieldByType$17,
        createLink: createLink,
        mergeData: mergeData$17,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LongTextAreaValue",
            version: VERSION$1l,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$17(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1p(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$18(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongTextArea': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$18(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$17, getFieldType$1p, selectType$18, parentRecordId);
}
function buildSelectionForNode$18(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$18, buildSelectionForField$18, parentRecordId);
}
function select$1l(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$18, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1f(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1c(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$17
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1p(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'LongTextArea'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$17(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongTextArea': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$17(field) {
    return false;
}
function isFragmentApplicable$18(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LongTextAreaValue", typename);
}
function getInContextFragmentType$1p(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$16 = 'RichTextAreaValue';
const VERSION$1k = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$1b(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$16(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1b(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1b(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$17,
        isMappedFieldImport: isMappedField$16,
        getFieldType: getFieldType$1o,
        ingestFieldByType: ingestFieldByType$16,
        createLink: createLink,
        mergeData: mergeData$16,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RichTextAreaValue",
            version: VERSION$1k,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$16(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1o(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$17(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RichTextArea': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$17(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$16, getFieldType$1o, selectType$17, parentRecordId);
}
function buildSelectionForNode$17(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$17, buildSelectionForField$17, parentRecordId);
}
function select$1k(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$17, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1e(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1b(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$16
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1o(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'RichTextArea'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$16(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RichTextArea': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$16(field) {
    return false;
}
function isFragmentApplicable$17(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "RichTextAreaValue", typename);
}
function getInContextFragmentType$1o(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$15 = 'PhoneNumberValue';
const VERSION$1j = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$1a(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$15(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1a(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$1a(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$16,
        isMappedFieldImport: isMappedField$15,
        getFieldType: getFieldType$1n,
        ingestFieldByType: ingestFieldByType$15,
        createLink: createLink,
        mergeData: mergeData$15,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PhoneNumberValue",
            version: VERSION$1j,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$15(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1n(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$16(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'PhoneNumber': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$16(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$15, getFieldType$1n, selectType$16, parentRecordId);
}
function buildSelectionForNode$16(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$16, buildSelectionForField$16, parentRecordId);
}
function select$1j(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$16, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1d(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$1a(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$15
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1n(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'PhoneNumber'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$15(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'PhoneNumber': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$15(field) {
    return false;
}
function isFragmentApplicable$16(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "PhoneNumberValue", typename);
}
function getInContextFragmentType$1n(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$14 = 'EmailValue';
const VERSION$1i = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$19(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$14(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$19(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$19(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$15,
        isMappedFieldImport: isMappedField$14,
        getFieldType: getFieldType$1m,
        ingestFieldByType: ingestFieldByType$14,
        createLink: createLink,
        mergeData: mergeData$14,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "EmailValue",
            version: VERSION$1i,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$14(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1m(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$15(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Email': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$15(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$14, getFieldType$1m, selectType$15, parentRecordId);
}
function buildSelectionForNode$15(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$15, buildSelectionForField$15, parentRecordId);
}
function select$1i(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$15, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1c(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$19(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$14
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1m(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Email'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$14(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Email': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$14(field) {
    return false;
}
function isFragmentApplicable$15(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "EmailValue", typename);
}
function getInContextFragmentType$1m(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$13 = 'UrlValue';
const VERSION$1h = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$18(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$13(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$18(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$18(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$14,
        isMappedFieldImport: isMappedField$13,
        getFieldType: getFieldType$1l,
        ingestFieldByType: ingestFieldByType$13,
        createLink: createLink,
        mergeData: mergeData$13,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "UrlValue",
            version: VERSION$1h,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$13(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1l(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$14(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Url': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$14(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$13, getFieldType$1l, selectType$14, parentRecordId);
}
function buildSelectionForNode$14(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$14, buildSelectionForField$14, parentRecordId);
}
function select$1h(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$14, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1b(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$18(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$13
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1l(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Url'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$13(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Url': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$13(field) {
    return false;
}
function isFragmentApplicable$14(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "UrlValue", typename);
}
function getInContextFragmentType$1l(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$12 = 'EncryptedStringValue';
const VERSION$1g = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$17(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$12(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$17(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$17(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$13,
        isMappedFieldImport: isMappedField$12,
        getFieldType: getFieldType$1k,
        ingestFieldByType: ingestFieldByType$12,
        createLink: createLink,
        mergeData: mergeData$12,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "EncryptedStringValue",
            version: VERSION$1g,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$12(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1k(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$13(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'EncryptedString': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$13(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$12, getFieldType$1k, selectType$13, parentRecordId);
}
function buildSelectionForNode$13(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$13, buildSelectionForField$13, parentRecordId);
}
function select$1g(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$13, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$1a(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$17(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$12
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1k(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'EncryptedString'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$12(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'EncryptedString': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$12(field) {
    return false;
}
function isFragmentApplicable$13(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "EncryptedStringValue", typename);
}
function getInContextFragmentType$1k(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$11 = 'CurrencyValue';
const VERSION$1f = 'de69c0962aca45d77a5bc8d9abacfa7d';
function keyBuilder$16(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$11(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$16(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$16(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$12,
        isMappedFieldImport: isMappedField$11,
        getFieldType: getFieldType$1j,
        ingestFieldByType: ingestFieldByType$11,
        createLink: createLink,
        mergeData: mergeData$11,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "CurrencyValue",
            version: VERSION$1f,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$11(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1j(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$12(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Currency': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$12(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$11, getFieldType$1j, selectType$12, parentRecordId);
}
function buildSelectionForNode$12(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$12, buildSelectionForField$12, parentRecordId);
}
function select$1f(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$12, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$19(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$16(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$11
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1j(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Currency'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$11(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Currency': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$11(field) {
    return false;
}
function isFragmentApplicable$12(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "CurrencyValue", typename);
}
function getInContextFragmentType$1j(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$10 = 'LongitudeValue';
const VERSION$1e = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$15(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$10(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$15(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$15(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$11,
        isMappedFieldImport: isMappedField$10,
        getFieldType: getFieldType$1i,
        ingestFieldByType: ingestFieldByType$10,
        createLink: createLink,
        mergeData: mergeData$10,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LongitudeValue",
            version: VERSION$1e,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$10(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1i(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$11(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Longitude': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$11(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$10, getFieldType$1i, selectType$11, parentRecordId);
}
function buildSelectionForNode$11(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$11, buildSelectionForField$11, parentRecordId);
}
function select$1e(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$11, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$18(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$15(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$10
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1i(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Longitude'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$10(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Longitude': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$10(field) {
    return false;
}
function isFragmentApplicable$11(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LongitudeValue", typename);
}
function getInContextFragmentType$1i(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$$ = 'LatitudeValue';
const VERSION$1d = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$14(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$$(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$14(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$14(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$10,
        isMappedFieldImport: isMappedField$$,
        getFieldType: getFieldType$1h,
        ingestFieldByType: ingestFieldByType$$,
        createLink: createLink,
        mergeData: mergeData$$,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LatitudeValue",
            version: VERSION$1d,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$$(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1h(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$10(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Latitude': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$10(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$$, getFieldType$1h, selectType$10, parentRecordId);
}
function buildSelectionForNode$10(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$10, buildSelectionForField$10, parentRecordId);
}
function select$1d(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$10, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$17(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$14(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$$
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1h(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Latitude'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$$(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Latitude': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$$(field) {
    return false;
}
function isFragmentApplicable$10(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LatitudeValue", typename);
}
function getInContextFragmentType$1h(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$_ = 'PicklistValue';
const VERSION$1c = '38d383da02de0256f51de5000c01e745';
function keyBuilder$13(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$_(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$13(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$13(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$$,
        isMappedFieldImport: isMappedField$_,
        getFieldType: getFieldType$1g,
        ingestFieldByType: ingestFieldByType$_,
        createLink: createLink,
        mergeData: mergeData$_,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PicklistValue",
            version: VERSION$1c,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$_(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1g(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$$(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Picklist': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$$(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$_, getFieldType$1g, selectType$$, parentRecordId);
}
function buildSelectionForNode$$(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$$, buildSelectionForField$$, parentRecordId);
}
function select$1c(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$$, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$16(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$13(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$_
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1g(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Picklist'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$_(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Picklist': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$_(field) {
    return false;
}
function isFragmentApplicable$$(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "PicklistValue", typename);
}
function getInContextFragmentType$1g(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$Z = 'MultiPicklistValue';
const VERSION$1b = '38d383da02de0256f51de5000c01e745';
function keyBuilder$12(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$Z(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$12(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$12(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$_,
        isMappedFieldImport: isMappedField$Z,
        getFieldType: getFieldType$1f,
        ingestFieldByType: ingestFieldByType$Z,
        createLink: createLink,
        mergeData: mergeData$Z,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "MultiPicklistValue",
            version: VERSION$1b,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$Z(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1f(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$_(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'MultiPicklist': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$_(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$Z, getFieldType$1f, selectType$_, parentRecordId);
}
function buildSelectionForNode$_(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$_, buildSelectionForField$_, parentRecordId);
}
function select$1b(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$_, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$15(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$12(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$Z
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1f(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'MultiPicklist'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$Z(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'MultiPicklist': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$Z(field) {
    return false;
}
function isFragmentApplicable$_(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "MultiPicklistValue", typename);
}
function getInContextFragmentType$1f(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$Y = 'Base64Value';
const VERSION$1a = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$11(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$Y(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$11(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$11(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$Z,
        isMappedFieldImport: isMappedField$Y,
        getFieldType: getFieldType$1e,
        ingestFieldByType: ingestFieldByType$Y,
        createLink: createLink,
        mergeData: mergeData$Y,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Base64Value",
            version: VERSION$1a,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$Y(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1e(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$Z(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Base64': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$Z(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$Y, getFieldType$1e, selectType$Z, parentRecordId);
}
function buildSelectionForNode$Z(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$Z, buildSelectionForField$Z, parentRecordId);
}
function select$1a(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$Z, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$14(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$11(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$Y
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1e(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Base64'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$Y(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Base64': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$Y(field) {
    return false;
}
function isFragmentApplicable$Z(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "Base64Value", typename);
}
function getInContextFragmentType$1e(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$X = 'JSONValue';
const VERSION$19 = 'c8376c7f60ac5cfe1c2c1521cd4664fa';
function keyBuilder$10(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$X(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$10(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$10(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$Y,
        isMappedFieldImport: isMappedField$X,
        getFieldType: getFieldType$1d,
        ingestFieldByType: ingestFieldByType$X,
        createLink: createLink,
        mergeData: mergeData$X,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "JSONValue",
            version: VERSION$19,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$X(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1d(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$Y(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'JSON': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$Y(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$X, getFieldType$1d, selectType$Y, parentRecordId);
}
function buildSelectionForNode$Y(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$Y, buildSelectionForField$Y, parentRecordId);
}
function select$19(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$Y, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$13(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$10(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$X
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$1d(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'JSON'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$X(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'JSON': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$X(field) {
    return false;
}
function isFragmentApplicable$Y(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "JSONValue", typename);
}
function getInContextFragmentType$1d(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

// union versions are undefined, selected versions must be specific to the type being selected
const VERSION$18 = undefined;
function ingest$$(astNode, state) {
    const typename = state.data.__typename;
    // Delegate key building and ingest to concrete implementations
    if (typename === 'RecordRepresentation') {
        return ingest$Y(astNode, state);
    }
}
function select$18(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const typename = source.data.__typename;
        if (typename === 'RecordRepresentation') {
            return select$15(field, variables, fragments)(source, reader, parentRecordId);
        }
    };
}
function getTypeCacheKeys$12(cacheKeys, astNode, state) {
    const { path, data } = state;
    const typename = data.__typename;
    if (typename === 'RecordRepresentation') {
        return getTypeCacheKeys$X(cacheKeys, astNode, state);
    }
}
function getInContextFragmentType$1c(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}
function getFieldType$1c(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getMinimumSelections$1d() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}

// Naive impl for pulling out a directive value from a field node. Doesn't handle multiple stacked
// directives or need for multiple argument values.
function getDirectiveArgumentValue(field, directiveName, argumentName) {
    if (field.directives) {
        const targetedDirective = field.directives.find((directiveNode) => directiveNode.name.value === directiveName);
        if (targetedDirective && targetedDirective.arguments) {
            const targetedArgument = targetedDirective.arguments.find((arg) => arg.name.value === argumentName);
            if (targetedArgument) {
                return targetedArgument.value;
            }
        }
    }
}

function getFieldNameOverride(field) {
    const categoryValue = getDirectiveArgumentValue(field, 'category', 'name');
    if (categoryValue) {
        // Only string types are allowed for metaschema category directives.
        if (categoryValue.kind === 'StringValue') {
            return categoryValue.value;
        }
    }
}

function getFieldType$1b(field) {
    const fieldNameOverride = getFieldNameOverride(field);
    const fieldName = fieldNameOverride || field.name.value;
    switch (fieldName) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'IntValue': {
            return {
                isArray: false,
                typename: 'IntValue',
            };
        }
        case 'StringValue': {
            return {
                isArray: false,
                typename: 'StringValue',
            };
        }
        case 'BooleanValue': {
            return {
                isArray: false,
                typename: 'BooleanValue',
            };
        }
        case 'IDValue': {
            return {
                isArray: false,
                typename: 'IDValue',
            };
        }
        case 'DateTimeValue': {
            return {
                isArray: false,
                typename: 'DateTimeValue',
            };
        }
        case 'TimeValue': {
            return {
                isArray: false,
                typename: 'TimeValue',
            };
        }
        case 'DateValue': {
            return {
                isArray: false,
                typename: 'DateValue',
            };
        }
        case 'TextAreaValue': {
            return {
                isArray: false,
                typename: 'TextAreaValue',
            };
        }
        case 'LongTextAreaValue': {
            return {
                isArray: false,
                typename: 'LongTextAreaValue',
            };
        }
        case 'RichTextAreaValue': {
            return {
                isArray: false,
                typename: 'RichTextAreaValue',
            };
        }
        case 'PhoneNumberValue': {
            return {
                isArray: false,
                typename: 'PhoneNumberValue',
            };
        }
        case 'EmailValue': {
            return {
                isArray: false,
                typename: 'EmailValue',
            };
        }
        case 'UrlValue': {
            return {
                isArray: false,
                typename: 'UrlValue',
            };
        }
        case 'EncryptedStringValue': {
            return {
                isArray: false,
                typename: 'EncryptedStringValue',
            };
        }
        case 'CurrencyValue': {
            return {
                isArray: false,
                typename: 'CurrencyValue',
            };
        }
        case 'LongitudeValue': {
            return {
                isArray: false,
                typename: 'LongitudeValue',
            };
        }
        case 'LatitudeValue': {
            return {
                isArray: false,
                typename: 'LatitudeValue',
            };
        }
        case 'PicklistValue': {
            return {
                isArray: false,
                typename: 'PicklistValue',
            };
        }
        case 'MultiPicklistValue': {
            return {
                isArray: false,
                typename: 'MultiPicklistValue',
            };
        }
        case 'LongValue': {
            return {
                isArray: false,
                typename: 'LongValue',
            };
        }
        case 'DoubleValue': {
            return {
                isArray: false,
                typename: 'DoubleValue',
            };
        }
        case 'PercentValue': {
            return {
                isArray: false,
                typename: 'PercentValue',
            };
        }
        case 'Base64Value': {
            return {
                isArray: false,
                typename: 'Base64Value',
            };
        }
        case 'JSONValue': {
            return {
                isArray: false,
                typename: 'JSONValue',
            };
        }
        default:
            return undefined;
    }
}

const { assign, create, freeze, isFrozen, keys } = Object;
const { isArray } = Array;
const { concat, filter, includes, push, reduce } = Array.prototype;

// we override the generated so we can set "mergeable: true" on the root key
const getTypeCacheKeys$11 = (rootKeySet, luvio, input, _fullPathFactory) => {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$2,
        mergeable: true,
    });
    const input_childRelationships = input.childRelationships;
    const input_childRelationships_keys = keys(input_childRelationships);
    const input_childRelationships_length = input_childRelationships_keys.length;
    for (let i = 0; i < input_childRelationships_length; i++) {
        const key = input_childRelationships_keys[i];
        getTypeCacheKeys$10(rootKeySet, luvio, input_childRelationships[key], () => rootKey + '__childRelationships' + '__' + key);
    }
    const input_fields = input.fields;
    const input_fields_keys = keys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$$(rootKeySet, luvio, input_fields[key], () => rootKey + '__fields__' + key);
    }
    return rootKeySet;
};

const RepresentationType$3 = 'RecordCollectionRepresentation';
function getTypeCacheKeys$10(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$3,
        mergeable: false
    });
    const input_records_length = input.records.length;
    for (let i = 0; i < input_records_length; i++) {
        getTypeCacheKeys$11(rootKeySet, luvio, input.records[i]);
    }
}

const VERSION$17 = "98c5b18512e48ca8d28727549507e4ba";
const RepresentationType$2 = 'RecordRepresentation';
function keyBuilder$$(luvio, config) {
    return keyPrefix + '::' + RepresentationType$2 + ':' + config.recordId;
}
function keyBuilderFromType(luvio, object) {
    const keyParams = {
        recordId: object.id
    };
    return keyBuilder$$(luvio, keyParams);
}

const VERSION$16 = "195d918987a35f45e1aa4dce9a11d8c5";
const RepresentationType$1 = 'FieldValueRepresentation';
function getTypeCacheKeys$$(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$1,
        mergeable: false
    });
    if (input.value !== null && typeof input.value === 'object') {
        getTypeCacheKeys$11(rootKeySet, luvio, input.value);
    }
}

function selectFieldValue(reader, fieldData, sel, variables, fragments, sink, key, selectFunction, __typename, hasFormat, hasLabel, parentRecordId) {
    const gqlFieldValue = readFieldValueAndConvertToGQL(reader, fieldData, hasFormat, hasLabel, __typename);
    if (gqlFieldValue !== undefined) {
        const result = selectFunction(sel, variables, fragments)({ data: gqlFieldValue }, reader, parentRecordId);
        reader.assignNonScalar(sink, key, result);
    }
    else {
        reader.markMissing();
    }
}
function readFieldValueAndConvertToGQL(reader, fieldData, hasFormat, hasLabel, __typename) {
    // Some top level fields aren't currently ingested as fields also, so if there's no ref, try returning the data.
    if (fieldData.__ref !== undefined) {
        const FieldValueLink = reader.read({
            recordId: fieldData.__ref,
            node: {
                kind: 'Fragment',
                private: [],
                opaque: true,
                version: VERSION$16,
            },
            variables: {},
        });
        reader.markSeenId(fieldData.__ref);
        if (FieldValueLink.data !== undefined) {
            const result = convertFieldValueRepresentationToGraphQL(FieldValueLink.data, hasFormat, hasLabel, __typename);
            return result;
        }
        else {
            reader.markMissingLink(fieldData.__ref);
        }
    }
    else {
        return fieldData;
    }
}
function convertFieldValueRepresentationToGraphQL(source, hasFormat, hasLabel, __typename) {
    const fieldValue = {
        ...source,
        __typename,
    };
    // Apparently these fields === displayValue.
    if (hasFormat) {
        fieldValue['format'] = source.displayValue;
    }
    if (hasLabel) {
        fieldValue['label'] = source.displayValue;
    }
    return fieldValue;
}
// Helper function to deal with all 'regular' Record fields
function selectScalarFieldValueRepresentation(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    const fieldValueConfig = {
        hasFormat: false,
        hasLabel: false,
    };
    switch (typename) {
        // All fields which extend FieldValue, and no other special fields (format etc)
        case 'BooleanValue':
            fieldValueConfig.selectFunction = select$1p;
            break;
        case 'LongitudeValue':
            fieldValueConfig.selectFunction = select$1e;
            break;
        case 'UrlValue':
            fieldValueConfig.selectFunction = select$1h;
            break;
        case 'RichTextAreaValue':
            fieldValueConfig.selectFunction = select$1k;
            break;
        case 'LongTextAreaValue':
            fieldValueConfig.selectFunction = select$1l;
            break;
        case 'LatitudeValue':
            fieldValueConfig.selectFunction = select$1d;
            break;
        case 'PhoneNumberValue':
            fieldValueConfig.selectFunction = select$1j;
            break;
        case 'TextAreaValue':
            fieldValueConfig.selectFunction = select$1m;
            break;
        case 'IDValue':
            fieldValueConfig.selectFunction = select$1r;
            break;
        case 'JSONValue':
            fieldValueConfig.selectFunction = select$19;
            break;
        case 'EmailValue':
            fieldValueConfig.selectFunction = select$1i;
            break;
        case 'Base64Value':
            fieldValueConfig.selectFunction = select$1a;
            break;
        case 'EncryptedStringValue':
            fieldValueConfig.selectFunction = select$1g;
            break;
        // All field values which support 'label'
        case 'StringValue':
            fieldValueConfig.selectFunction = select$1t;
            fieldValueConfig.hasLabel = true;
            break;
        case 'PicklistValue':
            fieldValueConfig.selectFunction = select$1c;
            fieldValueConfig.hasLabel = true;
            break;
        case 'MultiPicklistValue':
            fieldValueConfig.selectFunction = select$1b;
            fieldValueConfig.hasLabel = true;
            break;
        // All field values that support "format" field.
        case 'IntValue':
            fieldValueConfig.selectFunction = select$1u;
            fieldValueConfig.hasFormat = true;
            break;
        case 'DateValue':
            fieldValueConfig.selectFunction = select$1n;
            fieldValueConfig.hasFormat = true;
            break;
        case 'DoubleValue':
            fieldValueConfig.selectFunction = select$1y;
            fieldValueConfig.hasFormat = true;
            break;
        case 'TimeValue':
            fieldValueConfig.selectFunction = select$1o;
            fieldValueConfig.hasFormat = true;
            break;
        case 'DateTimeValue':
            fieldValueConfig.selectFunction = select$1q;
            fieldValueConfig.hasFormat = true;
            break;
        case 'LongValue':
            fieldValueConfig.selectFunction = select$1x;
            fieldValueConfig.hasFormat = true;
            break;
        case 'PercentValue':
            fieldValueConfig.selectFunction = select$1w;
            fieldValueConfig.hasFormat = true;
            break;
        case 'CurrencyValue':
            fieldValueConfig.selectFunction = select$1f;
            fieldValueConfig.hasFormat = true;
            break;
    }
    if (fieldValueConfig.selectFunction !== undefined) {
        selectFieldValue(reader, fieldData, sel, variables, fragments, sink, key, fieldValueConfig.selectFunction, typename, fieldValueConfig.hasFormat, fieldValueConfig.hasLabel, parentRecordId);
    }
}

function selectType$X(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'Boolean':
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        default:
            // If you didn't match any of the above, you're a FieldValueRepresentation (scalar Record field)
            selectScalarFieldValueRepresentation(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId);
    }
    return sink;
}

const name$W = 'CompoundField';
const VERSION$15 = 'e90ed8ffd8c8bf518fa166be5c214253';
function keyBuilder$_(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$W(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$_(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$_(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$X,
        isMappedFieldImport: isMappedField$W,
        getFieldType: getFieldType$1b,
        ingestFieldByType: ingestFieldByType$W,
        createLink: createLink,
        mergeData: mergeData$W,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "CompoundField",
            version: VERSION$15,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$W(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$1b(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function buildSelectionForField$X(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$W, getFieldType$1b, selectType$X, parentRecordId);
}
function buildSelectionForNode$X(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$X, buildSelectionForField$X, parentRecordId);
}
function select$17(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$X, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$1c() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$_(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$_(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$W
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$X) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$1b(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'IntValue': {
                const IntValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, IntValueState);
                break;
            }
            case 'StringValue': {
                const StringValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, StringValueState);
                break;
            }
            case 'BooleanValue': {
                const BooleanValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1j(cacheKeySink, requestedField, BooleanValueState);
                break;
            }
            case 'IDValue': {
                const IDValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, IDValueState);
                break;
            }
            case 'DateTimeValue': {
                const DateTimeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, DateTimeValueState);
                break;
            }
            case 'TimeValue': {
                const TimeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1i(cacheKeySink, requestedField, TimeValueState);
                break;
            }
            case 'DateValue': {
                const DateValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1h(cacheKeySink, requestedField, DateValueState);
                break;
            }
            case 'TextAreaValue': {
                const TextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1g(cacheKeySink, requestedField, TextAreaValueState);
                break;
            }
            case 'LongTextAreaValue': {
                const LongTextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1f(cacheKeySink, requestedField, LongTextAreaValueState);
                break;
            }
            case 'RichTextAreaValue': {
                const RichTextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1e(cacheKeySink, requestedField, RichTextAreaValueState);
                break;
            }
            case 'PhoneNumberValue': {
                const PhoneNumberValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1d(cacheKeySink, requestedField, PhoneNumberValueState);
                break;
            }
            case 'EmailValue': {
                const EmailValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1c(cacheKeySink, requestedField, EmailValueState);
                break;
            }
            case 'UrlValue': {
                const UrlValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1b(cacheKeySink, requestedField, UrlValueState);
                break;
            }
            case 'EncryptedStringValue': {
                const EncryptedStringValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1a(cacheKeySink, requestedField, EncryptedStringValueState);
                break;
            }
            case 'CurrencyValue': {
                const CurrencyValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$19(cacheKeySink, requestedField, CurrencyValueState);
                break;
            }
            case 'LongitudeValue': {
                const LongitudeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$18(cacheKeySink, requestedField, LongitudeValueState);
                break;
            }
            case 'LatitudeValue': {
                const LatitudeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$17(cacheKeySink, requestedField, LatitudeValueState);
                break;
            }
            case 'PicklistValue': {
                const PicklistValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$16(cacheKeySink, requestedField, PicklistValueState);
                break;
            }
            case 'MultiPicklistValue': {
                const MultiPicklistValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$15(cacheKeySink, requestedField, MultiPicklistValueState);
                break;
            }
            case 'LongValue': {
                const LongValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, LongValueState);
                break;
            }
            case 'DoubleValue': {
                const DoubleValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, DoubleValueState);
                break;
            }
            case 'PercentValue': {
                const PercentValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1q(cacheKeySink, requestedField, PercentValueState);
                break;
            }
            case 'Base64Value': {
                const Base64ValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$14(cacheKeySink, requestedField, Base64ValueState);
                break;
            }
            case 'JSONValue': {
                const JSONValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$13(cacheKeySink, requestedField, JSONValueState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function ingestFieldByType$W(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'StringValue': {
            const StringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1k(requestedField, StringValueState);
            break;
        }
        case 'BooleanValue': {
            const BooleanValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1g(requestedField, BooleanValueState);
            break;
        }
        case 'IDValue': {
            const IDValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1i(requestedField, IDValueState);
            break;
        }
        case 'DateTimeValue': {
            const DateTimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1h(requestedField, DateTimeValueState);
            break;
        }
        case 'TimeValue': {
            const TimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1f(requestedField, TimeValueState);
            break;
        }
        case 'DateValue': {
            const DateValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1e(requestedField, DateValueState);
            break;
        }
        case 'TextAreaValue': {
            const TextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1d(requestedField, TextAreaValueState);
            break;
        }
        case 'LongTextAreaValue': {
            const LongTextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1c(requestedField, LongTextAreaValueState);
            break;
        }
        case 'RichTextAreaValue': {
            const RichTextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1b(requestedField, RichTextAreaValueState);
            break;
        }
        case 'PhoneNumberValue': {
            const PhoneNumberValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1a(requestedField, PhoneNumberValueState);
            break;
        }
        case 'EmailValue': {
            const EmailValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$19(requestedField, EmailValueState);
            break;
        }
        case 'UrlValue': {
            const UrlValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$18(requestedField, UrlValueState);
            break;
        }
        case 'EncryptedStringValue': {
            const EncryptedStringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$17(requestedField, EncryptedStringValueState);
            break;
        }
        case 'CurrencyValue': {
            const CurrencyValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$16(requestedField, CurrencyValueState);
            break;
        }
        case 'LongitudeValue': {
            const LongitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$15(requestedField, LongitudeValueState);
            break;
        }
        case 'LatitudeValue': {
            const LatitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$14(requestedField, LatitudeValueState);
            break;
        }
        case 'PicklistValue': {
            const PicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$13(requestedField, PicklistValueState);
            break;
        }
        case 'MultiPicklistValue': {
            const MultiPicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$12(requestedField, MultiPicklistValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'PercentValue': {
            const PercentValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1n(requestedField, PercentValueState);
            break;
        }
        case 'Base64Value': {
            const Base64ValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$11(requestedField, Base64ValueState);
            break;
        }
        case 'JSONValue': {
            const JSONValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$10(requestedField, JSONValueState);
            break;
        }
    }
}
function isMappedField$W(field) {
    return false;
}
function isFragmentApplicable$X(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "CompoundField", typename);
}
function getInContextFragmentType$1b(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getFieldType$1a(field) {
    const fieldNameOverride = getFieldNameOverride(field);
    const fieldName = fieldNameOverride || field.name.value;
    switch (fieldName) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'String': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'Long': {
            return {
                isArray: false,
                typename: 'Long',
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID',
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'WeakEtag': {
            return {
                isArray: false,
                typename: 'Long',
            };
        }
        case 'DisplayValue': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'LastModifiedById': {
            return {
                isArray: false,
                typename: 'IDValue',
            };
        }
        case 'LastModifiedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue',
            };
        }
        case 'SystemModstamp': {
            return {
                isArray: false,
                typename: 'DateTimeValue',
            };
        }
        case 'RecordTypeId': {
            return {
                isArray: false,
                typename: 'IDValue',
            };
        }
        case 'IntValue': {
            return {
                isArray: false,
                typename: 'IntValue',
            };
        }
        case 'StringValue': {
            return {
                isArray: false,
                typename: 'StringValue',
            };
        }
        case 'BooleanValue': {
            return {
                isArray: false,
                typename: 'BooleanValue',
            };
        }
        case 'IDValue': {
            return {
                isArray: false,
                typename: 'IDValue',
            };
        }
        case 'DateTimeValue': {
            return {
                isArray: false,
                typename: 'DateTimeValue',
            };
        }
        case 'TimeValue': {
            return {
                isArray: false,
                typename: 'TimeValue',
            };
        }
        case 'DateValue': {
            return {
                isArray: false,
                typename: 'DateValue',
            };
        }
        case 'TextAreaValue': {
            return {
                isArray: false,
                typename: 'TextAreaValue',
            };
        }
        case 'LongTextAreaValue': {
            return {
                isArray: false,
                typename: 'LongTextAreaValue',
            };
        }
        case 'RichTextAreaValue': {
            return {
                isArray: false,
                typename: 'RichTextAreaValue',
            };
        }
        case 'PhoneNumberValue': {
            return {
                isArray: false,
                typename: 'PhoneNumberValue',
            };
        }
        case 'EmailValue': {
            return {
                isArray: false,
                typename: 'EmailValue',
            };
        }
        case 'UrlValue': {
            return {
                isArray: false,
                typename: 'UrlValue',
            };
        }
        case 'EncryptedStringValue': {
            return {
                isArray: false,
                typename: 'EncryptedStringValue',
            };
        }
        case 'CurrencyValue': {
            return {
                isArray: false,
                typename: 'CurrencyValue',
            };
        }
        case 'LongitudeValue': {
            return {
                isArray: false,
                typename: 'LongitudeValue',
            };
        }
        case 'LatitudeValue': {
            return {
                isArray: false,
                typename: 'LatitudeValue',
            };
        }
        case 'PicklistValue': {
            return {
                isArray: false,
                typename: 'PicklistValue',
            };
        }
        case 'MultiPicklistValue': {
            return {
                isArray: false,
                typename: 'MultiPicklistValue',
            };
        }
        case 'LongValue': {
            return {
                isArray: false,
                typename: 'LongValue',
            };
        }
        case 'DoubleValue': {
            return {
                isArray: false,
                typename: 'DoubleValue',
            };
        }
        case 'PercentValue': {
            return {
                isArray: false,
                typename: 'PercentValue',
            };
        }
        case 'Base64Value': {
            return {
                isArray: false,
                typename: 'Base64Value',
            };
        }
        case 'JSONValue': {
            return {
                isArray: false,
                typename: 'JSONValue',
            };
        }
        case 'polymorphicParentRelationship':
        case 'parentRelationship': {
            return {
                isArray: false,
                typename: 'RecordRepresentation',
            };
        }
        case 'childRelationship': {
            return {
                isArray: false,
                typename: 'RecordConnection',
            };
        }
        case 'CompoundField': {
            return {
                isArray: false,
                typename: 'CompoundField',
            };
        }
        // We don't know what type "value" is, so return a JSONValue type that uses an unknown for the value field.
        default:
            return {
                isArray: false,
                typename: 'JSONValue',
            };
    }
}

function isMappedField$V(field) {
    if (field.name.value === '__typename' || field.name.value === 'DisplayValue') {
        return false;
    }
    const fieldType = getFieldType$1a(field);
    // Map everything that isn't typename, DisplayValue or connection/childRelationship field.
    return fieldType !== undefined && fieldType.typename !== 'RecordConnection';
}

const SPECIAL_NORMALIZED_RECORD_FIELDS = ['ApiName', 'RecordTypeId', 'WeakEtag', 'DisplayValue'];
function convertGraphQLToRaml(astNode, state) {
    const { data } = state;
    const requestedFields = astNode.selectionSet
        ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$V)
        : new Map();
    const { fieldsBag, trie } = createFieldsBagAndTrie(data, requestedFields, state);
    const recordRepresentation = {
        apiName: data.ApiName,
        eTag: '',
        lastModifiedById: data.LastModifiedById.value,
        lastModifiedDate: data.LastModifiedDate.value,
        systemModstamp: data.SystemModstamp.value,
        recordTypeId: data.ldsRecordTypeId === null ? null : data.ldsRecordTypeId.value,
        recordTypeInfo: null,
        childRelationships: {},
        id: data.Id,
        weakEtag: data.WeakEtag,
        fields: fieldsBag,
    };
    return {
        recordRepresentation,
        fieldsTrie: trie,
    };
}
function createFieldsBagAndTrie(data, requestedFields, parentState) {
    const fieldsBag = ObjectCreate(null);
    const trieChildren = ObjectCreate(null);
    const trie = {
        name: data.ApiName,
        children: trieChildren,
    };
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // We got a field back we didn't ask for. Skip.
        }
        const fieldType = getFieldType$1a(requestedField);
        const fieldName = requestedField.name.value;
        // Skip any standard fields on RecordRep not in the fieldsBag, introspection fields, or unknown typed fields
        if (shouldSkipFieldNormalization(fieldName)) {
            continue;
        }
        // Id is special and _can_ be requested as a field in REST
        if (fieldName === 'Id') {
            fieldsBag[fieldName] = {
                value: fieldData !== undefined ? fieldData : null,
                displayValue: null,
            };
            trieChildren[fieldName] = {
                name: fieldName,
                children: {},
            };
            continue;
        }
        switch (fieldType.typename) {
            case 'RecordConnection':
                continue; // Let the 'normal' graphql handling get us into the Records in childRelationships.
            case 'PolymorphicParentRelationship':
            case 'RecordRepresentation': {
                // Spanning record field
                const state = {
                    ...parentState,
                    data: fieldData,
                };
                const { value, trie } = formatSpanningField(requestedField, state);
                trieChildren[fieldName] = trie;
                fieldsBag[fieldName] = value;
                break;
            }
            case 'CompoundField':
                // The REST endpoint has no concept of compound fields in a RecordRep, so best we can
                // do is just setting all the subfields as fields in the trie.
                Object.keys(fieldData).forEach((subfieldKey) => {
                    if (!shouldSkipFieldNormalization(subfieldKey)) {
                        setFieldsOnTrie(subfieldKey, fieldData[subfieldKey], fieldsBag, trieChildren);
                    }
                });
                break; // We don't set the top level compound field in the fieldTrie - There's no way to synthesize a Compound Field in REST responses w/o a lookaside table
            default:
                // Not a spanning field or a childRelationship - Do the standard field mapping.
                // There are edgecases where we don't inject all fields properly, which leads to an ingestion error
                // for FieldValueRepresentation. Default to null here to stop from throwing.
                setFieldsOnTrie(fieldName, fieldData, fieldsBag, trieChildren);
        }
    }
    return { fieldsBag, trie };
}
function setFieldsOnTrie(fieldName, fieldData, fieldsBag, trieChildren) {
    fieldsBag[fieldName] = {
        value: fieldData.value !== undefined ? fieldData.value : null,
        displayValue: getFieldDisplayValue(fieldData),
    };
    trieChildren[fieldName] = {
        name: fieldName,
        children: {},
    };
}
function shouldSkipFieldNormalization(fieldName) {
    return fieldName === '__typename' || SPECIAL_NORMALIZED_RECORD_FIELDS.includes(fieldName);
}
// GraphQL exposes field-specific properties of label/format depending on types. These values are
// always equal to the "normalized" displayValue field.
function getFieldDisplayValue(fieldData) {
    const displayValue = fieldData.label || fieldData.format || fieldData.displayValue;
    return displayValue !== undefined ? displayValue : null;
}
function formatSpanningField(field, state) {
    if (state.data === null) {
        return {
            value: {
                displayValue: null,
                value: null,
            },
            trie: convertAstToTrie(field, state.fragments),
        };
    }
    const { recordRepresentation, fieldsTrie } = convertGraphQLToRaml(field, state);
    return {
        trie: fieldsTrie,
        value: {
            displayValue: state.data.DisplayValue,
            value: recordRepresentation,
        },
    };
}
function convertAstToTrie(astNode, fragments) {
    const children = {};
    const trie = {
        name: astNode.name.value,
        children,
    };
    const requestedFields = astNode.selectionSet
        ? getRequestedFieldsForType('', // data is null here
        astNode.selectionSet, fragments, isFragmentApplicable$V)
        : new Map();
    for (const [, field] of requestedFields) {
        const fieldType = getFieldType$1a(field);
        const fieldName = field.name.value;
        //Untyped field - Adapter forwarded request?
        if (fieldType === undefined) {
            children[fieldName] = {
                name: fieldName,
                children: {},
            };
            continue;
        }
        if (shouldSkipFieldNormalization(field.name.value)) {
            continue;
        }
        switch (fieldType.typename) {
            case 'RecordConnection':
                continue; // Let the 'normal' graphql handling get us into the Records in childRelationships.
            case 'PolymorphicParentRelationship':
            case 'RecordRepresentation':
                // Spanning record field
                children[fieldName] = convertAstToTrie(field, fragments);
                break;
            default:
                // Does a Compound field need something special here?
                children[fieldName] = {
                    name: fieldName,
                    children: {},
                };
        }
    }
    return trie;
}

function ingestMappedData(astNode, state) {
    const ramlSink = convertGraphQLToRaml(astNode, state);
    // partially ingest with RAML
    const { recordRepresentation, fieldsTrie } = ramlSink;
    const ingestRecord = createIngestRecordWithFields(fieldsTrie, {
        name: recordRepresentation.apiName,
        children: {},
    });
    return ingestRecord(recordRepresentation, state.path, state.luvio, state.store, state.timestamp);
}

// Most of these could be generated off of GraphQL interface 'FieldValue'. Then just add RecordRepresentation and PolymorphicParentRelationship
const FieldValueTypes = [
    'IntValue',
    'StringValue',
    'BooleanValue',
    'IDValue',
    'DateTimeValue',
    'TimeValue',
    'DateValue',
    'TextAreaValue',
    'LongTextAreaValue',
    'RichTextAreaValue',
    'PhoneNumberValue',
    'EmailValue',
    'UrlValue',
    'EncryptedStringValue',
    'CurrencyValue',
    'LongitudeValue',
    'LatitudeValue',
    'PicklistValue',
    'MultiPicklistValue',
    'LongValue',
    'DoubleValue',
    'PercentValue',
    'Base64Value',
    'JSONValue',
    'RecordRepresentation',
    'PolymorphicParentRelationship',
];
/*
    This function is responsible for the inverse mapping of RecordRepresentation data into
    GraphQL shaped data.
*/
function getFieldData$V(source, sel, variables) {
    switch (sel.name.value) {
        // Scalar GraphQL fields (don't need to format, just return primitive values)
        case 'Id': {
            return source.__linkedData ? source.__linkedData['id'] : undefined;
        }
        case 'ApiName': {
            return source.__linkedData ? source.__linkedData['apiName'] : undefined;
        }
        case 'WeakEtag': {
            return source.__linkedData ? source.__linkedData['weakEtag'] : undefined;
        }
        // RecordTypeId is not requestable as field data in REST
        case 'RecordTypeId': {
            const topLevelKey = 'recordTypeId';
            const graphQLValue = source.__linkedData
                ? {
                    __typename: 'IDValue',
                    displayValue: null,
                    value: source.__linkedData[topLevelKey],
                }
                : undefined;
            return graphQLValue;
        }
        default: {
            const fieldType = getFieldType$1a(sel);
            if (fieldType !== undefined && FieldValueTypes.includes(fieldType.typename)) {
                // This is a FieldValue we need to unwind from the RecordRep
                return source.__linkedData ? source.__linkedData.fields[sel.name.value] : undefined;
            }
            if (fieldType !== undefined && fieldType.typename === 'CompoundField') {
                // Return the full fields array and let the sub selections sort out which ones we want
                return source.__linkedData ? source.__linkedData.fields : undefined;
            }
            // Everything else must be a 'regular' gql field (DisplayValue)
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}

function selectType$W(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'Long':
        case 'ID':
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'PolymorphicParentRelationship':
        case 'RecordRepresentation': {
            const spanningFieldLink = resolveLink(reader, fieldData, VERSION$16);
            const resolvedSpanningFieldValue = spanningFieldLink && spanningFieldLink.data;
            const fieldDataRef = fieldData.__ref;
            if (resolvedSpanningFieldValue !== undefined) {
                reader.markSeenId(fieldDataRef);
                const { value: spanningFieldResult } = resolvedSpanningFieldValue;
                // Handle null values - graphql will return it at the field level, not return nested { value: null }
                if (spanningFieldResult === null || typeof spanningFieldResult !== 'object') {
                    reader.assignScalar(key, sink, null);
                    break;
                }
                // Synthesize what a NormalizedGraphQL Record looks like, then recurse to our select function to get the value.
                const syntheticNormalizedGraphQLRecord = {
                    data: {
                        DisplayValue: resolvedSpanningFieldValue.displayValue,
                    },
                    __link: spanningFieldResult,
                };
                const result = select$15(sel, variables, fragments)(syntheticNormalizedGraphQLRecord, reader, parentRecordId);
                if (result) {
                    reader.assignNonScalar(sink, key, result);
                }
                else {
                    reader.markMissingLink(fieldData.__ref);
                    reader.markMissing();
                }
            }
            else {
                if (fieldDataRef !== undefined) {
                    reader.markMissingLink(fieldDataRef);
                }
                reader.markMissing();
            }
            break;
        }
        case 'RecordConnection':
            selectType$U(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId); // No need to copy paste this case (lots of pagination code).
            break;
        case 'CompoundField': {
            const syntheticResult = select$17(sel, variables, fragments)({
                data: fieldData,
            }, reader, parentRecordId);
            reader.assignNonScalar(sink, key, syntheticResult);
            break;
        }
        default:
            selectScalarFieldValueRepresentation(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId);
    }
    return sink;
}

const API_NAMESPACE = 'UiApi';
const RECORD_REPRESENTATION_NAME = 'RecordRepresentation';
const RECORD_VIEW_ENTITY_REPRESENTATION_NAME = 'RecordViewEntityRepresentation';
const RECORD_ID_PREFIX = `${API_NAMESPACE}::${RECORD_REPRESENTATION_NAME}:`;
const RECORD_VIEW_ENTITY_ID_PREFIX = `${API_NAMESPACE}::${RECORD_VIEW_ENTITY_REPRESENTATION_NAME}:Name:`;
const RECORD_FIELDS_KEY_JUNCTION = '__fields__';
function extractRecordIdFromStoreKey(key) {
    if (key === undefined ||
        (key.indexOf(RECORD_ID_PREFIX) === -1 && key.indexOf(RECORD_VIEW_ENTITY_ID_PREFIX) === -1)) {
        return undefined;
    }
    const parts = key.split(':');
    return parts[parts.length - 1].split('_')[0];
}
function isStoreKeyRecordViewEntity(key) {
    return (key.indexOf(RECORD_VIEW_ENTITY_ID_PREFIX) > -1 &&
        key.indexOf(RECORD_FIELDS_KEY_JUNCTION) === -1);
}
function buildRecordRepKeyFromId(recordId) {
    return `${API_NAMESPACE}::${RECORD_REPRESENTATION_NAME}:${recordId}`;
}

function attachMappedData(source, reader) {
    let linkedRecordId = source.__link && source.__link.__ref;
    if (linkedRecordId !== undefined) {
        // Discovered with: W-13612372
        // We get wrong apiName for polymorphic parents when using getRecord
        // this breaks store links as it essentially creates wrong keys
        // also worth noting that polymorphic parents from REST are stored in RecordViewEntityRepresentation
        // while polymorphic parents from graphql are just another RecordRepresentation
        // Here, if we see a RecordViewEntityRepresentation key then we point it to
        // corresponding RecordRepresentation key that graphql adapter can understand
        // this essentially also means that polymorphic parent Records can be inconsistent
        // across graphql and getRecord snapshots and subsequent requests from getRecord
        // to fetch the referenced parent record directly
        // This behavior is at parity with getRecord wire adapter
        if (isStoreKeyRecordViewEntity(linkedRecordId)) {
            const recordId = extractRecordIdFromStoreKey(linkedRecordId);
            if (recordId) {
                linkedRecordId = buildRecordRepKeyFromId(recordId);
            }
        }
        reader.markSeenId(linkedRecordId);
        const linkedData = reader.read({
            recordId: linkedRecordId,
            node: {
                kind: 'Fragment',
                private: [],
                opaque: true,
                version: VERSION$17,
            },
            variables: {},
        });
        if (linkedData.data !== undefined) {
            /// The Metaschema doesn't let us actually know that Account is a RecordRepresentation statically. This override will let us set __typename
            // so that we can properly use fragments that are on Account
            return {
                ...source,
                data: {
                    ...source.data,
                    __typename: linkedData.data.apiName,
                },
                __linkedData: linkedData.data,
            };
        }
        else {
            reader.markMissingLink(linkedRecordId);
        }
    }
    return source;
}

const name$V = 'PageInfo';
const VERSION$14 = '20ddc8913f009fcc648e94136b42e794';
function keyBuilder$Z(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$V(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$Z(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$Z(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$W,
        isMappedFieldImport: isMappedField$U,
        getFieldType: getFieldType$19,
        ingestFieldByType: ingestFieldByType$V,
        createLink: createLink,
        mergeData: mergeData$V,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PageInfo",
            version: VERSION$14,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$U(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$19(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$V(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$W(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$U, getFieldType$19, selectType$V, parentRecordId);
}
function buildSelectionForNode$W(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$W, buildSelectionForField$W, parentRecordId);
}
function select$16(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$W, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$1b() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$Z(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$Z(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$V
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$19(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'hasNextPage': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'hasPreviousPage': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'startCursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'endCursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$V(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$U(field) {
    return false;
}
function isFragmentApplicable$W(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "PageInfo", typename);
}
function getInContextFragmentType$1a(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getTypeCacheKeys$Y(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$W(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$S,
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet
        ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$T)
        : new Map();
    for (const fieldDataKey of ObjectKeys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$17(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordEdge': {
                const fullPath__edges = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: `${fullPath__edges}__${i}`,
                        },
                        data: item,
                    };
                    getTypeCacheKeys$W(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'PageInfo': {
                // I guess just return the pagination key here since pagination replaced it.
                cacheKeySink.set(`${rootKey}__pagination`, {
                    namespace: keyPrefix,
                    mergeable: true,
                    representationName: name$V,
                });
                break;
            }
        }
    }
}

function getMappedTypeCacheKeys(cache, astNode, state) {
    const convertedData = convertGraphQLToRaml(astNode, state);
    getTypeCacheKeys$11(cache, state.luvio, convertedData.recordRepresentation);
}

const name$U = 'RecordRepresentation';
const VERSION$13 = 'b09728109b666bc69fe789bade015193';
function keyBuilder$Y(luvio, path, data) {
    return keyPrefix + '::uiapi::' + name$U + '::' + data.Id; // We're missing idNodeName in the actual key here...
}
function mergeData$U(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
        __link: ObjectAssign({}, existingData["__link"] || {}, newData["__link"] || {}),
    };
}
function ingest$Y(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$Y(luvio, path, data);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$V,
        isMappedFieldImport: isMappedField$V,
        getFieldType: getFieldType$1a,
        ingestFieldByType: ingestFieldByType$U,
        ramlIngestBlock(newData) {
            newData["__link"] = ingestMappedData(astNode, state);
        },
        createLink: createLink,
        mergeData: mergeData$U,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordRepresentation",
            version: VERSION$13,
            ingestionTimestamp: timestamp,
        },
    });
}
function selectType$U(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Long': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'IDValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1r, select$1r, false);
            break;
        }
        case 'DateTimeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1q, select$1q, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'StringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1t, select$1t, false);
            break;
        }
        case 'BooleanValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1p, select$1p, false);
            break;
        }
        case 'TimeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1o, select$1o, false);
            break;
        }
        case 'DateValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1n, select$1n, false);
            break;
        }
        case 'TextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1m, select$1m, false);
            break;
        }
        case 'LongTextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1l, select$1l, false);
            break;
        }
        case 'RichTextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1k, select$1k, false);
            break;
        }
        case 'PhoneNumberValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1j, select$1j, false);
            break;
        }
        case 'EmailValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1i, select$1i, false);
            break;
        }
        case 'UrlValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1h, select$1h, false);
            break;
        }
        case 'EncryptedStringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1g, select$1g, false);
            break;
        }
        case 'CurrencyValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1f, select$1f, false);
            break;
        }
        case 'LongitudeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1e, select$1e, false);
            break;
        }
        case 'LatitudeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1d, select$1d, false);
            break;
        }
        case 'PicklistValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1c, select$1c, false);
            break;
        }
        case 'MultiPicklistValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1b, select$1b, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'PercentValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1w, select$1w, false);
            break;
        }
        case 'Base64Value': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1a, select$1a, false);
            break;
        }
        case 'JSONValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$19, select$19, false);
            break;
        }
        case 'RecordRepresentation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$13, select$15, false);
            break;
        }
        case 'PolymorphicParentRelationship': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$18, select$18, false);
            break;
        }
        case 'RecordConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$11, select$13, true);
            break;
        }
        case 'CompoundField': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$15, select$17, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$V(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$V, getFieldType$1a, selectType$W, parentRecordId);
}
function buildSelectionForNode$V(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$V, buildSelectionForField$V, parentRecordId);
}
function select$15(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        source = attachMappedData(source, reader);
        reader.markSeenId(parentRecordId); // Always mark identifiable types as seen
        return selectCalculateSink(sink, field, buildSelectionForNode$V, source, reader, variables, fragments, parentRecordId);
    };
}
function getTypeCacheKeys$X(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$Y(luvio, path, data);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$U
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$V) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$1a(requestedField);
        if (isMappedField$V(requestedField) || fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'IDValue': {
                const LastModifiedByIdState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, LastModifiedByIdState);
                break;
            }
            case 'DateTimeValue': {
                const LastModifiedDateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, LastModifiedDateState);
                break;
            }
            case 'DateTimeValue': {
                const SystemModstampState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, SystemModstampState);
                break;
            }
            case 'IDValue': {
                const RecordTypeIdState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, RecordTypeIdState);
                break;
            }
            case 'IntValue': {
                const IntValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, IntValueState);
                break;
            }
            case 'StringValue': {
                const StringValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, StringValueState);
                break;
            }
            case 'BooleanValue': {
                const BooleanValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1j(cacheKeySink, requestedField, BooleanValueState);
                break;
            }
            case 'IDValue': {
                const IDValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, IDValueState);
                break;
            }
            case 'DateTimeValue': {
                const DateTimeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, DateTimeValueState);
                break;
            }
            case 'TimeValue': {
                const TimeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1i(cacheKeySink, requestedField, TimeValueState);
                break;
            }
            case 'DateValue': {
                const DateValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1h(cacheKeySink, requestedField, DateValueState);
                break;
            }
            case 'TextAreaValue': {
                const TextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1g(cacheKeySink, requestedField, TextAreaValueState);
                break;
            }
            case 'LongTextAreaValue': {
                const LongTextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1f(cacheKeySink, requestedField, LongTextAreaValueState);
                break;
            }
            case 'RichTextAreaValue': {
                const RichTextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1e(cacheKeySink, requestedField, RichTextAreaValueState);
                break;
            }
            case 'PhoneNumberValue': {
                const PhoneNumberValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1d(cacheKeySink, requestedField, PhoneNumberValueState);
                break;
            }
            case 'EmailValue': {
                const EmailValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1c(cacheKeySink, requestedField, EmailValueState);
                break;
            }
            case 'UrlValue': {
                const UrlValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1b(cacheKeySink, requestedField, UrlValueState);
                break;
            }
            case 'EncryptedStringValue': {
                const EncryptedStringValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1a(cacheKeySink, requestedField, EncryptedStringValueState);
                break;
            }
            case 'CurrencyValue': {
                const CurrencyValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$19(cacheKeySink, requestedField, CurrencyValueState);
                break;
            }
            case 'LongitudeValue': {
                const LongitudeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$18(cacheKeySink, requestedField, LongitudeValueState);
                break;
            }
            case 'LatitudeValue': {
                const LatitudeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$17(cacheKeySink, requestedField, LatitudeValueState);
                break;
            }
            case 'PicklistValue': {
                const PicklistValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$16(cacheKeySink, requestedField, PicklistValueState);
                break;
            }
            case 'MultiPicklistValue': {
                const MultiPicklistValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$15(cacheKeySink, requestedField, MultiPicklistValueState);
                break;
            }
            case 'LongValue': {
                const LongValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, LongValueState);
                break;
            }
            case 'DoubleValue': {
                const DoubleValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, DoubleValueState);
                break;
            }
            case 'PercentValue': {
                const PercentValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1q(cacheKeySink, requestedField, PercentValueState);
                break;
            }
            case 'Base64Value': {
                const Base64ValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$14(cacheKeySink, requestedField, Base64ValueState);
                break;
            }
            case 'JSONValue': {
                const JSONValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$13(cacheKeySink, requestedField, JSONValueState);
                break;
            }
            case 'RecordRepresentation': {
                const parentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$X(cacheKeySink, requestedField, parentRelationshipState);
                break;
            }
            case 'PolymorphicParentRelationship': {
                const polymorphicParentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$12(cacheKeySink, requestedField, polymorphicParentRelationshipState);
                break;
            }
            case 'RecordConnection': {
                const childRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Y(cacheKeySink, requestedField, childRelationshipState);
                break;
            }
            case 'CompoundField': {
                const CompoundFieldState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$_(cacheKeySink, requestedField, CompoundFieldState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
    getMappedTypeCacheKeys(cacheKeySink, astNode, state);
}
function ingestFieldByType$U(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Long': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'IDValue': {
            const IDValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1i(requestedField, IDValueState);
            break;
        }
        case 'DateTimeValue': {
            const DateTimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1h(requestedField, DateTimeValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'StringValue': {
            const StringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1k(requestedField, StringValueState);
            break;
        }
        case 'BooleanValue': {
            const BooleanValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1g(requestedField, BooleanValueState);
            break;
        }
        case 'TimeValue': {
            const TimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1f(requestedField, TimeValueState);
            break;
        }
        case 'DateValue': {
            const DateValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1e(requestedField, DateValueState);
            break;
        }
        case 'TextAreaValue': {
            const TextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1d(requestedField, TextAreaValueState);
            break;
        }
        case 'LongTextAreaValue': {
            const LongTextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1c(requestedField, LongTextAreaValueState);
            break;
        }
        case 'RichTextAreaValue': {
            const RichTextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1b(requestedField, RichTextAreaValueState);
            break;
        }
        case 'PhoneNumberValue': {
            const PhoneNumberValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1a(requestedField, PhoneNumberValueState);
            break;
        }
        case 'EmailValue': {
            const EmailValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$19(requestedField, EmailValueState);
            break;
        }
        case 'UrlValue': {
            const UrlValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$18(requestedField, UrlValueState);
            break;
        }
        case 'EncryptedStringValue': {
            const EncryptedStringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$17(requestedField, EncryptedStringValueState);
            break;
        }
        case 'CurrencyValue': {
            const CurrencyValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$16(requestedField, CurrencyValueState);
            break;
        }
        case 'LongitudeValue': {
            const LongitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$15(requestedField, LongitudeValueState);
            break;
        }
        case 'LatitudeValue': {
            const LatitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$14(requestedField, LatitudeValueState);
            break;
        }
        case 'PicklistValue': {
            const PicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$13(requestedField, PicklistValueState);
            break;
        }
        case 'MultiPicklistValue': {
            const MultiPicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$12(requestedField, MultiPicklistValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'PercentValue': {
            const PercentValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1n(requestedField, PercentValueState);
            break;
        }
        case 'Base64Value': {
            const Base64ValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$11(requestedField, Base64ValueState);
            break;
        }
        case 'JSONValue': {
            const JSONValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$10(requestedField, JSONValueState);
            break;
        }
        case 'RecordRepresentation': {
            const RecordRepresentationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$Y(requestedField, RecordRepresentationState);
            break;
        }
        case 'PolymorphicParentRelationship': {
            const PolymorphicParentRelationshipState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$$(requestedField, PolymorphicParentRelationshipState);
            break;
        }
        case 'RecordConnection': {
            const RecordConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$W(requestedField, RecordConnectionState);
            break;
        }
        case 'CompoundField': {
            const CompoundFieldState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$_(requestedField, CompoundFieldState);
            break;
        }
    }
}
function isFragmentApplicable$V(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["Record"], "RecordRepresentation", typename);
}

const name$T = 'RecordEdge';
const VERSION$12 = 'cdc691302ae1cc80680781cd1ae1f830';
function keyBuilder$X(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$T(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$X(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$X(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$U,
        isMappedFieldImport: isMappedField$T,
        getFieldType: getFieldType$18,
        ingestFieldByType: ingestFieldByType$T,
        createLink: createLink,
        mergeData: mergeData$T,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordEdge",
            version: VERSION$12,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$T(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$18(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$T(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordRepresentation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$13, select$15, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$U(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$T, getFieldType$18, selectType$T, parentRecordId);
}
function buildSelectionForNode$U(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$U, buildSelectionForField$U, parentRecordId);
}
function select$14(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$U, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$1a() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$W(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$X(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$T
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$U) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$18(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordRepresentation': {
                const nodeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$X(cacheKeySink, requestedField, nodeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$18(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'RecordRepresentation'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$T(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordRepresentation': {
            const RecordRepresentationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$Y(requestedField, RecordRepresentationState);
            break;
        }
    }
}
function isMappedField$T(field) {
    return false;
}
function isFragmentApplicable$U(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordEdge", typename);
}
function getInContextFragmentType$19(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$S = 'RecordConnection';
const TTL$5 = 300000;
const VERSION$11 = '5109e37c62e492243c1e6ae3967b0655';
function keyBuilder$W(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$S(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingestPaginationMetadata$4(astNode, state, key, sink, existingData) {
    const { data, luvio, store } = state;
    const { pageInfo: { hasNextPage, startCursor }, edges } = data;
    if (!hasGraphQLPaginationFields(data))
        return;
    const paginationKey = key + '__pagination';
    let existingPaginationMetadata = store.readEntry(paginationKey);
    const afterArg = astNode.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', state.variables);
    const isPagedResponse = afterArgVal !== undefined &&
        existingPaginationMetadata !== undefined &&
        existingPaginationMetadata[afterArgVal] !== undefined;
    if (isPagedResponse && existingPaginationMetadata !== undefined) {
        const previousPageOffset = existingPaginationMetadata[afterArgVal];
        existingPaginationMetadata = {
            ...existingPaginationMetadata,
            [startCursor]: previousPageOffset + 1,
        };
    }
    // Default to a zero offset if we're not a result of a paged request
    const startOffset = isPagedResponse && existingPaginationMetadata !== undefined
        ? offsetFromToken(existingPaginationMetadata, startCursor)
        : 0;
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0) {
            throw new RangeError(`Cursor value ${startCursor} is not recognized. Cannot ingest the returned page. After: ${afterArgVal}`);
        }
    }
    const nextOffset = startOffset + edges.length;
    const incomingPaginationMetadata = createPaginationMetadata(startOffset, edges);
    if (hasNextPage) {
        // we know the data extends beyond NEXT_OFFSET_IDENTIFIER; clean up any old __END__ markers that say the data ended at/before that offset
        if (existingPaginationMetadata !== undefined && existingPaginationMetadata.__END__ !== undefined && existingPaginationMetadata.__END__ <= nextOffset) {
            existingPaginationMetadata = { ...existingPaginationMetadata };
            delete existingPaginationMetadata.__END__;
        }
    }
    else {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    // store the updated pagination metadata
    const mergedPaginationMetadata = mergeMetadata(existingPaginationMetadata, incomingPaginationMetadata);
    luvio.storePublish(paginationKey, mergedPaginationMetadata);
    luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata);
    // merge the edges
    assignMetadataLink(sink, paginationKey);
    const existingRecord = existingData ? existingData.data : undefined;
    if (existingRecord !== undefined && existingRecord.edges !== undefined) {
        sink.edges = [
            ...existingRecord.edges.slice(0, startOffset),
            ...sink.edges,
            ...existingRecord.edges.slice(nextOffset),
        ];
    }
}
function ingest$W(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$W(luvio, path);
    return ingestCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$T,
        isMappedFieldImport: isMappedField$S,
        getFieldType: getFieldType$17,
        ingestFieldByType: ingestFieldByType$S,
        hasGraphQLPaginationFields: hasGraphQLPaginationFields,
        ingestPaginatedMetadata: ingestPaginationMetadata$4,
        createLink: createLink,
        mergeData: mergeData$S,
        storeMetadataParams: {
            ttl: TTL$5,
            namespace: keyPrefix,
            representationName: "RecordConnection",
            version: VERSION$11,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$S(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$17(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$S(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordEdge': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$12, select$14, false);
            break;
        }
        case 'PageInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$14, select$16, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$T(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, true, getFieldData$S, getFieldType$17, selectType$S, parentRecordId);
}
function buildSelectionForNode$T(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$T, buildSelectionForField$T, parentRecordId);
}
function select$13(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$T, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$19() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        ...getCursorConnectionMinimumSelections()
    ];
    return minimumSelections;
}
function getFieldType$17(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'RecordEdge'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageResultCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$S(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordEdge': {
            const RecordEdgeState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$X(requestedField, RecordEdgeState);
            break;
        }
        case 'PageInfo': {
            const PageInfoState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$Z(requestedField, PageInfoState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$S(field) {
    return false;
}
function isFragmentApplicable$T(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordConnection", typename);
}
function getInContextFragmentType$18(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getFieldType$16(field) {
    const fieldNameOverride = getFieldNameOverride(field);
    const fieldName = fieldNameOverride || field.name.value;
    switch (fieldName) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'recordQuery': {
            return {
                isArray: false,
                typename: 'RecordConnection',
            };
        }
        default:
            return undefined;
    }
}

const name$R = 'RecordQuery';
const VERSION$10 = 'd70ec31adc7f4433b8c72751ce23f70e';
function keyBuilder$V(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$R(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$V(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$V(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$S,
        isMappedFieldImport: isMappedField$R,
        getFieldType: getFieldType$16,
        ingestFieldByType: ingestFieldByType$R,
        createLink: createLink,
        mergeData: mergeData$R,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordQuery",
            version: VERSION$10,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$R(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$16(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$R(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$11, select$13, true);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$S(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$R, getFieldType$16, selectType$R, parentRecordId);
}
function buildSelectionForNode$S(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$S, buildSelectionForField$S, parentRecordId);
}
function select$12(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$S, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$18() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$V(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$V(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$R
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$S) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$16(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordConnection': {
                const recordQueryState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Y(cacheKeySink, requestedField, recordQueryState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function ingestFieldByType$R(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordConnection': {
            const RecordConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$W(requestedField, RecordConnectionState);
            break;
        }
    }
}
function isMappedField$R(field) {
    return false;
}
function isFragmentApplicable$S(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordQuery", typename);
}
function getInContextFragmentType$17(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$Q = 'BooleanAggregate';
const VERSION$$ = 'a96004b34f561f154adc6a319a403141';
function keyBuilder$U(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$Q(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$U(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$U(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$R,
        isMappedFieldImport: isMappedField$Q,
        getFieldType: getFieldType$15,
        ingestFieldByType: ingestFieldByType$Q,
        createLink: createLink,
        mergeData: mergeData$Q,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "BooleanAggregate",
            version: VERSION$$,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$Q(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$15(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$Q(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$R(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$Q, getFieldType$15, selectType$Q, parentRecordId);
}
function buildSelectionForNode$R(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$R, buildSelectionForField$R, parentRecordId);
}
function select$11(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$R, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$17() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$U(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$U(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$Q
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$R) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$15(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$15(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$Q(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
    }
}
function isMappedField$Q(field) {
    return false;
}
function isFragmentApplicable$R(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "BooleanAggregate", typename);
}
function getInContextFragmentType$16(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$P = 'CurrencyAggregate';
const VERSION$_ = '82bb7a8eff45156d0ba4c1a51c17b9cc';
function keyBuilder$T(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$P(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$T(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$T(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$Q,
        isMappedFieldImport: isMappedField$P,
        getFieldType: getFieldType$14,
        ingestFieldByType: ingestFieldByType$P,
        createLink: createLink,
        mergeData: mergeData$P,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "CurrencyAggregate",
            version: VERSION$_,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$P(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$14(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$P(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Currency': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'CurrencyValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1f, select$1f, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$Q(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$P, getFieldType$14, selectType$P, parentRecordId);
}
function buildSelectionForNode$Q(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$Q, buildSelectionForField$Q, parentRecordId);
}
function select$10(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$Q, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$16() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$T(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$T(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$P
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$Q) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$14(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'CurrencyValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$19(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'CurrencyValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$19(cacheKeySink, requestedField, minState);
                break;
            }
            case 'CurrencyValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$19(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$14(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Currency'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'CurrencyValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'CurrencyValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'CurrencyValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$P(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Currency': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'CurrencyValue': {
            const CurrencyValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$16(requestedField, CurrencyValueState);
            break;
        }
    }
}
function isMappedField$P(field) {
    return false;
}
function isFragmentApplicable$Q(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "CurrencyAggregate", typename);
}
function getInContextFragmentType$15(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$O = 'DateFunctionAggregation';
const VERSION$Z = '2c6f28f604b988d12fd3fc208129d978';
function keyBuilder$S(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$O(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$S(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$S(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$P,
        isMappedFieldImport: isMappedField$O,
        getFieldType: getFieldType$13,
        ingestFieldByType: ingestFieldByType$O,
        createLink: createLink,
        mergeData: mergeData$O,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DateFunctionAggregation",
            version: VERSION$Z,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$O(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$13(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$O(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Long': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$P(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$O, getFieldType$13, selectType$O, parentRecordId);
}
function buildSelectionForNode$P(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$P, buildSelectionForField$P, parentRecordId);
}
function select$$(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$P, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$15() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$S(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$S(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$O
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$13(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$O(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Long': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$O(field) {
    return false;
}
function isFragmentApplicable$P(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "DateFunctionAggregation", typename);
}
function getInContextFragmentType$14(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$N = 'DateAggregate';
const VERSION$Y = '68225d7e1cf6bfa91f2ed998c9433705';
function keyBuilder$R(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$N(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$R(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$R(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$O,
        isMappedFieldImport: isMappedField$N,
        getFieldType: getFieldType$12,
        ingestFieldByType: ingestFieldByType$N,
        createLink: createLink,
        mergeData: mergeData$N,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DateAggregate",
            version: VERSION$Y,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$N(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$12(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$N(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Date': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DateFunctionAggregation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$Z, select$$, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'DateValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1n, select$1n, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$O(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$N, getFieldType$12, selectType$N, parentRecordId);
}
function buildSelectionForNode$O(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$O, buildSelectionForField$O, parentRecordId);
}
function select$_(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$O, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$14() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$R(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$R(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$N
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$O) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$12(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DateFunctionAggregation': {
                const calendarMonthState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, calendarMonthState);
                break;
            }
            case 'DateFunctionAggregation': {
                const calendarQuarterState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, calendarQuarterState);
                break;
            }
            case 'DateFunctionAggregation': {
                const calendarYearState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, calendarYearState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'DateFunctionAggregation': {
                const dayInMonthState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, dayInMonthState);
                break;
            }
            case 'DateFunctionAggregation': {
                const dayInWeekState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, dayInWeekState);
                break;
            }
            case 'DateFunctionAggregation': {
                const dayInYearState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, dayInYearState);
                break;
            }
            case 'DateFunctionAggregation': {
                const fiscalMonthState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, fiscalMonthState);
                break;
            }
            case 'DateFunctionAggregation': {
                const fiscalQuarterState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, fiscalQuarterState);
                break;
            }
            case 'DateFunctionAggregation': {
                const fiscalYearState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, fiscalYearState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'DateValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1h(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'DateValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1h(cacheKeySink, requestedField, minState);
                break;
            }
            case 'DateFunctionAggregation': {
                const weekInMonthState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, weekInMonthState);
                break;
            }
            case 'DateFunctionAggregation': {
                const weekInYearState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, weekInYearState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$12(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Date'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'calendarMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'calendarQuarter': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'calendarYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'dayInMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'dayInWeek': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'dayInYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'fiscalMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'fiscalQuarter': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'fiscalYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'DateValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'DateValue'
            };
        }
        case 'weekInMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'weekInYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$N(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Date': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DateFunctionAggregation': {
            const DateFunctionAggregationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$S(requestedField, DateFunctionAggregationState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'DateValue': {
            const DateValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1e(requestedField, DateValueState);
            break;
        }
    }
}
function isMappedField$N(field) {
    return false;
}
function isFragmentApplicable$O(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "DateAggregate", typename);
}
function getInContextFragmentType$13(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$M = 'DoubleAggregate';
const VERSION$X = '9eaf724d0ea753527e8dda845d53b97c';
function keyBuilder$Q(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$M(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$Q(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$Q(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$N,
        isMappedFieldImport: isMappedField$M,
        getFieldType: getFieldType$11,
        ingestFieldByType: ingestFieldByType$M,
        createLink: createLink,
        mergeData: mergeData$M,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DoubleAggregate",
            version: VERSION$X,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$M(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$11(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$M(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Double': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$N(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$M, getFieldType$11, selectType$M, parentRecordId);
}
function buildSelectionForNode$N(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$N, buildSelectionForField$N, parentRecordId);
}
function select$Z(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$N, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$13() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$Q(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$Q(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$M
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$N) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$11(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'DoubleValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'DoubleValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, minState);
                break;
            }
            case 'DoubleValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$11(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Double'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$M(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Double': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
    }
}
function isMappedField$M(field) {
    return false;
}
function isFragmentApplicable$N(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "DoubleAggregate", typename);
}
function getInContextFragmentType$12(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$L = 'EmailAggregate';
const VERSION$W = '2fd9198eb04453fc55c73879b3690167';
function keyBuilder$P(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$L(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$P(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$P(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$M,
        isMappedFieldImport: isMappedField$L,
        getFieldType: getFieldType$10,
        ingestFieldByType: ingestFieldByType$L,
        createLink: createLink,
        mergeData: mergeData$L,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "EmailAggregate",
            version: VERSION$W,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$L(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$10(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$L(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Email': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'EmailValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1i, select$1i, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$M(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$L, getFieldType$10, selectType$L, parentRecordId);
}
function buildSelectionForNode$M(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$M, buildSelectionForField$M, parentRecordId);
}
function select$Y(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$M, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$12() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$P(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$P(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$L
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$M) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$10(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'EmailValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1c(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'EmailValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1c(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$10(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Email'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'EmailValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'EmailValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$L(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Email': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'EmailValue': {
            const EmailValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$19(requestedField, EmailValueState);
            break;
        }
    }
}
function isMappedField$L(field) {
    return false;
}
function isFragmentApplicable$M(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "EmailAggregate", typename);
}
function getInContextFragmentType$11(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$K = 'IDAggregate';
const VERSION$V = '04d4a6d94a5e17c6259f9bf6f8429b01';
function keyBuilder$O(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$K(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$O(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$O(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$L,
        isMappedFieldImport: isMappedField$K,
        getFieldType: getFieldType$$,
        ingestFieldByType: ingestFieldByType$K,
        createLink: createLink,
        mergeData: mergeData$K,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "IDAggregate",
            version: VERSION$V,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$K(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$$(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$K(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'IDValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1r, select$1r, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$L(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$K, getFieldType$$, selectType$K, parentRecordId);
}
function buildSelectionForNode$L(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$L, buildSelectionForField$L, parentRecordId);
}
function select$X(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$L, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$11() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$O(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$O(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$K
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$L) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$$(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'IDValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'IDValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$$(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$K(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'IDValue': {
            const IDValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1i(requestedField, IDValueState);
            break;
        }
    }
}
function isMappedField$K(field) {
    return false;
}
function isFragmentApplicable$L(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "IDAggregate", typename);
}
function getInContextFragmentType$10(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$J = 'IntAggregate';
const VERSION$U = '2c4f51740c702f1652c59934464a1df8';
function keyBuilder$N(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$J(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$N(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$N(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$K,
        isMappedFieldImport: isMappedField$J,
        getFieldType: getFieldType$_,
        ingestFieldByType: ingestFieldByType$J,
        createLink: createLink,
        mergeData: mergeData$J,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "IntAggregate",
            version: VERSION$U,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$J(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$_(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$J(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$K(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$J, getFieldType$_, selectType$J, parentRecordId);
}
function buildSelectionForNode$K(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$K, buildSelectionForField$K, parentRecordId);
}
function select$W(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$K, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$10() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$N(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$N(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$J
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$K) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$_(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'IntValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'IntValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, minState);
                break;
            }
            case 'LongValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$_(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$J(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
    }
}
function isMappedField$J(field) {
    return false;
}
function isFragmentApplicable$K(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "IntAggregate", typename);
}
function getInContextFragmentType$$(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$I = 'LatitudeAggregate';
const VERSION$T = '878c5527afbaf070dd32e3a728cc6763';
function keyBuilder$M(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$I(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$M(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$M(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$J,
        isMappedFieldImport: isMappedField$I,
        getFieldType: getFieldType$Z,
        ingestFieldByType: ingestFieldByType$I,
        createLink: createLink,
        mergeData: mergeData$I,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LatitudeAggregate",
            version: VERSION$T,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$I(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$Z(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$I(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Latitude': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'LatitudeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1d, select$1d, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$J(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$I, getFieldType$Z, selectType$I, parentRecordId);
}
function buildSelectionForNode$J(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$J, buildSelectionForField$J, parentRecordId);
}
function select$V(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$J, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$$() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$M(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$M(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$I
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$J) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$Z(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'LatitudeValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$17(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'LatitudeValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$17(cacheKeySink, requestedField, minState);
                break;
            }
            case 'DoubleValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$Z(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Latitude'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'LatitudeValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'LatitudeValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$I(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Latitude': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'LatitudeValue': {
            const LatitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$14(requestedField, LatitudeValueState);
            break;
        }
    }
}
function isMappedField$I(field) {
    return false;
}
function isFragmentApplicable$J(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LatitudeAggregate", typename);
}
function getInContextFragmentType$_(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$H = 'LongitudeAggregate';
const VERSION$S = 'cfdbd03df0a9ea2e17eb1e0d76e264ec';
function keyBuilder$L(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$H(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$L(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$L(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$I,
        isMappedFieldImport: isMappedField$H,
        getFieldType: getFieldType$Y,
        ingestFieldByType: ingestFieldByType$H,
        createLink: createLink,
        mergeData: mergeData$H,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LongitudeAggregate",
            version: VERSION$S,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$H(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$Y(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$H(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Longitude': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'LongitudeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1e, select$1e, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$I(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$H, getFieldType$Y, selectType$H, parentRecordId);
}
function buildSelectionForNode$I(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$I, buildSelectionForField$I, parentRecordId);
}
function select$U(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$I, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$_() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$L(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$L(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$H
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$I) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$Y(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'LongitudeValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$18(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'LongitudeValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$18(cacheKeySink, requestedField, minState);
                break;
            }
            case 'DoubleValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$Y(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Longitude'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'LongitudeValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'LongitudeValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$H(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Longitude': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'LongitudeValue': {
            const LongitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$15(requestedField, LongitudeValueState);
            break;
        }
    }
}
function isMappedField$H(field) {
    return false;
}
function isFragmentApplicable$I(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LongitudeAggregate", typename);
}
function getInContextFragmentType$Z(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$G = 'LongAggregate';
const VERSION$R = 'bf2f24661739e3152f29a37117900a46';
function keyBuilder$K(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$G(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$K(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$K(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$H,
        isMappedFieldImport: isMappedField$G,
        getFieldType: getFieldType$X,
        ingestFieldByType: ingestFieldByType$G,
        createLink: createLink,
        mergeData: mergeData$G,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "LongAggregate",
            version: VERSION$R,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$G(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$X(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$G(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Long': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$H(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$G, getFieldType$X, selectType$G, parentRecordId);
}
function buildSelectionForNode$H(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$H, buildSelectionForField$H, parentRecordId);
}
function select$T(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$H, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$Z() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$K(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$K(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$G
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$H) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$X(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DoubleValue': {
                const avgState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, avgState);
                break;
            }
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'LongValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'LongValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, minState);
                break;
            }
            case 'LongValue': {
                const sumState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, sumState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$X(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'avg': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'sum': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$G(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Long': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
    }
}
function isMappedField$G(field) {
    return false;
}
function isFragmentApplicable$H(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "LongAggregate", typename);
}
function getInContextFragmentType$Y(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$F = 'PhoneNumberAggregate';
const VERSION$Q = '76e66d2f1d15218325d6a0601056ac0d';
function keyBuilder$J(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$F(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$J(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$J(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$G,
        isMappedFieldImport: isMappedField$F,
        getFieldType: getFieldType$W,
        ingestFieldByType: ingestFieldByType$F,
        createLink: createLink,
        mergeData: mergeData$F,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PhoneNumberAggregate",
            version: VERSION$Q,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$F(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$W(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$F(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'PhoneNumber': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'PhoneNumberValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1j, select$1j, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$G(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$F, getFieldType$W, selectType$F, parentRecordId);
}
function buildSelectionForNode$G(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$G, buildSelectionForField$G, parentRecordId);
}
function select$S(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$G, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$Y() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$J(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$J(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$F
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$G) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$W(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'PhoneNumberValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1d(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'PhoneNumberValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1d(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$W(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'PhoneNumber'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'PhoneNumberValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'PhoneNumberValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$F(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'PhoneNumber': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'PhoneNumberValue': {
            const PhoneNumberValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1a(requestedField, PhoneNumberValueState);
            break;
        }
    }
}
function isMappedField$F(field) {
    return false;
}
function isFragmentApplicable$G(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "PhoneNumberAggregate", typename);
}
function getInContextFragmentType$X(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$E = 'PicklistAggregate';
const VERSION$P = '6827470c6c52cedec0dfda19734a6b79';
function keyBuilder$I(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$E(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$I(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$I(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$F,
        isMappedFieldImport: isMappedField$E,
        getFieldType: getFieldType$V,
        ingestFieldByType: ingestFieldByType$E,
        createLink: createLink,
        mergeData: mergeData$E,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "PicklistAggregate",
            version: VERSION$P,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$E(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$V(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$E(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Picklist': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'PicklistValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1c, select$1c, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$F(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$E, getFieldType$V, selectType$E, parentRecordId);
}
function buildSelectionForNode$F(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$F, buildSelectionForField$F, parentRecordId);
}
function select$R(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$F, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$X() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$I(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$I(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$E
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$F) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$V(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'PicklistValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$16(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'PicklistValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$16(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$V(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Picklist'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'PicklistValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'PicklistValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$E(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Picklist': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'PicklistValue': {
            const PicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$13(requestedField, PicklistValueState);
            break;
        }
    }
}
function isMappedField$E(field) {
    return false;
}
function isFragmentApplicable$F(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "PicklistAggregate", typename);
}
function getInContextFragmentType$W(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$D = 'TextAreaAggregate';
const VERSION$O = 'a384df278f789db87864f6345adb134a';
function keyBuilder$H(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$D(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$H(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$H(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$E,
        isMappedFieldImport: isMappedField$D,
        getFieldType: getFieldType$U,
        ingestFieldByType: ingestFieldByType$D,
        createLink: createLink,
        mergeData: mergeData$D,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "TextAreaAggregate",
            version: VERSION$O,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$D(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$U(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$D(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'TextArea': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'TextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1m, select$1m, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$E(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$D, getFieldType$U, selectType$D, parentRecordId);
}
function buildSelectionForNode$E(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$E, buildSelectionForField$E, parentRecordId);
}
function select$Q(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$E, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$W() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$H(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$H(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$D
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$E) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$U(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'TextAreaValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1g(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'TextAreaValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1g(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$U(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'TextArea'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'TextAreaValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'TextAreaValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$D(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'TextArea': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'TextAreaValue': {
            const TextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1d(requestedField, TextAreaValueState);
            break;
        }
    }
}
function isMappedField$D(field) {
    return false;
}
function isFragmentApplicable$E(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "TextAreaAggregate", typename);
}
function getInContextFragmentType$V(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$C = 'TimeAggregate';
const VERSION$N = '4b7aa92a66dc688b7e2e15c3976dd8ff';
function keyBuilder$G(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$C(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$G(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$G(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$D,
        isMappedFieldImport: isMappedField$C,
        getFieldType: getFieldType$T,
        ingestFieldByType: ingestFieldByType$C,
        createLink: createLink,
        mergeData: mergeData$C,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "TimeAggregate",
            version: VERSION$N,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$C(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$T(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$C(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Time': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DateFunctionAggregation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$Z, select$$, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$D(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$C, getFieldType$T, selectType$C, parentRecordId);
}
function buildSelectionForNode$D(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$D, buildSelectionForField$D, parentRecordId);
}
function select$P(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$D, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$V() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$G(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$G(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$C
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$D) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$T(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'DateFunctionAggregation': {
                const hourInDayState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$S(cacheKeySink, requestedField, hourInDayState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$T(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Time'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'hourInDay': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$C(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Time': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DateFunctionAggregation': {
            const DateFunctionAggregationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$S(requestedField, DateFunctionAggregationState);
            break;
        }
    }
}
function isMappedField$C(field) {
    return false;
}
function isFragmentApplicable$D(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "TimeAggregate", typename);
}
function getInContextFragmentType$U(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$B = 'UrlAggregate';
const VERSION$M = 'a20a03966540b9046db5f606e20e3c8a';
function keyBuilder$F(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$B(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$F(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$F(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$C,
        isMappedFieldImport: isMappedField$B,
        getFieldType: getFieldType$S,
        ingestFieldByType: ingestFieldByType$B,
        createLink: createLink,
        mergeData: mergeData$B,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "UrlAggregate",
            version: VERSION$M,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$B(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$S(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$B(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Url': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'UrlValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1h, select$1h, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$C(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$B, getFieldType$S, selectType$B, parentRecordId);
}
function buildSelectionForNode$C(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$C, buildSelectionForField$C, parentRecordId);
}
function select$O(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$C, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$U() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$F(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$F(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$B
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$C) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$S(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'LongValue': {
                const countState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countState);
                break;
            }
            case 'LongValue': {
                const countDistinctState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, countDistinctState);
                break;
            }
            case 'IntValue': {
                const groupingState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, groupingState);
                break;
            }
            case 'UrlValue': {
                const maxState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1b(cacheKeySink, requestedField, maxState);
                break;
            }
            case 'UrlValue': {
                const minState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1b(cacheKeySink, requestedField, minState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$S(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Url'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'grouping': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'UrlValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'UrlValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$B(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Url': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'UrlValue': {
            const UrlValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$18(requestedField, UrlValueState);
            break;
        }
    }
}
function isMappedField$B(field) {
    return false;
}
function isFragmentApplicable$C(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["FieldValue"], "UrlAggregate", typename);
}
function getInContextFragmentType$T(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

// union versions are undefined, selected versions must be specific to the type being selected
const VERSION$L = undefined;
function ingest$E(astNode, state) {
    const typename = state.data.__typename;
    // Delegate key building and ingest to concrete implementations
    if (typename === 'RecordAggregate') {
        return ingest$D(astNode, state);
    }
}
function select$N(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const typename = source.data.__typename;
        if (typename === 'RecordAggregate') {
            return select$M(field, variables, fragments)(source, reader, parentRecordId);
        }
    };
}
function getTypeCacheKeys$E(cacheKeys, astNode, state) {
    const { path, data } = state;
    const typename = data.__typename;
    if (typename === 'RecordAggregate') {
        return getTypeCacheKeys$D(cacheKeys, astNode, state);
    }
}
function getInContextFragmentType$S(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}
function getFieldType$R(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getMinimumSelections$T() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}

function getFieldType$Q(field) {
    const fieldNameOverride = getFieldNameOverride(field);
    const fieldName = fieldNameOverride || field.name.value;
    switch (fieldName) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'BooleanAggregate': {
            return {
                isArray: false,
                typename: 'BooleanAggregate',
            };
        }
        case 'CurrencyAggregate': {
            return {
                isArray: false,
                typename: 'CurrencyAggregate',
            };
        }
        case 'DateAggregate': {
            return {
                isArray: false,
                typename: 'DateAggregate',
            };
        }
        case 'DoubleAggregate': {
            return {
                isArray: false,
                typename: 'DoubleAggregate',
            };
        }
        case 'EmailAggregate': {
            return {
                isArray: false,
                typename: 'EmailAggregate',
            };
        }
        case 'IDAggregate': {
            return {
                isArray: false,
                typename: 'IDAggregate',
            };
        }
        case 'IntAggregate': {
            return {
                isArray: false,
                typename: 'IntAggregate',
            };
        }
        case 'LatitudeAggregate': {
            return {
                isArray: false,
                typename: 'LatitudeAggregate',
            };
        }
        case 'LongitudeAggregate': {
            return {
                isArray: false,
                typename: 'LongitudeAggregate',
            };
        }
        case 'LongAggregate': {
            return {
                isArray: false,
                typename: 'LongAggregate',
            };
        }
        case 'PercentAggregate': {
            return {
                isArray: false,
                typename: 'PercentAggregate',
            };
        }
        case 'PhoneNumberAggregate': {
            return {
                isArray: false,
                typename: 'PhoneNumberAggregate',
            };
        }
        case 'PicklistAggregate': {
            return {
                isArray: false,
                typename: 'PicklistAggregate',
            };
        }
        case 'StringAggregate': {
            return {
                isArray: false,
                typename: 'StringAggregate',
            };
        }
        case 'TextAreaAggregate': {
            return {
                isArray: false,
                typename: 'TextAreaAggregate',
            };
        }
        case 'TimeAggregate': {
            return {
                isArray: false,
                typename: 'TimeAggregate',
            };
        }
        case 'UrlAggregate': {
            return {
                isArray: false,
                typename: 'UrlAggregate',
            };
        }
        default:
            return undefined;
    }
}

const name$A = 'RecordAggregate';
const VERSION$K = 'e7f09bcfe3bdaa58b46bbe4d724d0231';
function keyBuilder$E(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$A(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$D(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$E(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$B,
        isMappedFieldImport: isMappedField$A,
        getFieldType: getFieldType$Q,
        ingestFieldByType: ingestFieldByType$A,
        createLink: createLink,
        mergeData: mergeData$A,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordAggregate",
            version: VERSION$K,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$A(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$Q(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$A(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'BooleanAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$$, select$11, false);
            break;
        }
        case 'CurrencyAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$_, select$10, false);
            break;
        }
        case 'DateAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$Y, select$_, false);
            break;
        }
        case 'DoubleAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$X, select$Z, false);
            break;
        }
        case 'EmailAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$W, select$Y, false);
            break;
        }
        case 'IDAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$V, select$X, false);
            break;
        }
        case 'IntAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$U, select$W, false);
            break;
        }
        case 'LatitudeAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$T, select$V, false);
            break;
        }
        case 'LongitudeAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$S, select$U, false);
            break;
        }
        case 'LongAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$R, select$T, false);
            break;
        }
        case 'PercentAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1v, select$1v, false);
            break;
        }
        case 'PhoneNumberAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$Q, select$S, false);
            break;
        }
        case 'PicklistAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$P, select$R, false);
            break;
        }
        case 'StringAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1s, select$1s, false);
            break;
        }
        case 'TextAreaAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$O, select$Q, false);
            break;
        }
        case 'TimeAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$N, select$P, false);
            break;
        }
        case 'UrlAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$M, select$O, false);
            break;
        }
        case 'RecordAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$K, select$M, false);
            break;
        }
        case 'PolymorphicAggregateParentRelationship': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$L, select$N, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$B(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$A, getFieldType$Q, selectType$A, parentRecordId);
}
function buildSelectionForNode$B(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$B, buildSelectionForField$B, parentRecordId);
}
function select$M(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$B, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$S() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$D(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$E(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$A
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$B) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$Q(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'BooleanAggregate': {
                const BooleanAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$U(cacheKeySink, requestedField, BooleanAggregateState);
                break;
            }
            case 'CurrencyAggregate': {
                const CurrencyAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$T(cacheKeySink, requestedField, CurrencyAggregateState);
                break;
            }
            case 'DateAggregate': {
                const DateAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$R(cacheKeySink, requestedField, DateAggregateState);
                break;
            }
            case 'DoubleAggregate': {
                const DoubleAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Q(cacheKeySink, requestedField, DoubleAggregateState);
                break;
            }
            case 'EmailAggregate': {
                const EmailAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$P(cacheKeySink, requestedField, EmailAggregateState);
                break;
            }
            case 'IDAggregate': {
                const IDAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$O(cacheKeySink, requestedField, IDAggregateState);
                break;
            }
            case 'IntAggregate': {
                const IntAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$N(cacheKeySink, requestedField, IntAggregateState);
                break;
            }
            case 'LatitudeAggregate': {
                const LatitudeAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$M(cacheKeySink, requestedField, LatitudeAggregateState);
                break;
            }
            case 'LongitudeAggregate': {
                const LongitudeAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$L(cacheKeySink, requestedField, LongitudeAggregateState);
                break;
            }
            case 'LongAggregate': {
                const LongAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$K(cacheKeySink, requestedField, LongAggregateState);
                break;
            }
            case 'PercentAggregate': {
                const PercentAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1p(cacheKeySink, requestedField, PercentAggregateState);
                break;
            }
            case 'PhoneNumberAggregate': {
                const PhoneNumberAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$J(cacheKeySink, requestedField, PhoneNumberAggregateState);
                break;
            }
            case 'PicklistAggregate': {
                const PicklistAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$I(cacheKeySink, requestedField, PicklistAggregateState);
                break;
            }
            case 'StringAggregate': {
                const StringAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1m(cacheKeySink, requestedField, StringAggregateState);
                break;
            }
            case 'TextAreaAggregate': {
                const TextAreaAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$H(cacheKeySink, requestedField, TextAreaAggregateState);
                break;
            }
            case 'TimeAggregate': {
                const TimeAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$G(cacheKeySink, requestedField, TimeAggregateState);
                break;
            }
            case 'UrlAggregate': {
                const UrlAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$F(cacheKeySink, requestedField, UrlAggregateState);
                break;
            }
            case 'RecordAggregate': {
                const parentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$D(cacheKeySink, requestedField, parentRelationshipState);
                break;
            }
            case 'PolymorphicAggregateParentRelationship': {
                const polymorphicParentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$E(cacheKeySink, requestedField, polymorphicParentRelationshipState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function ingestFieldByType$A(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'BooleanAggregate': {
            const BooleanAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$U(requestedField, BooleanAggregateState);
            break;
        }
        case 'CurrencyAggregate': {
            const CurrencyAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$T(requestedField, CurrencyAggregateState);
            break;
        }
        case 'DateAggregate': {
            const DateAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$R(requestedField, DateAggregateState);
            break;
        }
        case 'DoubleAggregate': {
            const DoubleAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$Q(requestedField, DoubleAggregateState);
            break;
        }
        case 'EmailAggregate': {
            const EmailAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$P(requestedField, EmailAggregateState);
            break;
        }
        case 'IDAggregate': {
            const IDAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$O(requestedField, IDAggregateState);
            break;
        }
        case 'IntAggregate': {
            const IntAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$N(requestedField, IntAggregateState);
            break;
        }
        case 'LatitudeAggregate': {
            const LatitudeAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$M(requestedField, LatitudeAggregateState);
            break;
        }
        case 'LongitudeAggregate': {
            const LongitudeAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$L(requestedField, LongitudeAggregateState);
            break;
        }
        case 'LongAggregate': {
            const LongAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$K(requestedField, LongAggregateState);
            break;
        }
        case 'PercentAggregate': {
            const PercentAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1m(requestedField, PercentAggregateState);
            break;
        }
        case 'PhoneNumberAggregate': {
            const PhoneNumberAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$J(requestedField, PhoneNumberAggregateState);
            break;
        }
        case 'PicklistAggregate': {
            const PicklistAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$I(requestedField, PicklistAggregateState);
            break;
        }
        case 'StringAggregate': {
            const StringAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1j(requestedField, StringAggregateState);
            break;
        }
        case 'TextAreaAggregate': {
            const TextAreaAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$H(requestedField, TextAreaAggregateState);
            break;
        }
        case 'TimeAggregate': {
            const TimeAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$G(requestedField, TimeAggregateState);
            break;
        }
        case 'UrlAggregate': {
            const UrlAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$F(requestedField, UrlAggregateState);
            break;
        }
        case 'RecordAggregate': {
            const RecordAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$D(requestedField, RecordAggregateState);
            break;
        }
        case 'PolymorphicAggregateParentRelationship': {
            const PolymorphicAggregateParentRelationshipState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$E(requestedField, PolymorphicAggregateParentRelationshipState);
            break;
        }
    }
}
function isMappedField$A(field) {
    return false;
}
function isFragmentApplicable$B(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordAggregate", typename);
}
function getInContextFragmentType$R(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$z = 'RecordResult';
const VERSION$J = 'ac087a39402cb113c9336a78e228b27a';
function keyBuilder$D(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$z(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$C(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$D(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$A,
        isMappedFieldImport: isMappedField$z,
        getFieldType: getFieldType$P,
        ingestFieldByType: ingestFieldByType$z,
        createLink: createLink,
        mergeData: mergeData$z,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordResult",
            version: VERSION$J,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$z(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$P(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$z(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$K, select$M, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$A(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$z, getFieldType$P, selectType$z, parentRecordId);
}
function buildSelectionForNode$A(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$A, buildSelectionForField$A, parentRecordId);
}
function select$L(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$A, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$R() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$C(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$D(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$z
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$A) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$P(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordAggregate': {
                const aggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$D(cacheKeySink, requestedField, aggregateState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$P(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'aggregate': {
            return {
                isArray: false,
                typename: 'RecordAggregate'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$z(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordAggregate': {
            const RecordAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$D(requestedField, RecordAggregateState);
            break;
        }
    }
}
function isMappedField$z(field) {
    return false;
}
function isFragmentApplicable$A(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordResult", typename);
}
function getInContextFragmentType$Q(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$y = 'RecordAggregateEdge';
const VERSION$I = '109073e1a791313cf074cd8b4d78a64d';
function keyBuilder$C(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$y(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$B(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$C(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$z,
        isMappedFieldImport: isMappedField$y,
        getFieldType: getFieldType$O,
        ingestFieldByType: ingestFieldByType$y,
        createLink: createLink,
        mergeData: mergeData$y,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordAggregateEdge",
            version: VERSION$I,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$y(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$O(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$y(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordResult': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$J, select$L, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$z(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$y, getFieldType$O, selectType$y, parentRecordId);
}
function buildSelectionForNode$z(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$z, buildSelectionForField$z, parentRecordId);
}
function select$K(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$z, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$Q() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$B(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$C(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$y
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$z) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$O(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordResult': {
                const nodeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$C(cacheKeySink, requestedField, nodeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$O(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'RecordResult'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$y(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordResult': {
            const RecordResultState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$C(requestedField, RecordResultState);
            break;
        }
    }
}
function isMappedField$y(field) {
    return false;
}
function isFragmentApplicable$z(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordAggregateEdge", typename);
}
function getInContextFragmentType$P(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$x = 'RecordAggregateConnection';
const VERSION$H = '75a36f5de3df006f439ccc8e04bdca0f';
function keyBuilder$B(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$x(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingestPaginationMetadata$3(astNode, state, key, sink, existingData) {
    const { data, luvio, store } = state;
    const { pageInfo: { hasNextPage, startCursor }, edges } = data;
    if (!hasGraphQLPaginationFields(data))
        return;
    const paginationKey = key + '__pagination';
    let existingPaginationMetadata = store.readEntry(paginationKey);
    const afterArg = astNode.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', state.variables);
    const isPagedResponse = afterArgVal !== undefined &&
        existingPaginationMetadata !== undefined &&
        existingPaginationMetadata[afterArgVal] !== undefined;
    if (isPagedResponse && existingPaginationMetadata !== undefined) {
        const previousPageOffset = existingPaginationMetadata[afterArgVal];
        existingPaginationMetadata = {
            ...existingPaginationMetadata,
            [startCursor]: previousPageOffset + 1,
        };
    }
    // Default to a zero offset if we're not a result of a paged request
    const startOffset = isPagedResponse && existingPaginationMetadata !== undefined
        ? offsetFromToken(existingPaginationMetadata, startCursor)
        : 0;
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0) {
            throw new RangeError(`Cursor value ${startCursor} is not recognized. Cannot ingest the returned page. After: ${afterArgVal}`);
        }
    }
    const nextOffset = startOffset + edges.length;
    const incomingPaginationMetadata = createPaginationMetadata(startOffset, edges);
    if (hasNextPage) {
        // we know the data extends beyond NEXT_OFFSET_IDENTIFIER; clean up any old __END__ markers that say the data ended at/before that offset
        if (existingPaginationMetadata !== undefined && existingPaginationMetadata.__END__ !== undefined && existingPaginationMetadata.__END__ <= nextOffset) {
            existingPaginationMetadata = { ...existingPaginationMetadata };
            delete existingPaginationMetadata.__END__;
        }
    }
    else {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    // store the updated pagination metadata
    const mergedPaginationMetadata = mergeMetadata(existingPaginationMetadata, incomingPaginationMetadata);
    luvio.storePublish(paginationKey, mergedPaginationMetadata);
    luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata);
    // merge the edges
    assignMetadataLink(sink, paginationKey);
    const existingRecord = existingData ? existingData.data : undefined;
    if (existingRecord !== undefined && existingRecord.edges !== undefined) {
        sink.edges = [
            ...existingRecord.edges.slice(0, startOffset),
            ...sink.edges,
            ...existingRecord.edges.slice(nextOffset),
        ];
    }
}
function ingest$A(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$B(luvio, path);
    return ingestCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$y,
        isMappedFieldImport: isMappedField$x,
        getFieldType: getFieldType$N,
        ingestFieldByType: ingestFieldByType$x,
        hasGraphQLPaginationFields: hasGraphQLPaginationFields,
        ingestPaginatedMetadata: ingestPaginationMetadata$3,
        createLink: createLink,
        mergeData: mergeData$x,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordAggregateConnection",
            version: VERSION$H,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$x(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$N(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$x(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordAggregateEdge': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$I, select$K, false);
            break;
        }
        case 'PageInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$14, select$16, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$y(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, true, getFieldData$x, getFieldType$N, selectType$x, parentRecordId);
}
function buildSelectionForNode$y(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$y, buildSelectionForField$y, parentRecordId);
}
function select$J(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$y, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$P() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        ...getCursorConnectionMinimumSelections()
    ];
    return minimumSelections;
}
function getTypeCacheKeys$A(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$B(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$x
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$y) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$N(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordAggregateEdge': {
                const fullPath__edges = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__edges + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$B(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'PageInfo': {
                const pageInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Z(cacheKeySink, requestedField, pageInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$N(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'RecordAggregateEdge'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$x(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordAggregateEdge': {
            const RecordAggregateEdgeState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$B(requestedField, RecordAggregateEdgeState);
            break;
        }
        case 'PageInfo': {
            const PageInfoState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$Z(requestedField, PageInfoState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$x(field) {
    return false;
}
function isFragmentApplicable$y(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordAggregateConnection", typename);
}
function getInContextFragmentType$O(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getFieldType$M(field) {
    const fieldNameOverride = getFieldNameOverride(field);
    const fieldName = fieldNameOverride || field.name.value;
    switch (fieldName) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        case 'recordQueryAggregate': {
            return {
                isArray: false,
                typename: 'RecordAggregateConnection',
            };
        }
        default:
            return undefined;
    }
}

const name$w = 'RecordQueryAggregate';
const VERSION$G = 'd872f40fe358effab12441976e95ca71';
function keyBuilder$A(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$w(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$z(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$A(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$x,
        isMappedFieldImport: isMappedField$w,
        getFieldType: getFieldType$M,
        ingestFieldByType: ingestFieldByType$w,
        createLink: createLink,
        mergeData: mergeData$w,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordQueryAggregate",
            version: VERSION$G,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$w(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$M(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$w(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordAggregateConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$H, select$J, true);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$x(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$w, getFieldType$M, selectType$w, parentRecordId);
}
function buildSelectionForNode$x(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$x, buildSelectionForField$x, parentRecordId);
}
function select$I(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$x, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$O() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$z(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$A(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$w
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$x) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$M(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordAggregateConnection': {
                const recordQueryAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$A(cacheKeySink, requestedField, recordQueryAggregateState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function ingestFieldByType$w(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordAggregateConnection': {
            const RecordAggregateConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$A(requestedField, RecordAggregateConnectionState);
            break;
        }
    }
}
function isMappedField$w(field) {
    return false;
}
function isFragmentApplicable$x(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordQueryAggregate", typename);
}
function getInContextFragmentType$N(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$v = 'ChildRelationship';
const VERSION$F = '46fe6575916bfa87eabb7a722b4a9016';
function keyBuilder$z(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$v(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$y(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$z(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$w,
        isMappedFieldImport: isMappedField$v,
        getFieldType: getFieldType$L,
        ingestFieldByType: ingestFieldByType$v,
        createLink: createLink,
        mergeData: mergeData$v,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "ChildRelationship",
            version: VERSION$F,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$v(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$L(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$v(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ObjectInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$y, select$A, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$w(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$v, getFieldType$L, selectType$v, parentRecordId);
}
function buildSelectionForNode$w(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$w, buildSelectionForField$w, parentRecordId);
}
function select$H(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$w, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$N() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$y(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$z(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$v
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$w) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$L(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'ObjectInfo': {
                const objectInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$r(cacheKeySink, requestedField, objectInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$L(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'childObjectApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'fieldName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'junctionIdListNames': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        case 'junctionReferenceTo': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        case 'relationshipName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'objectInfo': {
            return {
                isArray: false,
                typename: 'ObjectInfo'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$v(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ObjectInfo': {
            const ObjectInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$r(requestedField, ObjectInfoState);
            break;
        }
    }
}
function isMappedField$v(field) {
    return false;
}
function isFragmentApplicable$w(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "ChildRelationship", typename);
}
function getInContextFragmentType$M(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$u = 'DependentField';
const VERSION$E = 'f1e7745a7b6da3e3a08e24836f72104f';
function keyBuilder$y(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$u(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$x(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$y(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$v,
        isMappedFieldImport: isMappedField$u,
        getFieldType: getFieldType$K,
        ingestFieldByType: ingestFieldByType$u,
        createLink: createLink,
        mergeData: mergeData$u,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "DependentField",
            version: VERSION$E,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$u(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$K(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$u(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$v(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$u, getFieldType$K, selectType$u, parentRecordId);
}
function buildSelectionForNode$v(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$v, buildSelectionForField$v, parentRecordId);
}
function select$G(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$v, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$M() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$x(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$y(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$u
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$K(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'controllingField': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'dependentFields': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$u(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$u(field) {
    return false;
}
function isFragmentApplicable$v(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "DependentField", typename);
}
function getInContextFragmentType$L(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$t = 'FilteredLookupInfo';
const VERSION$D = '5925c1087557ba234bfee8acff9cffb8';
function keyBuilder$x(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$t(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$w(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$x(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$u,
        isMappedFieldImport: isMappedField$t,
        getFieldType: getFieldType$J,
        ingestFieldByType: ingestFieldByType$t,
        createLink: createLink,
        mergeData: mergeData$t,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "FilteredLookupInfo",
            version: VERSION$D,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$t(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$J(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$t(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$u(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$t, getFieldType$J, selectType$t, parentRecordId);
}
function buildSelectionForNode$u(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$u, buildSelectionForField$u, parentRecordId);
}
function select$F(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$u, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$L() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$w(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$x(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$t
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$J(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'controllingFields': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        case 'dependent': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'optionalFilter': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$t(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$t(field) {
    return false;
}
function isFragmentApplicable$u(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "FilteredLookupInfo", typename);
}
function getInContextFragmentType$K(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$s = 'ReferenceToInfo';
const VERSION$C = '604954665bd0a8e8093001263b6d94ee';
function keyBuilder$w(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$s(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$v(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$w(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$t,
        isMappedFieldImport: isMappedField$s,
        getFieldType: getFieldType$I,
        ingestFieldByType: ingestFieldByType$s,
        createLink: createLink,
        mergeData: mergeData$s,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "ReferenceToInfo",
            version: VERSION$C,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$s(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$I(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$s(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ObjectInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$y, select$A, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$t(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$s, getFieldType$I, selectType$s, parentRecordId);
}
function buildSelectionForNode$t(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$t, buildSelectionForField$t, parentRecordId);
}
function select$E(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$t, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$K() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$v(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$w(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$s
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$t) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$I(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'ObjectInfo': {
                const objectInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$r(cacheKeySink, requestedField, objectInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$I(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'nameFields': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        case 'objectInfo': {
            return {
                isArray: false,
                typename: 'ObjectInfo'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$s(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ObjectInfo': {
            const ObjectInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$r(requestedField, ObjectInfoState);
            break;
        }
    }
}
function isMappedField$s(field) {
    return false;
}
function isFragmentApplicable$t(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "ReferenceToInfo", typename);
}
function getInContextFragmentType$J(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$r = 'Field';
const VERSION$B = '85f2db3fa3aa538eb507ff991c47f227';
function keyBuilder$v(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$r(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$u(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$v(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$s,
        isMappedFieldImport: isMappedField$r,
        getFieldType: getFieldType$H,
        ingestFieldByType: ingestFieldByType$r,
        createLink: createLink,
        mergeData: mergeData$r,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Field",
            version: VERSION$B,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$r(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$H(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$r(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DataType': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'FieldExtraTypeInfo': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'FilteredLookupInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$D, select$F, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ReferenceToInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$C, select$E, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$s(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$r, getFieldType$H, selectType$r, parentRecordId);
}
function buildSelectionForNode$s(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$s, buildSelectionForField$s, parentRecordId);
}
function select$D(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$s, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$J() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$u(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$v(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$r
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$s) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$H(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'FilteredLookupInfo': {
                const filteredLookupInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$w(cacheKeySink, requestedField, filteredLookupInfoState);
                break;
            }
            case 'ReferenceToInfo': {
                const fullPath__referenceToInfos = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__referenceToInfos + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$v(cacheKeySink, requestedField, itemState);
                }
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$H(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'calculated': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'compound': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'compoundComponentName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'compoundFieldName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'controllerName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'controllingFields': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        case 'createable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'custom': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'dataType': {
            return {
                isArray: false,
                typename: 'DataType'
            };
        }
        case 'extraTypeInfo': {
            return {
                isArray: false,
                typename: 'FieldExtraTypeInfo'
            };
        }
        case 'filterable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'filteredLookupInfo': {
            return {
                isArray: false,
                typename: 'FilteredLookupInfo'
            };
        }
        case 'highScaleNumber': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'htmlFormatted': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'inlineHelpText': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'nameField': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'polymorphicForeignKey': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'precision': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'reference': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'referenceTargetField': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'referenceToInfos': {
            return {
                isArray: true,
                typename: 'ReferenceToInfo'
            };
        }
        case 'relationshipName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'required': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'scale': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'searchPrefilterable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'sortable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'updateable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$r(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DataType': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'FieldExtraTypeInfo': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'FilteredLookupInfo': {
            const FilteredLookupInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$w(requestedField, FilteredLookupInfoState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ReferenceToInfo': {
            const ReferenceToInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$v(requestedField, ReferenceToInfoState);
            break;
        }
    }
}
function isMappedField$r(field) {
    return false;
}
function isFragmentApplicable$s(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Field", typename);
}
function getInContextFragmentType$I(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$q = 'RecordTypeInfo';
const VERSION$A = '4b9c8f1341c2ab9e0dddddaa0935dd09';
function keyBuilder$u(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$q(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$t(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$u(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$r,
        isMappedFieldImport: isMappedField$q,
        getFieldType: getFieldType$G,
        ingestFieldByType: ingestFieldByType$q,
        createLink: createLink,
        mergeData: mergeData$q,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "RecordTypeInfo",
            version: VERSION$A,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$q(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$G(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$q(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$r(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$q, getFieldType$G, selectType$q, parentRecordId);
}
function buildSelectionForNode$r(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$r, buildSelectionForField$r, parentRecordId);
}
function select$C(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$r, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$I() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$t(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$u(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$q
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$G(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'available': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'defaultRecordTypeMapping': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'master': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'name': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'recordTypeId': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$q(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$q(field) {
    return false;
}
function isFragmentApplicable$r(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RecordTypeInfo", typename);
}
function getInContextFragmentType$H(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$p = 'ThemeInfo';
const VERSION$z = '8d51202c3e44b6e99239b346b483a513';
function keyBuilder$t(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$p(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$s(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$t(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$q,
        isMappedFieldImport: isMappedField$p,
        getFieldType: getFieldType$F,
        ingestFieldByType: ingestFieldByType$p,
        createLink: createLink,
        mergeData: mergeData$p,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "ThemeInfo",
            version: VERSION$z,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$p(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$F(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$p(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$q(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$p, getFieldType$F, selectType$p, parentRecordId);
}
function buildSelectionForNode$q(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$q, buildSelectionForField$q, parentRecordId);
}
function select$B(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$q, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$H() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$s(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$t(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$p
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$F(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'color': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'iconUrl': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$p(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$p(field) {
    return false;
}
function isFragmentApplicable$q(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "ThemeInfo", typename);
}
function getInContextFragmentType$G(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$o = 'ObjectInfo';
const TTL$4 = 900000;
const VERSION$y = 'f8f627dd56d42a39e1a6642edb039182';
function keyBuilder$s(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$o(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$r(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$s(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$p,
        isMappedFieldImport: isMappedField$o,
        getFieldType: getFieldType$E,
        ingestFieldByType: ingestFieldByType$o,
        createLink: createLink,
        mergeData: mergeData$o,
        storeMetadataParams: {
            ttl: TTL$4,
            namespace: keyPrefix,
            representationName: "ObjectInfo",
            version: VERSION$y,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$o(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$E(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$o(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ChildRelationship': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$F, select$H, false);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'DependentField': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$E, select$G, false);
            break;
        }
        case 'Field': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$B, select$D, false);
            break;
        }
        case 'RecordTypeInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$A, select$C, false);
            break;
        }
        case 'ThemeInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$z, select$B, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$p(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$o, getFieldType$E, selectType$o, parentRecordId);
}
function buildSelectionForNode$p(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$p, buildSelectionForField$p, parentRecordId);
}
function select$A(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$p, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$G() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$r(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$s(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$o
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$p) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$E(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'ChildRelationship': {
                const fullPath__childRelationships = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__childRelationships + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$y(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'DependentField': {
                const fullPath__dependentFields = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__dependentFields + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$x(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'Field': {
                const fullPath__fields = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__fields + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$u(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'RecordTypeInfo': {
                const fullPath__recordTypeInfos = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__recordTypeInfos + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$t(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'ThemeInfo': {
                const themeInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$s(cacheKeySink, requestedField, themeInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$E(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'childRelationships': {
            return {
                isArray: true,
                typename: 'ChildRelationship'
            };
        }
        case 'createable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'custom': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'defaultRecordTypeId': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'deletable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'dependentFields': {
            return {
                isArray: true,
                typename: 'DependentField'
            };
        }
        case 'feedEnabled': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'fields': {
            return {
                isArray: true,
                typename: 'Field'
            };
        }
        case 'keyPrefix': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'labelPlural': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'layoutable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'mruEnabled': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'nameFields': {
            return {
                isArray: true,
                typename: 'String'
            };
        }
        case 'queryable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'recordTypeInfos': {
            return {
                isArray: true,
                typename: 'RecordTypeInfo'
            };
        }
        case 'searchable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'themeInfo': {
            return {
                isArray: false,
                typename: 'ThemeInfo'
            };
        }
        case 'updateable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        case 'locale': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$o(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ChildRelationship': {
            const ChildRelationshipState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$y(requestedField, ChildRelationshipState);
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'DependentField': {
            const DependentFieldState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$x(requestedField, DependentFieldState);
            break;
        }
        case 'Field': {
            const FieldState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$u(requestedField, FieldState);
            break;
        }
        case 'RecordTypeInfo': {
            const RecordTypeInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$t(requestedField, RecordTypeInfoState);
            break;
        }
        case 'ThemeInfo': {
            const ThemeInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$s(requestedField, ThemeInfoState);
            break;
        }
    }
}
function isMappedField$o(field) {
    return false;
}
function isFragmentApplicable$p(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "ObjectInfo", typename);
}
function getInContextFragmentType$F(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$n = 'ListColumn';
const VERSION$x = '8dcf4b78cc643cef31522376d8fa2ec9';
function keyBuilder$r(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$n(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$q(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$r(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$o,
        isMappedFieldImport: isMappedField$n,
        getFieldType: getFieldType$D,
        ingestFieldByType: ingestFieldByType$n,
        createLink: createLink,
        mergeData: mergeData$n,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "ListColumn",
            version: VERSION$x,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$n(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$D(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$n(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Boolean': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$o(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$n, getFieldType$D, selectType$n, parentRecordId);
}
function buildSelectionForNode$o(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$o, buildSelectionForField$o, parentRecordId);
}
function select$z(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$o, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$F() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$q(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$r(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$n
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$D(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'fieldApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'lookupId': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'sortable': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$n(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Boolean': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$n(field) {
    return false;
}
function isFragmentApplicable$o(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "ListColumn", typename);
}
function getInContextFragmentType$E(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$m = 'ListOrder';
const VERSION$w = '242dbbb2adb06b43073f9f14f401250a';
function keyBuilder$q(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$m(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$p(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$q(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$n,
        isMappedFieldImport: isMappedField$m,
        getFieldType: getFieldType$C,
        ingestFieldByType: ingestFieldByType$m,
        createLink: createLink,
        mergeData: mergeData$m,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "ListOrder",
            version: VERSION$w,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$m(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$C(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$m(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ResultOrder': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$n(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$m, getFieldType$C, selectType$m, parentRecordId);
}
function buildSelectionForNode$n(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$n, buildSelectionForField$n, parentRecordId);
}
function select$y(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$n, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$E() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$p(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$q(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$m
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$C(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'fieldApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'sortDirection': {
            return {
                isArray: false,
                typename: 'ResultOrder'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$m(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ResultOrder': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$m(field) {
    return false;
}
function isFragmentApplicable$n(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "ListOrder", typename);
}
function getInContextFragmentType$D(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$l = 'RelatedListInfo';
const TTL$3 = 900000;
const VERSION$v = 'a32cfdff7ca8dcf4b534b3491fef2019';
function keyBuilder$p(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$l(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$o(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$p(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$m,
        isMappedFieldImport: isMappedField$l,
        getFieldType: getFieldType$B,
        ingestFieldByType: ingestFieldByType$l,
        createLink: createLink,
        mergeData: mergeData$l,
        storeMetadataParams: {
            ttl: TTL$3,
            namespace: keyPrefix,
            representationName: "RelatedListInfo",
            version: VERSION$v,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$l(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$B(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$l(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ListColumn': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$x, select$z, false);
            break;
        }
        case 'ListOrder': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$w, select$y, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$m(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$l, getFieldType$B, selectType$l, parentRecordId);
}
function buildSelectionForNode$m(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$m, buildSelectionForField$m, parentRecordId);
}
function select$x(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$m, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$D() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$o(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$p(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$l
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$m) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$B(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'ListColumn': {
                const fullPath__displayColumns = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__displayColumns + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$q(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'ListOrder': {
                const fullPath__orderedByInfo = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__orderedByInfo + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$p(cacheKeySink, requestedField, itemState);
                }
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$B(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'childApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'relatedListName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'label': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'displayColumns': {
            return {
                isArray: true,
                typename: 'ListColumn'
            };
        }
        case 'orderedByInfo': {
            return {
                isArray: true,
                typename: 'ListOrder'
            };
        }
        case 'parentApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'fieldApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$l(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ListColumn': {
            const ListColumnState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$q(requestedField, ListColumnState);
            break;
        }
        case 'ListOrder': {
            const ListOrderState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$p(requestedField, ListOrderState);
            break;
        }
    }
}
function isMappedField$l(field) {
    return false;
}
function isFragmentApplicable$m(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "RelatedListInfo", typename);
}
function getInContextFragmentType$C(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$k = 'UIAPI';
const VERSION$u = '86b00be929ac510584ee034a4df812ea';
function keyBuilder$o(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$k(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$n(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$o(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$l,
        isMappedFieldImport: isMappedField$k,
        getFieldType: getFieldType$A,
        ingestFieldByType: ingestFieldByType$k,
        createLink: createLink,
        mergeData: mergeData$k,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "UIAPI",
            version: VERSION$u,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$k(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$A(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$k(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'RecordQuery': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$10, select$12, false);
            break;
        }
        case 'RecordQueryAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$G, select$I, false);
            break;
        }
        case 'ObjectInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$y, select$A, false);
            break;
        }
        case 'RelatedListInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$v, select$x, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$l(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$k, getFieldType$A, selectType$k, parentRecordId);
}
function buildSelectionForNode$l(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$l, buildSelectionForField$l, parentRecordId);
}
function select$w(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$l, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$C() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$n(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$o(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$k
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$l) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$A(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'RecordQuery': {
                const queryState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$V(cacheKeySink, requestedField, queryState);
                break;
            }
            case 'RecordQueryAggregate': {
                const aggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$z(cacheKeySink, requestedField, aggregateState);
                break;
            }
            case 'ObjectInfo': {
                const fullPath__objectInfos = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__objectInfos + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$r(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'RelatedListInfo': {
                const relatedListByNameState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$o(cacheKeySink, requestedField, relatedListByNameState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$A(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'query': {
            return {
                isArray: false,
                typename: 'RecordQuery'
            };
        }
        case 'aggregate': {
            return {
                isArray: false,
                typename: 'RecordQueryAggregate'
            };
        }
        case 'objectInfos': {
            return {
                isArray: true,
                typename: 'ObjectInfo'
            };
        }
        case 'relatedListByName': {
            return {
                isArray: false,
                typename: 'RelatedListInfo'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$k(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'RecordQuery': {
            const RecordQueryState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$V(requestedField, RecordQueryState);
            break;
        }
        case 'RecordQueryAggregate': {
            const RecordQueryAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$z(requestedField, RecordQueryAggregateState);
            break;
        }
        case 'ObjectInfo': {
            const ObjectInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$r(requestedField, ObjectInfoState);
            break;
        }
        case 'RelatedListInfo': {
            const RelatedListInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$o(requestedField, RelatedListInfoState);
            break;
        }
    }
}
function isMappedField$k(field) {
    return false;
}
function isFragmentApplicable$l(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "UIAPI", typename);
}
function getInContextFragmentType$B(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$j = 'Analytics__AnalyticsWorkspace';
const VERSION$t = 'bffae11a51f3d226cfaab2a3f3d33ac7';
function keyBuilder$n(luvio, path, data) {
    return keyPrefix + '::uiapi::' + name$j + '::' + data.Id; // We're missing idNodeName in the actual key here...
}
function mergeData$j(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$m(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$n(luvio, path, data);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$k,
        isMappedFieldImport: isMappedField$j,
        getFieldType: getFieldType$z,
        ingestFieldByType: ingestFieldByType$j,
        createLink: createLink,
        mergeData: mergeData$j,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsWorkspace",
            version: VERSION$t,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$j(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$z(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$j(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'StringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1t, select$1t, false);
            break;
        }
        case 'IDValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1r, select$1r, false);
            break;
        }
        case 'DateTimeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1q, select$1q, false);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$k(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$j, getFieldType$z, selectType$j, parentRecordId);
}
function buildSelectionForNode$k(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$k, buildSelectionForField$k, parentRecordId);
}
function select$v(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        reader.markSeenId(parentRecordId); // Always mark identifiable types as seen
        return selectCalculateSink(sink, field, buildSelectionForNode$k, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$B() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$m(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$n(luvio, path, data);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$j
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$k) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$z(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'StringValue': {
                const MasterLabelState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, MasterLabelState);
                break;
            }
            case 'StringValue': {
                const DeveloperNameState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, DeveloperNameState);
                break;
            }
            case 'IDValue': {
                const CreatedByIdState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, CreatedByIdState);
                break;
            }
            case 'IDValue': {
                const LastModifiedByIdState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, LastModifiedByIdState);
                break;
            }
            case 'DateTimeValue': {
                const LastModifiedDateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, LastModifiedDateState);
                break;
            }
            case 'DateTimeValue': {
                const CreatedDateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, CreatedDateState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$z(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'MasterLabel': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'DeveloperName': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'CreatedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'CreatedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$j(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'StringValue': {
            const StringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1k(requestedField, StringValueState);
            break;
        }
        case 'IDValue': {
            const IDValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1i(requestedField, IDValueState);
            break;
        }
        case 'DateTimeValue': {
            const DateTimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1h(requestedField, DateTimeValueState);
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$j(field) {
    return false;
}
function isFragmentApplicable$k(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__AnalyticsWorkspace", typename);
}
function getInContextFragmentType$A(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$i = 'Analytics__AnalyticsWorkspaceAsset';
const VERSION$s = 'c6366c7948f7ccacf02a144c87c0ca0b';
function keyBuilder$m(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$i(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$l(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$m(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$j,
        isMappedFieldImport: isMappedField$i,
        getFieldType: getFieldType$y,
        ingestFieldByType: ingestFieldByType$i,
        createLink: createLink,
        mergeData: mergeData$i,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsWorkspaceAsset",
            version: VERSION$s,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$i(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$y(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$i(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsWorkspace': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$t, select$v, false);
            break;
        }
        case 'PicklistValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1c, select$1c, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$j(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$i, getFieldType$y, selectType$i, parentRecordId);
}
function buildSelectionForNode$j(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$j, buildSelectionForField$j, parentRecordId);
}
function select$u(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$j, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$A() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$l(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$m(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$i
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$j) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$y(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Analytics__AnalyticsWorkspace': {
                const AnalyticsWorkspaceState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$m(cacheKeySink, requestedField, AnalyticsWorkspaceState);
                break;
            }
            case 'PicklistValue': {
                const AssetUsageTypeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$16(cacheKeySink, requestedField, AssetUsageTypeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$y(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'AnalyticsWorkspace': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsWorkspace'
            };
        }
        case 'AssetUsageType': {
            return {
                isArray: false,
                typename: 'PicklistValue'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$i(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsWorkspace': {
            const Analytics__AnalyticsWorkspaceState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$m(requestedField, Analytics__AnalyticsWorkspaceState);
            break;
        }
        case 'PicklistValue': {
            const PicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$13(requestedField, PicklistValueState);
            break;
        }
    }
}
function isMappedField$i(field) {
    return false;
}
function isFragmentApplicable$j(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__AnalyticsWorkspaceAsset", typename);
}
function getInContextFragmentType$z(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$h = 'Analytics__AnalyticsWorkspaceAssetEdge';
const VERSION$r = '59034a43231eec177f353ead0325ff66';
function keyBuilder$l(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$h(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$k(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$l(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$i,
        isMappedFieldImport: isMappedField$h,
        getFieldType: getFieldType$x,
        ingestFieldByType: ingestFieldByType$h,
        createLink: createLink,
        mergeData: mergeData$h,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsWorkspaceAssetEdge",
            version: VERSION$r,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$h(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$x(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$h(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsWorkspaceAsset': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$s, select$u, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$i(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$h, getFieldType$x, selectType$h, parentRecordId);
}
function buildSelectionForNode$i(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$i, buildSelectionForField$i, parentRecordId);
}
function select$t(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$i, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$z() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$k(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$l(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$h
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$i) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$x(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Analytics__AnalyticsWorkspaceAsset': {
                const nodeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$l(cacheKeySink, requestedField, nodeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$x(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsWorkspaceAsset'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$h(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsWorkspaceAsset': {
            const Analytics__AnalyticsWorkspaceAssetState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$l(requestedField, Analytics__AnalyticsWorkspaceAssetState);
            break;
        }
    }
}
function isMappedField$h(field) {
    return false;
}
function isFragmentApplicable$i(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__AnalyticsWorkspaceAssetEdge", typename);
}
function getInContextFragmentType$y(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$g = 'Analytics__AnalyticsWorkspaceAssetConnection';
const VERSION$q = '4fcd92af2b51c70cd9164767a7f28c75';
function keyBuilder$k(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$g(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingestPaginationMetadata$2(astNode, state, key, sink, existingData) {
    const { data, luvio, store } = state;
    const { pageInfo: { hasNextPage, startCursor }, edges } = data;
    if (!hasGraphQLPaginationFields(data))
        return;
    const paginationKey = key + '__pagination';
    let existingPaginationMetadata = store.readEntry(paginationKey);
    const afterArg = astNode.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', state.variables);
    const isPagedResponse = afterArgVal !== undefined &&
        existingPaginationMetadata !== undefined &&
        existingPaginationMetadata[afterArgVal] !== undefined;
    if (isPagedResponse && existingPaginationMetadata !== undefined) {
        const previousPageOffset = existingPaginationMetadata[afterArgVal];
        existingPaginationMetadata = {
            ...existingPaginationMetadata,
            [startCursor]: previousPageOffset + 1,
        };
    }
    // Default to a zero offset if we're not a result of a paged request
    const startOffset = isPagedResponse && existingPaginationMetadata !== undefined
        ? offsetFromToken(existingPaginationMetadata, startCursor)
        : 0;
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0) {
            throw new RangeError(`Cursor value ${startCursor} is not recognized. Cannot ingest the returned page. After: ${afterArgVal}`);
        }
    }
    const nextOffset = startOffset + edges.length;
    const incomingPaginationMetadata = createPaginationMetadata(startOffset, edges);
    if (hasNextPage) {
        // we know the data extends beyond NEXT_OFFSET_IDENTIFIER; clean up any old __END__ markers that say the data ended at/before that offset
        if (existingPaginationMetadata !== undefined && existingPaginationMetadata.__END__ !== undefined && existingPaginationMetadata.__END__ <= nextOffset) {
            existingPaginationMetadata = { ...existingPaginationMetadata };
            delete existingPaginationMetadata.__END__;
        }
    }
    else {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    // store the updated pagination metadata
    const mergedPaginationMetadata = mergeMetadata(existingPaginationMetadata, incomingPaginationMetadata);
    luvio.storePublish(paginationKey, mergedPaginationMetadata);
    luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata);
    // merge the edges
    assignMetadataLink(sink, paginationKey);
    const existingRecord = existingData ? existingData.data : undefined;
    if (existingRecord !== undefined && existingRecord.edges !== undefined) {
        sink.edges = [
            ...existingRecord.edges.slice(0, startOffset),
            ...sink.edges,
            ...existingRecord.edges.slice(nextOffset),
        ];
    }
}
function ingest$j(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$k(luvio, path);
    return ingestCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$h,
        isMappedFieldImport: isMappedField$g,
        getFieldType: getFieldType$w,
        ingestFieldByType: ingestFieldByType$g,
        hasGraphQLPaginationFields: hasGraphQLPaginationFields,
        ingestPaginatedMetadata: ingestPaginationMetadata$2,
        createLink: createLink,
        mergeData: mergeData$g,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsWorkspaceAssetConnection",
            version: VERSION$q,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$g(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$w(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$g(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsWorkspaceAssetEdge': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$r, select$t, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'PageInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$14, select$16, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$h(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, true, getFieldData$g, getFieldType$w, selectType$g, parentRecordId);
}
function buildSelectionForNode$h(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$h, buildSelectionForField$h, parentRecordId);
}
function select$s(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$h, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$y() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        ...getCursorConnectionMinimumSelections()
    ];
    return minimumSelections;
}
function getTypeCacheKeys$j(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$k(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$g
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$h) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$w(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Analytics__AnalyticsWorkspaceAssetEdge': {
                const fullPath__edges = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__edges + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$k(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'PageInfo': {
                const pageInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Z(cacheKeySink, requestedField, pageInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$w(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'Analytics__AnalyticsWorkspaceAssetEdge'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageResultCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$g(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsWorkspaceAssetEdge': {
            const Analytics__AnalyticsWorkspaceAssetEdgeState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$k(requestedField, Analytics__AnalyticsWorkspaceAssetEdgeState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'PageInfo': {
            const PageInfoState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$Z(requestedField, PageInfoState);
            break;
        }
    }
}
function isMappedField$g(field) {
    return false;
}
function isFragmentApplicable$h(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__AnalyticsWorkspaceAssetConnection", typename);
}
function getInContextFragmentType$x(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$f = 'Analytics__AnalyticsRepresentation';
const VERSION$p = '9719233aaf1a82094e73b9cbd55205ac';
function keyBuilder$j(luvio, path, data) {
    return keyPrefix + '::uiapi::' + name$f + '::' + data.Id; // We're missing idNodeName in the actual key here...
}
function mergeData$f(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$i(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$j(luvio, path, data);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$g,
        isMappedFieldImport: isMappedField$f,
        getFieldType: getFieldType$v,
        ingestFieldByType: ingestFieldByType$f,
        createLink: createLink,
        mergeData: mergeData$f,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsRepresentation",
            version: VERSION$p,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$f(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$v(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$f(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'StringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1t, select$1t, false);
            break;
        }
        case 'IDValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1r, select$1r, false);
            break;
        }
        case 'DateTimeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1q, select$1q, false);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsWorkspaceAssetConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$q, select$s, true);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$g(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$f, getFieldType$v, selectType$f, parentRecordId);
}
function buildSelectionForNode$g(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$g, buildSelectionForField$g, parentRecordId);
}
function select$r(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        reader.markSeenId(parentRecordId); // Always mark identifiable types as seen
        return selectCalculateSink(sink, field, buildSelectionForNode$g, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$x() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$i(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$j(luvio, path, data);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$f
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$g) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$v(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'StringValue': {
                const MasterLabelState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, MasterLabelState);
                break;
            }
            case 'StringValue': {
                const DeveloperNameState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, DeveloperNameState);
                break;
            }
            case 'IDValue': {
                const CreatedByIdState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, CreatedByIdState);
                break;
            }
            case 'IDValue': {
                const LastModifiedByIdState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, LastModifiedByIdState);
                break;
            }
            case 'DateTimeValue': {
                const LastModifiedDateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, LastModifiedDateState);
                break;
            }
            case 'DateTimeValue': {
                const CreatedDateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, CreatedDateState);
                break;
            }
            case 'StringValue': {
                const NamespacePrefixState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, NamespacePrefixState);
                break;
            }
            case 'Analytics__AnalyticsWorkspaceAssetConnection': {
                const AnalyticsWorkspacesState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$j(cacheKeySink, requestedField, AnalyticsWorkspacesState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$v(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'MasterLabel': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'DeveloperName': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'CreatedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'CreatedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'NamespacePrefix': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'AnalyticsWorkspaces': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsWorkspaceAssetConnection'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$f(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'StringValue': {
            const StringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1k(requestedField, StringValueState);
            break;
        }
        case 'IDValue': {
            const IDValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1i(requestedField, IDValueState);
            break;
        }
        case 'DateTimeValue': {
            const DateTimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1h(requestedField, DateTimeValueState);
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsWorkspaceAssetConnection': {
            const Analytics__AnalyticsWorkspaceAssetConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$j(requestedField, Analytics__AnalyticsWorkspaceAssetConnectionState);
            break;
        }
    }
}
function isMappedField$f(field) {
    return false;
}
function isFragmentApplicable$g(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, ["Analytics__AnalyticsRepresentationInterface"], "Analytics__AnalyticsRepresentation", typename);
}
function getInContextFragmentType$w(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$e = 'Analytics__AnalyticsEdge';
const VERSION$o = 'bd0e530079262569dd4afee14b0d9b8e';
function keyBuilder$i(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$e(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$h(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$i(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$f,
        isMappedFieldImport: isMappedField$e,
        getFieldType: getFieldType$u,
        ingestFieldByType: ingestFieldByType$e,
        createLink: createLink,
        mergeData: mergeData$e,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsEdge",
            version: VERSION$o,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$e(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$u(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$e(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsRepresentation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$p, select$r, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$f(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$e, getFieldType$u, selectType$e, parentRecordId);
}
function buildSelectionForNode$f(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$f, buildSelectionForField$f, parentRecordId);
}
function select$q(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$f, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$w() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$h(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$i(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$e
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$f) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$u(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Analytics__AnalyticsRepresentation': {
                const nodeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$i(cacheKeySink, requestedField, nodeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$u(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsRepresentation'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$e(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsRepresentation': {
            const Analytics__AnalyticsRepresentationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$i(requestedField, Analytics__AnalyticsRepresentationState);
            break;
        }
    }
}
function isMappedField$e(field) {
    return false;
}
function isFragmentApplicable$f(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__AnalyticsEdge", typename);
}
function getInContextFragmentType$v(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$d = 'Analytics__AnalyticsBrowse';
const VERSION$n = 'de14944e92aa0e199e1e9f72d8d98551';
function keyBuilder$h(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$d(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$g(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$h(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$e,
        isMappedFieldImport: isMappedField$d,
        getFieldType: getFieldType$t,
        ingestFieldByType: ingestFieldByType$d,
        createLink: createLink,
        mergeData: mergeData$d,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__AnalyticsBrowse",
            version: VERSION$n,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$d(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$t(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$d(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsEdge': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$o, select$q, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'PageInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$14, select$16, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$e(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$d, getFieldType$t, selectType$d, parentRecordId);
}
function buildSelectionForNode$e(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$e, buildSelectionForField$e, parentRecordId);
}
function select$p(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$e, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$v() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$g(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$h(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$d
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$e) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$t(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Analytics__AnalyticsEdge': {
                const fullPath__edges = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__edges + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$h(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'PageInfo': {
                const pageInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Z(cacheKeySink, requestedField, pageInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$t(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'Analytics__AnalyticsEdge'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageResultCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$d(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsEdge': {
            const Analytics__AnalyticsEdgeState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$h(requestedField, Analytics__AnalyticsEdgeState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'PageInfo': {
            const PageInfoState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$Z(requestedField, PageInfoState);
            break;
        }
    }
}
function isMappedField$d(field) {
    return false;
}
function isFragmentApplicable$e(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__AnalyticsBrowse", typename);
}
function getInContextFragmentType$u(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$c = 'Analytics__Analytics';
const VERSION$m = '7eb7858d53c6e210d35985480d71a083';
function keyBuilder$g(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$c(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$f(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$g(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$d,
        isMappedFieldImport: isMappedField$c,
        getFieldType: getFieldType$s,
        ingestFieldByType: ingestFieldByType$c,
        createLink: createLink,
        mergeData: mergeData$c,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Analytics__Analytics",
            version: VERSION$m,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$c(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$s(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$c(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Analytics__AnalyticsBrowse': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$n, select$p, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$d(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$c, getFieldType$s, selectType$c, parentRecordId);
}
function buildSelectionForNode$d(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$d, buildSelectionForField$d, parentRecordId);
}
function select$o(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$d, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$u() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$f(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$g(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$c
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$d) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$s(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Analytics__AnalyticsBrowse': {
                const browseState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$g(cacheKeySink, requestedField, browseState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$s(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'browse': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsBrowse'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$c(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Analytics__AnalyticsBrowse': {
            const Analytics__AnalyticsBrowseState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$g(requestedField, Analytics__AnalyticsBrowseState);
            break;
        }
    }
}
function isMappedField$c(field) {
    return false;
}
function isFragmentApplicable$d(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Analytics__Analytics", typename);
}
function getInContextFragmentType$t(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$b = 'SObject__Field';
const VERSION$l = '7acebed646d199da2d0c03c956162517';
function keyBuilder$f(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$b(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$e(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$f(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$c,
        isMappedFieldImport: isMappedField$b,
        getFieldType: getFieldType$r,
        ingestFieldByType: ingestFieldByType$b,
        createLink: createLink,
        mergeData: mergeData$b,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "SObject__Field",
            version: VERSION$l,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$b(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$r(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$b(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$c(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$b, getFieldType$r, selectType$b, parentRecordId);
}
function buildSelectionForNode$c(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$c, buildSelectionForField$c, parentRecordId);
}
function select$n(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$c, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$t() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$e(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$f(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$b
    });
    // get all cache keys from normalizable fields
    // Deal with mapped types' cache keys
}
function getFieldType$r(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'name': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$b(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$b(field) {
    return false;
}
function isFragmentApplicable$c(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "SObject__Field", typename);
}
function getInContextFragmentType$s(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

// union versions are undefined, selected versions must be specific to the type being selected
const VERSION$k = undefined;
function ingest$d(astNode, state) {
    const typename = state.data.__typename;
    // Delegate key building and ingest to concrete implementations
    if (typename === 'Setup__EntityRepresentation') {
        return ingest$c(astNode, state);
    }
}
function select$m(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const typename = source.data.__typename;
        if (typename === 'Setup__EntityRepresentation') {
            return select$l(field, variables, fragments)(source, reader, parentRecordId);
        }
    };
}
function getTypeCacheKeys$d(cacheKeys, astNode, state) {
    const { path, data } = state;
    const typename = data.__typename;
    if (typename === 'Setup__EntityRepresentation') {
        return getTypeCacheKeys$c(cacheKeys, astNode, state);
    }
}
function getInContextFragmentType$r(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}
function getFieldType$q(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getMinimumSelections$s() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}

const name$a = 'Setup__EntityRepresentation';
const VERSION$j = 'd45b0eb67ba6273ed9b38313a773b15a';
function keyBuilder$e(luvio, path, data) {
    return keyPrefix + '::uiapi::' + name$a + '::' + data.Id; // We're missing idNodeName in the actual key here...
}
function mergeData$a(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$c(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$e(luvio, path, data);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$b,
        isMappedFieldImport: isMappedField$a,
        getFieldType: getFieldType$p,
        ingestFieldByType: ingestFieldByType$a,
        createLink: createLink,
        mergeData: mergeData$a,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__EntityRepresentation",
            version: VERSION$j,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$a(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$p(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$a(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'ID': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'IntValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1u, select$1u, false);
            break;
        }
        case 'StringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1t, select$1t, false);
            break;
        }
        case 'BooleanValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1p, select$1p, false);
            break;
        }
        case 'IDValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1r, select$1r, false);
            break;
        }
        case 'DateTimeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1q, select$1q, false);
            break;
        }
        case 'TimeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1o, select$1o, false);
            break;
        }
        case 'DateValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1n, select$1n, false);
            break;
        }
        case 'TextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1m, select$1m, false);
            break;
        }
        case 'LongTextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1l, select$1l, false);
            break;
        }
        case 'RichTextAreaValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1k, select$1k, false);
            break;
        }
        case 'PhoneNumberValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1j, select$1j, false);
            break;
        }
        case 'EmailValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1i, select$1i, false);
            break;
        }
        case 'UrlValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1h, select$1h, false);
            break;
        }
        case 'EncryptedStringValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1g, select$1g, false);
            break;
        }
        case 'SObject__Field': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$l, select$n, false);
            break;
        }
        case 'CurrencyValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1f, select$1f, false);
            break;
        }
        case 'LongitudeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1e, select$1e, false);
            break;
        }
        case 'LatitudeValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1d, select$1d, false);
            break;
        }
        case 'PicklistValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1c, select$1c, false);
            break;
        }
        case 'MultiPicklistValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1b, select$1b, false);
            break;
        }
        case 'LongValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1x, select$1x, false);
            break;
        }
        case 'DoubleValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1y, select$1y, false);
            break;
        }
        case 'PercentValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1w, select$1w, false);
            break;
        }
        case 'Base64Value': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1a, select$1a, false);
            break;
        }
        case 'JSONValue': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$19, select$19, false);
            break;
        }
        case 'Setup__EntityRepresentation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$j, select$l, false);
            break;
        }
        case 'Setup__SetupPolymorphicParentRelationship': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$k, select$m, false);
            break;
        }
        case 'Setup__SetupConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$h, select$j, true);
            break;
        }
        case 'CompoundField': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$15, select$17, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$b(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$a, getFieldType$p, selectType$a, parentRecordId);
}
function buildSelectionForNode$b(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$b, buildSelectionForField$b, parentRecordId);
}
function select$l(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        reader.markSeenId(parentRecordId); // Always mark identifiable types as seen
        return selectCalculateSink(sink, field, buildSelectionForNode$b, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$r() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$c(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$e(luvio, path, data);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$a
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$b) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$p(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'IntValue': {
                const IntValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1o(cacheKeySink, requestedField, IntValueState);
                break;
            }
            case 'StringValue': {
                const StringValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1n(cacheKeySink, requestedField, StringValueState);
                break;
            }
            case 'BooleanValue': {
                const BooleanValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1j(cacheKeySink, requestedField, BooleanValueState);
                break;
            }
            case 'IDValue': {
                const IDValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1l(cacheKeySink, requestedField, IDValueState);
                break;
            }
            case 'DateTimeValue': {
                const DateTimeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1k(cacheKeySink, requestedField, DateTimeValueState);
                break;
            }
            case 'TimeValue': {
                const TimeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1i(cacheKeySink, requestedField, TimeValueState);
                break;
            }
            case 'DateValue': {
                const DateValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1h(cacheKeySink, requestedField, DateValueState);
                break;
            }
            case 'TextAreaValue': {
                const TextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1g(cacheKeySink, requestedField, TextAreaValueState);
                break;
            }
            case 'LongTextAreaValue': {
                const LongTextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1f(cacheKeySink, requestedField, LongTextAreaValueState);
                break;
            }
            case 'RichTextAreaValue': {
                const RichTextAreaValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1e(cacheKeySink, requestedField, RichTextAreaValueState);
                break;
            }
            case 'PhoneNumberValue': {
                const PhoneNumberValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1d(cacheKeySink, requestedField, PhoneNumberValueState);
                break;
            }
            case 'EmailValue': {
                const EmailValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1c(cacheKeySink, requestedField, EmailValueState);
                break;
            }
            case 'UrlValue': {
                const UrlValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1b(cacheKeySink, requestedField, UrlValueState);
                break;
            }
            case 'EncryptedStringValue': {
                const EncryptedStringValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1a(cacheKeySink, requestedField, EncryptedStringValueState);
                break;
            }
            case 'SObject__Field': {
                const fullPath__Entity__fields = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__Entity__fields + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$e(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'CurrencyValue': {
                const CurrencyValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$19(cacheKeySink, requestedField, CurrencyValueState);
                break;
            }
            case 'LongitudeValue': {
                const LongitudeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$18(cacheKeySink, requestedField, LongitudeValueState);
                break;
            }
            case 'LatitudeValue': {
                const LatitudeValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$17(cacheKeySink, requestedField, LatitudeValueState);
                break;
            }
            case 'PicklistValue': {
                const PicklistValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$16(cacheKeySink, requestedField, PicklistValueState);
                break;
            }
            case 'MultiPicklistValue': {
                const MultiPicklistValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$15(cacheKeySink, requestedField, MultiPicklistValueState);
                break;
            }
            case 'LongValue': {
                const LongValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1r(cacheKeySink, requestedField, LongValueState);
                break;
            }
            case 'DoubleValue': {
                const DoubleValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1s(cacheKeySink, requestedField, DoubleValueState);
                break;
            }
            case 'PercentValue': {
                const PercentValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1q(cacheKeySink, requestedField, PercentValueState);
                break;
            }
            case 'Base64Value': {
                const Base64ValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$14(cacheKeySink, requestedField, Base64ValueState);
                break;
            }
            case 'JSONValue': {
                const JSONValueState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$13(cacheKeySink, requestedField, JSONValueState);
                break;
            }
            case 'Setup__EntityRepresentation': {
                const parentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$c(cacheKeySink, requestedField, parentRelationshipState);
                break;
            }
            case 'Setup__SetupPolymorphicParentRelationship': {
                const polymorphicParentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$d(cacheKeySink, requestedField, polymorphicParentRelationshipState);
                break;
            }
            case 'Setup__SetupConnection': {
                const childRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$a(cacheKeySink, requestedField, childRelationshipState);
                break;
            }
            case 'CompoundField': {
                const CompoundFieldState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$_(cacheKeySink, requestedField, CompoundFieldState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$p(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'IntValue': {
            return {
                isArray: false,
                typename: 'IntValue'
            };
        }
        case 'StringValue': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'BooleanValue': {
            return {
                isArray: false,
                typename: 'BooleanValue'
            };
        }
        case 'IDValue': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'DateTimeValue': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'TimeValue': {
            return {
                isArray: false,
                typename: 'TimeValue'
            };
        }
        case 'DateValue': {
            return {
                isArray: false,
                typename: 'DateValue'
            };
        }
        case 'TextAreaValue': {
            return {
                isArray: false,
                typename: 'TextAreaValue'
            };
        }
        case 'LongTextAreaValue': {
            return {
                isArray: false,
                typename: 'LongTextAreaValue'
            };
        }
        case 'RichTextAreaValue': {
            return {
                isArray: false,
                typename: 'RichTextAreaValue'
            };
        }
        case 'PhoneNumberValue': {
            return {
                isArray: false,
                typename: 'PhoneNumberValue'
            };
        }
        case 'EmailValue': {
            return {
                isArray: false,
                typename: 'EmailValue'
            };
        }
        case 'UrlValue': {
            return {
                isArray: false,
                typename: 'UrlValue'
            };
        }
        case 'EncryptedStringValue': {
            return {
                isArray: false,
                typename: 'EncryptedStringValue'
            };
        }
        case 'Entity__fields': {
            return {
                isArray: true,
                typename: 'SObject__Field'
            };
        }
        case 'CurrencyValue': {
            return {
                isArray: false,
                typename: 'CurrencyValue'
            };
        }
        case 'LongitudeValue': {
            return {
                isArray: false,
                typename: 'LongitudeValue'
            };
        }
        case 'LatitudeValue': {
            return {
                isArray: false,
                typename: 'LatitudeValue'
            };
        }
        case 'PicklistValue': {
            return {
                isArray: false,
                typename: 'PicklistValue'
            };
        }
        case 'MultiPicklistValue': {
            return {
                isArray: false,
                typename: 'MultiPicklistValue'
            };
        }
        case 'LongValue': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'DoubleValue': {
            return {
                isArray: false,
                typename: 'DoubleValue'
            };
        }
        case 'PercentValue': {
            return {
                isArray: false,
                typename: 'PercentValue'
            };
        }
        case 'Base64Value': {
            return {
                isArray: false,
                typename: 'Base64Value'
            };
        }
        case 'JSONValue': {
            return {
                isArray: false,
                typename: 'JSONValue'
            };
        }
        case 'parentRelationship': {
            return {
                isArray: false,
                typename: 'Setup__EntityRepresentation'
            };
        }
        case 'polymorphicParentRelationship': {
            return {
                isArray: false,
                typename: 'Setup__SetupPolymorphicParentRelationship'
            };
        }
        case 'childRelationship': {
            return {
                isArray: false,
                typename: 'Setup__SetupConnection'
            };
        }
        case 'CompoundField': {
            return {
                isArray: false,
                typename: 'CompoundField'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$a(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'ID': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'IntValue': {
            const IntValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1l(requestedField, IntValueState);
            break;
        }
        case 'StringValue': {
            const StringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1k(requestedField, StringValueState);
            break;
        }
        case 'BooleanValue': {
            const BooleanValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1g(requestedField, BooleanValueState);
            break;
        }
        case 'IDValue': {
            const IDValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1i(requestedField, IDValueState);
            break;
        }
        case 'DateTimeValue': {
            const DateTimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1h(requestedField, DateTimeValueState);
            break;
        }
        case 'TimeValue': {
            const TimeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1f(requestedField, TimeValueState);
            break;
        }
        case 'DateValue': {
            const DateValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1e(requestedField, DateValueState);
            break;
        }
        case 'TextAreaValue': {
            const TextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1d(requestedField, TextAreaValueState);
            break;
        }
        case 'LongTextAreaValue': {
            const LongTextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1c(requestedField, LongTextAreaValueState);
            break;
        }
        case 'RichTextAreaValue': {
            const RichTextAreaValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1b(requestedField, RichTextAreaValueState);
            break;
        }
        case 'PhoneNumberValue': {
            const PhoneNumberValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1a(requestedField, PhoneNumberValueState);
            break;
        }
        case 'EmailValue': {
            const EmailValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$19(requestedField, EmailValueState);
            break;
        }
        case 'UrlValue': {
            const UrlValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$18(requestedField, UrlValueState);
            break;
        }
        case 'EncryptedStringValue': {
            const EncryptedStringValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$17(requestedField, EncryptedStringValueState);
            break;
        }
        case 'SObject__Field': {
            const SObject__FieldState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$e(requestedField, SObject__FieldState);
            break;
        }
        case 'CurrencyValue': {
            const CurrencyValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$16(requestedField, CurrencyValueState);
            break;
        }
        case 'LongitudeValue': {
            const LongitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$15(requestedField, LongitudeValueState);
            break;
        }
        case 'LatitudeValue': {
            const LatitudeValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$14(requestedField, LatitudeValueState);
            break;
        }
        case 'PicklistValue': {
            const PicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$13(requestedField, PicklistValueState);
            break;
        }
        case 'MultiPicklistValue': {
            const MultiPicklistValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$12(requestedField, MultiPicklistValueState);
            break;
        }
        case 'LongValue': {
            const LongValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1o(requestedField, LongValueState);
            break;
        }
        case 'DoubleValue': {
            const DoubleValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1p(requestedField, DoubleValueState);
            break;
        }
        case 'PercentValue': {
            const PercentValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1n(requestedField, PercentValueState);
            break;
        }
        case 'Base64Value': {
            const Base64ValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$11(requestedField, Base64ValueState);
            break;
        }
        case 'JSONValue': {
            const JSONValueState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$10(requestedField, JSONValueState);
            break;
        }
        case 'Setup__EntityRepresentation': {
            const Setup__EntityRepresentationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$c(requestedField, Setup__EntityRepresentationState);
            break;
        }
        case 'Setup__SetupPolymorphicParentRelationship': {
            const Setup__SetupPolymorphicParentRelationshipState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$d(requestedField, Setup__SetupPolymorphicParentRelationshipState);
            break;
        }
        case 'Setup__SetupConnection': {
            const Setup__SetupConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$a(requestedField, Setup__SetupConnectionState);
            break;
        }
        case 'CompoundField': {
            const CompoundFieldState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$_(requestedField, CompoundFieldState);
            break;
        }
    }
}
function isMappedField$a(field) {
    return false;
}
function isFragmentApplicable$b(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__EntityRepresentation", typename);
}
function getInContextFragmentType$q(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$9 = 'Setup__SetupEdge';
const VERSION$i = 'b62a2103dcf86300f0ad705b5694328e';
function keyBuilder$d(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$9(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$b(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$d(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$a,
        isMappedFieldImport: isMappedField$9,
        getFieldType: getFieldType$o,
        ingestFieldByType: ingestFieldByType$9,
        createLink: createLink,
        mergeData: mergeData$9,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupEdge",
            version: VERSION$i,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$9(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$o(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$9(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__EntityRepresentation': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$j, select$l, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$a(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$9, getFieldType$o, selectType$9, parentRecordId);
}
function buildSelectionForNode$a(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$a, buildSelectionForField$a, parentRecordId);
}
function select$k(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$a, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$q() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$b(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$d(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$9
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$a) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$o(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__EntityRepresentation': {
                const nodeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$c(cacheKeySink, requestedField, nodeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$o(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'Setup__EntityRepresentation'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$9(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__EntityRepresentation': {
            const Setup__EntityRepresentationState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$c(requestedField, Setup__EntityRepresentationState);
            break;
        }
    }
}
function isMappedField$9(field) {
    return false;
}
function isFragmentApplicable$a(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupEdge", typename);
}
function getInContextFragmentType$p(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$8 = 'Setup__SetupConnection';
const VERSION$h = '02512d7a4706e18f377cc4abf3094579';
function keyBuilder$c(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$8(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingestPaginationMetadata$1(astNode, state, key, sink, existingData) {
    const { data, luvio, store } = state;
    const { pageInfo: { hasNextPage, startCursor }, edges } = data;
    if (!hasGraphQLPaginationFields(data))
        return;
    const paginationKey = key + '__pagination';
    let existingPaginationMetadata = store.readEntry(paginationKey);
    const afterArg = astNode.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', state.variables);
    const isPagedResponse = afterArgVal !== undefined &&
        existingPaginationMetadata !== undefined &&
        existingPaginationMetadata[afterArgVal] !== undefined;
    if (isPagedResponse && existingPaginationMetadata !== undefined) {
        const previousPageOffset = existingPaginationMetadata[afterArgVal];
        existingPaginationMetadata = {
            ...existingPaginationMetadata,
            [startCursor]: previousPageOffset + 1,
        };
    }
    // Default to a zero offset if we're not a result of a paged request
    const startOffset = isPagedResponse && existingPaginationMetadata !== undefined
        ? offsetFromToken(existingPaginationMetadata, startCursor)
        : 0;
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0) {
            throw new RangeError(`Cursor value ${startCursor} is not recognized. Cannot ingest the returned page. After: ${afterArgVal}`);
        }
    }
    const nextOffset = startOffset + edges.length;
    const incomingPaginationMetadata = createPaginationMetadata(startOffset, edges);
    if (hasNextPage) {
        // we know the data extends beyond NEXT_OFFSET_IDENTIFIER; clean up any old __END__ markers that say the data ended at/before that offset
        if (existingPaginationMetadata !== undefined && existingPaginationMetadata.__END__ !== undefined && existingPaginationMetadata.__END__ <= nextOffset) {
            existingPaginationMetadata = { ...existingPaginationMetadata };
            delete existingPaginationMetadata.__END__;
        }
    }
    else {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    // store the updated pagination metadata
    const mergedPaginationMetadata = mergeMetadata(existingPaginationMetadata, incomingPaginationMetadata);
    luvio.storePublish(paginationKey, mergedPaginationMetadata);
    luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata);
    // merge the edges
    assignMetadataLink(sink, paginationKey);
    const existingRecord = existingData ? existingData.data : undefined;
    if (existingRecord !== undefined && existingRecord.edges !== undefined) {
        sink.edges = [
            ...existingRecord.edges.slice(0, startOffset),
            ...sink.edges,
            ...existingRecord.edges.slice(nextOffset),
        ];
    }
}
function ingest$a(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$c(luvio, path);
    return ingestCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$9,
        isMappedFieldImport: isMappedField$8,
        getFieldType: getFieldType$n,
        ingestFieldByType: ingestFieldByType$8,
        hasGraphQLPaginationFields: hasGraphQLPaginationFields,
        ingestPaginatedMetadata: ingestPaginationMetadata$1,
        createLink: createLink,
        mergeData: mergeData$8,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupConnection",
            version: VERSION$h,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$8(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$n(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$8(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupEdge': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$i, select$k, false);
            break;
        }
        case 'PageInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$14, select$16, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$9(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, true, getFieldData$8, getFieldType$n, selectType$8, parentRecordId);
}
function buildSelectionForNode$9(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$9, buildSelectionForField$9, parentRecordId);
}
function select$j(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$9, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$p() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        ...getCursorConnectionMinimumSelections()
    ];
    return minimumSelections;
}
function getTypeCacheKeys$a(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$c(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$8
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$9) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$n(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupEdge': {
                const fullPath__edges = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__edges + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$b(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'PageInfo': {
                const pageInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Z(cacheKeySink, requestedField, pageInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$n(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'Setup__SetupEdge'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageResultCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$8(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupEdge': {
            const Setup__SetupEdgeState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$b(requestedField, Setup__SetupEdgeState);
            break;
        }
        case 'PageInfo': {
            const PageInfoState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$Z(requestedField, PageInfoState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$8(field) {
    return false;
}
function isFragmentApplicable$9(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupConnection", typename);
}
function getInContextFragmentType$o(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getFieldType$m(field) {
    const fieldName = field.name.value;
    switch (fieldName) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        /*
            Probably should use metaschema like the RecordQuery graphql-artifact,
            but this type only has one generic type possible. Also, the most likely scenario for future schema additions,
            is UISDK adding the the parent of this type, Setup__Setup. Therefore, we will just default to SetupConnection so that
            query authors don't need to use metaschema when there's no real decision point in this type.
         */
        default:
            return {
                isArray: false,
                typename: 'Setup__SetupConnection',
            };
    }
}

const name$7 = 'Setup__SetupQuery';
const VERSION$g = 'b89cccb5fa5e458d89dc1137af3e5469';
function keyBuilder$b(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$7(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$9(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$b(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$8,
        isMappedFieldImport: isMappedField$7,
        getFieldType: getFieldType$m,
        ingestFieldByType: ingestFieldByType$7,
        createLink: createLink,
        mergeData: mergeData$7,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupQuery",
            version: VERSION$g,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$7(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$m(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$7(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$h, select$j, true);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$8(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$7, getFieldType$m, selectType$7, parentRecordId);
}
function buildSelectionForNode$8(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$8, buildSelectionForField$8, parentRecordId);
}
function select$i(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$8, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$o() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$9(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$b(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$7
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$8) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$m(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupConnection': {
                const recordQueryState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$a(cacheKeySink, requestedField, recordQueryState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function ingestFieldByType$7(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupConnection': {
            const Setup__SetupConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$a(requestedField, Setup__SetupConnectionState);
            break;
        }
    }
}
function isMappedField$7(field) {
    return false;
}
function isFragmentApplicable$8(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupQuery", typename);
}
function getInContextFragmentType$n(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

// union versions are undefined, selected versions must be specific to the type being selected
const VERSION$f = undefined;
function ingest$8(astNode, state) {
    const typename = state.data.__typename;
    // Delegate key building and ingest to concrete implementations
    if (typename === 'Setup__SetupRecordAggregate') {
        return ingest$7(astNode, state);
    }
}
function select$h(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const typename = source.data.__typename;
        if (typename === 'Setup__SetupRecordAggregate') {
            return select$g(field, variables, fragments)(source, reader, parentRecordId);
        }
    };
}
function getTypeCacheKeys$8(cacheKeys, astNode, state) {
    const { path, data } = state;
    const typename = data.__typename;
    if (typename === 'Setup__SetupRecordAggregate') {
        return getTypeCacheKeys$7(cacheKeys, astNode, state);
    }
}
function getInContextFragmentType$m(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}
function getFieldType$l(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getMinimumSelections$n() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}

const name$6 = 'Setup__SetupRecordAggregate';
const VERSION$e = '47f8092aa692ffc3ab1a2cc12b530dbc';
function keyBuilder$a(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$6(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$7(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$a(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$7,
        isMappedFieldImport: isMappedField$6,
        getFieldType: getFieldType$k,
        ingestFieldByType: ingestFieldByType$6,
        createLink: createLink,
        mergeData: mergeData$6,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupRecordAggregate",
            version: VERSION$e,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$6(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$k(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$6(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'BooleanAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$$, select$11, false);
            break;
        }
        case 'CurrencyAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$_, select$10, false);
            break;
        }
        case 'DateAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$Y, select$_, false);
            break;
        }
        case 'DoubleAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$X, select$Z, false);
            break;
        }
        case 'EmailAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$W, select$Y, false);
            break;
        }
        case 'IDAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$V, select$X, false);
            break;
        }
        case 'IntAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$U, select$W, false);
            break;
        }
        case 'LatitudeAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$T, select$V, false);
            break;
        }
        case 'LongAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$R, select$T, false);
            break;
        }
        case 'LongitudeAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$S, select$U, false);
            break;
        }
        case 'PercentAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1v, select$1v, false);
            break;
        }
        case 'PhoneNumberAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$Q, select$S, false);
            break;
        }
        case 'PicklistAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$P, select$R, false);
            break;
        }
        case 'StringAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$1s, select$1s, false);
            break;
        }
        case 'TextAreaAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$O, select$Q, false);
            break;
        }
        case 'TimeAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$N, select$P, false);
            break;
        }
        case 'UrlAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$M, select$O, false);
            break;
        }
        case 'Setup__SetupRecordAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$e, select$g, false);
            break;
        }
        case 'Setup__SetupPolymorphicAggregateParentRelationship': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$f, select$h, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$7(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$6, getFieldType$k, selectType$6, parentRecordId);
}
function buildSelectionForNode$7(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$7, buildSelectionForField$7, parentRecordId);
}
function select$g(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$7, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$m() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$7(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$a(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$6
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$7) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$k(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'BooleanAggregate': {
                const BooleanAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$U(cacheKeySink, requestedField, BooleanAggregateState);
                break;
            }
            case 'CurrencyAggregate': {
                const CurrencyAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$T(cacheKeySink, requestedField, CurrencyAggregateState);
                break;
            }
            case 'DateAggregate': {
                const DateAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$R(cacheKeySink, requestedField, DateAggregateState);
                break;
            }
            case 'DoubleAggregate': {
                const DoubleAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Q(cacheKeySink, requestedField, DoubleAggregateState);
                break;
            }
            case 'EmailAggregate': {
                const EmailAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$P(cacheKeySink, requestedField, EmailAggregateState);
                break;
            }
            case 'IDAggregate': {
                const IDAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$O(cacheKeySink, requestedField, IDAggregateState);
                break;
            }
            case 'IntAggregate': {
                const IntAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$N(cacheKeySink, requestedField, IntAggregateState);
                break;
            }
            case 'LatitudeAggregate': {
                const LatitudeAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$M(cacheKeySink, requestedField, LatitudeAggregateState);
                break;
            }
            case 'LongAggregate': {
                const LongAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$K(cacheKeySink, requestedField, LongAggregateState);
                break;
            }
            case 'LongitudeAggregate': {
                const LongitudeAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$L(cacheKeySink, requestedField, LongitudeAggregateState);
                break;
            }
            case 'PercentAggregate': {
                const PercentAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1p(cacheKeySink, requestedField, PercentAggregateState);
                break;
            }
            case 'PhoneNumberAggregate': {
                const PhoneNumberAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$J(cacheKeySink, requestedField, PhoneNumberAggregateState);
                break;
            }
            case 'PicklistAggregate': {
                const PicklistAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$I(cacheKeySink, requestedField, PicklistAggregateState);
                break;
            }
            case 'StringAggregate': {
                const StringAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$1m(cacheKeySink, requestedField, StringAggregateState);
                break;
            }
            case 'TextAreaAggregate': {
                const TextAreaAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$H(cacheKeySink, requestedField, TextAreaAggregateState);
                break;
            }
            case 'TimeAggregate': {
                const TimeAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$G(cacheKeySink, requestedField, TimeAggregateState);
                break;
            }
            case 'UrlAggregate': {
                const UrlAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$F(cacheKeySink, requestedField, UrlAggregateState);
                break;
            }
            case 'Setup__SetupRecordAggregate': {
                const parentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$7(cacheKeySink, requestedField, parentRelationshipState);
                break;
            }
            case 'Setup__SetupPolymorphicAggregateParentRelationship': {
                const polymorphicParentRelationshipState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$8(cacheKeySink, requestedField, polymorphicParentRelationshipState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$k(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'BooleanAggregate': {
            return {
                isArray: false,
                typename: 'BooleanAggregate'
            };
        }
        case 'CurrencyAggregate': {
            return {
                isArray: false,
                typename: 'CurrencyAggregate'
            };
        }
        case 'DateAggregate': {
            return {
                isArray: false,
                typename: 'DateAggregate'
            };
        }
        case 'DoubleAggregate': {
            return {
                isArray: false,
                typename: 'DoubleAggregate'
            };
        }
        case 'EmailAggregate': {
            return {
                isArray: false,
                typename: 'EmailAggregate'
            };
        }
        case 'IDAggregate': {
            return {
                isArray: false,
                typename: 'IDAggregate'
            };
        }
        case 'IntAggregate': {
            return {
                isArray: false,
                typename: 'IntAggregate'
            };
        }
        case 'LatitudeAggregate': {
            return {
                isArray: false,
                typename: 'LatitudeAggregate'
            };
        }
        case 'LongAggregate': {
            return {
                isArray: false,
                typename: 'LongAggregate'
            };
        }
        case 'LongitudeAggregate': {
            return {
                isArray: false,
                typename: 'LongitudeAggregate'
            };
        }
        case 'PercentAggregate': {
            return {
                isArray: false,
                typename: 'PercentAggregate'
            };
        }
        case 'PhoneNumberAggregate': {
            return {
                isArray: false,
                typename: 'PhoneNumberAggregate'
            };
        }
        case 'PicklistAggregate': {
            return {
                isArray: false,
                typename: 'PicklistAggregate'
            };
        }
        case 'StringAggregate': {
            return {
                isArray: false,
                typename: 'StringAggregate'
            };
        }
        case 'TextAreaAggregate': {
            return {
                isArray: false,
                typename: 'TextAreaAggregate'
            };
        }
        case 'TimeAggregate': {
            return {
                isArray: false,
                typename: 'TimeAggregate'
            };
        }
        case 'UrlAggregate': {
            return {
                isArray: false,
                typename: 'UrlAggregate'
            };
        }
        case 'parentRelationship': {
            return {
                isArray: false,
                typename: 'Setup__SetupRecordAggregate'
            };
        }
        case 'polymorphicParentRelationship': {
            return {
                isArray: false,
                typename: 'Setup__SetupPolymorphicAggregateParentRelationship'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$6(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'BooleanAggregate': {
            const BooleanAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$U(requestedField, BooleanAggregateState);
            break;
        }
        case 'CurrencyAggregate': {
            const CurrencyAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$T(requestedField, CurrencyAggregateState);
            break;
        }
        case 'DateAggregate': {
            const DateAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$R(requestedField, DateAggregateState);
            break;
        }
        case 'DoubleAggregate': {
            const DoubleAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$Q(requestedField, DoubleAggregateState);
            break;
        }
        case 'EmailAggregate': {
            const EmailAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$P(requestedField, EmailAggregateState);
            break;
        }
        case 'IDAggregate': {
            const IDAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$O(requestedField, IDAggregateState);
            break;
        }
        case 'IntAggregate': {
            const IntAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$N(requestedField, IntAggregateState);
            break;
        }
        case 'LatitudeAggregate': {
            const LatitudeAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$M(requestedField, LatitudeAggregateState);
            break;
        }
        case 'LongAggregate': {
            const LongAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$K(requestedField, LongAggregateState);
            break;
        }
        case 'LongitudeAggregate': {
            const LongitudeAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$L(requestedField, LongitudeAggregateState);
            break;
        }
        case 'PercentAggregate': {
            const PercentAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1m(requestedField, PercentAggregateState);
            break;
        }
        case 'PhoneNumberAggregate': {
            const PhoneNumberAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$J(requestedField, PhoneNumberAggregateState);
            break;
        }
        case 'PicklistAggregate': {
            const PicklistAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$I(requestedField, PicklistAggregateState);
            break;
        }
        case 'StringAggregate': {
            const StringAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$1j(requestedField, StringAggregateState);
            break;
        }
        case 'TextAreaAggregate': {
            const TextAreaAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$H(requestedField, TextAreaAggregateState);
            break;
        }
        case 'TimeAggregate': {
            const TimeAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$G(requestedField, TimeAggregateState);
            break;
        }
        case 'UrlAggregate': {
            const UrlAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$F(requestedField, UrlAggregateState);
            break;
        }
        case 'Setup__SetupRecordAggregate': {
            const Setup__SetupRecordAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$7(requestedField, Setup__SetupRecordAggregateState);
            break;
        }
        case 'Setup__SetupPolymorphicAggregateParentRelationship': {
            const Setup__SetupPolymorphicAggregateParentRelationshipState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$8(requestedField, Setup__SetupPolymorphicAggregateParentRelationshipState);
            break;
        }
    }
}
function isMappedField$6(field) {
    return false;
}
function isFragmentApplicable$7(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupRecordAggregate", typename);
}
function getInContextFragmentType$l(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$5 = 'Setup__SetupRecordResult';
const VERSION$d = 'daf27c777ff084ce986416e1b392ccf8';
function keyBuilder$9(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$5(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$6(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$9(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$6,
        isMappedFieldImport: isMappedField$5,
        getFieldType: getFieldType$j,
        ingestFieldByType: ingestFieldByType$5,
        createLink: createLink,
        mergeData: mergeData$5,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupRecordResult",
            version: VERSION$d,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$5(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$j(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$5(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupRecordAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$e, select$g, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$6(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$5, getFieldType$j, selectType$5, parentRecordId);
}
function buildSelectionForNode$6(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$6, buildSelectionForField$6, parentRecordId);
}
function select$f(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$6, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$l() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$6(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$9(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$5
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$6) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$j(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupRecordAggregate': {
                const aggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$7(cacheKeySink, requestedField, aggregateState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$j(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'aggregate': {
            return {
                isArray: false,
                typename: 'Setup__SetupRecordAggregate'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$5(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupRecordAggregate': {
            const Setup__SetupRecordAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$7(requestedField, Setup__SetupRecordAggregateState);
            break;
        }
    }
}
function isMappedField$5(field) {
    return false;
}
function isFragmentApplicable$6(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupRecordResult", typename);
}
function getInContextFragmentType$k(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$4 = 'Setup__SetupAggregateEdge';
const VERSION$c = '3c03396221f538e0cd1d5076c30cd8ee';
function keyBuilder$8(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$4(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$5(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$8(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$5,
        isMappedFieldImport: isMappedField$4,
        getFieldType: getFieldType$i,
        ingestFieldByType: ingestFieldByType$4,
        createLink: createLink,
        mergeData: mergeData$4,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupAggregateEdge",
            version: VERSION$c,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$4(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$i(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$4(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupRecordResult': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$d, select$f, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$5(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$4, getFieldType$i, selectType$4, parentRecordId);
}
function buildSelectionForNode$5(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$5, buildSelectionForField$5, parentRecordId);
}
function select$e(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$5, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$k() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$5(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$8(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$4
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$5) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$i(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupRecordResult': {
                const nodeState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$6(cacheKeySink, requestedField, nodeState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$i(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'Setup__SetupRecordResult'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$4(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupRecordResult': {
            const Setup__SetupRecordResultState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$6(requestedField, Setup__SetupRecordResultState);
            break;
        }
    }
}
function isMappedField$4(field) {
    return false;
}
function isFragmentApplicable$5(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupAggregateEdge", typename);
}
function getInContextFragmentType$j(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$3 = 'Setup__SetupAggregateConnection';
const VERSION$b = '25dc88119696a06f67107fb7fd7f1aba';
function keyBuilder$7(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$3(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingestPaginationMetadata(astNode, state, key, sink, existingData) {
    const { data, luvio, store } = state;
    const { pageInfo: { hasNextPage, startCursor }, edges } = data;
    if (!hasGraphQLPaginationFields(data))
        return;
    const paginationKey = key + '__pagination';
    let existingPaginationMetadata = store.readEntry(paginationKey);
    const afterArg = astNode.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', state.variables);
    const isPagedResponse = afterArgVal !== undefined &&
        existingPaginationMetadata !== undefined &&
        existingPaginationMetadata[afterArgVal] !== undefined;
    if (isPagedResponse && existingPaginationMetadata !== undefined) {
        const previousPageOffset = existingPaginationMetadata[afterArgVal];
        existingPaginationMetadata = {
            ...existingPaginationMetadata,
            [startCursor]: previousPageOffset + 1,
        };
    }
    // Default to a zero offset if we're not a result of a paged request
    const startOffset = isPagedResponse && existingPaginationMetadata !== undefined
        ? offsetFromToken(existingPaginationMetadata, startCursor)
        : 0;
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0) {
            throw new RangeError(`Cursor value ${startCursor} is not recognized. Cannot ingest the returned page. After: ${afterArgVal}`);
        }
    }
    const nextOffset = startOffset + edges.length;
    const incomingPaginationMetadata = createPaginationMetadata(startOffset, edges);
    if (hasNextPage) {
        // we know the data extends beyond NEXT_OFFSET_IDENTIFIER; clean up any old __END__ markers that say the data ended at/before that offset
        if (existingPaginationMetadata !== undefined && existingPaginationMetadata.__END__ !== undefined && existingPaginationMetadata.__END__ <= nextOffset) {
            existingPaginationMetadata = { ...existingPaginationMetadata };
            delete existingPaginationMetadata.__END__;
        }
    }
    else {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    // store the updated pagination metadata
    const mergedPaginationMetadata = mergeMetadata(existingPaginationMetadata, incomingPaginationMetadata);
    luvio.storePublish(paginationKey, mergedPaginationMetadata);
    luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata);
    // merge the edges
    assignMetadataLink(sink, paginationKey);
    const existingRecord = existingData ? existingData.data : undefined;
    if (existingRecord !== undefined && existingRecord.edges !== undefined) {
        sink.edges = [
            ...existingRecord.edges.slice(0, startOffset),
            ...sink.edges,
            ...existingRecord.edges.slice(nextOffset),
        ];
    }
}
function ingest$4(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$7(luvio, path);
    return ingestCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$4,
        isMappedFieldImport: isMappedField$3,
        getFieldType: getFieldType$h,
        ingestFieldByType: ingestFieldByType$3,
        hasGraphQLPaginationFields: hasGraphQLPaginationFields,
        ingestPaginatedMetadata: ingestPaginationMetadata,
        createLink: createLink,
        mergeData: mergeData$3,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupAggregateConnection",
            version: VERSION$b,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$3(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$h(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$3(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupAggregateEdge': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$c, select$e, false);
            break;
        }
        case 'PageInfo': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$14, select$16, false);
            break;
        }
        case 'Int': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$4(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, true, getFieldData$3, getFieldType$h, selectType$3, parentRecordId);
}
function buildSelectionForNode$4(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$4, buildSelectionForField$4, parentRecordId);
}
function select$d(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$4, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$j() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        ...getCursorConnectionMinimumSelections()
    ];
    return minimumSelections;
}
function getTypeCacheKeys$4(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$7(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$3
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$4) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$h(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupAggregateEdge': {
                const fullPath__edges = `${rootKey}__${fieldKey}`;
                for (let i = 0, len = fieldData.length; i < len; i++) {
                    const item = fieldData[i];
                    const itemState = {
                        ...state,
                        path: {
                            parent: null,
                            propertyName: null,
                            fullPath: fullPath__edges + '__' + i
                        },
                        data: item,
                    };
                    getTypeCacheKeys$5(cacheKeySink, requestedField, itemState);
                }
                break;
            }
            case 'PageInfo': {
                const pageInfoState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$Z(cacheKeySink, requestedField, pageInfoState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$h(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'Setup__SetupAggregateEdge'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$3(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupAggregateEdge': {
            const Setup__SetupAggregateEdgeState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$5(requestedField, Setup__SetupAggregateEdgeState);
            break;
        }
        case 'PageInfo': {
            const PageInfoState = buildFieldState(state, fullPathKey, fieldData);
            sink[fieldKey] = ingest$Z(requestedField, PageInfoState);
            break;
        }
        case 'Int': {
            sink[fieldKey] = fieldData;
            break;
        }
    }
}
function isMappedField$3(field) {
    return false;
}
function isFragmentApplicable$4(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupAggregateConnection", typename);
}
function getInContextFragmentType$i(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getFieldType$g(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String',
            };
        }
        default: {
            return {
                isArray: false,
                typename: 'Setup__SetupAggregateConnection',
            };
        }
    }
}

const name$2 = 'Setup__SetupQueryAggregate';
const VERSION$a = '0592284764c8e58016880e291b9ffb64';
function keyBuilder$6(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$2(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$3(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$6(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$3,
        isMappedFieldImport: isMappedField$2,
        getFieldType: getFieldType$g,
        ingestFieldByType: ingestFieldByType$2,
        createLink: createLink,
        mergeData: mergeData$2,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Setup__SetupQueryAggregate",
            version: VERSION$a,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$2(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$g(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$2(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupAggregateConnection': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$b, select$d, true);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$3(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$2, getFieldType$g, selectType$2, parentRecordId);
}
function buildSelectionForNode$3(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$3, buildSelectionForField$3, parentRecordId);
}
function select$c(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$3, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$i() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$3(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$6(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$2
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$3) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$g(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupAggregateConnection': {
                const recordQueryAggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$4(cacheKeySink, requestedField, recordQueryAggregateState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function ingestFieldByType$2(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupAggregateConnection': {
            const Setup__SetupAggregateConnectionState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$4(requestedField, Setup__SetupAggregateConnectionState);
            break;
        }
    }
}
function isMappedField$2(field) {
    return false;
}
function isFragmentApplicable$3(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__SetupQueryAggregate", typename);
}
function getInContextFragmentType$h(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name$1 = 'Setup__Setup';
const TTL$2 = 1000;
const VERSION$9 = 'c9078f9a3c6d16c68179c4007365a008';
function keyBuilder$5(luvio, path, data) {
    return path.fullPath;
}
// W-12356727: To be switched over once path.fullPath is a structured key.
// export function keyBuilder_StructuredKey(luvio: $64$luvio_engine_Luvio, path: $64$luvio_engine_IngestPath, data: PartialInterface): $64$luvio_engine_NormalizedKeyMetadata {
//     return path.fullPath;
// }
function mergeData$1(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$2(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$5(luvio, path);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$2,
        isMappedFieldImport: isMappedField$1,
        getFieldType: getFieldType$f,
        ingestFieldByType: ingestFieldByType$1,
        createLink: createLink,
        mergeData: mergeData$1,
        storeMetadataParams: {
            ttl: TTL$2,
            namespace: keyPrefix,
            representationName: "Setup__Setup",
            version: VERSION$9,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData$1(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$f(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType$1(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'Setup__SetupQuery': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$g, select$i, false);
            break;
        }
        case 'Setup__SetupQueryAggregate': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$a, select$c, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$2(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData$1, getFieldType$f, selectType$1, parentRecordId);
}
function buildSelectionForNode$2(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$2, buildSelectionForField$2, parentRecordId);
}
function select$b(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$2, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$h() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getTypeCacheKeys$2(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$5(luvio, path);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name$1
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$2) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$f(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'Setup__SetupQuery': {
                const queryState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$9(cacheKeySink, requestedField, queryState);
                break;
            }
            case 'Setup__SetupQueryAggregate': {
                const aggregateState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$3(cacheKeySink, requestedField, aggregateState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$f(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'query': {
            return {
                isArray: false,
                typename: 'Setup__SetupQuery'
            };
        }
        case 'aggregate': {
            return {
                isArray: false,
                typename: 'Setup__SetupQueryAggregate'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType$1(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'Setup__SetupQuery': {
            const Setup__SetupQueryState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$9(requestedField, Setup__SetupQueryState);
            break;
        }
        case 'Setup__SetupQueryAggregate': {
            const Setup__SetupQueryAggregateState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$3(requestedField, Setup__SetupQueryAggregateState);
            break;
        }
    }
}
function isMappedField$1(field) {
    return false;
}
function isFragmentApplicable$2(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Setup__Setup", typename);
}
function getInContextFragmentType$g(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const name = 'Query';
const VERSION$8 = '54885a089621803969258215830eec97';
function keyBuilder$4(luvio, operationNode, variables, fragmentMap) {
    return buildQueryTypeStringKey({
        luvio,
        keyPrefix: keyPrefix,
        schemaName: 'uiapi',
        queryTypeName: name,
        operationNode,
        variables,
        fragmentMap
    });
}
function mergeData(existingData, newData) {
    return {
        data: ObjectAssign({}, existingData["data"], newData["data"]),
    };
}
function ingest$1(astNode, state) {
    const { path, data, timestamp, luvio } = state;
    const key = keyBuilder$4(luvio, astNode, state.variables, state.fragments);
    return ingestNonCursorConnectionType(astNode, state, {
        key,
        isFragmentApplicable: isFragmentApplicable$1,
        isMappedFieldImport: isMappedField,
        getFieldType: getFieldType$e,
        ingestFieldByType,
        createLink: createLink,
        mergeData,
        storeMetadataParams: {
            ttl: TTL$1,
            namespace: keyPrefix,
            representationName: "Query",
            version: VERSION$8,
            ingestionTimestamp: timestamp,
        },
    });
}
function getFieldData(source, sel, variables) {
    switch (sel.name.value) {
        default: {
            const fieldType = getFieldType$e(sel);
            const fieldKey = getSerializedKeyForField(sel, variables, fieldType);
            return source.data[fieldKey];
        }
    }
}
function selectType(typename, sel, fieldData, reader, key, sink, variables, fragments, parentRecordId) {
    if (fieldData === null) {
        reader.markSeenId(parentRecordId);
        reader.assignScalar(key, sink, fieldData);
        return sink;
    }
    switch (typename) {
        case 'String': {
            reader.markSeenId(parentRecordId);
            reader.assignScalar(key, sink, fieldData);
            break;
        }
        case 'UIAPI': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$u, select$w, false);
            break;
        }
        case 'Analytics__Analytics': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$m, select$o, false);
            break;
        }
        case 'Setup__Setup': {
            selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, VERSION$9, select$b, false);
            break;
        }
    }
    return sink;
}
function buildSelectionForField$1(source, reader, sel, variables, fragments, parentRecordId) {
    return buildSelectionForField(source, reader, sel, variables, fragments, false, getFieldData, getFieldType$e, selectType, parentRecordId);
}
function buildSelectionForNode$1(source, reader, parentNode, selectionNode, variables, fragments, parentRecordId) {
    return buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable$1, buildSelectionForField$1, parentRecordId);
}
function select$a(field, variables, fragments) {
    return (source, reader, parentRecordId) => {
        const sink = {};
        return selectCalculateSink(sink, field, buildSelectionForNode$1, source, reader, variables, fragments, parentRecordId);
    };
}
function getMinimumSelections$g() {
    const minimumSelections = [];
    return minimumSelections;
}
function getTypeCacheKeys$1(cacheKeySink, astNode, state) {
    const { path, data, luvio } = state;
    const rootKey = keyBuilder$4(luvio, astNode, state.variables, state.fragments);
    cacheKeySink.set(rootKey, {
        namespace: keyPrefix,
        mergeable: true,
        representationName: name
    });
    // get all cache keys from normalizable fields
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable$1) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // Skip unknown field.
        }
        const fieldType = getFieldType$e(requestedField);
        if (fieldType === undefined) {
            continue;
        }
        const fieldKey = getSerializedKeyForField(requestedField, state.variables, fieldType);
        switch (fieldType.typename) {
            case 'UIAPI': {
                const uiapiState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$n(cacheKeySink, requestedField, uiapiState);
                break;
            }
            case 'Analytics__Analytics': {
                const analyticsState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$f(cacheKeySink, requestedField, analyticsState);
                break;
            }
            case 'Setup__Setup': {
                const setupState = buildFieldState(state, rootKey + '__' + fieldKey, fieldData);
                getTypeCacheKeys$2(cacheKeySink, requestedField, setupState);
                break;
            }
        }
    }
    // Deal with mapped types' cache keys
}
function getFieldType$e(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'uiapi': {
            return {
                isArray: false,
                typename: 'UIAPI'
            };
        }
        case 'analytics': {
            return {
                isArray: false,
                typename: 'Analytics__Analytics'
            };
        }
        case 'setup': {
            return {
                isArray: false,
                typename: 'Setup__Setup'
            };
        }
        default:
            return undefined;
    }
}
function ingestFieldByType(typename, parentKey, requestedField, sink, fieldKey, fieldData, state) {
    // TODO: add validation logic to only allow nullable fields to be null in the future
    if (fieldData === null) {
        sink[fieldKey] = null;
        return;
    }
    switch (typename) {
        case 'String': {
            sink[fieldKey] = fieldData;
            break;
        }
        case 'UIAPI': {
            const UIAPIState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$n(requestedField, UIAPIState);
            break;
        }
        case 'Analytics__Analytics': {
            const Analytics__AnalyticsState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$f(requestedField, Analytics__AnalyticsState);
            break;
        }
        case 'Setup__Setup': {
            const Setup__SetupState = buildFieldState(state, parentKey + '__' + fieldKey, fieldData);
            sink[fieldKey] = ingest$2(requestedField, Setup__SetupState);
            break;
        }
    }
}
function isMappedField(field) {
    return false;
}
function isFragmentApplicable$1(fragmentNode, typename) {
    return isFragmentApplicable(fragmentNode, [], "Query", typename);
}
function getInContextFragmentType$f(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$f() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$d(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'Date'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$e(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$e() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$c(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'Record': {
            return {
                isArray: false,
                typename: 'RecordRepresentation'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$d(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const DEFAULT_FIELD_VALUE_SELECTIONS = [
    {
        kind: 'Field',
        name: {
            kind: 'Name',
            value: '__typename',
        },
    },
    {
        kind: 'Field',
        name: {
            kind: 'Name',
            value: 'value',
        },
    },
    {
        kind: 'Field',
        name: {
            kind: 'Name',
            value: 'displayValue',
        },
    },
];
// All FieldValues should use theseMinimumSelections
function getMinimumSelections$d() {
    return DEFAULT_FIELD_VALUE_SELECTIONS;
}

function getMinimumSelections$c() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$b(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'value': {
            return {
                isArray: false,
                typename: 'DateTime'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'calendarMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'calendarQuarter': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'calendarYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'count': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'countDistinct': {
            return {
                isArray: false,
                typename: 'LongValue'
            };
        }
        case 'dayInMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'dayInWeek': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'dayInYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'dayOnly': {
            return {
                isArray: false,
                typename: 'DateOnlyAggregation'
            };
        }
        case 'fiscalMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'fiscalQuarter': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'fiscalYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'format': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'hourInDay': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'max': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'min': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'weekInMonth': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        case 'weekInYear': {
            return {
                isArray: false,
                typename: 'DateFunctionAggregation'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$c(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$b() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$a(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'displayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$b(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$a() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$9(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'success': {
            return {
                isArray: false,
                typename: 'Boolean'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$a(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$9() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$8(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$9(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

const defaultFieldValueSelection = {
    kind: 'SelectionSet',
    selections: DEFAULT_FIELD_VALUE_SELECTIONS,
};
const recordTypeIdFieldWithFallback = {
    kind: 'Field',
    name: {
        kind: 'Name',
        value: 'RecordTypeId',
    },
    arguments: [
        {
            kind: 'Argument',
            name: {
                kind: 'Name',
                value: 'fallback',
            },
            value: {
                kind: 'BooleanValue',
                value: true,
            },
        },
    ],
    alias: {
        kind: 'Name',
        value: 'ldsRecordTypeId', // Alias fields that have arguments to avoid a conflict.
    },
    selectionSet: defaultFieldValueSelection,
};
/**
 * This is a special inline fragment that can be applied to both PolymorphicParentRelationship fields
 * and parentRelationship Fields. It looks just like the defaultRecord fields fragment from the handrolled adapter.
 *
 *
 *
 */
const minimumRecordFieldsFragment = {
    kind: 'InlineFragment',
    typeCondition: {
        kind: 'NamedType',
        name: {
            kind: 'Name',
            value: 'Record',
        },
    },
    selectionSet: {
        kind: 'SelectionSet',
        selections: [
            getFieldSelection('__typename'),
            getFieldSelection('Id'),
            getFieldSelection('DisplayValue'),
            getFieldSelection('ApiName'),
            getFieldSelection('WeakEtag'),
            getFieldSelection('LastModifiedById', defaultFieldValueSelection),
            getFieldSelection('LastModifiedDate', defaultFieldValueSelection),
            getFieldSelection('SystemModstamp', defaultFieldValueSelection),
            recordTypeIdFieldWithFallback,
        ],
    },
};
function getMinimumSelections$8() {
    return [minimumRecordFieldsFragment];
}
function getFieldSelection(name, selectionSet) {
    return {
        kind: 'Field',
        name: {
            kind: 'Name',
            value: name,
        },
        selectionSet,
    };
}

// RecordRepresentation is a generic type, so all we can do is the default if it's Record, else we assume RecordRepresentation
function getInContextFragmentType$8(fragment, fragmentMap) {
    const fragmentType = sharedGetFragmentType(fragment, fragmentMap);
    return fragmentType === 'Record' ? 'Record' : 'RecordRepresentation';
}

function getMinimumSelections$7() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$7(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'cost': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'limit': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'remaining': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'resetAt': {
            return {
                isArray: false,
                typename: 'DateTime'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$7(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$6() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$6(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'recordCreate': {
            return {
                isArray: false,
                typename: 'RecordCreatePayload'
            };
        }
        case 'recordDelete': {
            return {
                isArray: false,
                typename: 'RecordDeletePayload'
            };
        }
        case 'recordUpdate': {
            return {
                isArray: false,
                typename: 'RecordUpdatePayload'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$6(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$5() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$5(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'WeakEtag': {
            return {
                isArray: false,
                typename: 'Long'
            };
        }
        case 'DisplayValue': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'LastModifiedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'SystemModstamp': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'RecordTypeId': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$5(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$4() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$4(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$4(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$3() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$3(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'node': {
            return {
                isArray: false,
                typename: 'Analytics__SemanticSubMetricDefinitionRepresentation'
            };
        }
        case 'cursor': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$3(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$2() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        ...getCursorConnectionMinimumSelections()
    ];
    return minimumSelections;
}
function getFieldType$2(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'edges': {
            return {
                isArray: true,
                typename: 'Analytics__SemanticSubMetricDefinitionEdge'
            };
        }
        case 'totalCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageResultCount': {
            return {
                isArray: false,
                typename: 'Int'
            };
        }
        case 'pageInfo': {
            return {
                isArray: false,
                typename: 'PageInfo'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$2(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections$1() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType$1(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'MasterLabel': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'DeveloperName': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'CreatedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'CreatedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'NamespacePrefix': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'AnalyticsWorkspaces': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsWorkspaceAssetConnection'
            };
        }
        case 'SubMetrics': {
            return {
                isArray: false,
                typename: 'Analytics__SemanticSubMetricDefinitionConnection'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType$1(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function getMinimumSelections() {
    const minimumSelections = [
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: '__typename',
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'Id',
            },
        },
    ];
    return minimumSelections;
}
function getFieldType(field) {
    switch (field.name.value) {
        case '__typename': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'MasterLabel': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'DeveloperName': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'CreatedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedById': {
            return {
                isArray: false,
                typename: 'IDValue'
            };
        }
        case 'LastModifiedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'CreatedDate': {
            return {
                isArray: false,
                typename: 'DateTimeValue'
            };
        }
        case 'Id': {
            return {
                isArray: false,
                typename: 'ID'
            };
        }
        case 'ApiName': {
            return {
                isArray: false,
                typename: 'String'
            };
        }
        case 'NamespacePrefix': {
            return {
                isArray: false,
                typename: 'StringValue'
            };
        }
        case 'AnalyticsWorkspaces': {
            return {
                isArray: false,
                typename: 'Analytics__AnalyticsWorkspaceAssetConnection'
            };
        }
        default:
            return undefined;
    }
}
function getInContextFragmentType(fragment, fragmentMap) {
    return sharedGetFragmentType(fragment, fragmentMap);
}

function applyToSelection$6(selection, directive, variables) {
    return selection;
}

function applyToSelection$5(selection, directive, variables) {
    return selection;
}

function applyToSelection$4(selection, directive, variables) {
    return selection;
}

function applyToSelection$3(selection, directive, variables) {
    const ifArg = directive.arguments?.find(argument => argument.name.value === "if");
    if (ifArg && ifArg.value) {
        if (ifArg.value.kind === "BooleanValue") {
            return ifArg.value.value ? selection : undefined;
        }
        if (ifArg.value.kind === "Variable") {
            return variables[ifArg.value.name.value] ? selection : undefined;
        }
    }
    return selection;
}

function applyToSelection$2(selection, directive, variables) {
    const ifArg = directive.arguments?.find(argument => argument.name.value === "if");
    if (ifArg && ifArg.value) {
        if (ifArg.value.kind === "BooleanValue") {
            return ifArg.value.value ? undefined : selection;
        }
        if (ifArg.value.kind === "Variable") {
            return variables[ifArg.value.name.value] ? undefined : selection;
        }
    }
    return selection;
}

function applyToSelection$1(selection, directive, variables) {
    return selection;
}

function applyToSelection(selection, directive, variables) {
    return selection;
}

function applyDirectivesForSelection(selection, variables) {
    let result = selection;
    if (selection && selection.directives) {
        // iterate through directives in order. Directives _can_ be stacked.
        for (var i = 0; i < selection.directives.length; i++) {
            const directive = selection.directives[i];
            switch (directive.name.value) {
                // Generate Case for each directive in the schema that supports SelectionNodes
                case ("generic"):
                    result = applyToSelection$6(selection);
                    break;
                case ("fieldCategory"):
                    result = applyToSelection$5(selection);
                    break;
                case ("category"):
                    result = applyToSelection$4(selection);
                    break;
                case ("include"):
                    result = applyToSelection$3(selection, directive, variables);
                    break;
                case ("skip"):
                    result = applyToSelection$2(selection, directive, variables);
                    break;
                case ("deprecated"):
                    result = applyToSelection$1(selection);
                    break;
                case ("specifiedBy"):
                    result = applyToSelection(selection);
                    break;
            }
            if (result === undefined) {
                // Selection was removed.
                break;
            }
        }
    }
    return result;
}

function createLink(ref) {
    return {
        __ref: serializeStructuredKey(ref),
    };
}
function ingestCursorConnectionType(astNode, state, specifics) {
    const { data } = state;
    const { key, ingestFieldByType: typeIngestFieldByType, hasGraphQLPaginationFields } = specifics;
    return ingestTypeWithStrategy(astNode, state, true, specifics, {
        getPaginationOffset() {
            return hasGraphQLPaginationFields(data)
                ? getArrayOffsetForPage(state, astNode, key)
                : 0;
        },
        ingestFieldByType(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
            typeIngestFieldByType(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state);
        }
    });
}
function ingestNonCursorConnectionType(astNode, state, specifics) {
    const { ingestFieldByType: typeIngestFieldByType } = specifics;
    return ingestTypeWithStrategy(astNode, state, false, specifics, {
        getPaginationOffset() {
            return 0;
        },
        ingestFieldByType(typename, parentKey, fullPathKey, requestedField, sink, fieldKey, fieldData, state) {
            typeIngestFieldByType(typename, parentKey, requestedField, sink, fieldKey, fieldData, state);
        }
    });
}
function ingestTypeWithStrategy(astNode, state, isCursorConnectionType, { key, isFragmentApplicable, isMappedFieldImport, getFieldType, ramlIngestBlock, ingestPaginatedMetadata, mergeData, storeMetadataParams, createLink, }, strategy) {
    const { data, variables, luvio, store } = state;
    const sink = {};
    const requestedFields = astNode.selectionSet ? getRequestedFieldsForType(data.__typename, astNode.selectionSet, state.fragments, isFragmentApplicable) : new Map();
    for (const fieldDataKey of Object.keys(data)) {
        const fieldData = data[fieldDataKey];
        const requestedField = requestedFields.get(fieldDataKey);
        if (requestedField === undefined) {
            continue; // TODO: (W-11132802) We got a field back we didn't ask for. Call handleUnknownField.
        }
        if (isMappedFieldImport(requestedField)) {
            continue; // Skips scalar fields that are mapped to RAML.
        }
        const fieldType = getFieldType(requestedField);
        const fieldKey = getSerializedKeyForField(requestedField, variables, fieldType);
        if (fieldType === undefined) {
            console.warn(`Unknown Field: ${requestedField}. This field or nested fields cannot participate in normalization`);
            deepFreeze(fieldData);
            sink[fieldKey] = fieldData;
            continue;
        }
        if (isCursorConnectionType) {
            if (fieldKey === 'pageInfo')
                continue; // pageInfo is always synthesized from pagination metadata
        }
        if (fieldData === null) {
            sink[fieldKey] = fieldData;
            continue; // Don't delegate null to type ingest.
        }
        if (fieldType.isArray && fieldData.length !== undefined) {
            const arrayLength = fieldData.length;
            const arraySink = new Array(arrayLength);
            let paginationOffset = strategy.getPaginationOffset();
            for (let i = 0, len = arrayLength; i < len; i += 1) {
                const arrayFullPathKey = key + '__' + fieldKey;
                strategy.ingestFieldByType(fieldType.typename, arrayFullPathKey, arrayFullPathKey + '__' + (i + paginationOffset), requestedField, arraySink, i, fieldData[i], state);
            }
            sink[fieldKey] = arraySink;
        }
        else {
            strategy.ingestFieldByType(fieldType.typename, key, key + '__' + fieldKey, requestedField, sink, fieldKey, fieldData, state);
        }
    }
    // merge existing cache data and new request response data
    const newData = { data: sink };
    if (ramlIngestBlock !== undefined) {
        ramlIngestBlock(newData);
    }
    const existingData = store.readEntry(key);
    if (ingestPaginatedMetadata !== undefined) {
        ingestPaginatedMetadata(astNode, state, key, sink, existingData);
    }
    if (existingData !== undefined && existingData !== null && ObjectPrototypeHasOwnProperty.call(existingData, "__type") === false) {
        const mergedData = mergeData(existingData, newData);
        if (!equalsObject(existingData, mergedData, (propA, propB) => stableJSONStringify(propA) === stableJSONStringify(propB))) { // naive impl
            luvio.storePublish(key, mergedData);
        }
    }
    else {
        luvio.storePublish(key, newData);
    }
    luvio.publishStoreMetadata(key, storeMetadataParams);
    return createLink(key);
}
const TTL$1 = 900000;
function applyMinimumFieldsToQuery(query) {
    const fragmentMap = createFragmentMap(query);
    query.definitions.forEach(queryDefinitionNode => {
        if (queryDefinitionNode.kind === 'OperationDefinition' && queryDefinitionNode.operation === 'query') {
            injectSelectionSet(queryDefinitionNode.selectionSet, getQueryTransformerForType("Query"), fragmentMap);
        }
    });
    return query;
}
function injectSelectionSet(selectionSetNode, queryTransformHelper, fragmentMap) {
    if (queryTransformHelper === undefined ||
        queryTransformHelper === null ||
        selectionSetNode === undefined) {
        return;
    }
    const minimumSelectionSet = {
        kind: 'SelectionSet',
        selections: queryTransformHelper.getMinimumSelections()
    };
    const mergedSelections = mergeSelectionSets(selectionSetNode, minimumSelectionSet);
    mergedSelections?.selections.forEach(selection => {
        if (selection.kind === 'Field') {
            const fieldType = queryTransformHelper.getFieldType(selection);
            const fieldTransformHelper = fieldType === undefined ? undefined : getQueryTransformerForType(fieldType.typename);
            if (fieldTransformHelper && !selection.selectionSet) {
                Object.assign(selection, {
                    selectionSet: {
                        kind: 'SelectionSet',
                        selections: []
                    }
                });
            }
            injectSelectionSet(selection.selectionSet, fieldTransformHelper, fragmentMap);
        }
        else {
            const fragmentType = queryTransformHelper.getInContextFragmentType(selection, fragmentMap);
            const fragmentSelections = getSelectionSetFromFragment(selection, fragmentMap);
            if (fragmentType === undefined) { // Untyped or unknown fragment
                injectSelectionSet(fragmentSelections, queryTransformHelper, fragmentMap);
            }
            else {
                const fragmentTransformHelper = getQueryTransformerForType(fragmentType);
                if (fragmentTransformHelper === undefined) {
                    return;
                }
                injectSelectionSet(fragmentSelections, fragmentTransformHelper, fragmentMap);
            }
        }
    });
    Object.assign(selectionSetNode, mergedSelections);
}
function getPageMetadata(paginationMetadata, paginationParams) {
    const metadataProperties = {};
    const sink = {
        metadataProperties
    };
    if (paginationMetadata === undefined) {
        return sink;
    }
    const { token, pageSize } = paginationParams;
    const pageTokenAndOffset = getPageTokenAndOffset(paginationMetadata, token);
    if (pageTokenAndOffset === undefined) {
        return sink;
    }
    const [pageToken, startOffset] = pageTokenAndOffset;
    const endOffset = pageEndOffset(paginationMetadata, startOffset, pageSize);
    sink.startOffset = startOffset;
    sink.endOffset = endOffset;
    metadataProperties.startCursor = pageToken;
    const nextToken = getNextPageToken(paginationMetadata, endOffset);
    if (nextToken !== undefined) {
        metadataProperties.endCursor = nextToken;
    }
    return sink;
}
const CURSOR_CONNECTION_TYPES = [
    'RecordAggregateConnection',
    'Setup__SetupAggregateConnection',
    'Setup__SetupConnection',
    'RecordConnection',
    'Analytics__AnalyticsWorkspaceAssetConnection',
    'Analytics__SemanticSubMetricDefinitionConnection',
];
function isCursorConnectionType(fieldType) {
    return fieldType !== undefined && CURSOR_CONNECTION_TYPES.includes(fieldType.typename);
}
function getSerializedKeyForField(field, variables, fieldType) {
    let mutableArgumentNodes = Object.assign([], field.arguments);
    // Paginated types are stored as a consolidated collection.  Their keys should not include
    // the "first" and "after" pagination parameters.
    if (isCursorConnectionType(fieldType)) {
        mutableArgumentNodes = mutableArgumentNodes.filter(node => {
            return node.name.value !== 'first' && node.name.value !== 'after';
        });
    }
    // Serialize the arguments given to this field. Luvio can't "eval" these arguments atm
    const argumentString = mutableArgumentNodes.length > 0 ? '__' + serializeFieldArguments(mutableArgumentNodes, variables) : '';
    return field.name.value + argumentString; // It should be safe to always use the fieldName - If an alias is meaningful, there will be arguments on the key also.
}
function getQueryTransformerForType(typename, fragmentMap) {
    switch (typename) {
        case "PercentAggregate": return {
            getMinimumSelections: getMinimumSelections$1f,
            getFieldType: getFieldType$1z,
            getInContextFragmentType: getInContextFragmentType$1z
        };
        case "StringAggregate": return {
            getMinimumSelections: getMinimumSelections$1e,
            getFieldType: getFieldType$1w,
            getInContextFragmentType: getInContextFragmentType$1w
        };
        case "Query": return {
            getMinimumSelections: getMinimumSelections$g,
            getFieldType: getFieldType$e,
            getInContextFragmentType: getInContextFragmentType$f
        };
        case "DateOnlyAggregation": return {
            getMinimumSelections: getMinimumSelections$f,
            getFieldType: getFieldType$d,
            getInContextFragmentType: getInContextFragmentType$e
        };
        case "RecordCreatePayload": return {
            getMinimumSelections: getMinimumSelections$e,
            getFieldType: getFieldType$c,
            getInContextFragmentType: getInContextFragmentType$d
        };
        case "DateAggregate": return {
            getMinimumSelections: getMinimumSelections$14,
            getFieldType: getFieldType$12,
            getInContextFragmentType: getInContextFragmentType$13
        };
        case "RecordTypeInfo": return {
            getMinimumSelections: getMinimumSelections$I,
            getFieldType: getFieldType$G,
            getInContextFragmentType: getInContextFragmentType$H
        };
        case "BooleanValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1t,
            getInContextFragmentType: getInContextFragmentType$1t
        };
        case "ReferenceToInfo": return {
            getMinimumSelections: getMinimumSelections$K,
            getFieldType: getFieldType$I,
            getInContextFragmentType: getInContextFragmentType$J
        };
        case "FieldValue": return {
            getMinimumSelections: getMinimumSelections$b,
            getFieldType: getFieldType$a,
            getInContextFragmentType: getInContextFragmentType$b
        };
        case "LongitudeValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1i,
            getInContextFragmentType: getInContextFragmentType$1i
        };
        case "StringValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1x,
            getInContextFragmentType: getInContextFragmentType$1x
        };
        case "IntValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1y,
            getInContextFragmentType: getInContextFragmentType$1y
        };
        case "UrlValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1l,
            getInContextFragmentType: getInContextFragmentType$1l
        };
        case "LongAggregate": return {
            getMinimumSelections: getMinimumSelections$Z,
            getFieldType: getFieldType$X,
            getInContextFragmentType: getInContextFragmentType$Y
        };
        case "PhoneNumberAggregate": return {
            getMinimumSelections: getMinimumSelections$Y,
            getFieldType: getFieldType$W,
            getInContextFragmentType: getInContextFragmentType$X
        };
        case "PicklistValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1g,
            getInContextFragmentType: getInContextFragmentType$1g
        };
        case "CurrencyAggregate": return {
            getMinimumSelections: getMinimumSelections$16,
            getFieldType: getFieldType$14,
            getInContextFragmentType: getInContextFragmentType$15
        };
        case "RelatedListInfo": return {
            getMinimumSelections: getMinimumSelections$D,
            getFieldType: getFieldType$B,
            getInContextFragmentType: getInContextFragmentType$C
        };
        case "UIAPI": return {
            getMinimumSelections: getMinimumSelections$C,
            getFieldType: getFieldType$A,
            getInContextFragmentType: getInContextFragmentType$B
        };
        case "DateTimeAggregate": return {
            getMinimumSelections: getMinimumSelections$c,
            getFieldType: getFieldType$b,
            getInContextFragmentType: getInContextFragmentType$c
        };
        case "EmailAggregate": return {
            getMinimumSelections: getMinimumSelections$12,
            getFieldType: getFieldType$10,
            getInContextFragmentType: getInContextFragmentType$11
        };
        case "RichTextAreaValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1o,
            getInContextFragmentType: getInContextFragmentType$1o
        };
        case "MultiPicklistValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1f,
            getInContextFragmentType: getInContextFragmentType$1f
        };
        case "Setup__SetupEdge": return {
            getMinimumSelections: getMinimumSelections$q,
            getFieldType: getFieldType$o,
            getInContextFragmentType: getInContextFragmentType$p
        };
        case "TimeAggregate": return {
            getMinimumSelections: getMinimumSelections$V,
            getFieldType: getFieldType$T,
            getInContextFragmentType: getInContextFragmentType$U
        };
        case "ListColumn": return {
            getMinimumSelections: getMinimumSelections$F,
            getFieldType: getFieldType$D,
            getInContextFragmentType: getInContextFragmentType$E
        };
        case "Setup__SetupQuery": return {
            getMinimumSelections: getMinimumSelections$o,
            getFieldType: getFieldType$m,
            getInContextFragmentType: getInContextFragmentType$n
        };
        case "Setup__SetupQueryAggregate": return {
            getMinimumSelections: getMinimumSelections$i,
            getFieldType: getFieldType$g,
            getInContextFragmentType: getInContextFragmentType$h
        };
        case "Setup__SetupRecordAggregate": return {
            getMinimumSelections: getMinimumSelections$m,
            getFieldType: getFieldType$k,
            getInContextFragmentType: getInContextFragmentType$l
        };
        case "Setup__SetupRecordResult": return {
            getMinimumSelections: getMinimumSelections$l,
            getFieldType: getFieldType$j,
            getInContextFragmentType: getInContextFragmentType$k
        };
        case "SObject__Field": return {
            getMinimumSelections: getMinimumSelections$t,
            getFieldType: getFieldType$r,
            getInContextFragmentType: getInContextFragmentType$s
        };
        case "Setup__EntityRepresentation": return {
            getMinimumSelections: getMinimumSelections$r,
            getFieldType: getFieldType$p,
            getInContextFragmentType: getInContextFragmentType$q
        };
        case "LatitudeAggregate": return {
            getMinimumSelections: getMinimumSelections$$,
            getFieldType: getFieldType$Z,
            getInContextFragmentType: getInContextFragmentType$_
        };
        case "PolymorphicAggregateParentRelationship": return {
            getMinimumSelections: getMinimumSelections$T,
            getFieldType: getFieldType$R,
            getInContextFragmentType: getInContextFragmentType$S
        };
        case "PolymorphicParentRelationship": return {
            getMinimumSelections: getMinimumSelections$1d,
            getFieldType: getFieldType$1c,
            getInContextFragmentType: getInContextFragmentType$1c
        };
        case "LongTextAreaValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1p,
            getInContextFragmentType: getInContextFragmentType$1p
        };
        case "LatitudeValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1h,
            getInContextFragmentType: getInContextFragmentType$1h
        };
        case "RecordAggregateConnection": return {
            getMinimumSelections: getMinimumSelections$P,
            getFieldType: getFieldType$N,
            getInContextFragmentType: getInContextFragmentType$O
        };
        case "LongitudeAggregate": return {
            getMinimumSelections: getMinimumSelections$_,
            getFieldType: getFieldType$Y,
            getInContextFragmentType: getInContextFragmentType$Z
        };
        case "RecordEdge": return {
            getMinimumSelections: getMinimumSelections$1a,
            getFieldType: getFieldType$18,
            getInContextFragmentType: getInContextFragmentType$19
        };
        case "Setup__SetupPolymorphicParentRelationship": return {
            getMinimumSelections: getMinimumSelections$s,
            getFieldType: getFieldType$q,
            getInContextFragmentType: getInContextFragmentType$r
        };
        case "DateValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1r,
            getInContextFragmentType: getInContextFragmentType$1r
        };
        case "PhoneNumberValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1n,
            getInContextFragmentType: getInContextFragmentType$1n
        };
        case "DoubleAggregate": return {
            getMinimumSelections: getMinimumSelections$13,
            getFieldType: getFieldType$11,
            getInContextFragmentType: getInContextFragmentType$12
        };
        case "TextAreaValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1q,
            getInContextFragmentType: getInContextFragmentType$1q
        };
        case "RecordUpdatePayload": return {
            getMinimumSelections: getMinimumSelections$a,
            getFieldType: getFieldType$9,
            getInContextFragmentType: getInContextFragmentType$a
        };
        case "DoubleValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1C,
            getInContextFragmentType: getInContextFragmentType$1C
        };
        case "IDAggregate": return {
            getMinimumSelections: getMinimumSelections$11,
            getFieldType: getFieldType$$,
            getInContextFragmentType: getInContextFragmentType$10
        };
        case "RecordAggregateEdge": return {
            getMinimumSelections: getMinimumSelections$Q,
            getFieldType: getFieldType$O,
            getInContextFragmentType: getInContextFragmentType$P
        };
        case "ThemeInfo": return {
            getMinimumSelections: getMinimumSelections$H,
            getFieldType: getFieldType$F,
            getInContextFragmentType: getInContextFragmentType$G
        };
        case "RecordDeletePayload": return {
            getMinimumSelections: getMinimumSelections$9,
            getFieldType: getFieldType$8,
            getInContextFragmentType: getInContextFragmentType$9
        };
        case "UrlAggregate": return {
            getMinimumSelections: getMinimumSelections$U,
            getFieldType: getFieldType$S,
            getInContextFragmentType: getInContextFragmentType$T
        };
        case "RecordRepresentation": return {
            getMinimumSelections: getMinimumSelections$8,
            getFieldType: getFieldType$1a,
            getInContextFragmentType: getInContextFragmentType$8
        };
        case "IDValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1v,
            getInContextFragmentType: getInContextFragmentType$1v
        };
        case "TextAreaAggregate": return {
            getMinimumSelections: getMinimumSelections$W,
            getFieldType: getFieldType$U,
            getInContextFragmentType: getInContextFragmentType$V
        };
        case "TimeValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1s,
            getInContextFragmentType: getInContextFragmentType$1s
        };
        case "PicklistAggregate": return {
            getMinimumSelections: getMinimumSelections$X,
            getFieldType: getFieldType$V,
            getInContextFragmentType: getInContextFragmentType$W
        };
        case "DateTimeValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1u,
            getInContextFragmentType: getInContextFragmentType$1u
        };
        case "IntAggregate": return {
            getMinimumSelections: getMinimumSelections$10,
            getFieldType: getFieldType$_,
            getInContextFragmentType: getInContextFragmentType$$
        };
        case "ListOrder": return {
            getMinimumSelections: getMinimumSelections$E,
            getFieldType: getFieldType$C,
            getInContextFragmentType: getInContextFragmentType$D
        };
        case "RecordAggregate": return {
            getMinimumSelections: getMinimumSelections$S,
            getFieldType: getFieldType$Q,
            getInContextFragmentType: getInContextFragmentType$R
        };
        case "JSONValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1d,
            getInContextFragmentType: getInContextFragmentType$1d
        };
        case "EmailValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1m,
            getInContextFragmentType: getInContextFragmentType$1m
        };
        case "Setup__Setup": return {
            getMinimumSelections: getMinimumSelections$h,
            getFieldType: getFieldType$f,
            getInContextFragmentType: getInContextFragmentType$g
        };
        case "Setup__SetupAggregateConnection": return {
            getMinimumSelections: getMinimumSelections$j,
            getFieldType: getFieldType$h,
            getInContextFragmentType: getInContextFragmentType$i
        };
        case "Setup__SetupAggregateEdge": return {
            getMinimumSelections: getMinimumSelections$k,
            getFieldType: getFieldType$i,
            getInContextFragmentType: getInContextFragmentType$j
        };
        case "LongValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1B,
            getInContextFragmentType: getInContextFragmentType$1B
        };
        case "DependentField": return {
            getMinimumSelections: getMinimumSelections$M,
            getFieldType: getFieldType$K,
            getInContextFragmentType: getInContextFragmentType$L
        };
        case "Setup__SetupConnection": return {
            getMinimumSelections: getMinimumSelections$p,
            getFieldType: getFieldType$n,
            getInContextFragmentType: getInContextFragmentType$o
        };
        case "PercentValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1A,
            getInContextFragmentType: getInContextFragmentType$1A
        };
        case "BooleanAggregate": return {
            getMinimumSelections: getMinimumSelections$17,
            getFieldType: getFieldType$15,
            getInContextFragmentType: getInContextFragmentType$16
        };
        case "RecordQueryAggregate": return {
            getMinimumSelections: getMinimumSelections$O,
            getFieldType: getFieldType$M,
            getInContextFragmentType: getInContextFragmentType$N
        };
        case "RecordConnection": return {
            getMinimumSelections: getMinimumSelections$19,
            getFieldType: getFieldType$17,
            getInContextFragmentType: getInContextFragmentType$18
        };
        case "FilteredLookupInfo": return {
            getMinimumSelections: getMinimumSelections$L,
            getFieldType: getFieldType$J,
            getInContextFragmentType: getInContextFragmentType$K
        };
        case "ObjectInfo": return {
            getMinimumSelections: getMinimumSelections$G,
            getFieldType: getFieldType$E,
            getInContextFragmentType: getInContextFragmentType$F
        };
        case "Field": return {
            getMinimumSelections: getMinimumSelections$J,
            getFieldType: getFieldType$H,
            getInContextFragmentType: getInContextFragmentType$I
        };
        case "RateLimit": return {
            getMinimumSelections: getMinimumSelections$7,
            getFieldType: getFieldType$7,
            getInContextFragmentType: getInContextFragmentType$7
        };
        case "UIAPIMutations": return {
            getMinimumSelections: getMinimumSelections$6,
            getFieldType: getFieldType$6,
            getInContextFragmentType: getInContextFragmentType$6
        };
        case "Base64Value": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1e,
            getInContextFragmentType: getInContextFragmentType$1e
        };
        case "EncryptedStringValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1k,
            getInContextFragmentType: getInContextFragmentType$1k
        };
        case "Record": return {
            getMinimumSelections: getMinimumSelections$5,
            getFieldType: getFieldType$5,
            getInContextFragmentType: getInContextFragmentType$5
        };
        case "Setup__SetupPolymorphicAggregateParentRelationship": return {
            getMinimumSelections: getMinimumSelections$n,
            getFieldType: getFieldType$l,
            getInContextFragmentType: getInContextFragmentType$m
        };
        case "CompoundField": return {
            getMinimumSelections: getMinimumSelections$1c,
            getFieldType: getFieldType$1b,
            getInContextFragmentType: getInContextFragmentType$1b
        };
        case "ChildRelationship": return {
            getMinimumSelections: getMinimumSelections$N,
            getFieldType: getFieldType$L,
            getInContextFragmentType: getInContextFragmentType$M
        };
        case "RecordResult": return {
            getMinimumSelections: getMinimumSelections$R,
            getFieldType: getFieldType$P,
            getInContextFragmentType: getInContextFragmentType$Q
        };
        case "PageInfo": return {
            getMinimumSelections: getMinimumSelections$1b,
            getFieldType: getFieldType$19,
            getInContextFragmentType: getInContextFragmentType$1a
        };
        case "CurrencyValue": return {
            getMinimumSelections: getMinimumSelections$d,
            getFieldType: getFieldType$1j,
            getInContextFragmentType: getInContextFragmentType$1j
        };
        case "DateFunctionAggregation": return {
            getMinimumSelections: getMinimumSelections$15,
            getFieldType: getFieldType$13,
            getInContextFragmentType: getInContextFragmentType$14
        };
        case "RecordQuery": return {
            getMinimumSelections: getMinimumSelections$18,
            getFieldType: getFieldType$16,
            getInContextFragmentType: getInContextFragmentType$17
        };
        case "Analytics__Analytics": return {
            getMinimumSelections: getMinimumSelections$u,
            getFieldType: getFieldType$s,
            getInContextFragmentType: getInContextFragmentType$t
        };
        case "Analytics__AnalyticsBrowse": return {
            getMinimumSelections: getMinimumSelections$v,
            getFieldType: getFieldType$t,
            getInContextFragmentType: getInContextFragmentType$u
        };
        case "Analytics__AnalyticsEdge": return {
            getMinimumSelections: getMinimumSelections$w,
            getFieldType: getFieldType$u,
            getInContextFragmentType: getInContextFragmentType$v
        };
        case "Analytics__AnalyticsRepresentationInterface": return {
            getMinimumSelections: getMinimumSelections,
            getFieldType: getFieldType,
            getInContextFragmentType: getInContextFragmentType
        };
        case "Analytics__AnalyticsRepresentation": return {
            getMinimumSelections: getMinimumSelections$x,
            getFieldType: getFieldType$v,
            getInContextFragmentType: getInContextFragmentType$w
        };
        case "Analytics__SemanticDefinition": return {
            getMinimumSelections: getMinimumSelections$1,
            getFieldType: getFieldType$1,
            getInContextFragmentType: getInContextFragmentType$1
        };
        case "Analytics__AnalyticsWorkspaceAssetConnection": return {
            getMinimumSelections: getMinimumSelections$y,
            getFieldType: getFieldType$w,
            getInContextFragmentType: getInContextFragmentType$x
        };
        case "Analytics__AnalyticsWorkspaceAssetEdge": return {
            getMinimumSelections: getMinimumSelections$z,
            getFieldType: getFieldType$x,
            getInContextFragmentType: getInContextFragmentType$y
        };
        case "Analytics__AnalyticsWorkspaceAsset": return {
            getMinimumSelections: getMinimumSelections$A,
            getFieldType: getFieldType$y,
            getInContextFragmentType: getInContextFragmentType$z
        };
        case "Analytics__AnalyticsWorkspace": return {
            getMinimumSelections: getMinimumSelections$B,
            getFieldType: getFieldType$z,
            getInContextFragmentType: getInContextFragmentType$A
        };
        case "Analytics__SemanticSubMetricDefinitionConnection": return {
            getMinimumSelections: getMinimumSelections$2,
            getFieldType: getFieldType$2,
            getInContextFragmentType: getInContextFragmentType$2
        };
        case "Analytics__SemanticSubMetricDefinitionEdge": return {
            getMinimumSelections: getMinimumSelections$3,
            getFieldType: getFieldType$3,
            getInContextFragmentType: getInContextFragmentType$3
        };
        case "Analytics__SemanticSubMetricDefinitionRepresentation": return {
            getMinimumSelections: getMinimumSelections$4,
            getFieldType: getFieldType$4,
            getInContextFragmentType: getInContextFragmentType$4
        };
        default:
            return undefined;
    }
}
function sharedGetFragmentType(fragment, fragmentMap) {
    const typeCondition = fragment.kind === 'FragmentSpread' ? fragmentMap[fragment.name.value].typeCondition : fragment.typeCondition;
    return typeCondition !== undefined ? typeCondition.name.value : undefined;
}
function getSelectionSetFromFragment(fragment, fragmentMap) {
    return fragment.kind === 'FragmentSpread' ? fragmentMap[fragment.name.value].selectionSet : fragment.selectionSet;
}
// Shared export so that we dont repeat this in every connection type. Using fields for now since untyped inline fragment fails on Core
function getCursorConnectionMinimumSelections() {
    return [{
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'edges',
            },
            selectionSet: {
                kind: 'SelectionSet',
                selections: [{
                        kind: 'Field',
                        name: {
                            kind: 'Name',
                            value: 'node',
                        },
                    },
                    {
                        kind: 'Field',
                        name: {
                            kind: 'Name',
                            value: 'cursor',
                        },
                    },
                ]
            },
        },
        {
            kind: 'Field',
            name: {
                kind: 'Name',
                value: 'pageInfo',
            },
            selectionSet: {
                kind: 'SelectionSet',
                selections: [{
                        kind: 'Field',
                        name: {
                            kind: 'Name',
                            value: 'hasNextPage',
                        },
                    },
                    {
                        kind: 'Field',
                        name: {
                            kind: 'Name',
                            value: 'endCursor',
                        },
                    },
                    {
                        kind: 'Field',
                        name: {
                            kind: 'Name',
                            value: 'startCursor',
                        },
                    },
                ]
            },
        },
    ];
}
// Shared export for evaluating the value of an argument
function evaluateArgumentValue(argumentNode, expectedKind, variables) {
    if (argumentNode === undefined) {
        return undefined;
    }
    switch (argumentNode.value.kind) {
        case expectedKind:
            return argumentNode.value.value;
        case 'Variable':
            return variables[argumentNode.value.name.value] !== null ? variables[argumentNode.value.name.value] : undefined;
        default:
            return undefined;
    }
}
// Shared export for getting the offset of the current page in the edges array
function getArrayOffsetForPage(state, node, key) {
    const { variables, data, store } = state;
    // if we have pagination metadata, see if we can locate either the start or
    // after cursor in it to determine the correct index to use for the fullPath
    const paginationKey = key + '__pagination';
    let existingPaginationMetadata = store.readEntry(paginationKey);
    const afterArg = node.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', variables);
    if (existingPaginationMetadata !== undefined) {
        // if the starting cursor for current page exists in the existing metadata use that as offset
        if (existingPaginationMetadata[data.pageInfo.startCursor] !== undefined) {
            return existingPaginationMetadata[data.pageInfo.startCursor];
        }
        else if (afterArgVal !== undefined && existingPaginationMetadata[afterArgVal] !== undefined) {
            // We need to ingest at the end of the array so use the after value and add 1
            const previousPageOffset = existingPaginationMetadata[afterArgVal];
            return previousPageOffset + 1;
        }
    }
    return 0;
}
function isFragmentApplicable(fragmentNode, implementedInterfaces, graphqlTypeName, typename) {
    const isUntypedInlineFragment = fragmentNode.typeCondition === undefined;
    const matchesTypeCondition = !isUntypedInlineFragment && fragmentNode.typeCondition.name.value === graphqlTypeName;
    const doesImplementInterface = !isUntypedInlineFragment && implementedInterfaces.includes(fragmentNode.typeCondition.name.value);
    const typenameMatchesCondition = typename !== undefined && !isUntypedInlineFragment && typename === fragmentNode.typeCondition.name.value;
    return isUntypedInlineFragment || matchesTypeCondition || doesImplementInterface || typenameMatchesCondition;
}
function buildSelectionForNode(source, reader, parentNode, selectionNode, variables, fragments, isFragmentApplicable, buildSelectionForField, parentRecordId) {
    const sink = {};
    if (selectionNode.directives) {
        const selectionWithDirectives = applyDirectivesForSelection(selectionNode, variables);
        if (selectionWithDirectives === undefined) {
            return;
        }
        selectionNode = selectionWithDirectives;
    }
    if (selectionNode.kind === "InlineFragment") {
        if (isFragmentApplicable(selectionNode, source.data.__typename)) {
            // Get selections out of the inline fragment
            selectionNode.selectionSet.selections.forEach(fragmentSelection => {
                // Call into field handling with selections
                Object.assign(sink, buildSelectionForNode(source, reader, parentNode, fragmentSelection, variables, fragments, isFragmentApplicable, buildSelectionForField, parentRecordId));
            });
        }
    }
    if (selectionNode.kind === "FragmentSpread") {
        const namedFragment = fragments[selectionNode.name.value];
        if (namedFragment && isFragmentApplicable(namedFragment, source.data.__typename)) {
            namedFragment.selectionSet.selections.forEach(fragmentSelection => {
                // Call into field handling with selections
                Object.assign(sink, buildSelectionForNode(source, reader, parentNode, fragmentSelection, variables, fragments, isFragmentApplicable, buildSelectionForField, parentRecordId));
            });
        }
    }
    if (selectionNode.kind === "Field") {
        Object.assign(sink, buildSelectionForField(source, reader, selectionNode, variables, fragments, parentRecordId));
    }
    return sink;
}
function buildSelectionForField(source, reader, sel, variables, fragments, isCursorConnectionType, getFieldData, getFieldType, selectType, parentRecordId) {
    const sink = {};
    const fieldData = getFieldData(source, sel, variables);
    const requestedFieldName = sel.alias ? sel.alias.value : sel.name.value;
    if (isCursorConnectionType && requestedFieldName === 'pageInfo') {
        return;
    }
    reader.enterPath(requestedFieldName);
    if (fieldData === undefined) {
        reader.markMissing();
        reader.exitPath();
        return;
    }
    if (fieldData === null) {
        reader.assignScalar(requestedFieldName, sink, fieldData);
        reader.exitPath();
        return sink;
    }
    const fieldType = getFieldType(sel);
    if (fieldType === undefined) {
        // This field's type is unknown to us. This breaks normalization.
        console.warn(`Unknown Field: ${requestedFieldName}. This field or nested fields cannot participate in normalization`);
        reader.assignNonScalar(sink, requestedFieldName, fieldData);
    }
    else if (fieldType.isArray) {
        const arraySink = [];
        reader.markSeenId(parentRecordId); // Always mark the parent of an array as seen.
        for (let i = 0, len = fieldData.length; i < len; i += 1) {
            reader.enterPath(i);
            selectType(fieldType.typename, sel, fieldData[i], reader, i, arraySink, variables, fragments, parentRecordId);
            reader.exitPath();
        }
        reader.assignNonScalar(sink, requestedFieldName, arraySink);
    }
    else {
        selectType(fieldType.typename, sel, fieldData, reader, requestedFieldName, sink, variables, fragments, parentRecordId);
    }
    reader.exitPath();
    return sink;
}
function selectTypeLink(sel, fieldData, reader, key, sink, variables, fragments, version, selectFn, isCursorConnection) {
    const resolvedLink = resolveLink(reader, fieldData, version);
    if (resolvedLink && resolvedLink.data !== undefined) {
        if (isCursorConnection) {
            selectTypeLinkWithPagination(resolvedLink, sel, fieldData, reader, key, sink, variables, fragments, selectFn);
        }
        else {
            const result = selectFn(sel, variables, fragments)(resolvedLink.data, reader, resolvedLink.recordId);
            reader.assignNonScalar(sink, key, result);
        }
    }
    else {
        reader.markMissingLink(fieldData.__ref);
        reader.markMissing();
    }
}
function augmentDefaultVariableValues(variableDefinitions, variables) {
    variableDefinitions.forEach(({ defaultValue, variable }) => {
        if (defaultValue !== undefined && variables[variable.name.value] === undefined) {
            switch (defaultValue.kind) {
                case ("IntValue"):
                case ("FloatValue"):
                    variables[variable.name.value] = Number(defaultValue.value);
                    break;
                case ("NullValue"):
                    variables[variable.name.value] = null;
                    break;
                case ("BooleanValue"):
                case ("StringValue"):
                case ("EnumValue"):
                    variables[variable.name.value] = defaultValue.value;
            }
        }
    });
}
function selectCalculateSink(sink, field, buildSelectionForNodeFn, source, reader, variables, fragments, parentRecordId) {
    field.selectionSet?.selections.forEach((sel) => {
        const builtSelection = buildSelectionForNodeFn(source, reader, field, sel, variables, fragments, parentRecordId);
        if (builtSelection !== undefined) {
            deepMerge(sink, builtSelection);
        }
    });
    return sink;
}
function selectTypeLinkWithPagination(resolvedLink, sel, fieldData, reader, key, sink, variables, fragments, selectFn) {
    const source = resolvedLink.data.data;
    const parentRecordId = resolvedLink.recordId;
    const totalEdges = source.edges !== undefined ? source.edges.length : 0;
    const metadata = reader.resolveMetadata(source, PAGINATION_VERSION);
    if (metadata === undefined) {
        reader.markMissingLink(fieldData.__ref);
        reader.markMissing();
        return;
    }
    const firstArg = sel.arguments?.find(argument => { return argument.name.value === 'first'; });
    const firstArgVal = evaluateArgumentValue(firstArg, 'IntValue', variables);
    const pageSize = firstArgVal !== undefined ? firstArgVal : totalEdges;
    const afterArg = sel.arguments?.find(argument => { return argument.name.value === 'after'; });
    const afterArgVal = evaluateArgumentValue(afterArg, 'StringValue', variables);
    const paginationParams = {
        pageSize: parseInt(pageSize, 10),
        token: afterArgVal
    };
    let { startOffset, endOffset } = getPageMetadata(metadata, paginationParams);
    const listIsComplete = (metadata.__END__ !== undefined);
    let trimmedEdges = [];
    let maxOffset = undefined;
    if (process.env.NODE_ENV !== 'production') {
        const afterArgIsUnknownToLuvio = afterArgVal !== undefined && (startOffset === undefined || endOffset === undefined);
        if (afterArgIsUnknownToLuvio) {
            throw new RangeError("after argument value '" + afterArgVal + "' is unknown in the list. Check that non-paging arguments are constant when paginating.");
        }
    }
    if (totalEdges === 0 && listIsComplete) {
        // We have an empty edge list
        // If after token was specified, it will never be a good cursor, so defer to a cache miss
        if (afterArgVal !== undefined) {
            reader.markMissingLink(fieldData.__ref);
            reader.markMissing();
            return;
        }
    }
    else if (totalEdges === 0 && !listIsComplete) {
        // empty edge list, but the list isn't complete?
        if (process.env.NODE_ENV !== 'production') {
            throw new Error("page size of zero, but pageInfo .hasNextPage is true.");
        }
    }
    else {
        if (startOffset === undefined || endOffset === undefined) {
            reader.markMissingLink(fieldData.__ref);
            reader.markMissing();
            return;
        }
        // gql paging semantics is "after" the requested cursor, so shift the offsets provided a valid cursor is provided
        if (afterArgVal !== undefined) {
            startOffset++;
            // if the "first" argument was not provided then the endOffset
            // is already set to the index of the last edge.
            // if the "first" argument was provided then we need to increment the endOffset
            // however we still need to make sure the endOffset doesn't go past totalEdges
            // if the list is already complete and we can't fetch any more edges
            if (firstArgVal !== undefined && (!listIsComplete || endOffset < totalEdges)) {
                endOffset++;
            }
        }
        if (startOffset >= totalEdges && listIsComplete) {
            // Data after the last page was requested, return empty set
            startOffset = undefined;
            endOffset = undefined;
        }
        else {
            trimmedEdges = trimEdges(source.edges, startOffset, endOffset);
            maxOffset = findMaxOffset(metadata);
            const listHasEnoughItems = (endOffset - 1 <= maxOffset);
            if (trimmedEdges === undefined || !listHasEnoughItems) {
                reader.markMissingLink(fieldData.__ref);
                reader.markMissing();
                // optimize pagination when "first" and "after" args are part of the variable
                if (firstArg?.value?.kind === 'Variable' && afterArg?.value?.kind === 'Variable') {
                    optimizePagination(metadata, firstArg.value.name.value, afterArg.value.name.value, variables);
                }
                return;
            }
        }
    }
    deepFreeze(trimmedEdges);
    const paginatedData = {
        data: {
            ...source,
            edges: trimmedEdges,
        }
    };
    reader.markSeenId(parentRecordId);
    const result = selectFn(sel, variables, fragments)(paginatedData, reader, parentRecordId);
    const pageInfo = createPageInfo(result?.edges, startOffset, endOffset, maxOffset, metadata);
    if (pageInfo !== undefined) {
        const selectedPageInfo = selectPageInfo(sel.selectionSet?.selections, fragments, pageInfo);
        if (selectedPageInfo !== undefined) {
            reader.assignNonScalar(result, 'pageInfo', selectedPageInfo);
        }
    }
    reader.assignNonScalar(sink, key, result);
}
function selectPageInfo(selections, fragments, pageInfo) {
    const pageInfoSelection = getSelectionNode(selections, fragments, 'pageInfo');
    if (pageInfo === undefined || pageInfoSelection === undefined || pageInfoSelection.kind !== 'Field')
        return undefined;
    const pageInfoSelections = pageInfoSelection.selectionSet?.selections;
    const selectedPageInfo = Object.assign({}, pageInfo);
    Object.keys(pageInfo).forEach((fieldName) => {
        if (getSelectionNode(pageInfoSelections, fragments, fieldName) === undefined) {
            delete selectedPageInfo[fieldName];
        }
    });
    return selectedPageInfo;
}
function getSelectionNode(selections, fragments, fieldName) {
    if (selections === undefined)
        return undefined;
    for (let i = 0; i < selections.length; i++) {
        const selection = selections[i];
        if (selection.kind === 'Field' && selection.name.value === fieldName) {
            return selection;
        }
        else if (selection.kind === 'FragmentSpread') {
            const fragment = fragments[selection.name.value];
            return getSelectionNode(fragment?.selectionSet.selections, fragments, fieldName);
        }
        else if (selection.kind === 'InlineFragment') {
            return getSelectionNode(selection.selectionSet.selections, fragments, fieldName);
        }
    }
    return undefined;
}

const TTL = 900000;
const VERSION$7 = "b440235e7e724631f92002fe50e3e096";
const RepresentationType = 'GraphQLRepresentation';
function select$9(luvio, document, variables, operationName) {
    const operationToExecute = getOperationFromDocument(document, operationName);
    return {
        kind: 'Fragment',
        synthetic: true,
        reader: true,
        read: (builder) => {
            builder.enterPath('data');
            const gqlData = {};
            if (operationToExecute === undefined) {
                builder.markMissing(); // Never give a cache hit for an undefined operation
                return gqlData;
            }
            if (operationToExecute.variableDefinitions !== undefined) {
                augmentDefaultVariableValues(operationToExecute.variableDefinitions, variables);
            }
            const fragments = createFragmentMap(document);
            const queryTypeRecordId = keyBuilder$4(luvio, operationToExecute, variables, fragments);
            const snapshot = builder.read({
                recordId: queryTypeRecordId,
                node: {
                    kind: 'Fragment',
                    private: [],
                    opaque: true,
                    version: VERSION$8
                },
                variables: {}
            });
            if (snapshot.data === undefined) {
                builder.markMissingLink(queryTypeRecordId);
            }
            else {
                const data = select$a(operationToExecute, variables, fragments)(snapshot.data, builder, queryTypeRecordId);
                builder.assignNonScalar(gqlData, 'data', data);
            }
            builder.exitPath();
            return gqlData;
        }
    };
}
function ingestOperationNode(luvio, input, node, state) {
    if (node.operation === 'query') {
        if (node.variableDefinitions !== undefined) {
            augmentDefaultVariableValues(node.variableDefinitions, state.variables);
        }
        ingest$1(node, {
            ...state,
            path: {
                ...state.path,
                fullPath: ''
            }
        });
    }
}
const ingest = function GraphQLRepresentationIngest(document, variables, operationName) {
    return (input, path, luvio, store, timestamp) => {
        if (input.data) {
            const fragments = createFragmentMap(document);
            const state = {
                data: input.data,
                luvio,
                store,
                timestamp,
                path: path,
                variables,
                fragments,
            };
            const operationToExecute = getOperationFromDocument(document, operationName);
            if (operationToExecute !== undefined) {
                ingestOperationNode(luvio, input, operationToExecute, state);
            }
        }
        return {
            __ref: undefined
        };
    };
};
function getTypeCacheKeys(sink, luvio, document, variables, data, operationName) {
    if (data.data) {
        const fragments = createFragmentMap(document);
        const operationToExecute = getOperationFromDocument(document, operationName);
        if (operationToExecute !== undefined) {
            const state = {
                luvio,
                variables,
                fragments,
                data: data.data,
                path: {
                    parent: null,
                    propertyName: null,
                    fullPath: '' // TODO: W-13079691 - Need to take another pass at what we want to do for structured keys
                }
            };
            getTypeCacheKeys$1(sink, operationToExecute, state);
        }
    }
    return sink;
}

function select$8(luvio, config) {
    const { query, variables, operationName } = config;
    return select$9(luvio, query, variables, operationName);
}
function keyBuilder$3(luvio, params) {
    const { query, operationName, variables } = params.body;
    const operationToExecute = getOperationFromDocument(query, operationName);
    if (operationToExecute !== undefined) {
        const fragments = createFragmentMap(query);
        return keyBuilder$4(luvio, operationToExecute, variables || {}, fragments);
    }
    return `adapters_adapter$45$utils_keyPrefix::GraphQLRepresentation::InvalidOperation`;
}
function getResponseCacheKeys$1(cacheKeys, luvio, resourceParams, response) {
    const query = resourceParams.body.query;
    const variables = resourceParams.body.variables || {};
    const operationName = resourceParams.body.operationName;
    getTypeCacheKeys(cacheKeys, luvio, query, variables, response, operationName);
}
function ingestSuccess$1(luvio, config, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$3(luvio, resourceParams);
    const { query, variables, operationName } = resourceParams.body;
    luvio.storeIngest(key, ingest(query, variables, operationName), body);
    // revert the optimized pagination variables back to its original so that subsequent store lookup will include all records, not just the ones loaded by an optimized query
    // see optimizePagination for initial update to optimize the query
    revertPaginationOptimization(variables);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$8(luvio, config),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    return snapshot;
}
function ingestError$1(luvio, config, params, error, snapshotRefresh) {
    const key = keyBuilder$3(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL,
        namespace: keyPrefix,
        representationName: RepresentationType,
        version: VERSION$7
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$2(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/graphql',
        method: 'post',
        body: { ...config.body,
            query: print(config.body.query)
        },
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

function stripMetaschemaFromFieldNode(fieldNode) {
    if (fieldNode.directives) {
        const indexOfCategoryDirective = fieldNode.directives.findIndex((directive) => directive.name.value === 'category');
        if (indexOfCategoryDirective !== -1) {
            const newDirectives = fieldNode.directives
                .slice(0, indexOfCategoryDirective)
                .concat(fieldNode.directives.slice(indexOfCategoryDirective + 1));
            return {
                ...fieldNode,
                directives: newDirectives,
            };
        }
    }
    return fieldNode;
}
function stripDocumentOfMetaschema(documentNode) {
    return visit(documentNode, {
        Field(node) {
            return stripMetaschemaFromFieldNode(node);
        },
    });
}
function createResourceRequest$1(config) {
    const queryWithoutMetaschemaDirectives = stripDocumentOfMetaschema(config.body.query);
    const newBody = {
        ...config.body,
        query: queryWithoutMetaschemaDirectives,
    };
    return createResourceRequest$2({
        ...config,
        body: newBody,
    });
}

const adapterName$3 = 'graphql';
const graphql_ConfigPropertyMetadata = [
    generateParamConfigMetadata('operationName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('query', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('variables', false, 2 /* Body */, 4 /* Unsupported */),
];
const graphql_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$3, graphql_ConfigPropertyMetadata);
const createResourceParams$1 = /*#__PURE__*/ createResourceParams$2(graphql_ConfigPropertyMetadata);
function keyBuilder$2(luvio, config) {
    const resourceParams = createResourceParams$1(config);
    return keyBuilder$3(luvio, resourceParams);
}
function typeCheckConfig$1(untrustedConfig) {
    const config = {};
    const untrustedConfig_operationName = untrustedConfig.operationName;
    if (typeof untrustedConfig_operationName === 'string') {
        config.operationName = untrustedConfig_operationName;
    }
    const untrustedConfig_query = untrustedConfig.query;
    if (untrustedIsObject(untrustedConfig_query) && untrustedConfig_query.kind === 'Document') {
        config.query = untrustedConfig_query;
    }
    const untrustedConfig_variables = untrustedConfig.variables;
    if (untrustedIsObject(untrustedConfig_variables)) {
        const untrustedConfig_variables_object = {};
        const untrustedConfig_variables_keys = Object.keys(untrustedConfig_variables);
        for (let i = 0, arrayLength = untrustedConfig_variables_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_variables_keys[i];
            const untrustedConfig_variables_prop = untrustedConfig_variables[key];
            if (untrustedConfig_variables_object !== undefined) {
                untrustedConfig_variables_object[key] = untrustedConfig_variables_prop;
            }
        }
        if (untrustedConfig_variables_object !== undefined && Object.keys(untrustedConfig_variables_object).length >= 0) {
            config.variables = untrustedConfig_variables_object;
        }
    }
    return config;
}
function validateAdapterConfig$2(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$1(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function transformConfiguration$1(config) {
    // Make a copy of the config before running transform to avoid mutating the original config
    const adapterConfigCopy = {
        ...config,
        query: parse(print(config.query))
    };
    return {
        ...adapterConfigCopy,
        query: applyMinimumFieldsToQuery(adapterConfigCopy.query)
    };
}
function adapterFragment$1(luvio, config) {
    return select$8(luvio, config);
}
function onFetchResponseSuccess$1(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$1(luvio, config, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$1(luvio, config, resourceParams, response) {
    const snapshot = ingestError$1(luvio, config, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$1(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$1(luvio, config, options) {
    const resourceParams = createResourceParams$1(transformConfiguration$1(config));
    const request = createResourceRequest$1(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        const graphqlErrors = response?.body?.errors;
        if ((graphqlErrors || []).length === 0) {
            return response;
        }
        return Promise.reject({ errorType: 'adapterError', error: response?.body?.errors });
    })
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$1(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$1(cache, luvio, resourceParams, response.body);
            return cache;
        });
    })
        .catch((response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$1(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$1(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$2(context, coercedAdapterRequestContext, buildNetworkSnapshot$1, undefined, false);
}
function buildCachedSnapshotCachePolicy$1(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$2(luvio, config),
        node: adapterFragment$1(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$1(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}

/**
 * Defines configuration for the module with a default value which can be overridden by the runtime environment.
 */
// A holder for a configurable adapter override
class Configurable {
    constructor() {
        this.getAdapter = () => {
            return this.adapter;
        };
        this.setAdapter = (value) => {
            this.adapter = value;
        };
        this.adapter = undefined;
    }
}
// Configurable adapters that can have environmental overrides
let configurableCreateRecordAdapter = new Configurable();
let configurableUpdateRecordAdapter = new Configurable();
let configurableDeleteRecordAdapter = new Configurable();
let configurablePerformQuickActionAdapter = new Configurable();
let configurablePerformUpdateRecordQuickActionAdapter = new Configurable();
let configurableCreateContentDocumentAndVersion = new Configurable();
let configurableCreateContentVersion = new Configurable();
/**
 * Depth to which tracked fields will be added to a request that results from a cache miss.
 * A value of 0 inhibits the addition of tracked fields, 1 will add tracked fields that can
 * be reached by following 1 relationship from the root record, etc.
 * @defaultValue '5', replicates the current behavior
 */
let trackedFieldDepthOnCacheMiss = 5;
/**
 * Depth to which tracked fields will be added to a request that results from a merge conflict
 * A value of 0 inhibits the addition of tracked fields, 1 will add tracked fields that can
 * be reached by following 1 relationship from the root record, etc.
 * @defaultValue '5', replicates the current behavior
 */
let trackedFieldDepthOnCacheMergeConflict = 5;
/**
 * Depth to which tracked fields will be added to a request that results from a notify change invocation by the consumer
 * A value of 0 inhibits the addition of tracked fields, 1 will add tracked fields that can
 * be reached by following 1 relationship from the root record, etc.
 * @defaultValue '5', replicates the current behavior
 */
let trackedFieldDepthOnNotifyChange = 5;
/**
 * Determines if we will only fetch the 'Id' field for the leaf relationship record
 * @defaultValue 'false', replicates the current behavior and fetches all fields in the store for the leaf relationship record
 */
let trackedFieldLeafNodeIdAndNameOnly = false;
/**
 * One store enabled Get Object Info adapter
 */
let oneStoreGetObjectInfoAdapter = undefined;
/**
 * One store enabled Get Object Infos adapter
 */
let oneStoreGetObjectInfosAdapter = undefined;
/**
 * Determines when to include PDL strategies for Related Lists
 */
let relatedListsPredictionsEnabled = false;
/**
 * Determines whether to include additional PDL strategies for Related Lists
 */
let relatedListsPlusPredictionsEnabled = false;
let recordRepresentationIngestionOverride = undefined;
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for one store enabled REST adapters only.
 */
const configurationForOneStoreEnabledAdapters = {
    setGetObjectInfoAdapter: function (adapter) {
        oneStoreGetObjectInfoAdapter = adapter;
    },
    getGetObjectInfoAdapter: function () {
        return oneStoreGetObjectInfoAdapter;
    },
    setGetObjectInfosAdapter: function (adapter) {
        oneStoreGetObjectInfosAdapter = adapter;
    },
    getGetObjectInfosAdapter: function () {
        return oneStoreGetObjectInfosAdapter;
    },
};
const getKeywordSearchResultsFactory = new Configurable();
const getListRecordsByNameFactory = new Configurable();
const getListUiFactory = new Configurable();
const getLookupRecordsFactory = new Configurable();
const getQuickActionDefaultsFactory = new Configurable();
const getRecordCreateDefaultsFactory = new Configurable();
const getRecordTemplateCloneFactory = new Configurable();
const getRecordTemplateCreateFactory = new Configurable();
const getRecordUiFactory = new Configurable();
const getRecordFactory = new Configurable();
const getRecordsFactory = new Configurable();
const getRelatedListRecordsFactory = new Configurable();
const getRelatedListRecordsBatchFactory = new Configurable();
const getSearchResultsFactory = new Configurable();
// The following set of adapters all touch RecordRepresentation directly or indirectly,
// so they need to support having a custom factory provided by the mobile environment.
const configurationForEnvironmentFactoryOverrides = {
    getKeywordSearchResultsAdapterFactory: getKeywordSearchResultsFactory.getAdapter,
    setGetKeywordSearchResultsAdapterFactory: getKeywordSearchResultsFactory.setAdapter,
    getListRecordsByNameAdapterFactory: getListRecordsByNameFactory.getAdapter,
    setGetListRecordsByNameAdapterFactory: getListRecordsByNameFactory.setAdapter,
    getListUiAdapterFactory: getListUiFactory.getAdapter,
    setGetListUiAdapterFactory: getListUiFactory.setAdapter,
    getLookupRecordsAdapterFactory: getLookupRecordsFactory.getAdapter,
    setGetLookupRecordsAdapterFactory: getLookupRecordsFactory.setAdapter,
    getQuickActionDefaultsAdapterFactory: getQuickActionDefaultsFactory.getAdapter,
    setGetQuickActionDefaultsAdapterFactory: getQuickActionDefaultsFactory.setAdapter,
    getRecordCreateDefaultsAdapterFactory: getRecordCreateDefaultsFactory.getAdapter,
    setGetRecordCreateDefaultsAdapterFactory: getRecordCreateDefaultsFactory.setAdapter,
    getRecordTemplateCloneAdapterFactory: getRecordTemplateCloneFactory.getAdapter,
    setGetRecordTemplateCloneAdapterFactory: getRecordTemplateCloneFactory.setAdapter,
    getRecordTemplateCreateAdapterFactory: getRecordTemplateCreateFactory.getAdapter,
    setGetRecordTemplateCreateAdapterFactory: getRecordTemplateCreateFactory.setAdapter,
    getRecordUiAdapterFactory: getRecordUiFactory.getAdapter,
    setGetRecordUiAdapterFactory: getRecordUiFactory.setAdapter,
    getRecordAdapterFactory: getRecordFactory.getAdapter,
    setGetRecordAdapterFactory: getRecordFactory.setAdapter,
    getRecordsAdapterFactory: getRecordsFactory.getAdapter,
    setGetRecordsAdapterFactory: getRecordsFactory.setAdapter,
    getRelatedListRecordsAdapterFactory: getRelatedListRecordsFactory.getAdapter,
    setGetRelatedListRecordsAdapterFactory: getRelatedListRecordsFactory.setAdapter,
    getRelatedListRecordsBatchAdapterFactory: getRelatedListRecordsBatchFactory.getAdapter,
    setGetRelatedListRecordsBatchAdapterFactory: getRelatedListRecordsBatchFactory.setAdapter,
    getSearchResultsAdapterFactory: getSearchResultsFactory.getAdapter,
    setGetSearchResultsAdapterFactory: getSearchResultsFactory.setAdapter,
};
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for REST adapters only.
 */
const configurationForRestAdapters = {
    setTrackedFieldDepthOnCacheMiss: function (trackedFieldDepthOnCacheMissParam) {
        trackedFieldDepthOnCacheMiss = trackedFieldDepthOnCacheMissParam;
    },
    getTrackedFieldDepthOnCacheMiss: function () {
        return trackedFieldDepthOnCacheMiss;
    },
    setTrackedFieldDepthOnCacheMergeConflict: function (trackedFieldDepthOnCacheMergeConflictParam) {
        trackedFieldDepthOnCacheMergeConflict = trackedFieldDepthOnCacheMergeConflictParam;
    },
    getTrackedFieldDepthOnCacheMergeConflict: function () {
        return trackedFieldDepthOnCacheMergeConflict;
    },
    setTrackedFieldDepthOnNotifyChange: function (trackedFieldDepthOnNotifyChangeParam) {
        trackedFieldDepthOnNotifyChange = trackedFieldDepthOnNotifyChangeParam;
    },
    getTrackedFieldDepthOnNotifyChange: function () {
        return trackedFieldDepthOnNotifyChange;
    },
    setTrackedFieldLeafNodeIdAndNameOnly: function (trackedFieldLeafNodeIdAndNameOnlyParam) {
        trackedFieldLeafNodeIdAndNameOnly = trackedFieldLeafNodeIdAndNameOnlyParam;
    },
    getTrackedFieldLeafNodeIdAndNameOnly: function () {
        return trackedFieldLeafNodeIdAndNameOnly;
    },
    setRelatedListsPredictionsEnabled: function (f) {
        relatedListsPredictionsEnabled = f;
    },
    areRelatedListsPredictionsEnabled: function () {
        return relatedListsPredictionsEnabled === true;
    },
    setRelatedListsPlusPredictionsEnabled: function (f) {
        relatedListsPlusPredictionsEnabled = f;
    },
    areRelatedListsPlusPredictionsEnabled: function () {
        return relatedListsPlusPredictionsEnabled === true;
    },
    setRecordRepresentationIngestionOverride: function (ingest) {
        recordRepresentationIngestionOverride = ingest;
    },
    getRecordRepresentationIngestionOverride: function () {
        return recordRepresentationIngestionOverride;
    },
    // createRecord
    getDraftAwareCreateRecordAdapter: configurableCreateRecordAdapter.getAdapter,
    setDraftAwareCreateRecordAdapter: configurableCreateRecordAdapter.setAdapter,
    // updateRecord
    getDraftAwareUpdateRecordAdapter: configurableUpdateRecordAdapter.getAdapter,
    setDraftAwareUpdateRecordAdapter: configurableUpdateRecordAdapter.setAdapter,
    // deleteRecord
    getDraftAwareDeleteRecordAdapter: configurableDeleteRecordAdapter.getAdapter,
    setDraftAwareDeleteRecordAdapter: configurableDeleteRecordAdapter.setAdapter,
    // performQuickAction
    getDraftAwarePerformQuickActionAdapter: configurablePerformQuickActionAdapter.getAdapter,
    setDraftAwarePerformQuickActionAdapter: configurablePerformQuickActionAdapter.setAdapter,
    // performRecordUpdateQuickAction
    getDraftAwarePerformUpdateRecordQuickActionAdapter: configurablePerformUpdateRecordQuickActionAdapter.getAdapter,
    setDraftAwarePerformUpdateRecordQuickActionAdapter: configurablePerformUpdateRecordQuickActionAdapter.setAdapter,
    // createContentDocumentAndVersion
    getDraftAwareCreateContentDocumentAndVersionAdapter: configurableCreateContentDocumentAndVersion.getAdapter,
    setDraftAwareCreateContentDocumentAndVersionAdapter: configurableCreateContentDocumentAndVersion.setAdapter,
    // createContentVersion
    getDraftAwareCreateContentVersionAdapter: configurableCreateContentVersion.getAdapter,
    setDraftAwareCreateContentVersionAdapter: configurableCreateContentVersion.setAdapter,
    ...configurationForOneStoreEnabledAdapters,
    ...configurationForEnvironmentFactoryOverrides,
};
let configurableGraphQLAdapter = new Configurable();
let configurableGraphQLBatchAdapter = new Configurable();
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for GraphQL adapters only.
 */
const configurationForGraphQLAdapters = {
    getDraftAwareGraphQLAdapter: configurableGraphQLAdapter.getAdapter,
    setDraftAwareGraphQLAdapter: configurableGraphQLAdapter.setAdapter,
    getEnvironmentAwareGraphQLBatchAdapter: configurableGraphQLBatchAdapter.getAdapter,
    setEnvironmentAwareGraphQLBatchAdapter: configurableGraphQLBatchAdapter.setAdapter,
};
const registrations = new Set();
/**
 * lds-adapter-uiapi is special.  The non-SFDC bundle combines REST and GQL adapters,
 * yet for SFDC those are separate bundles.  So non-SFDC bundle (./main.ts) registers
 * both REST and GQL configs.  We want each SFDC bundle to register (we don't want one
 * SFDC bundle to assume the other is being loaded and therefore the other one will
 * take care of registration) but we don't want to double register either.
 *
 * So we make this function that memoizes if it's been called before and only
 * actually registers once.
 */
function ensureRegisteredOnce(registration) {
    const { id } = registration;
    if (!registrations.has(id)) {
        register(registration);
        registrations.add(id);
    }
}

function validateAdapterConfig$1(untrustedConfig, _configPropertyNames) {
    if (untrustedConfig !== null && typeof untrustedConfig === 'object') {
        const operationNameIsDefinedAsUndefined = ObjectPrototypeHasOwnProperty.call(untrustedConfig, 'operationName') &&
            untrustedConfig.operationName === undefined;
        const variablesIsDefinedAsUndefined = ObjectPrototypeHasOwnProperty.call(untrustedConfig, 'variables') &&
            untrustedConfig.variables === undefined;
        if (operationNameIsDefinedAsUndefined || variablesIsDefinedAsUndefined) {
            return null;
        }
    }
    return validateAdapterConfig$2(untrustedConfig, _configPropertyNames);
}

const factory$1 = (luvio) => function graphql(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$1(untrustedConfig, graphql_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const { getDraftAwareGraphQLAdapter } = configurationForGraphQLAdapters;
    const adapter = getDraftAwareGraphQLAdapter();
    if (adapter !== undefined) {
        return adapter(config, requestContext);
    }
    return luvio.applyCachePolicy(requestContext || {}, { config, luvio }, buildCachedSnapshotCachePolicy$1, buildNetworkSnapshotCachePolicy$1);
};

function createResourceRequest(config) {
    const headers = {};
    const transformedConfig = stripDocumentsOfMetaschema(config);
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/graphql/batch',
        method: 'post',
        body: transformedConfig.body,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}
function stripDocumentsOfMetaschema(config) {
    // Map returns a copy of the config before running transform to avoid mutating the original config
    const batchQueryTransformed = config.body.batchQuery.map((singleConfig) => {
        return {
            ...singleConfig,
            query: print(stripDocumentOfMetaschema(singleConfig.query)),
        };
    });
    return {
        ...config,
        body: {
            batchQuery: batchQueryTransformed,
        },
    };
}
// Just iterate over each item
function createChildResourceParams(resourceParams) {
    const childConfigs = [];
    for (let index = 0, len = resourceParams.body.batchQuery.length; index < len; index += 1) {
        const item = resourceParams.body.batchQuery[index];
        childConfigs.push({
            body: {
                ...item,
            },
        });
    }
    return childConfigs;
}
// This function required a few tweaks to make Typescript not angry. And also properly Select based off the original config, not the injected config
function selectChildResourceParams(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$1(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error &&
                result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$3(luvio, childResource);
                const childFragment = select$8(luvio, childResource.body); // MUST read from the ORIGINAL config not injected
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    // eslint-disable-next-line no-fallthrough
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error': {
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    }
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors[childKey];
                            if (nonCachedError === undefined) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            deepFreeze(sink);
            reader.exitPath();
            return sink;
        },
    };
}
// The rest of this is copy-pasted. Sorry.
const nonCachedErrors = ObjectCreate$1(null);
function select$7(luvio, resourceParams) {
    const childResources = createChildResourceParams(resourceParams);
    return selectChildResourceParams(luvio, childResources, resourceParams);
}
function keyBuilder$1(luvio, params) {
    return (keyPrefix +
        '::GraphQLBatchRepresentation:(' +
        'batchQuery:' +
        params.body.batchQuery +
        ')');
}
function getResponseCacheKeys(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' +
                childResourceParamsArray.length +
                ' items, received ' +
                childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$1(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$3(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType,
                mergeable: false,
            });
        }
    }
}
function ingestSuccessChildResourceParams(luvio, childConfigs, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        // There's an assumption here that the config and resource params aren't reordered.
        const childConfig = childConfigs[index];
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$3(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200 &&
            childBody.errors !== undefined &&
            childBody.errors.length === 0) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$1(luvio, childConfig, childResourceParams, childResponse);
            if (childSnapshot.state === 'Stale') {
                snapshotState = 'Stale';
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse',
            };
            ingestError$1(luvio, childResourceParams.body, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors[childKey] = { response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses,
    };
    deepFreeze(childSnapshotData);
    return {
        childSnapshotData: childSnapshotData,
        seenRecords,
        snapshotState,
    };
}
function ingestSuccess(luvio, resourceParams, response, snapshotRefresh // Handrolled to not be optional.
) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' +
                childResourceParamsArray.length +
                ' items, received ' +
                childEnvelopes.length);
        }
    }
    const key = keyBuilder$1(luvio, resourceParams);
    const originalConfig = snapshotRefresh.config; // Can we.. not use the snapshot refresh?
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams(luvio, originalConfig.batchQuery, // can we make this safer?
    childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$7(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {},
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}

function createResourceParams(config) {
    const resourceParams = {
        body: {
            batchQuery: config.batchQuery,
        },
    };
    return resourceParams;
}
function transformConfiguration(config) {
    const batchQueryTransformed = config.batchQuery.map((singleConfig) => {
        return {
            ...singleConfig,
            query: applyMinimumFieldsToQuery(parse(print(singleConfig.query))), // Stringifies and parses again to avoid mutating original. Should we just JSON.stringify to avoid the dependency on the parser?
        };
    });
    return {
        ...config,
        batchQuery: batchQueryTransformed,
    };
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfig_batchQuery = untrustedConfig.batchQuery;
    if (untrustedConfig_batchQuery !== undefined && ArrayIsArray(untrustedConfig_batchQuery)) {
        const untrustedConfig_batchQuery_array = [];
        for (let i = 0, arrayLength = untrustedConfig_batchQuery.length; i < arrayLength; i++) {
            const untrustedConfig_batchQuery_item = untrustedConfig_batchQuery[i];
            // No real validation here - if it's an object and has a query key, add it.
            if (untrustedIsObject(untrustedConfig_batchQuery_item)) {
                const untrustedConfig_batchQuery_item_object = untrustedConfig_batchQuery_item;
                if (untrustedConfig_batchQuery_item_object !== undefined &&
                    ObjectPrototypeHasOwnProperty.call(untrustedConfig_batchQuery_item_object, 'query') // Handrolled validation
                ) {
                    untrustedConfig_batchQuery_array.push(untrustedConfig_batchQuery_item_object);
                }
            }
        }
        config.batchQuery = untrustedConfig_batchQuery_array;
    }
    return config;
}
//  Handroll offline support here
const factory = (luvio) => function UiApi__graphqlBatch(untrustedConfig, requestContext) {
    const config = validateAdapterConfig(untrustedConfig, graphqlBatch_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const { getEnvironmentAwareGraphQLBatchAdapter } = configurationForGraphQLAdapters;
    const adapter = getEnvironmentAwareGraphQLBatchAdapter();
    if (adapter !== undefined) {
        return adapter(config, requestContext);
    }
    return luvio.applyCachePolicy(requestContext || {}, { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy, buildNetworkSnapshotCachePolicy);
};
const graphqlBatch_ConfigPropertyNames = {
    displayName: 'graphqlBatch',
    parameters: {
        required: ['batchQuery'],
        optional: [],
    },
};
function keyBuilder(luvio, config) {
    const resourceParams = createResourceParams(config);
    return keyBuilder$1(luvio, resourceParams);
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment(luvio, config) {
    const resourceParams = createResourceParams(config);
    return select$7(luvio, resourceParams);
}
function onFetchResponseSuccess(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions),
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError(luvio, config, resourceParams, response) {
    const snapshot = ingestError(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions),
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot(luvio, config, options) {
    const resourceParams = createResourceParams(transformConfiguration(config));
    const request = createResourceRequest(resourceParams);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy(context, coercedAdapterRequestContext) {
    const { luvio, config } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
            luvioRequestMethod: 'get',
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot(luvio, config, dispatchOptions);
}
function buildCachedSnapshotCachePolicy(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder(luvio, config),
        node: adapterFragment(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions),
    });
    return cacheSnapshot;
}

let graphql;
let graphqlBatch;
// Imperative GET Adapters
let graphql_imperative;
let graphqlBatch_imperative;
// Adapter Metadata
const graphqlMetadata = { apiFamily: keyPrefix, name: 'graphql', ttl: 900000 };
const graphqlBatchMetadata = { apiFamily: keyPrefix, name: 'graphqlBatch' };
function bindExportsTo(luvio) {
    // LDS adapters
    const graphql_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'graphql', factory$1), graphqlMetadata);
    const graphqlBatch_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'graphqlBatch', factory), graphqlBatchMetadata);
    return {
        // Wire Adapters
        graphql: createGraphQLWireAdapterConstructor(luvio, graphql_ldsAdapter, graphqlMetadata, astResolver),
        graphqlBatch: createGraphQLWireAdapterConstructor(luvio, graphqlBatch_ldsAdapter, graphqlBatchMetadata, astResolver),
        // One Store Enabled Adapters
        // Imperative Adapters
        graphql_imperative: createGraphQLImperativeAdapter(luvio, graphql_ldsAdapter, graphqlMetadata, astResolver),
        graphqlBatch_imperative: createGraphQLImperativeAdapter(luvio, graphqlBatch_ldsAdapter, graphqlBatchMetadata, astResolver),
    };
}
withDefaultLuvio((luvio) => {
    ({
        graphql,
        graphqlBatch,
        graphql_imperative,
        graphqlBatch_imperative,
    } = bindExportsTo(luvio));
});

// For use by callers within this module to instrument interesting things.
let instrumentation = {
    /**
     * Called when a set of record conflicts has been fully resolved. The
     * parameter indicates the number of server requests that were needed
     * to fully resolve all the record conflicts.
     */
    recordConflictsResolved: (_serverRequestCount) => { },
    /**
     * Called during merging of incoming and existing FieldValues.
     * Called when the incoming FieldValue display value is null.
     *
     * Note: Temporary instrumentation to capture distribution and frequency, W-8990630
     * Flipped to counter metric due to W-9611107
     */
    nullDisplayValueConflict: (_fieldInfo) => { },
    /**
     * SFDC Throttling
     * getRecordNotifyChange and notifyRecordUpdateAvailable are both throttled
     */
    getRecordNotifyChangeAllowed: () => { },
    getRecordNotifyChangeDropped: () => { },
    notifyRecordUpdateAvailableAllowed: () => { },
    notifyRecordUpdateAvailableDropped: () => { },
    /**
     * RecordRepresentation merge
     * Called when records change apiName
     */
    recordApiNameChanged: (_existingApiName, _incomingApiName) => { },
    recordTypeIdIsNull: (_apiName) => { },
    /**
     * RecordRepresentation merge
     * Called when either incoming or existing RecordRepresentation has a weakEtag=0
     */
    weakEtagZero: (_incomingWeakEtagZero, _existingWeakEtagZero, _apiName) => { },
    /**
     * getRecord notifyChangeFactory
     * Called when dispatchResourceRequest is resolved/rejected
     */
    getRecordNotifyChangeNetworkResult: (_uniqueWeakEtags, _error) => { },
};
/**
 * Allows external modules (typically a runtime environment) to set
 * instrumentation hooks for this module. Note that the hooks are
 * incremental - hooks not suppiled in newInstrumentation will retain
 * their previous values. The default instrumentation hooks are no-ops.
 *
 * @param newInstrumentation instrumentation hooks to be overridden
 */
function instrument(newInstrumentation) {
    instrumentation = Object.assign(instrumentation, newInstrumentation);
}

function isString(value) {
    return typeof value === 'string';
}
/**
 * @param value The array to dedupe
 * @returns An array without duplicates.
 */
function dedupe(value) {
    const result = {};
    for (let i = 0, len = value.length; i < len; i += 1) {
        result[value[i]] = true;
    }
    return keys(result);
}

function isObjectId(unknown) {
    if (typeof unknown !== 'object' || unknown === null) {
        return false;
    }
    return isString(unknown.objectApiName);
}

/**
 * Returns the object API name.
 * @param value The value from which to get the object API name.
 * @returns The object API name.
 */
function getObjectApiName(value) {
    // Note: tightening validation logic changes behavior from userland getting
    // a server-provided error to the adapter noop'ing. In 224 we decided to not
    // change the behavior.
    if (typeof value === 'string') {
        const trimmed = value.trim();
        if (trimmed.length > 0) {
            return trimmed;
        }
    }
    else if (isObjectId(value)) {
        return value.objectApiName.trim();
    }
    return undefined;
}

function isFieldId(unknown) {
    if (typeof unknown !== 'object' || unknown === null) {
        return false;
    }
    const value = unknown;
    return isString(value.objectApiName) && isString(value.fieldApiName);
}

/**
 * Returns the field API name, qualified with an object name if possible.
 * @param value The value from which to get the qualified field API name.
 * @param onlyQualifiedFieldNames - Whether or not this function should skip fieldApiName that do not include the delimiter '.'
 * @return The qualified field API name.
 */
function getFieldApiName(value, onlyQualifiedFieldNames = false) {
    // Note: tightening validation logic changes behavior from userland getting
    // a server-provided error to the adapter noop'ing. In 224 we decided to not
    // change the behavior. In 250 we decided to add the 'onlyQualifiedFieldName' flag to tighten the logic
    // optionally to avoid issues with persisted invalid field names.
    if (isString(value)) {
        const trimmed = value.trim();
        if (trimmed.length > 0 && (onlyQualifiedFieldNames ? trimmed.indexOf('.') > -1 : true)) {
            return trimmed;
        }
    }
    else if (isFieldId(value)) {
        return value.objectApiName + '.' + value.fieldApiName;
    }
    return undefined;
}

/**
 * Returns the field API name.
 * @param value The value from which to get the field API name.
 * @param options Option bag. onlyQualifiedFieldNames is a boolean that allows this function to skip returning invalid FieldApiNames.
 * @returns The field API name.
 */
function getFieldApiNamesArray(value, options = { onlyQualifiedFieldNames: false }) {
    const valueArray = isArray(value) ? value : [value];
    const array = [];
    for (let i = 0, len = valueArray.length; i < len; i += 1) {
        const item = valueArray[i];
        const apiName = getFieldApiName(item, options.onlyQualifiedFieldNames);
        if (apiName === undefined) {
            if (options.onlyQualifiedFieldNames) {
                continue; // Just skips invalid field names rather than failing to return an array at all
            }
            return undefined;
        }
        push.call(array, apiName);
    }
    if (array.length === 0) {
        return undefined;
    }
    return dedupe(array).sort();
}

const adapterName$2 = 'getListUiByApiName';
const getListUiByApiName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
];
const getListUiByApiName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$2, getListUiByApiName_ConfigPropertyMetadata);

const adapterName$1 = 'getListUiByListViewId';
const getListUiByListViewId_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
];
const getListUiByListViewId_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$1, getListUiByListViewId_ConfigPropertyMetadata);

ObjectCreate$1(null);

ObjectCreate$1(null);

freeze({
    name: '',
    children: {},
});

const adapterName = 'getMruListUi';
const getMruListUi_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
];
const getMruListUi_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName, getMruListUi_ConfigPropertyMetadata);

// make local copies of the adapter configs so we can ignore other getListUi config parameters to match
// lds222 behavior
({
    ...getMruListUi_ConfigPropertyNames,
    parameters: {
        ...getMruListUi_ConfigPropertyNames.parameters,
        optional: [
            ...getMruListUi_ConfigPropertyNames.parameters.optional,
            'listViewApiName',
            'listViewId',
        ],
    },
});

// make local copies of the adapter configs so we can have them ignore each other's config parameters
// to match lds222 behavior
({
    ...getListUiByApiName_ConfigPropertyNames,
    parameters: {
        ...getListUiByApiName_ConfigPropertyNames.parameters,
        optional: [...getListUiByApiName_ConfigPropertyNames.parameters.optional, 'listViewId'],
    },
});
({
    ...getListUiByListViewId_ConfigPropertyNames,
    parameters: {
        ...getListUiByListViewId_ConfigPropertyNames.parameters,
        optional: [
            ...getListUiByListViewId_ConfigPropertyNames.parameters.optional,
            'listViewApiName',
            'objectApiName',
        ],
    },
});

var DiscriminatorValues$4;
(function (DiscriminatorValues) {
    DiscriminatorValues["EmptySpace"] = "EmptySpace";
    DiscriminatorValues["ReportChart"] = "ReportChart";
    DiscriminatorValues["VisualforcePage"] = "VisualforcePage";
    DiscriminatorValues["Canvas"] = "Canvas";
    DiscriminatorValues["Field"] = "Field";
    DiscriminatorValues["CustomLink"] = "CustomLink";
})(DiscriminatorValues$4 || (DiscriminatorValues$4 = {}));

var LayoutMode;
(function (LayoutMode) {
    LayoutMode["View"] = "View";
    LayoutMode["Edit"] = "Edit";
    LayoutMode["Create"] = "Create";
})(LayoutMode || (LayoutMode = {}));

LayoutMode.View;

var FormFactor;
(function (FormFactor) {
    FormFactor["Large"] = "Large";
    FormFactor["Medium"] = "Medium";
    FormFactor["Small"] = "Small";
})(FormFactor || (FormFactor = {}));

ObjectCreate$1(null);

var LayoutType;
(function (LayoutType) {
    LayoutType["Full"] = "Full";
    LayoutType["Compact"] = "Compact";
})(LayoutType || (LayoutType = {}));

ObjectCreate$1(null);

ObjectCreate$1(null);

const VERSION$6 = "8d2032474fb4fabdf5cf4042be9042d9";
const select$6 = function WorkStepPicklistValueAttributeRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$2();
    return {
        kind: 'Fragment',
        version: VERSION$6,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'sortOrder',
                kind: 'Scalar'
            },
            {
                name: 'statusCode',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$5 = "53893a219bc0888951863f2c44317cac";
const select$5 = function LeadStatusPicklistValueAttributesRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$2();
    return {
        kind: 'Fragment',
        version: VERSION$5,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'converted',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$4 = "4818ec07c499784571c1012ead048c88";
const select$4 = function CaseStatusPicklistValueAttributesRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$2();
    return {
        kind: 'Fragment',
        version: VERSION$4,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'closed',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$3 = "950a3a962acbd2b128f937d4c055a9d6";
const select$3 = function OpportunityStagePicklistValueAttributesRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$2();
    return {
        kind: 'Fragment',
        version: VERSION$3,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'closed',
                kind: 'Scalar'
            },
            {
                name: 'defaultProbability',
                kind: 'Scalar'
            },
            {
                name: 'forecastCategoryName',
                kind: 'Scalar'
            },
            {
                name: 'won',
                kind: 'Scalar'
            }
        ]
    };
};

var DiscriminatorValues$3;
(function (DiscriminatorValues) {
    DiscriminatorValues["WorkStepStatus"] = "WorkStepStatus";
    DiscriminatorValues["LeadStatus"] = "LeadStatus";
    DiscriminatorValues["CaseStatus"] = "CaseStatus";
    DiscriminatorValues["OpportunityStage"] = "OpportunityStage";
})(DiscriminatorValues$3 || (DiscriminatorValues$3 = {}));
const VERSION$2 = "bd523b2343366edfc25a2dbee2c4e986";
const selectChildren = function AbstractPicklistValueAttributesRepresentationSelectChildren() {
    const workStepPicklistValueAttributeRepresentationSelections = select$6();
    const leadStatusPicklistValueAttributesRepresentationSelections = select$5();
    const caseStatusPicklistValueAttributesRepresentationSelections = select$4();
    const opportunityStagePicklistValueAttributesRepresentationSelections = select$3();
    return {
        kind: 'Fragment',
        union: true,
        discriminator: 'picklistAtrributesValueType',
        unionSelections: {
            [DiscriminatorValues$3.WorkStepStatus]: workStepPicklistValueAttributeRepresentationSelections,
            [DiscriminatorValues$3.LeadStatus]: leadStatusPicklistValueAttributesRepresentationSelections,
            [DiscriminatorValues$3.CaseStatus]: caseStatusPicklistValueAttributesRepresentationSelections,
            [DiscriminatorValues$3.OpportunityStage]: opportunityStagePicklistValueAttributesRepresentationSelections
        }
    };
};
const select$2 = function AbstractPicklistValueAttributesRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$2,
        private: [],
        selections: [
            {
                name: 'picklistAtrributesValueType',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$1 = "9e2a16a80378487f557124c771201cf9";
const select$1 = function PicklistValueRepresentationSelect() {
    const AbstractPicklistValueAttributesRepresentation__unionSelections = selectChildren();
    return {
        kind: 'Fragment',
        version: VERSION$1,
        private: [],
        selections: [
            {
                kind: 'Object',
                name: 'attributes',
                discriminator: AbstractPicklistValueAttributesRepresentation__unionSelections.discriminator,
                union: true,
                nullable: true,
                unionSelections: AbstractPicklistValueAttributesRepresentation__unionSelections.unionSelections
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'validFor',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'value',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION = "0a361a49370acb4c6a31721a2057649a";
const select = function PicklistValuesRepresentationSelect() {
    const { selections: PicklistValueRepresentation__selections, opaque: PicklistValueRepresentation__opaque, } = select$1();
    return {
        kind: 'Fragment',
        version: VERSION,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'controllerValues',
                kind: 'Scalar',
                map: true
            },
            {
                name: 'defaultValue',
                kind: 'Object',
                nullable: true,
                selections: PicklistValueRepresentation__selections
            },
            {
                name: 'url',
                kind: 'Scalar'
            },
            {
                name: 'values',
                kind: 'Object',
                plural: true,
                selections: PicklistValueRepresentation__selections
            }
        ]
    };
};

select().selections;

var DiscriminatorValues$2;
(function (DiscriminatorValues) {
    DiscriminatorValues["Photo"] = "Photo";
    DiscriminatorValues["Theme"] = "Theme";
})(DiscriminatorValues$2 || (DiscriminatorValues$2 = {}));

ObjectCreate$1(null);

ObjectCreate$1(null);

ObjectCreate$1(null);

ObjectCreate$1(null);

var DiscriminatorValues$1;
(function (DiscriminatorValues) {
    DiscriminatorValues["Text"] = "Text";
    DiscriminatorValues["Select"] = "Select";
})(DiscriminatorValues$1 || (DiscriminatorValues$1 = {}));

var DiscriminatorValues;
(function (DiscriminatorValues) {
    DiscriminatorValues["Field"] = "Field";
    DiscriminatorValues["DataCategory"] = "DataCategory";
})(DiscriminatorValues || (DiscriminatorValues = {}));

({
    ...configurationForRestAdapters,
    ...configurationForGraphQLAdapters,
    ...configurationForOneStoreEnabledAdapters,
});
ensureRegisteredOnce({
    id: '@salesforce/lds-adapters-uiapi',
    configuration: {
        ...configurationForRestAdapters,
        ...configurationForGraphQLAdapters,
        ...configurationForOneStoreEnabledAdapters,
    },
    instrument,
});

register({
    id: '@salesforce/lds-adapters-uiapi/graphql',
    configuration: { ...configurationForGraphQLAdapters },
    instrument,
});

export { configurationForGraphQLAdapters as configuration, graphql, factory$1 as graphqlAdapterFactory, graphqlBatch, graphqlBatch_imperative, graphql_imperative };
// version: 1.353.1-4693659f9b
