/**
 * Copyright (c) 2022, Salesforce, Inc.,
 * All rights reserved.
 * For full license text, see the LICENSE.txt file
 */

/*
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce-experience-platform-emu/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createInstrumentedAdapter, createLDSAdapter, createWireAdapterConstructor, createInfiniteScrollingWireAdapterConstructor, createImperativeAdapter, bindWireRefresh, refresh as refresh$2 } from 'force/ldsBindings';
import { register, withDefaultLuvio } from 'force/ldsEngine';
import { serializeStructuredKey, ingestShape, coerceConfig as coerceConfig$1, typeCheckConfig as typeCheckConfig$17, createResourceParams as createResourceParams$13, StoreKeyMap, StoreKeySet, deepFreeze, buildNetworkSnapshotCachePolicy as buildNetworkSnapshotCachePolicy$S, HttpStatusCode, coerceAdapterRequestContext, Wildcard } from 'force/luvioEngine';
export { createRecordInputFilteredByEditedFields, generateRecordInputForCreate, generateRecordInputForUpdate, getFieldDisplayValue, getFieldValue, getRecordInput } from './uiapi-static-functions';

/**
 * Limit the frequency and the duration that a function is invoked.
 *
 * @param invokeLimit The frequency a function could be invoked.
 * @param timeLimit The duration a function could be invoked with the rate limit, in milliseconds.
 * @param fn The function to be invoked.
 * @param options Extra options for instrumentation, logging, or bookkeeping purposes.
 * @returns The wrapped rate limited function.
 */
function throttle(invokeLimit, timeLimit, fn, options) {
    if (invokeLimit <= 0 || timeLimit <= 0) {
        if (process.env.NODE_ENV !== 'production') {
            throw new Error('only supports throttling with positive invokeLimit and timeLimit');
        }
    }
    let invokeCount = 0;
    let time = Date.now();
    const allowFunction = options && options.allowFunction ? options.allowFunction : () => { };
    const dropFunction = options && options.dropFunction ? options.dropFunction : () => { };
    return (...args) => {
        const calledTime = Date.now();
        if (calledTime - time <= timeLimit) {
            if (invokeCount < invokeLimit) {
                invokeCount += 1;
                allowFunction();
                return fn(...args);
            }
            else {
                dropFunction();
            }
        }
        else {
            time = calledTime;
            invokeCount = 1;
            allowFunction();
            return fn(...args);
        }
    };
}

/**
 * Defines configuration for the module with a default value which can be overridden by the runtime environment.
 */
// A holder for a configurable adapter override
class Configurable {
    constructor() {
        this.getAdapter = () => {
            return this.adapter;
        };
        this.setAdapter = (value) => {
            this.adapter = value;
        };
        this.adapter = undefined;
    }
}
// Configurable adapters that can have environmental overrides
let configurableCreateRecordAdapter = new Configurable();
let configurableUpdateRecordAdapter = new Configurable();
let configurableDeleteRecordAdapter = new Configurable();
let configurablePerformQuickActionAdapter = new Configurable();
let configurablePerformUpdateRecordQuickActionAdapter = new Configurable();
let configurableCreateContentDocumentAndVersion = new Configurable();
let configurableCreateContentVersion = new Configurable();
/**
 * Depth to which tracked fields will be added to a request that results from a cache miss.
 * A value of 0 inhibits the addition of tracked fields, 1 will add tracked fields that can
 * be reached by following 1 relationship from the root record, etc.
 * @defaultValue '5', replicates the current behavior
 */
let trackedFieldDepthOnCacheMiss = 5;
/**
 * Depth to which tracked fields will be added to a request that results from a merge conflict
 * A value of 0 inhibits the addition of tracked fields, 1 will add tracked fields that can
 * be reached by following 1 relationship from the root record, etc.
 * @defaultValue '5', replicates the current behavior
 */
let trackedFieldDepthOnCacheMergeConflict = 5;
/**
 * Depth to which tracked fields will be added to a request that results from a notify change invocation by the consumer
 * A value of 0 inhibits the addition of tracked fields, 1 will add tracked fields that can
 * be reached by following 1 relationship from the root record, etc.
 * @defaultValue '5', replicates the current behavior
 */
let trackedFieldDepthOnNotifyChange = 5;
/**
 * Determines if we will only fetch the 'Id' field for the leaf relationship record
 * @defaultValue 'false', replicates the current behavior and fetches all fields in the store for the leaf relationship record
 */
let trackedFieldLeafNodeIdAndNameOnly = false;
/**
 * One store enabled Get Object Info adapter
 */
let oneStoreGetObjectInfoAdapter = undefined;
/**
 * One store enabled Get Object Infos adapter
 */
let oneStoreGetObjectInfosAdapter = undefined;
/**
 * Determines when to include PDL strategies for Related Lists
 */
let relatedListsPredictionsEnabled = false;
/**
 * Determines whether to include additional PDL strategies for Related Lists
 */
let relatedListsPlusPredictionsEnabled = false;
let recordRepresentationIngestionOverride = undefined;
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for one store enabled REST adapters only.
 */
const configurationForOneStoreEnabledAdapters = {
    setGetObjectInfoAdapter: function (adapter) {
        oneStoreGetObjectInfoAdapter = adapter;
    },
    getGetObjectInfoAdapter: function () {
        return oneStoreGetObjectInfoAdapter;
    },
    setGetObjectInfosAdapter: function (adapter) {
        oneStoreGetObjectInfosAdapter = adapter;
    },
    getGetObjectInfosAdapter: function () {
        return oneStoreGetObjectInfosAdapter;
    },
};
/**
 * Helper function to return the one store adapter if it's defined, otherwise return the luvio adapter.
 * @param luvioAdapter - The luvio bound adapter.
 * @param oneStoreAdapter - The one store bound adapter.
 * @returns Luvio or one store wire adapter constructor.
 */
function getLuvioOrOneStoreAdapter(luvioAdapter, oneStoreAdapter) {
    return oneStoreAdapter ?? luvioAdapter;
}
const getKeywordSearchResultsFactory = new Configurable();
const getListRecordsByNameFactory = new Configurable();
const getListUiFactory = new Configurable();
const getLookupRecordsFactory = new Configurable();
const getQuickActionDefaultsFactory = new Configurable();
const getRecordCreateDefaultsFactory = new Configurable();
const getRecordTemplateCloneFactory = new Configurable();
const getRecordTemplateCreateFactory = new Configurable();
const getRecordUiFactory = new Configurable();
const getRecordFactory = new Configurable();
const getRecordsFactory = new Configurable();
const getRelatedListRecordsFactory = new Configurable();
const getRelatedListRecordsBatchFactory = new Configurable();
const getSearchResultsFactory = new Configurable();
// The following set of adapters all touch RecordRepresentation directly or indirectly,
// so they need to support having a custom factory provided by the mobile environment.
const configurationForEnvironmentFactoryOverrides = {
    getKeywordSearchResultsAdapterFactory: getKeywordSearchResultsFactory.getAdapter,
    setGetKeywordSearchResultsAdapterFactory: getKeywordSearchResultsFactory.setAdapter,
    getListRecordsByNameAdapterFactory: getListRecordsByNameFactory.getAdapter,
    setGetListRecordsByNameAdapterFactory: getListRecordsByNameFactory.setAdapter,
    getListUiAdapterFactory: getListUiFactory.getAdapter,
    setGetListUiAdapterFactory: getListUiFactory.setAdapter,
    getLookupRecordsAdapterFactory: getLookupRecordsFactory.getAdapter,
    setGetLookupRecordsAdapterFactory: getLookupRecordsFactory.setAdapter,
    getQuickActionDefaultsAdapterFactory: getQuickActionDefaultsFactory.getAdapter,
    setGetQuickActionDefaultsAdapterFactory: getQuickActionDefaultsFactory.setAdapter,
    getRecordCreateDefaultsAdapterFactory: getRecordCreateDefaultsFactory.getAdapter,
    setGetRecordCreateDefaultsAdapterFactory: getRecordCreateDefaultsFactory.setAdapter,
    getRecordTemplateCloneAdapterFactory: getRecordTemplateCloneFactory.getAdapter,
    setGetRecordTemplateCloneAdapterFactory: getRecordTemplateCloneFactory.setAdapter,
    getRecordTemplateCreateAdapterFactory: getRecordTemplateCreateFactory.getAdapter,
    setGetRecordTemplateCreateAdapterFactory: getRecordTemplateCreateFactory.setAdapter,
    getRecordUiAdapterFactory: getRecordUiFactory.getAdapter,
    setGetRecordUiAdapterFactory: getRecordUiFactory.setAdapter,
    getRecordAdapterFactory: getRecordFactory.getAdapter,
    setGetRecordAdapterFactory: getRecordFactory.setAdapter,
    getRecordsAdapterFactory: getRecordsFactory.getAdapter,
    setGetRecordsAdapterFactory: getRecordsFactory.setAdapter,
    getRelatedListRecordsAdapterFactory: getRelatedListRecordsFactory.getAdapter,
    setGetRelatedListRecordsAdapterFactory: getRelatedListRecordsFactory.setAdapter,
    getRelatedListRecordsBatchAdapterFactory: getRelatedListRecordsBatchFactory.getAdapter,
    setGetRelatedListRecordsBatchAdapterFactory: getRelatedListRecordsBatchFactory.setAdapter,
    getSearchResultsAdapterFactory: getSearchResultsFactory.getAdapter,
    setGetSearchResultsAdapterFactory: getSearchResultsFactory.setAdapter,
};
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for REST adapters only.
 */
const configurationForRestAdapters = {
    setTrackedFieldDepthOnCacheMiss: function (trackedFieldDepthOnCacheMissParam) {
        trackedFieldDepthOnCacheMiss = trackedFieldDepthOnCacheMissParam;
    },
    getTrackedFieldDepthOnCacheMiss: function () {
        return trackedFieldDepthOnCacheMiss;
    },
    setTrackedFieldDepthOnCacheMergeConflict: function (trackedFieldDepthOnCacheMergeConflictParam) {
        trackedFieldDepthOnCacheMergeConflict = trackedFieldDepthOnCacheMergeConflictParam;
    },
    getTrackedFieldDepthOnCacheMergeConflict: function () {
        return trackedFieldDepthOnCacheMergeConflict;
    },
    setTrackedFieldDepthOnNotifyChange: function (trackedFieldDepthOnNotifyChangeParam) {
        trackedFieldDepthOnNotifyChange = trackedFieldDepthOnNotifyChangeParam;
    },
    getTrackedFieldDepthOnNotifyChange: function () {
        return trackedFieldDepthOnNotifyChange;
    },
    setTrackedFieldLeafNodeIdAndNameOnly: function (trackedFieldLeafNodeIdAndNameOnlyParam) {
        trackedFieldLeafNodeIdAndNameOnly = trackedFieldLeafNodeIdAndNameOnlyParam;
    },
    getTrackedFieldLeafNodeIdAndNameOnly: function () {
        return trackedFieldLeafNodeIdAndNameOnly;
    },
    setRelatedListsPredictionsEnabled: function (f) {
        relatedListsPredictionsEnabled = f;
    },
    areRelatedListsPredictionsEnabled: function () {
        return relatedListsPredictionsEnabled === true;
    },
    setRelatedListsPlusPredictionsEnabled: function (f) {
        relatedListsPlusPredictionsEnabled = f;
    },
    areRelatedListsPlusPredictionsEnabled: function () {
        return relatedListsPlusPredictionsEnabled === true;
    },
    setRecordRepresentationIngestionOverride: function (ingest) {
        recordRepresentationIngestionOverride = ingest;
    },
    getRecordRepresentationIngestionOverride: function () {
        return recordRepresentationIngestionOverride;
    },
    // createRecord
    getDraftAwareCreateRecordAdapter: configurableCreateRecordAdapter.getAdapter,
    setDraftAwareCreateRecordAdapter: configurableCreateRecordAdapter.setAdapter,
    // updateRecord
    getDraftAwareUpdateRecordAdapter: configurableUpdateRecordAdapter.getAdapter,
    setDraftAwareUpdateRecordAdapter: configurableUpdateRecordAdapter.setAdapter,
    // deleteRecord
    getDraftAwareDeleteRecordAdapter: configurableDeleteRecordAdapter.getAdapter,
    setDraftAwareDeleteRecordAdapter: configurableDeleteRecordAdapter.setAdapter,
    // performQuickAction
    getDraftAwarePerformQuickActionAdapter: configurablePerformQuickActionAdapter.getAdapter,
    setDraftAwarePerformQuickActionAdapter: configurablePerformQuickActionAdapter.setAdapter,
    // performRecordUpdateQuickAction
    getDraftAwarePerformUpdateRecordQuickActionAdapter: configurablePerformUpdateRecordQuickActionAdapter.getAdapter,
    setDraftAwarePerformUpdateRecordQuickActionAdapter: configurablePerformUpdateRecordQuickActionAdapter.setAdapter,
    // createContentDocumentAndVersion
    getDraftAwareCreateContentDocumentAndVersionAdapter: configurableCreateContentDocumentAndVersion.getAdapter,
    setDraftAwareCreateContentDocumentAndVersionAdapter: configurableCreateContentDocumentAndVersion.setAdapter,
    // createContentVersion
    getDraftAwareCreateContentVersionAdapter: configurableCreateContentVersion.getAdapter,
    setDraftAwareCreateContentVersionAdapter: configurableCreateContentVersion.setAdapter,
    ...configurationForOneStoreEnabledAdapters,
    ...configurationForEnvironmentFactoryOverrides,
};
let configurableGraphQLAdapter = new Configurable();
let configurableGraphQLBatchAdapter = new Configurable();
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for GraphQL adapters only.
 */
const configurationForGraphQLAdapters = {
    getDraftAwareGraphQLAdapter: configurableGraphQLAdapter.getAdapter,
    setDraftAwareGraphQLAdapter: configurableGraphQLAdapter.setAdapter,
    getEnvironmentAwareGraphQLBatchAdapter: configurableGraphQLBatchAdapter.getAdapter,
    setEnvironmentAwareGraphQLBatchAdapter: configurableGraphQLBatchAdapter.setAdapter,
};
const registrations = new Set();
/**
 * lds-adapter-uiapi is special.  The non-SFDC bundle combines REST and GQL adapters,
 * yet for SFDC those are separate bundles.  So non-SFDC bundle (./main.ts) registers
 * both REST and GQL configs.  We want each SFDC bundle to register (we don't want one
 * SFDC bundle to assume the other is being loaded and therefore the other one will
 * take care of registration) but we don't want to double register either.
 *
 * So we make this function that memoizes if it's been called before and only
 * actually registers once.
 */
function ensureRegisteredOnce(registration) {
    const { id } = registration;
    if (!registrations.has(id)) {
        register(registration);
        registrations.add(id);
    }
}

// For use by callers within this module to instrument interesting things.
let instrumentation = {
    /**
     * Called when a set of record conflicts has been fully resolved. The
     * parameter indicates the number of server requests that were needed
     * to fully resolve all the record conflicts.
     */
    recordConflictsResolved: (_serverRequestCount) => { },
    /**
     * Called during merging of incoming and existing FieldValues.
     * Called when the incoming FieldValue display value is null.
     *
     * Note: Temporary instrumentation to capture distribution and frequency, W-8990630
     * Flipped to counter metric due to W-9611107
     */
    nullDisplayValueConflict: (_fieldInfo) => { },
    /**
     * SFDC Throttling
     * getRecordNotifyChange and notifyRecordUpdateAvailable are both throttled
     */
    getRecordNotifyChangeAllowed: () => { },
    getRecordNotifyChangeDropped: () => { },
    notifyRecordUpdateAvailableAllowed: () => { },
    notifyRecordUpdateAvailableDropped: () => { },
    /**
     * RecordRepresentation merge
     * Called when records change apiName
     */
    recordApiNameChanged: (_existingApiName, _incomingApiName) => { },
    recordTypeIdIsNull: (_apiName) => { },
    /**
     * RecordRepresentation merge
     * Called when either incoming or existing RecordRepresentation has a weakEtag=0
     */
    weakEtagZero: (_incomingWeakEtagZero, _existingWeakEtagZero, _apiName) => { },
    /**
     * getRecord notifyChangeFactory
     * Called when dispatchResourceRequest is resolved/rejected
     */
    getRecordNotifyChangeNetworkResult: (_uniqueWeakEtags, _error) => { },
};
/**
 * Allows external modules (typically a runtime environment) to set
 * instrumentation hooks for this module. Note that the hooks are
 * incremental - hooks not suppiled in newInstrumentation will retain
 * their previous values. The default instrumentation hooks are no-ops.
 *
 * @param newInstrumentation instrumentation hooks to be overridden
 */
function instrument(newInstrumentation) {
    instrumentation = Object.assign(instrumentation, newInstrumentation);
}

const engineForPrefetcherMap = new Map();
function registerPrefetcher(luvio, prefetcher) {
    if (process.env.NODE_ENV !== 'production') {
        if (engineForPrefetcherMap.has(luvio)) {
            throw new Error('Environment error: Only one prefetcher per engine is allowed.');
        }
    }
    engineForPrefetcherMap.set(luvio, prefetcher);
}
function getPrefetcherFor(luvio) {
    return engineForPrefetcherMap.get(luvio);
}
function createLDSAdapterWithPrediction(adapter, luvio, name) {
    return (config, requestContext) => {
        const prefetcher = getPrefetcherFor(luvio);
        const result = adapter(config, requestContext);
        // only save requests with a valid config.
        if (result !== null &&
            prefetcher !== undefined &&
            !(requestContext && requestContext.excludeFromPredictions)) {
            prefetcher.saveRequest({ adapterName: name, config });
        }
        return result;
    };
}
function createRelatedListAdapterWithPrediction(adapter, luvio, name) {
    if (configurationForRestAdapters.areRelatedListsPredictionsEnabled() /* gate is open */) {
        return createLDSAdapterWithPrediction(adapter, luvio, name);
    }
    else {
        return (config, requestContext) => {
            return adapter(config, requestContext);
        };
    }
}
function createRelatedListPlusAdapterWithPrediction(adapter, luvio, name) {
    if (configurationForRestAdapters.areRelatedListsPlusPredictionsEnabled() /* gate is open */) {
        return createLDSAdapterWithPrediction(adapter, luvio, name);
    }
    else {
        return (config, requestContext) => {
            return adapter(config, requestContext);
        };
    }
}

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys$1, create: ObjectCreate$1 } = Object;
const { stringify: JSONStringify$1 } = JSON;
const { isArray: ArrayIsArray$1 } = Array;
const { push: ArrayPrototypePush } = Array.prototype;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys$1(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray$1(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const SNAPSHOT_STATE_UNFULFILLED = 'Unfulfilled';
const snapshotRefreshOptions = {
    overrides: {
        headers: {
            'Cache-Control': 'no-cache',
        },
    }
};
/**
 * A deterministic JSON stringify implementation. Heavily adapted from https://github.com/epoberezkin/fast-json-stable-stringify.
 * This is needed because insertion order for JSON.stringify(object) affects output:
 * JSON.stringify({a: 1, b: 2})
 *      "{"a":1,"b":2}"
 * JSON.stringify({b: 2, a: 1})
 *      "{"b":2,"a":1}"
 * @param data Data to be JSON-stringified.
 * @returns JSON.stringified value with consistent ordering of keys.
 */
function stableJSONStringify(node) {
    // This is for Date values.
    if (node && node.toJSON && typeof node.toJSON === 'function') {
        // eslint-disable-next-line no-param-reassign
        node = node.toJSON();
    }
    if (node === undefined) {
        return;
    }
    if (typeof node === 'number') {
        return isFinite(node) ? '' + node : 'null';
    }
    if (typeof node !== 'object') {
        return JSONStringify$1(node);
    }
    let i;
    let out;
    if (ArrayIsArray$1(node)) {
        out = '[';
        for (i = 0; i < node.length; i++) {
            if (i) {
                out += ',';
            }
            out += stableJSONStringify(node[i]) || 'null';
        }
        return out + ']';
    }
    if (node === null) {
        return 'null';
    }
    const keys = ObjectKeys$1(node).sort();
    out = '';
    for (i = 0; i < keys.length; i++) {
        const key = keys[i];
        const value = stableJSONStringify(node[key]);
        if (!value) {
            continue;
        }
        if (out) {
            out += ',';
        }
        out += JSONStringify$1(key) + ':' + value;
    }
    return '{' + out + '}';
}
function getFetchResponseStatusText(status) {
    switch (status) {
        case 200:
            return 'OK';
        case 201:
            return 'Created';
        case 304:
            return 'Not Modified';
        case 404:
            return 'Not Found';
        case 400:
            return 'Bad Request';
        case 500:
            return 'Server Error';
        default:
            return `Unexpected HTTP Status Code: ${status}`;
    }
}
function isUnfulfilledSnapshot$1(snapshot) {
    return snapshot.state === SNAPSHOT_STATE_UNFULFILLED;
}
function generateParamConfigMetadata(name, required, resourceType, typeCheckShape, isArrayShape = false, coerceFn) {
    return {
        name,
        required,
        resourceType,
        typeCheckShape,
        isArrayShape,
        coerceFn,
    };
}
function buildAdapterValidationConfig(displayName, paramsMeta) {
    const required = paramsMeta.filter(p => p.required).map(p => p.name);
    const optional = paramsMeta.filter(p => !p.required).map(p => p.name);
    return {
        displayName,
        parameters: {
            required,
            optional,
        }
    };
}
const keyPrefix = 'UiApi';

const { assign, create, freeze, isFrozen, keys } = Object;
const { hasOwnProperty } = Object.prototype;
const { split, endsWith } = String.prototype;
const { isArray } = Array;
const { concat, filter, includes, push, reduce } = Array.prototype;
const { parse, stringify } = JSON;

function isString(value) {
    return typeof value === 'string';
}
/**
 * @param value The array to inspect.
 * @returns True if the array is non-empty and contains only non-empty strings.
 */
function isArrayOfNonEmptyStrings(value) {
    if (value.length === 0) {
        return false;
    }
    return value.every((v) => isString(v) && v.trim().length > 0);
}
/**
 * @param value The array to dedupe
 * @returns An array without duplicates.
 */
function dedupe(value) {
    const result = {};
    for (let i = 0, len = value.length; i < len; i += 1) {
        result[value[i]] = true;
    }
    return keys(result);
}
/**
 * @param source The array of string to filter
 * @param compare The array to filter against
 * @returns An array with values from source that do not exist in compare
 * If the "compare" array is empty, "source" array itself is returned, not a shallow copy
 */
function difference(source, compare) {
    const { length: sourceLength } = source;
    const { length: compareLength } = compare;
    if (sourceLength === 0 || source === compare) {
        return [];
    }
    if (compareLength === 0) {
        return source;
    }
    // Put all the values from "compare" into a map
    // This should be faster than doing an indexOf for every string in source
    const map = {};
    for (let i = 0; i < compareLength; i += 1) {
        map[compare[i]] = true;
    }
    const strings = [];
    for (let i = 0; i < sourceLength; i += 1) {
        const string = source[i];
        if (map[string] === undefined) {
            strings.push(string);
        }
    }
    return strings;
}
/**
 * @param word The string to title case
 * @returns The sames string but in title case
 */
function toTitleCase(word) {
    return word.charAt(0).toUpperCase() + word.slice(1).toLowerCase();
}

function isObjectId(unknown) {
    if (typeof unknown !== 'object' || unknown === null) {
        return false;
    }
    return isString(unknown.objectApiName);
}

/**
 * Returns the object API name.
 * @param value The value from which to get the object API name.
 * @returns The object API name.
 */
function getObjectApiName$1(value) {
    // Note: tightening validation logic changes behavior from userland getting
    // a server-provided error to the adapter noop'ing. In 224 we decided to not
    // change the behavior.
    if (typeof value === 'string') {
        const trimmed = value.trim();
        if (trimmed.length > 0) {
            return trimmed;
        }
    }
    else if (isObjectId(value)) {
        return value.objectApiName.trim();
    }
    return undefined;
}

function isFieldId(unknown) {
    if (typeof unknown !== 'object' || unknown === null) {
        return false;
    }
    const value = unknown;
    return isString(value.objectApiName) && isString(value.fieldApiName);
}
function stringToFieldId(fieldApiName) {
    const split = fieldApiName.split('.');
    if (process.env.NODE_ENV !== 'production') {
        if (split.length === 1) {
            // object api name must non-empty
            throw new TypeError('Value does not include an object API name.');
        }
    }
    return {
        objectApiName: split[0],
        fieldApiName: split[1],
    };
}
function getFieldId(value) {
    if (isFieldId(value)) {
        return value;
    }
    return stringToFieldId(value);
}
/**
 * Split the object API name and field API name from a qualified field name.
 * Eg: Opportunity.Title returns ['Opportunity', 'Title']
 * Eg: Opportunity.Account.Name returns ['Opportunity', 'Account.Name']
 * @param fieldApiName The qualified field name.
 * @return The object and field API names.
 */
function splitQualifiedFieldApiName(fieldApiName) {
    const idx = fieldApiName.indexOf('.');
    if (idx < 1) {
        // object api name must non-empty
        throw new TypeError('Value does not include an object API name.');
    }
    return [fieldApiName.substring(0, idx), fieldApiName.substring(idx + 1)];
}

/**
 * Returns the field API name, qualified with an object name if possible.
 * @param value The value from which to get the qualified field API name.
 * @param onlyQualifiedFieldNames - Whether or not this function should skip fieldApiName that do not include the delimiter '.'
 * @return The qualified field API name.
 */
function getFieldApiName(value, onlyQualifiedFieldNames = false) {
    // Note: tightening validation logic changes behavior from userland getting
    // a server-provided error to the adapter noop'ing. In 224 we decided to not
    // change the behavior. In 250 we decided to add the 'onlyQualifiedFieldName' flag to tighten the logic
    // optionally to avoid issues with persisted invalid field names.
    if (isString(value)) {
        const trimmed = value.trim();
        if (trimmed.length > 0 && (onlyQualifiedFieldNames ? trimmed.indexOf('.') > -1 : true)) {
            return trimmed;
        }
    }
    else if (isFieldId(value)) {
        return value.objectApiName + '.' + value.fieldApiName;
    }
    return undefined;
}

/**
 * Returns the field API name.
 * @param value The value from which to get the field API name.
 * @param options Option bag. onlyQualifiedFieldNames is a boolean that allows this function to skip returning invalid FieldApiNames.
 * @returns The field API name.
 */
function getFieldApiNamesArray(value, options = { onlyQualifiedFieldNames: false }) {
    const valueArray = isArray(value) ? value : [value];
    const array = [];
    for (let i = 0, len = valueArray.length; i < len; i += 1) {
        const item = valueArray[i];
        const apiName = getFieldApiName(item, options.onlyQualifiedFieldNames);
        if (apiName === undefined) {
            if (options.onlyQualifiedFieldNames) {
                continue; // Just skips invalid field names rather than failing to return an array at all
            }
            return undefined;
        }
        push.call(array, apiName);
    }
    if (array.length === 0) {
        return undefined;
    }
    return dedupe(array).sort();
}

const { keys: ObjectKeys, create: ObjectCreate, assign: ObjectAssign } = Object;
const { isArray: ArrayIsArray } = Array;
const { stringify: JSONStringify } = JSON;
function equalsArray(a, b, equalsItem) {
    const aLength = a.length;
    const bLength = b.length;
    if (aLength !== bLength) {
        return false;
    }
    for (let i = 0; i < aLength; i++) {
        if (equalsItem(a[i], b[i]) === false) {
            return false;
        }
    }
    return true;
}
function equalsObject(a, b, equalsProp) {
    const aKeys = ObjectKeys(a).sort();
    const bKeys = ObjectKeys(b).sort();
    const aKeysLength = aKeys.length;
    const bKeysLength = bKeys.length;
    if (aKeysLength !== bKeysLength) {
        return false;
    }
    for (let i = 0; i < aKeys.length; i++) {
        const key = aKeys[i];
        if (key !== bKeys[i]) {
            return false;
        }
        if (equalsProp(a[key], b[key]) === false) {
            return false;
        }
    }
    return true;
}
function createLink(ref) {
    return {
        __ref: serializeStructuredKey(ref),
    };
}
function assignMetadataLink(entry, metadataKey) {
    entry['__metadata'] = createLink(metadataKey);
}

const VERSION$1v = "623aa9ce3a11031e35faf5671a41746e";
function validate$2b(obj, path = 'ListFilterByInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_operandLabels = obj.operandLabels;
        const path_operandLabels = path + '.operandLabels';
        if (!ArrayIsArray(obj_operandLabels)) {
            return new TypeError('Expected "array" but received "' + typeof obj_operandLabels + '" (at "' + path_operandLabels + '")');
        }
        for (let i = 0; i < obj_operandLabels.length; i++) {
            const obj_operandLabels_item = obj_operandLabels[i];
            const path_operandLabels_item = path_operandLabels + '[' + i + ']';
            if (typeof obj_operandLabels_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_operandLabels_item + '" (at "' + path_operandLabels_item + '")');
            }
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$28 = function ListFilterByInfoRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1v,
        private: [],
        selections: [
            {
                name: 'fieldApiName',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'operandLabels',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'operator',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$1u = "f98dc7dec10408a9648ef8e5b37002a3";
function validate$2a(obj, path = 'ListInlineEditDetailsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_message = obj.message;
        const path_message = path + '.message';
        let obj_message_union0 = null;
        const obj_message_union0_error = (() => {
            if (typeof obj_message !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_message + '" (at "' + path_message + '")');
            }
        })();
        if (obj_message_union0_error != null) {
            obj_message_union0 = obj_message_union0_error.message;
        }
        let obj_message_union1 = null;
        const obj_message_union1_error = (() => {
            if (obj_message !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_message + '" (at "' + path_message + '")');
            }
        })();
        if (obj_message_union1_error != null) {
            obj_message_union1 = obj_message_union1_error.message;
        }
        if (obj_message_union0 && obj_message_union1) {
            let message = 'Object doesn\'t match union (at "' + path_message + '")';
            message += '\n' + obj_message_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_message_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_state = obj.state;
        const path_state = path + '.state';
        let obj_state_union0 = null;
        const obj_state_union0_error = (() => {
            if (typeof obj_state !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_state + '" (at "' + path_state + '")');
            }
        })();
        if (obj_state_union0_error != null) {
            obj_state_union0 = obj_state_union0_error.message;
        }
        let obj_state_union1 = null;
        const obj_state_union1_error = (() => {
            if (obj_state !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_state + '" (at "' + path_state + '")');
            }
        })();
        if (obj_state_union1_error != null) {
            obj_state_union1 = obj_state_union1_error.message;
        }
        if (obj_state_union0 && obj_state_union1) {
            let message = 'Object doesn\'t match union (at "' + path_state + '")';
            message += '\n' + obj_state_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_state_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$27 = function ListInlineEditDetailsRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1u,
        private: [],
        selections: [
            {
                name: 'message',
                kind: 'Scalar'
            },
            {
                name: 'state',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$1t = "76042ff4af603b2ac0ec69fa0bd12046";
function validate$29(obj, path = 'ListReferenceRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_listViewApiName = obj.listViewApiName;
        const path_listViewApiName = path + '.listViewApiName';
        let obj_listViewApiName_union0 = null;
        const obj_listViewApiName_union0_error = (() => {
            if (typeof obj_listViewApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_listViewApiName + '" (at "' + path_listViewApiName + '")');
            }
        })();
        if (obj_listViewApiName_union0_error != null) {
            obj_listViewApiName_union0 = obj_listViewApiName_union0_error.message;
        }
        let obj_listViewApiName_union1 = null;
        const obj_listViewApiName_union1_error = (() => {
            if (obj_listViewApiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_listViewApiName + '" (at "' + path_listViewApiName + '")');
            }
        })();
        if (obj_listViewApiName_union1_error != null) {
            obj_listViewApiName_union1 = obj_listViewApiName_union1_error.message;
        }
        if (obj_listViewApiName_union0 && obj_listViewApiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_listViewApiName + '")';
            message += '\n' + obj_listViewApiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_listViewApiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$26 = function ListReferenceRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1t,
        private: [],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'listViewApiName',
                kind: 'Scalar'
            },
            {
                name: 'objectApiName',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$1c(existing, incoming) {
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_listViewApiName = existing.listViewApiName;
    const incoming_listViewApiName = incoming.listViewApiName;
    if (!(existing_listViewApiName === incoming_listViewApiName)) {
        return false;
    }
    return true;
}

const VERSION$1s = "f1519bef57e70ab7c5ef160dc5ff0c47";
function validate$28(obj, path = 'ListInfoShareRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_shareApiName = obj.shareApiName;
        const path_shareApiName = path + '.shareApiName';
        if (typeof obj_shareApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_shareApiName + '" (at "' + path_shareApiName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$25 = function ListInfoShareRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1s,
        private: [],
        selections: [
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'shareApiName',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$1r = "561657f32721ec1dac1601575b029640";
function validate$27(obj, path = 'ListInfoShareCategoryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_shareType = obj.shareType;
        const path_shareType = path + '.shareType';
        if (typeof obj_shareType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_shareType + '" (at "' + path_shareType + '")');
        }
        const obj_shares = obj.shares;
        const path_shares = path + '.shares';
        if (!ArrayIsArray(obj_shares)) {
            return new TypeError('Expected "array" but received "' + typeof obj_shares + '" (at "' + path_shares + '")');
        }
        for (let i = 0; i < obj_shares.length; i++) {
            const obj_shares_item = obj_shares[i];
            const path_shares_item = path_shares + '[' + i + ']';
            const referencepath_shares_itemValidationError = validate$28(obj_shares_item, path_shares_item);
            if (referencepath_shares_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListInfoShareRepresentation (at "' + path_shares_item + '")\n';
                message += referencepath_shares_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$24 = function ListInfoShareCategoryRepresentationSelect() {
    const { selections: ListInfoShareRepresentation__selections, opaque: ListInfoShareRepresentation__opaque, } = select$25();
    return {
        kind: 'Fragment',
        version: VERSION$1r,
        private: [],
        selections: [
            {
                name: 'shareType',
                kind: 'Scalar'
            },
            {
                name: 'shares',
                kind: 'Object',
                plural: true,
                selections: ListInfoShareRepresentation__selections
            }
        ]
    };
};

const VERSION$1q = "32def9b631252c12b91a8209c1f49f5a";
function validate$26(obj, path = 'ListOrderByInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_isAscending = obj.isAscending;
        const path_isAscending = path + '.isAscending';
        if (typeof obj_isAscending !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isAscending + '" (at "' + path_isAscending + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        let obj_label_union0 = null;
        const obj_label_union0_error = (() => {
            if (typeof obj_label !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        })();
        if (obj_label_union0_error != null) {
            obj_label_union0 = obj_label_union0_error.message;
        }
        let obj_label_union1 = null;
        const obj_label_union1_error = (() => {
            if (obj_label !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        })();
        if (obj_label_union1_error != null) {
            obj_label_union1 = obj_label_union1_error.message;
        }
        if (obj_label_union0 && obj_label_union1) {
            let message = 'Object doesn\'t match union (at "' + path_label + '")';
            message += '\n' + obj_label_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_label_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$23 = function ListOrderByInfoRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1q,
        private: [],
        selections: [
            {
                name: 'fieldApiName',
                kind: 'Scalar'
            },
            {
                name: 'isAscending',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$1b(existing, incoming) {
    const existing_isAscending = existing.isAscending;
    const incoming_isAscending = incoming.isAscending;
    if (!(existing_isAscending === incoming_isAscending)) {
        return false;
    }
    const existing_fieldApiName = existing.fieldApiName;
    const incoming_fieldApiName = incoming.fieldApiName;
    if (!(existing_fieldApiName === incoming_fieldApiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    return true;
}

const VERSION$1p = "2634258f216db34315c06d759a35676d";
function validate$25(obj, path = 'ListScopeEntityRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$22 = function ListScopeEntityRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1p,
        private: [],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$1o = "3b85c5a08d50ce328481b9f8ab56127b";
function validate$24(obj, path = 'ListScopeRelatedEntityRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$21 = function ListScopeRelatedEntityRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1o,
        private: [],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$1n = "2fe9814e7124b47f59da585483c1b3f9";
function validate$23(obj, path = 'ListScopeRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_entity = obj.entity;
        const path_entity = path + '.entity';
        let obj_entity_union0 = null;
        const obj_entity_union0_error = (() => {
            const referencepath_entityValidationError = validate$25(obj_entity, path_entity);
            if (referencepath_entityValidationError !== null) {
                let message = 'Object doesn\'t match ListScopeEntityRepresentation (at "' + path_entity + '")\n';
                message += referencepath_entityValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_entity_union0_error != null) {
            obj_entity_union0 = obj_entity_union0_error.message;
        }
        let obj_entity_union1 = null;
        const obj_entity_union1_error = (() => {
            if (obj_entity !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_entity + '" (at "' + path_entity + '")');
            }
        })();
        if (obj_entity_union1_error != null) {
            obj_entity_union1 = obj_entity_union1_error.message;
        }
        if (obj_entity_union0 && obj_entity_union1) {
            let message = 'Object doesn\'t match union (at "' + path_entity + '")';
            message += '\n' + obj_entity_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_entity_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        let obj_label_union0 = null;
        const obj_label_union0_error = (() => {
            if (typeof obj_label !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        })();
        if (obj_label_union0_error != null) {
            obj_label_union0 = obj_label_union0_error.message;
        }
        let obj_label_union1 = null;
        const obj_label_union1_error = (() => {
            if (obj_label !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        })();
        if (obj_label_union1_error != null) {
            obj_label_union1 = obj_label_union1_error.message;
        }
        if (obj_label_union0 && obj_label_union1) {
            let message = 'Object doesn\'t match union (at "' + path_label + '")';
            message += '\n' + obj_label_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_label_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_relatedEntity = obj.relatedEntity;
        const path_relatedEntity = path + '.relatedEntity';
        let obj_relatedEntity_union0 = null;
        const obj_relatedEntity_union0_error = (() => {
            const referencepath_relatedEntityValidationError = validate$24(obj_relatedEntity, path_relatedEntity);
            if (referencepath_relatedEntityValidationError !== null) {
                let message = 'Object doesn\'t match ListScopeRelatedEntityRepresentation (at "' + path_relatedEntity + '")\n';
                message += referencepath_relatedEntityValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_relatedEntity_union0_error != null) {
            obj_relatedEntity_union0 = obj_relatedEntity_union0_error.message;
        }
        let obj_relatedEntity_union1 = null;
        const obj_relatedEntity_union1_error = (() => {
            if (obj_relatedEntity !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_relatedEntity + '" (at "' + path_relatedEntity + '")');
            }
        })();
        if (obj_relatedEntity_union1_error != null) {
            obj_relatedEntity_union1 = obj_relatedEntity_union1_error.message;
        }
        if (obj_relatedEntity_union0 && obj_relatedEntity_union1) {
            let message = 'Object doesn\'t match union (at "' + path_relatedEntity + '")';
            message += '\n' + obj_relatedEntity_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_relatedEntity_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$20 = function ListScopeRepresentationSelect() {
    const { selections: ListScopeEntityRepresentation__selections, opaque: ListScopeEntityRepresentation__opaque, } = select$22();
    const { selections: ListScopeRelatedEntityRepresentation__selections, opaque: ListScopeRelatedEntityRepresentation__opaque, } = select$21();
    return {
        kind: 'Fragment',
        version: VERSION$1n,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'entity',
                kind: 'Object',
                nullable: true,
                selections: ListScopeEntityRepresentation__selections
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'relatedEntity',
                kind: 'Object',
                nullable: true,
                selections: ListScopeRelatedEntityRepresentation__selections
            }
        ]
    };
};

const VERSION$1m = "6506134f4d72fdfa349fe60ef1af2413";
function validate$22(obj, path = 'ListUserPreferenceRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_columnWidths = obj.columnWidths;
        const path_columnWidths = path + '.columnWidths';
        if (typeof obj_columnWidths !== 'object' || ArrayIsArray(obj_columnWidths) || obj_columnWidths === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWidths + '" (at "' + path_columnWidths + '")');
        }
        const obj_columnWidths_keys = ObjectKeys(obj_columnWidths);
        for (let i = 0; i < obj_columnWidths_keys.length; i++) {
            const key = obj_columnWidths_keys[i];
            const obj_columnWidths_prop = obj_columnWidths[key];
            const path_columnWidths_prop = path_columnWidths + '["' + key + '"]';
            if (typeof obj_columnWidths_prop !== 'number' || (typeof obj_columnWidths_prop === 'number' && Math.floor(obj_columnWidths_prop) !== obj_columnWidths_prop)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_columnWidths_prop + '" (at "' + path_columnWidths_prop + '")');
            }
        }
        const obj_columnWrap = obj.columnWrap;
        const path_columnWrap = path + '.columnWrap';
        if (typeof obj_columnWrap !== 'object' || ArrayIsArray(obj_columnWrap) || obj_columnWrap === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWrap + '" (at "' + path_columnWrap + '")');
        }
        const obj_columnWrap_keys = ObjectKeys(obj_columnWrap);
        for (let i = 0; i < obj_columnWrap_keys.length; i++) {
            const key = obj_columnWrap_keys[i];
            const obj_columnWrap_prop = obj_columnWrap[key];
            const path_columnWrap_prop = path_columnWrap + '["' + key + '"]';
            if (typeof obj_columnWrap_prop !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_columnWrap_prop + '" (at "' + path_columnWrap_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1$ = function ListUserPreferenceRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1m,
        private: [],
        selections: [
            {
                name: 'columnWidths',
                kind: 'Scalar',
                map: true
            },
            {
                name: 'columnWrap',
                kind: 'Scalar',
                map: true
            }
        ]
    };
};

function validate$21(obj, path = 'ListColumnInlineEditAttributesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_editable = obj.editable;
        const path_editable = path + '.editable';
        if (typeof obj_editable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_editable + '" (at "' + path_editable + '")');
        }
        const obj_required = obj.required;
        const path_required = path + '.required';
        if (typeof obj_required !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_required + '" (at "' + path_required + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$20(obj, path = 'ListColumnInlineEditAttributesRepresentationWrapper') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_keys = ObjectKeys(obj);
        for (let i = 0; i < obj_keys.length; i++) {
            const key = obj_keys[i];
            const obj_prop = obj[key];
            const path_prop = path + '["' + key + '"]';
            const referencepath_propValidationError = validate$21(obj_prop, path_prop);
            if (referencepath_propValidationError !== null) {
                let message = 'Object doesn\'t match ListColumnInlineEditAttributesRepresentation (at "' + path_prop + '")\n';
                message += referencepath_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

const VERSION$1l = "64e2cac6d374ad92f491a9f8a952c6c3";
function validate$1$(obj, path = 'ListColumnRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_inlineEditAttributes = obj.inlineEditAttributes;
        const path_inlineEditAttributes = path + '.inlineEditAttributes';
        let obj_inlineEditAttributes_union0 = null;
        const obj_inlineEditAttributes_union0_error = (() => {
            const referencepath_inlineEditAttributesValidationError = validate$20(obj_inlineEditAttributes, path_inlineEditAttributes);
            if (referencepath_inlineEditAttributesValidationError !== null) {
                let message = 'Object doesn\'t match ListColumnInlineEditAttributesRepresentationWrapper (at "' + path_inlineEditAttributes + '")\n';
                message += referencepath_inlineEditAttributesValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_inlineEditAttributes_union0_error != null) {
            obj_inlineEditAttributes_union0 = obj_inlineEditAttributes_union0_error.message;
        }
        let obj_inlineEditAttributes_union1 = null;
        const obj_inlineEditAttributes_union1_error = (() => {
            if (obj_inlineEditAttributes !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_inlineEditAttributes + '" (at "' + path_inlineEditAttributes + '")');
            }
        })();
        if (obj_inlineEditAttributes_union1_error != null) {
            obj_inlineEditAttributes_union1 = obj_inlineEditAttributes_union1_error.message;
        }
        if (obj_inlineEditAttributes_union0 && obj_inlineEditAttributes_union1) {
            let message = 'Object doesn\'t match union (at "' + path_inlineEditAttributes + '")';
            message += '\n' + obj_inlineEditAttributes_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_inlineEditAttributes_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_lookupId = obj.lookupId;
        const path_lookupId = path + '.lookupId';
        let obj_lookupId_union0 = null;
        const obj_lookupId_union0_error = (() => {
            if (typeof obj_lookupId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lookupId + '" (at "' + path_lookupId + '")');
            }
        })();
        if (obj_lookupId_union0_error != null) {
            obj_lookupId_union0 = obj_lookupId_union0_error.message;
        }
        let obj_lookupId_union1 = null;
        const obj_lookupId_union1_error = (() => {
            if (obj_lookupId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lookupId + '" (at "' + path_lookupId + '")');
            }
        })();
        if (obj_lookupId_union1_error != null) {
            obj_lookupId_union1 = obj_lookupId_union1_error.message;
        }
        if (obj_lookupId_union0 && obj_lookupId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lookupId + '")';
            message += '\n' + obj_lookupId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lookupId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_searchable = obj.searchable;
        const path_searchable = path + '.searchable';
        if (typeof obj_searchable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_searchable + '" (at "' + path_searchable + '")');
        }
        const obj_sortable = obj.sortable;
        const path_sortable = path + '.sortable';
        if (typeof obj_sortable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_sortable + '" (at "' + path_sortable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$Z = 'ListColumnRepresentation';
function normalize$S(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1_ = function ListColumnRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1l,
        private: [],
        opaque: true
    };
};
function equals$1a(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$S = function ListColumnRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1$(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$S, "UiApi", VERSION$1l, RepresentationType$Z, equals$1a);
    return createLink(key);
};
function getTypeCacheKeys$_(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$Z,
        mergeable: false
    });
}

const keyBuilderFromType$F = function ListInfoRepresentationKeyBuilderFromType(luvio, object) {
    const keyParams = {
        listViewApiName: object.listReference.listViewApiName
            ? object.listReference.listViewApiName.toLowerCase()
            : object.listReference.listViewApiName,
        objectApiName: object.listReference.objectApiName.toLowerCase(),
        type: object.listReference.type,
    };
    return keyBuilder$2a(luvio, keyParams);
};

const TTL$B = 900000;
const VERSION$1k = "5adf17d38be03c0f71b1c52485b377a6";
function validate$1_(obj, path = 'ListInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_cloneable = obj.cloneable;
        const path_cloneable = path + '.cloneable';
        if (typeof obj_cloneable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_cloneable + '" (at "' + path_cloneable + '")');
        }
        const obj_createable = obj.createable;
        const path_createable = path + '.createable';
        if (typeof obj_createable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_createable + '" (at "' + path_createable + '")');
        }
        const obj_deletable = obj.deletable;
        const path_deletable = path + '.deletable';
        if (typeof obj_deletable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_deletable + '" (at "' + path_deletable + '")');
        }
        const obj_displayColumns = obj.displayColumns;
        const path_displayColumns = path + '.displayColumns';
        if (!ArrayIsArray(obj_displayColumns)) {
            return new TypeError('Expected "array" but received "' + typeof obj_displayColumns + '" (at "' + path_displayColumns + '")');
        }
        for (let i = 0; i < obj_displayColumns.length; i++) {
            const obj_displayColumns_item = obj_displayColumns[i];
            const path_displayColumns_item = path_displayColumns + '[' + i + ']';
            if (typeof obj_displayColumns_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_displayColumns_item + '" (at "' + path_displayColumns_item + '")');
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_filterLogicString = obj.filterLogicString;
        const path_filterLogicString = path + '.filterLogicString';
        let obj_filterLogicString_union0 = null;
        const obj_filterLogicString_union0_error = (() => {
            if (typeof obj_filterLogicString !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_filterLogicString + '" (at "' + path_filterLogicString + '")');
            }
        })();
        if (obj_filterLogicString_union0_error != null) {
            obj_filterLogicString_union0 = obj_filterLogicString_union0_error.message;
        }
        let obj_filterLogicString_union1 = null;
        const obj_filterLogicString_union1_error = (() => {
            if (obj_filterLogicString !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_filterLogicString + '" (at "' + path_filterLogicString + '")');
            }
        })();
        if (obj_filterLogicString_union1_error != null) {
            obj_filterLogicString_union1 = obj_filterLogicString_union1_error.message;
        }
        if (obj_filterLogicString_union0 && obj_filterLogicString_union1) {
            let message = 'Object doesn\'t match union (at "' + path_filterLogicString + '")';
            message += '\n' + obj_filterLogicString_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_filterLogicString_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_filteredByInfo = obj.filteredByInfo;
        const path_filteredByInfo = path + '.filteredByInfo';
        if (!ArrayIsArray(obj_filteredByInfo)) {
            return new TypeError('Expected "array" but received "' + typeof obj_filteredByInfo + '" (at "' + path_filteredByInfo + '")');
        }
        for (let i = 0; i < obj_filteredByInfo.length; i++) {
            const obj_filteredByInfo_item = obj_filteredByInfo[i];
            const path_filteredByInfo_item = path_filteredByInfo + '[' + i + ']';
            const referencepath_filteredByInfo_itemValidationError = validate$2b(obj_filteredByInfo_item, path_filteredByInfo_item);
            if (referencepath_filteredByInfo_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListFilterByInfoRepresentation (at "' + path_filteredByInfo_item + '")\n';
                message += referencepath_filteredByInfo_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.hasMassActions !== undefined) {
            const obj_hasMassActions = obj.hasMassActions;
            const path_hasMassActions = path + '.hasMassActions';
            if (typeof obj_hasMassActions !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_hasMassActions + '" (at "' + path_hasMassActions + '")');
            }
        }
        const obj_inlineEditDetails = obj.inlineEditDetails;
        const path_inlineEditDetails = path + '.inlineEditDetails';
        const referencepath_inlineEditDetailsValidationError = validate$2a(obj_inlineEditDetails, path_inlineEditDetails);
        if (referencepath_inlineEditDetailsValidationError !== null) {
            let message = 'Object doesn\'t match ListInlineEditDetailsRepresentation (at "' + path_inlineEditDetails + '")\n';
            message += referencepath_inlineEditDetailsValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        let obj_label_union0 = null;
        const obj_label_union0_error = (() => {
            if (typeof obj_label !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        })();
        if (obj_label_union0_error != null) {
            obj_label_union0 = obj_label_union0_error.message;
        }
        let obj_label_union1 = null;
        const obj_label_union1_error = (() => {
            if (obj_label !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        })();
        if (obj_label_union1_error != null) {
            obj_label_union1 = obj_label_union1_error.message;
        }
        if (obj_label_union0 && obj_label_union1) {
            let message = 'Object doesn\'t match union (at "' + path_label + '")';
            message += '\n' + obj_label_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_label_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_listReference = obj.listReference;
        const path_listReference = path + '.listReference';
        const referencepath_listReferenceValidationError = validate$29(obj_listReference, path_listReference);
        if (referencepath_listReferenceValidationError !== null) {
            let message = 'Object doesn\'t match ListReferenceRepresentation (at "' + path_listReference + '")\n';
            message += referencepath_listReferenceValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_listShares = obj.listShares;
        const path_listShares = path + '.listShares';
        if (!ArrayIsArray(obj_listShares)) {
            return new TypeError('Expected "array" but received "' + typeof obj_listShares + '" (at "' + path_listShares + '")');
        }
        for (let i = 0; i < obj_listShares.length; i++) {
            const obj_listShares_item = obj_listShares[i];
            const path_listShares_item = path_listShares + '[' + i + ']';
            const referencepath_listShares_itemValidationError = validate$27(obj_listShares_item, path_listShares_item);
            if (referencepath_listShares_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListInfoShareCategoryRepresentation (at "' + path_listShares_item + '")\n';
                message += referencepath_listShares_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_objectApiNames = obj.objectApiNames;
        const path_objectApiNames = path + '.objectApiNames';
        if (!ArrayIsArray(obj_objectApiNames)) {
            return new TypeError('Expected "array" but received "' + typeof obj_objectApiNames + '" (at "' + path_objectApiNames + '")');
        }
        for (let i = 0; i < obj_objectApiNames.length; i++) {
            const obj_objectApiNames_item = obj_objectApiNames[i];
            const path_objectApiNames_item = path_objectApiNames + '[' + i + ']';
            if (typeof obj_objectApiNames_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectApiNames_item + '" (at "' + path_objectApiNames_item + '")');
            }
        }
        const obj_orderedByInfo = obj.orderedByInfo;
        const path_orderedByInfo = path + '.orderedByInfo';
        if (!ArrayIsArray(obj_orderedByInfo)) {
            return new TypeError('Expected "array" but received "' + typeof obj_orderedByInfo + '" (at "' + path_orderedByInfo + '")');
        }
        for (let i = 0; i < obj_orderedByInfo.length; i++) {
            const obj_orderedByInfo_item = obj_orderedByInfo[i];
            const path_orderedByInfo_item = path_orderedByInfo + '[' + i + ']';
            const referencepath_orderedByInfo_itemValidationError = validate$26(obj_orderedByInfo_item, path_orderedByInfo_item);
            if (referencepath_orderedByInfo_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListOrderByInfoRepresentation (at "' + path_orderedByInfo_item + '")\n';
                message += referencepath_orderedByInfo_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_scope = obj.scope;
        const path_scope = path + '.scope';
        let obj_scope_union0 = null;
        const obj_scope_union0_error = (() => {
            const referencepath_scopeValidationError = validate$23(obj_scope, path_scope);
            if (referencepath_scopeValidationError !== null) {
                let message = 'Object doesn\'t match ListScopeRepresentation (at "' + path_scope + '")\n';
                message += referencepath_scopeValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_scope_union0_error != null) {
            obj_scope_union0 = obj_scope_union0_error.message;
        }
        let obj_scope_union1 = null;
        const obj_scope_union1_error = (() => {
            if (obj_scope !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_scope + '" (at "' + path_scope + '")');
            }
        })();
        if (obj_scope_union1_error != null) {
            obj_scope_union1 = obj_scope_union1_error.message;
        }
        if (obj_scope_union0 && obj_scope_union1) {
            let message = 'Object doesn\'t match union (at "' + path_scope + '")';
            message += '\n' + obj_scope_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_scope_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_searchable = obj.searchable;
        const path_searchable = path + '.searchable';
        if (typeof obj_searchable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_searchable + '" (at "' + path_searchable + '")');
        }
        const obj_updateable = obj.updateable;
        const path_updateable = path + '.updateable';
        if (typeof obj_updateable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_updateable + '" (at "' + path_updateable + '")');
        }
        const obj_userPreferences = obj.userPreferences;
        const path_userPreferences = path + '.userPreferences';
        const referencepath_userPreferencesValidationError = validate$22(obj_userPreferences, path_userPreferences);
        if (referencepath_userPreferencesValidationError !== null) {
            let message = 'Object doesn\'t match ListUserPreferenceRepresentation (at "' + path_userPreferences + '")\n';
            message += referencepath_userPreferencesValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_visibility = obj.visibility;
        const path_visibility = path + '.visibility';
        if (typeof obj_visibility !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_visibility + '" (at "' + path_visibility + '")');
        }
        const obj_visibilityEditable = obj.visibilityEditable;
        const path_visibilityEditable = path + '.visibilityEditable';
        if (typeof obj_visibilityEditable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_visibilityEditable + '" (at "' + path_visibilityEditable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$Y = 'ListInfoRepresentation';
function keyBuilder$2a(luvio, config) {
    return keyPrefix + '::' + RepresentationType$Y + ':' + (config.listViewApiName === null ? '' : config.listViewApiName) + ':' + config.objectApiName + ':' + config.type;
}
function normalize$R(input, existing, path, luvio, store, timestamp) {
    const input_displayColumns = input.displayColumns;
    const input_displayColumns_id = path.fullPath + '__displayColumns';
    for (let i = 0; i < input_displayColumns.length; i++) {
        const input_displayColumns_item = input_displayColumns[i];
        let input_displayColumns_item_id = input_displayColumns_id + '__' + i;
        input_displayColumns[i] = ingest$S(input_displayColumns_item, {
            fullPath: input_displayColumns_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1Z = function ListInfoRepresentationSelect() {
    const { selections: ListFilterByInfoRepresentation__selections, opaque: ListFilterByInfoRepresentation__opaque, } = select$28();
    const { selections: ListInlineEditDetailsRepresentation__selections, opaque: ListInlineEditDetailsRepresentation__opaque, } = select$27();
    const { selections: ListReferenceRepresentation__selections, opaque: ListReferenceRepresentation__opaque, } = select$26();
    const { selections: ListInfoShareCategoryRepresentation__selections, opaque: ListInfoShareCategoryRepresentation__opaque, } = select$24();
    const { selections: ListOrderByInfoRepresentation__selections, opaque: ListOrderByInfoRepresentation__opaque, } = select$23();
    const { selections: ListScopeRepresentation__selections, opaque: ListScopeRepresentation__opaque, } = select$20();
    const { selections: ListUserPreferenceRepresentation__selections, opaque: ListUserPreferenceRepresentation__opaque, } = select$1$();
    return {
        kind: 'Fragment',
        version: VERSION$1k,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'cloneable',
                kind: 'Scalar'
            },
            {
                name: 'createable',
                kind: 'Scalar'
            },
            {
                name: 'deletable',
                kind: 'Scalar'
            },
            {
                name: 'displayColumns',
                kind: 'Link',
                plural: true,
                fragment: select$1_()
            },
            {
                name: 'filterLogicString',
                kind: 'Scalar'
            },
            {
                name: 'filteredByInfo',
                kind: 'Object',
                plural: true,
                selections: ListFilterByInfoRepresentation__selections
            },
            {
                name: 'hasMassActions',
                kind: 'Scalar',
                required: false
            },
            {
                name: 'inlineEditDetails',
                kind: 'Object',
                selections: ListInlineEditDetailsRepresentation__selections
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'listReference',
                kind: 'Object',
                selections: ListReferenceRepresentation__selections
            },
            {
                name: 'listShares',
                kind: 'Object',
                plural: true,
                selections: ListInfoShareCategoryRepresentation__selections
            },
            {
                name: 'objectApiNames',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'orderedByInfo',
                kind: 'Object',
                plural: true,
                selections: ListOrderByInfoRepresentation__selections
            },
            {
                name: 'scope',
                kind: 'Object',
                nullable: true,
                selections: ListScopeRepresentation__selections
            },
            {
                name: 'searchable',
                kind: 'Scalar'
            },
            {
                name: 'updateable',
                kind: 'Scalar'
            },
            {
                name: 'userPreferences',
                kind: 'Object',
                selections: ListUserPreferenceRepresentation__selections
            },
            {
                name: 'visibility',
                kind: 'Scalar'
            },
            {
                name: 'visibilityEditable',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$19(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$R = function ListInfoRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1_(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$F(luvio, input);
    const ttlToUse = TTL$B;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$R, "UiApi", VERSION$1k, RepresentationType$Y, equals$19);
    return createLink(key);
};
function getTypeCacheKeys$Z(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$F(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$Y,
        mergeable: false
    });
    const input_displayColumns_length = input.displayColumns.length;
    for (let i = 0; i < input_displayColumns_length; i++) {
        getTypeCacheKeys$_(rootKeySet, luvio, input.displayColumns[i], () => '');
    }
}
const notifyUpdateAvailableFactory$6 = (luvio) => {
    return function notifyListInfoUpdateAvailable(configs) {
        if (process.env.NODE_ENV !== 'production') {
            const requiredKeyParams = ['listViewApiName', 'objectApiName', 'type'];
            configs.forEach(config => {
                if (false === requiredKeyParams.every(req => req in config)) {
                    throw new Error(`one of the configs did not contain all required parameters: ${JSONStringify(ObjectKeys(config))}`);
                }
            });
        }
        const keys = configs.map(c => keyBuilder$2a(luvio, c));
        return luvio.notifyStoreUpdateAvailable(keys);
    };
};

const RECORD_ID_DECODER = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456';
/**
 * Converts to 18-char record ids. Details at http://sfdc.co/bnBMvm.
 * @param value A 15- or 18-char record id.
 * @returns An 18-char record id, and throws error if an invalid record id was provided.
 */
function getRecordId18(value) {
    if (isString(value)) {
        if (value.length === 18) {
            return value;
        }
        else if (value.length === 15) {
            // Add the 3 character suffix
            let recordId = value;
            for (let offset = 0; offset < 15; offset += 5) {
                let decodeValue = 0;
                for (let bit = 0; bit < 5; bit++) {
                    const c = value[offset + bit];
                    if (c >= 'A' && c <= 'Z') {
                        decodeValue += 1 << bit;
                    }
                }
                recordId += RECORD_ID_DECODER[decodeValue];
            }
            return recordId;
        }
    }
    else if (value === undefined || value === null) {
        // Not throwing here - input params might not have settled
        return undefined;
    }
    if (process.env.NODE_ENV !== 'production') {
        throw new Error(`Configuration Error: Invalid RecordId passed: ${JSON.stringify(value)}. RecordIds must be 15 or 18 character strings.`);
    }
    return undefined;
}

// Copy of SortedStringArray but calls toTitleCase
function toSortedStringArrayTitleCase(value) {
    const valueArray = isArray(value) ? value : [value];
    if (valueArray.length !== 0 && isArrayOfNonEmptyStrings(valueArray)) {
        return dedupe(valueArray)
            .sort()
            .map((value) => toTitleCase(value));
    }
    return undefined;
}

function toSortedStringArray(value) {
    const valueArray = isArray(value) ? value : [value];
    if (valueArray.length !== 0 && isArrayOfNonEmptyStrings(valueArray)) {
        return dedupe(valueArray).sort();
    }
    return undefined;
}

const VERSION$1j = "d1e589a127fb1060c89070cdb6f500b2";
function validate$1Z(obj, path = 'RecordTypeInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_available = obj.available;
        const path_available = path + '.available';
        if (typeof obj_available !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_available + '" (at "' + path_available + '")');
        }
        const obj_defaultRecordTypeMapping = obj.defaultRecordTypeMapping;
        const path_defaultRecordTypeMapping = path + '.defaultRecordTypeMapping';
        if (typeof obj_defaultRecordTypeMapping !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_defaultRecordTypeMapping + '" (at "' + path_defaultRecordTypeMapping + '")');
        }
        const obj_master = obj.master;
        const path_master = path + '.master';
        if (typeof obj_master !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_master + '" (at "' + path_master + '")');
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        if (typeof obj_recordTypeId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1Y = function RecordTypeInfoRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1j,
        private: [],
        selections: [
            {
                name: 'available',
                kind: 'Scalar'
            },
            {
                name: 'defaultRecordTypeMapping',
                kind: 'Scalar'
            },
            {
                name: 'master',
                kind: 'Scalar'
            },
            {
                name: 'name',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$18(existing, incoming) {
    const existing_available = existing.available;
    const incoming_available = incoming.available;
    if (!(existing_available === incoming_available)) {
        return false;
    }
    const existing_defaultRecordTypeMapping = existing.defaultRecordTypeMapping;
    const incoming_defaultRecordTypeMapping = incoming.defaultRecordTypeMapping;
    if (!(existing_defaultRecordTypeMapping === incoming_defaultRecordTypeMapping)) {
        return false;
    }
    const existing_master = existing.master;
    const incoming_master = incoming.master;
    if (!(existing_master === incoming_master)) {
        return false;
    }
    const existing_name = existing.name;
    const incoming_name = incoming.name;
    if (!(existing_name === incoming_name)) {
        return false;
    }
    const existing_recordTypeId = existing.recordTypeId;
    const incoming_recordTypeId = incoming.recordTypeId;
    if (!(existing_recordTypeId === incoming_recordTypeId)) {
        return false;
    }
    return true;
}

const VERSION$1i = "195d918987a35f45e1aa4dce9a11d8c5";
function validate$1Y(obj, path = 'FieldValueRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_displayValue = obj.displayValue;
        const path_displayValue = path + '.displayValue';
        let obj_displayValue_union0 = null;
        const obj_displayValue_union0_error = (() => {
            if (typeof obj_displayValue !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_displayValue + '" (at "' + path_displayValue + '")');
            }
        })();
        if (obj_displayValue_union0_error != null) {
            obj_displayValue_union0 = obj_displayValue_union0_error.message;
        }
        let obj_displayValue_union1 = null;
        const obj_displayValue_union1_error = (() => {
            if (obj_displayValue !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_displayValue + '" (at "' + path_displayValue + '")');
            }
        })();
        if (obj_displayValue_union1_error != null) {
            obj_displayValue_union1 = obj_displayValue_union1_error.message;
        }
        if (obj_displayValue_union0 && obj_displayValue_union1) {
            let message = 'Object doesn\'t match union (at "' + path_displayValue + '")';
            message += '\n' + obj_displayValue_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_displayValue_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_value = obj.value;
        const path_value = path + '.value';
        let obj_value_union0 = null;
        const obj_value_union0_error = (() => {
            if (typeof obj_value !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_value + '" (at "' + path_value + '")');
            }
        })();
        if (obj_value_union0_error != null) {
            obj_value_union0 = obj_value_union0_error.message;
        }
        let obj_value_union1 = null;
        const obj_value_union1_error = (() => {
            if (typeof obj_value !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_value + '" (at "' + path_value + '")');
            }
        })();
        if (obj_value_union1_error != null) {
            obj_value_union1 = obj_value_union1_error.message;
        }
        let obj_value_union2 = null;
        const obj_value_union2_error = (() => {
            if (typeof obj_value !== 'number') {
                return new TypeError('Expected "number" but received "' + typeof obj_value + '" (at "' + path_value + '")');
            }
        })();
        if (obj_value_union2_error != null) {
            obj_value_union2 = obj_value_union2_error.message;
        }
        let obj_value_union3 = null;
        const obj_value_union3_error = (() => {
            if (typeof obj_value !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_value + '" (at "' + path_value + '")');
            }
        })();
        if (obj_value_union3_error != null) {
            obj_value_union3 = obj_value_union3_error.message;
        }
        let obj_value_union4 = null;
        const obj_value_union4_error = (() => {
            if (obj_value !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_value + '" (at "' + path_value + '")');
            }
        })();
        if (obj_value_union4_error != null) {
            obj_value_union4 = obj_value_union4_error.message;
        }
        if (obj_value_union0 && obj_value_union1 && obj_value_union2 && obj_value_union3 && obj_value_union4) {
            let message = 'Object doesn\'t match union (at "' + path_value + '")';
            message += '\n' + obj_value_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_value_union1.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_value_union2.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_value_union3.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_value_union4.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$X = 'FieldValueRepresentation';
function normalize$Q(input, existing, path, luvio, store, timestamp) {
    const input_value = input.value;
    const input_value_id = path.fullPath + '__value';
    if (input_value !== null && typeof input_value === 'object') {
        input.value = ingest$O(input_value, {
            fullPath: input_value_id,
            propertyName: 'value',
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1X = function FieldValueRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1i,
        private: [],
        selections: [
            {
                name: 'displayValue',
                kind: 'Scalar'
            },
            {
                name: 'value',
                kind: 'Link',
                nullable: true,
                fragment: select$1V()
            }
        ]
    };
};
function equals$17(existing, incoming) {
    const existing_displayValue = existing.displayValue;
    const incoming_displayValue = incoming.displayValue;
    if (!(existing_displayValue === incoming_displayValue)) {
        return false;
    }
    const existing_value = existing.value;
    const incoming_value = incoming.value;
    if (!(existing_value === incoming_value
        || (existing_value != null &&
            incoming_value != null &&
            existing_value.__ref != null &&
            incoming_value.__ref != null &&
            existing_value.__ref === incoming_value.__ref))) {
        return false;
    }
    return true;
}
const ingest$Q = function FieldValueRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1Y(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$Q, "UiApi", VERSION$1i, RepresentationType$X, equals$17);
    return createLink(key);
};
function getTypeCacheKeys$Y(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$X,
        mergeable: false
    });
    if (input.value !== null && typeof input.value === 'object') {
        getTypeCacheKeys$X(rootKeySet, luvio, input.value);
    }
}

// we override the generated so we can set "mergeable: true" on the root key
const getTypeCacheKeys$X = (rootKeySet, luvio, input, _fullPathFactory) => {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$D(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$V,
        mergeable: true,
    });
    const input_childRelationships = input.childRelationships;
    const input_childRelationships_keys = keys(input_childRelationships);
    const input_childRelationships_length = input_childRelationships_keys.length;
    for (let i = 0; i < input_childRelationships_length; i++) {
        const key = input_childRelationships_keys[i];
        getTypeCacheKeys$W(rootKeySet, luvio, input_childRelationships[key], () => rootKey + '__childRelationships' + '__' + key);
    }
    const input_fields = input.fields;
    const input_fields_keys = keys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$Y(rootKeySet, luvio, input_fields[key], () => rootKey + '__fields__' + key);
    }
    return rootKeySet;
};

const TTL$A = 120000;
const VERSION$1h = "79cb5ac9f44542f683d00245fdfe500d";
function validate$1X(obj, path = 'RecordCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_count = obj.count;
        const path_count = path + '.count';
        if (typeof obj_count !== 'number' || (typeof obj_count === 'number' && Math.floor(obj_count) !== obj_count)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_count + '" (at "' + path_count + '")');
        }
        const obj_currentPageToken = obj.currentPageToken;
        const path_currentPageToken = path + '.currentPageToken';
        let obj_currentPageToken_union0 = null;
        const obj_currentPageToken_union0_error = (() => {
            if (typeof obj_currentPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
            }
        })();
        if (obj_currentPageToken_union0_error != null) {
            obj_currentPageToken_union0 = obj_currentPageToken_union0_error.message;
        }
        let obj_currentPageToken_union1 = null;
        const obj_currentPageToken_union1_error = (() => {
            if (obj_currentPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
            }
        })();
        if (obj_currentPageToken_union1_error != null) {
            obj_currentPageToken_union1 = obj_currentPageToken_union1_error.message;
        }
        if (obj_currentPageToken_union0 && obj_currentPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_currentPageToken + '")';
            message += '\n' + obj_currentPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_currentPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_nextPageToken = obj.nextPageToken;
        const path_nextPageToken = path + '.nextPageToken';
        let obj_nextPageToken_union0 = null;
        const obj_nextPageToken_union0_error = (() => {
            if (typeof obj_nextPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union0_error != null) {
            obj_nextPageToken_union0 = obj_nextPageToken_union0_error.message;
        }
        let obj_nextPageToken_union1 = null;
        const obj_nextPageToken_union1_error = (() => {
            if (obj_nextPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union1_error != null) {
            obj_nextPageToken_union1 = obj_nextPageToken_union1_error.message;
        }
        if (obj_nextPageToken_union0 && obj_nextPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageToken + '")';
            message += '\n' + obj_nextPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        let obj_nextPageUrl_union0 = null;
        const obj_nextPageUrl_union0_error = (() => {
            if (typeof obj_nextPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union0_error != null) {
            obj_nextPageUrl_union0 = obj_nextPageUrl_union0_error.message;
        }
        let obj_nextPageUrl_union1 = null;
        const obj_nextPageUrl_union1_error = (() => {
            if (obj_nextPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union1_error != null) {
            obj_nextPageUrl_union1 = obj_nextPageUrl_union1_error.message;
        }
        if (obj_nextPageUrl_union0 && obj_nextPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageUrl + '")';
            message += '\n' + obj_nextPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_previousPageToken = obj.previousPageToken;
        const path_previousPageToken = path + '.previousPageToken';
        let obj_previousPageToken_union0 = null;
        const obj_previousPageToken_union0_error = (() => {
            if (typeof obj_previousPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union0_error != null) {
            obj_previousPageToken_union0 = obj_previousPageToken_union0_error.message;
        }
        let obj_previousPageToken_union1 = null;
        const obj_previousPageToken_union1_error = (() => {
            if (obj_previousPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union1_error != null) {
            obj_previousPageToken_union1 = obj_previousPageToken_union1_error.message;
        }
        if (obj_previousPageToken_union0 && obj_previousPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageToken + '")';
            message += '\n' + obj_previousPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_previousPageUrl = obj.previousPageUrl;
        const path_previousPageUrl = path + '.previousPageUrl';
        let obj_previousPageUrl_union0 = null;
        const obj_previousPageUrl_union0_error = (() => {
            if (typeof obj_previousPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union0_error != null) {
            obj_previousPageUrl_union0 = obj_previousPageUrl_union0_error.message;
        }
        let obj_previousPageUrl_union1 = null;
        const obj_previousPageUrl_union1_error = (() => {
            if (obj_previousPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union1_error != null) {
            obj_previousPageUrl_union1 = obj_previousPageUrl_union1_error.message;
        }
        if (obj_previousPageUrl_union0 && obj_previousPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageUrl + '")';
            message += '\n' + obj_previousPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (!ArrayIsArray(obj_records)) {
            return new TypeError('Expected "array" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
        for (let i = 0; i < obj_records.length; i++) {
            const obj_records_item = obj_records[i];
            const path_records_item = path_records + '[' + i + ']';
            if (typeof obj_records_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_records_item + '" (at "' + path_records_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$W = 'RecordCollectionRepresentation';
function normalize$P(input, existing, path, luvio, store, timestamp) {
    const input_records = input.records;
    const input_records_id = path.fullPath + '__records';
    for (let i = 0; i < input_records.length; i++) {
        const input_records_item = input_records[i];
        let input_records_item_id = input_records_id + '__' + i;
        input_records[i] = ingest$O(input_records_item, {
            fullPath: input_records_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1W = function RecordCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1h,
        private: [],
        selections: [
            {
                name: 'count',
                kind: 'Scalar'
            },
            {
                name: 'currentPageToken',
                kind: 'Scalar'
            },
            {
                name: 'currentPageUrl',
                kind: 'Scalar'
            },
            {
                name: 'nextPageToken',
                kind: 'Scalar'
            },
            {
                name: 'nextPageUrl',
                kind: 'Scalar'
            },
            {
                name: 'previousPageToken',
                kind: 'Scalar'
            },
            {
                name: 'previousPageUrl',
                kind: 'Scalar'
            },
            {
                name: 'records',
                kind: 'Link',
                plural: true,
                fragment: select$1V()
            }
        ]
    };
};
function equals$16(existing, incoming) {
    const existing_count = existing.count;
    const incoming_count = incoming.count;
    if (!(existing_count === incoming_count)) {
        return false;
    }
    const existing_currentPageUrl = existing.currentPageUrl;
    const incoming_currentPageUrl = incoming.currentPageUrl;
    if (!(existing_currentPageUrl === incoming_currentPageUrl)) {
        return false;
    }
    const existing_currentPageToken = existing.currentPageToken;
    const incoming_currentPageToken = incoming.currentPageToken;
    if (!(existing_currentPageToken === incoming_currentPageToken)) {
        return false;
    }
    const existing_nextPageToken = existing.nextPageToken;
    const incoming_nextPageToken = incoming.nextPageToken;
    if (!(existing_nextPageToken === incoming_nextPageToken)) {
        return false;
    }
    const existing_nextPageUrl = existing.nextPageUrl;
    const incoming_nextPageUrl = incoming.nextPageUrl;
    if (!(existing_nextPageUrl === incoming_nextPageUrl)) {
        return false;
    }
    const existing_previousPageToken = existing.previousPageToken;
    const incoming_previousPageToken = incoming.previousPageToken;
    if (!(existing_previousPageToken === incoming_previousPageToken)) {
        return false;
    }
    const existing_previousPageUrl = existing.previousPageUrl;
    const incoming_previousPageUrl = incoming.previousPageUrl;
    if (!(existing_previousPageUrl === incoming_previousPageUrl)) {
        return false;
    }
    const existing_records = existing.records;
    const incoming_records = incoming.records;
    const equals_records_items = equalsArray(existing_records, incoming_records, (existing_records_item, incoming_records_item) => {
        if (!(existing_records_item.__ref === incoming_records_item.__ref)) {
            return false;
        }
    });
    if (equals_records_items === false) {
        return false;
    }
    return true;
}
const ingest$P = function RecordCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1X(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$A;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$P, "UiApi", VERSION$1h, RepresentationType$W, equals$16);
    return createLink(key);
};
function getTypeCacheKeys$W(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$W,
        mergeable: false
    });
    const input_records_length = input.records.length;
    for (let i = 0; i < input_records_length; i++) {
        getTypeCacheKeys$X(rootKeySet, luvio, input.records[i]);
    }
}

const VIEW_ENTITY_API_NAME = 'Name';
const VIEW_ENTITY_KEY_PREFIX = `${keyPrefix}::RecordViewEntityRepresentation:${VIEW_ENTITY_API_NAME}:`;
const keyBuilderFromType$E = function RecordRepresentationKeyBuilderFromType(luvio, object) {
    const { apiName, id } = object;
    if (apiName === VIEW_ENTITY_API_NAME) {
        return VIEW_ENTITY_KEY_PREFIX + id;
    }
    return keyBuilderFromType$D(luvio, object);
};

const TTL$z = 30000;
const VERSION$1g = "98c5b18512e48ca8d28727549507e4ba";
function validate$1W(obj, path = 'RecordRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_childRelationships = obj.childRelationships;
        const path_childRelationships = path + '.childRelationships';
        if (typeof obj_childRelationships !== 'object' || ArrayIsArray(obj_childRelationships) || obj_childRelationships === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_childRelationships + '" (at "' + path_childRelationships + '")');
        }
        const obj_childRelationships_keys = ObjectKeys(obj_childRelationships);
        for (let i = 0; i < obj_childRelationships_keys.length; i++) {
            const key = obj_childRelationships_keys[i];
            const obj_childRelationships_prop = obj_childRelationships[key];
            const path_childRelationships_prop = path_childRelationships + '["' + key + '"]';
            if (typeof obj_childRelationships_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_childRelationships_prop + '" (at "' + path_childRelationships_prop + '")');
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            if (typeof obj_fields_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
            }
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_lastModifiedById = obj.lastModifiedById;
        const path_lastModifiedById = path + '.lastModifiedById';
        let obj_lastModifiedById_union0 = null;
        const obj_lastModifiedById_union0_error = (() => {
            if (typeof obj_lastModifiedById !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lastModifiedById + '" (at "' + path_lastModifiedById + '")');
            }
        })();
        if (obj_lastModifiedById_union0_error != null) {
            obj_lastModifiedById_union0 = obj_lastModifiedById_union0_error.message;
        }
        let obj_lastModifiedById_union1 = null;
        const obj_lastModifiedById_union1_error = (() => {
            if (obj_lastModifiedById !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lastModifiedById + '" (at "' + path_lastModifiedById + '")');
            }
        })();
        if (obj_lastModifiedById_union1_error != null) {
            obj_lastModifiedById_union1 = obj_lastModifiedById_union1_error.message;
        }
        if (obj_lastModifiedById_union0 && obj_lastModifiedById_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lastModifiedById + '")';
            message += '\n' + obj_lastModifiedById_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lastModifiedById_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_lastModifiedDate = obj.lastModifiedDate;
        const path_lastModifiedDate = path + '.lastModifiedDate';
        let obj_lastModifiedDate_union0 = null;
        const obj_lastModifiedDate_union0_error = (() => {
            if (typeof obj_lastModifiedDate !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lastModifiedDate + '" (at "' + path_lastModifiedDate + '")');
            }
        })();
        if (obj_lastModifiedDate_union0_error != null) {
            obj_lastModifiedDate_union0 = obj_lastModifiedDate_union0_error.message;
        }
        let obj_lastModifiedDate_union1 = null;
        const obj_lastModifiedDate_union1_error = (() => {
            if (obj_lastModifiedDate !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lastModifiedDate + '" (at "' + path_lastModifiedDate + '")');
            }
        })();
        if (obj_lastModifiedDate_union1_error != null) {
            obj_lastModifiedDate_union1 = obj_lastModifiedDate_union1_error.message;
        }
        if (obj_lastModifiedDate_union0 && obj_lastModifiedDate_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lastModifiedDate + '")';
            message += '\n' + obj_lastModifiedDate_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lastModifiedDate_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        let obj_recordTypeId_union0 = null;
        const obj_recordTypeId_union0_error = (() => {
            if (typeof obj_recordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union0_error != null) {
            obj_recordTypeId_union0 = obj_recordTypeId_union0_error.message;
        }
        let obj_recordTypeId_union1 = null;
        const obj_recordTypeId_union1_error = (() => {
            if (obj_recordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union1_error != null) {
            obj_recordTypeId_union1 = obj_recordTypeId_union1_error.message;
        }
        if (obj_recordTypeId_union0 && obj_recordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeId + '")';
            message += '\n' + obj_recordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recordTypeInfo = obj.recordTypeInfo;
        const path_recordTypeInfo = path + '.recordTypeInfo';
        let obj_recordTypeInfo_union0 = null;
        const obj_recordTypeInfo_union0_error = (() => {
            const referencepath_recordTypeInfoValidationError = validate$1Z(obj_recordTypeInfo, path_recordTypeInfo);
            if (referencepath_recordTypeInfoValidationError !== null) {
                let message = 'Object doesn\'t match RecordTypeInfoRepresentation (at "' + path_recordTypeInfo + '")\n';
                message += referencepath_recordTypeInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_recordTypeInfo_union0_error != null) {
            obj_recordTypeInfo_union0 = obj_recordTypeInfo_union0_error.message;
        }
        let obj_recordTypeInfo_union1 = null;
        const obj_recordTypeInfo_union1_error = (() => {
            if (obj_recordTypeInfo !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeInfo + '" (at "' + path_recordTypeInfo + '")');
            }
        })();
        if (obj_recordTypeInfo_union1_error != null) {
            obj_recordTypeInfo_union1 = obj_recordTypeInfo_union1_error.message;
        }
        if (obj_recordTypeInfo_union0 && obj_recordTypeInfo_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeInfo + '")';
            message += '\n' + obj_recordTypeInfo_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeInfo_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_systemModstamp = obj.systemModstamp;
        const path_systemModstamp = path + '.systemModstamp';
        let obj_systemModstamp_union0 = null;
        const obj_systemModstamp_union0_error = (() => {
            if (typeof obj_systemModstamp !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_systemModstamp + '" (at "' + path_systemModstamp + '")');
            }
        })();
        if (obj_systemModstamp_union0_error != null) {
            obj_systemModstamp_union0 = obj_systemModstamp_union0_error.message;
        }
        let obj_systemModstamp_union1 = null;
        const obj_systemModstamp_union1_error = (() => {
            if (obj_systemModstamp !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_systemModstamp + '" (at "' + path_systemModstamp + '")');
            }
        })();
        if (obj_systemModstamp_union1_error != null) {
            obj_systemModstamp_union1 = obj_systemModstamp_union1_error.message;
        }
        if (obj_systemModstamp_union0 && obj_systemModstamp_union1) {
            let message = 'Object doesn\'t match union (at "' + path_systemModstamp + '")';
            message += '\n' + obj_systemModstamp_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_systemModstamp_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_weakEtag = obj.weakEtag;
        const path_weakEtag = path + '.weakEtag';
        if (typeof obj_weakEtag !== 'number' || (typeof obj_weakEtag === 'number' && Math.floor(obj_weakEtag) !== obj_weakEtag)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_weakEtag + '" (at "' + path_weakEtag + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$V = 'RecordRepresentation';
function keyBuilder$29(luvio, config) {
    return keyPrefix + '::' + RepresentationType$V + ':' + config.recordId;
}
function keyBuilderFromType$D(luvio, object) {
    const keyParams = {
        recordId: object.id
    };
    return keyBuilder$29(luvio, keyParams);
}
function dynamicNormalize$5(ingestParams) {
    return function normalize_dynamic(input, existing, path, luvio, store, timestamp) {
        const input_childRelationships = input.childRelationships;
        const input_childRelationships_id = path.fullPath + '__childRelationships';
        const input_childRelationships_keys = Object.keys(input_childRelationships);
        const input_childRelationships_length = input_childRelationships_keys.length;
        for (let i = 0; i < input_childRelationships_length; i++) {
            const key = input_childRelationships_keys[i];
            const input_childRelationships_prop = input_childRelationships[key];
            const input_childRelationships_prop_id = input_childRelationships_id + '__' + key;
            input_childRelationships[key] = ingestParams.childRelationships(input_childRelationships_prop, {
                fullPath: input_childRelationships_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        const input_fields = input.fields;
        const input_fields_id = path.fullPath + '__fields';
        const input_fields_keys = Object.keys(input_fields);
        const input_fields_length = input_fields_keys.length;
        for (let i = 0; i < input_fields_length; i++) {
            const key = input_fields_keys[i];
            const input_fields_prop = input_fields[key];
            const input_fields_prop_id = input_fields_id + '__' + key;
            input_fields[key] = ingestParams.fields(input_fields_prop, {
                fullPath: input_fields_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        return input;
    };
}
const select$1V = function RecordRepresentationSelect() {
    const { selections: RecordTypeInfoRepresentation__selections, opaque: RecordTypeInfoRepresentation__opaque, } = select$1Y();
    return {
        kind: 'Fragment',
        version: VERSION$1g,
        private: [
            'eTag',
            'weakEtag'
        ],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'childRelationships',
                kind: 'Link',
                map: true,
                fragment: select$1W()
            },
            {
                name: 'fields',
                kind: 'Link',
                map: true,
                fragment: select$1X()
            },
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'lastModifiedById',
                kind: 'Scalar'
            },
            {
                name: 'lastModifiedDate',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeInfo',
                kind: 'Object',
                nullable: true,
                selections: RecordTypeInfoRepresentation__selections
            },
            {
                name: 'systemModstamp',
                kind: 'Scalar'
            }
        ]
    };
};
const dynamicSelect$8 = function dynamicRecordRepresentationSelect(params) {
    const childRelationshipsPathSelection = params.childRelationships === undefined ? {
        name: 'childRelationships',
        kind: 'Link',
        map: true,
        fragment: select$1W()
    } : params.childRelationships;
    const fieldsPathSelection = params.fields === undefined ? {
        name: 'fields',
        kind: 'Link',
        map: true,
        fragment: select$1X()
    } : params.fields;
    const { selections: RecordTypeInfoRepresentation__selections, opaque: RecordTypeInfoRepresentation__opaque, } = select$1Y();
    return {
        kind: 'Fragment',
        version: VERSION$1g,
        private: [
            'eTag',
            'weakEtag'
        ],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            childRelationshipsPathSelection,
            fieldsPathSelection,
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'lastModifiedById',
                kind: 'Scalar'
            },
            {
                name: 'lastModifiedDate',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeInfo',
                kind: 'Object',
                nullable: true,
                selections: RecordTypeInfoRepresentation__selections
            },
            {
                name: 'systemModstamp',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$15(existing, incoming) {
    const existing_weakEtag = existing.weakEtag;
    const incoming_weakEtag = incoming.weakEtag;
    if (!(existing_weakEtag === incoming_weakEtag)) {
        return false;
    }
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_childRelationships = existing.childRelationships;
    const incoming_childRelationships = incoming.childRelationships;
    const equals_childRelationships_props = equalsObject(existing_childRelationships, incoming_childRelationships, (existing_childRelationships_prop, incoming_childRelationships_prop) => {
        if (!(existing_childRelationships_prop.__ref === incoming_childRelationships_prop.__ref)) {
            return false;
        }
    });
    if (equals_childRelationships_props === false) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_props = equalsObject(existing_fields, incoming_fields, (existing_fields_prop, incoming_fields_prop) => {
        if (!(existing_fields_prop.__ref === incoming_fields_prop.__ref)) {
            return false;
        }
    });
    if (equals_fields_props === false) {
        return false;
    }
    const existing_lastModifiedById = existing.lastModifiedById;
    const incoming_lastModifiedById = incoming.lastModifiedById;
    if (!(existing_lastModifiedById === incoming_lastModifiedById)) {
        return false;
    }
    const existing_lastModifiedDate = existing.lastModifiedDate;
    const incoming_lastModifiedDate = incoming.lastModifiedDate;
    if (!(existing_lastModifiedDate === incoming_lastModifiedDate)) {
        return false;
    }
    const existing_recordTypeId = existing.recordTypeId;
    const incoming_recordTypeId = incoming.recordTypeId;
    if (!(existing_recordTypeId === incoming_recordTypeId)) {
        return false;
    }
    const existing_recordTypeInfo = existing.recordTypeInfo;
    const incoming_recordTypeInfo = incoming.recordTypeInfo;
    if (!(existing_recordTypeInfo === incoming_recordTypeInfo
        || (existing_recordTypeInfo != null &&
            incoming_recordTypeInfo != null &&
            equals$18(existing_recordTypeInfo, incoming_recordTypeInfo)))) {
        return false;
    }
    const existing_systemModstamp = existing.systemModstamp;
    const incoming_systemModstamp = incoming.systemModstamp;
    if (!(existing_systemModstamp === incoming_systemModstamp)) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$V(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$E(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$V,
        mergeable: false
    });
    const input_childRelationships = input.childRelationships;
    const input_childRelationships_keys = ObjectKeys(input_childRelationships);
    const input_childRelationships_length = input_childRelationships_keys.length;
    for (let i = 0; i < input_childRelationships_length; i++) {
        const key = input_childRelationships_keys[i];
        getTypeCacheKeys$W(rootKeySet, luvio, input_childRelationships[key], () => rootKey + "__childRelationships" + "__" + key);
    }
    const input_fields = input.fields;
    const input_fields_keys = ObjectKeys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$Y(rootKeySet, luvio, input_fields[key], () => rootKey + "__fields" + "__" + key);
    }
}
const notifyUpdateAvailableFactory$5 = (luvio) => {
    return function notifyRecordUpdateAvailable(configs) {
        if (process.env.NODE_ENV !== 'production') {
            const requiredKeyParams = ['recordId'];
            configs.forEach(config => {
                if (false === requiredKeyParams.every(req => req in config)) {
                    throw new Error(`one of the configs did not contain all required parameters: ${JSONStringify(ObjectKeys(config))}`);
                }
            });
        }
        const keys = configs.map(c => keyBuilder$29(luvio, c));
        return luvio.notifyStoreUpdateAvailable(keys);
    };
};

/**
 * The master record type id.
 */
const MAIN_RECORD_TYPE_ID = '012000000000000AAA';

/**
 * A set of the string names of known entities.
 *
 * Generated
 *     from: ui-services-private-object-allow-list.yaml
 *     API version: 63
 *     at: Wed, 21 Aug 2024 19:39:55 GMT
 */
const UIAPI_SUPPORTED_ENTITY_API_NAMES = new Set([
    'AIPredictionScore',
    'AISentimentResult',
    'AcademicSession',
    'AcademicTerm',
    'AcademicTermEnrollment',
    'AcademicYear',
    'Account',
    'AccountAccountRelation',
    'AccountBrand',
    'AccountContactRelation',
    'AccountForecast',
    'AccountForecastAdjustment',
    'AccountForecastPeriodMetric',
    'AccountParticipant',
    'AccountPartner',
    'AccountProductForecast',
    'AccountProductPeriodForecast',
    'AccountRelationship',
    'AccountTeamMember',
    'Accreditation',
    'AcctMgrPeriodicTargetDstr',
    'AcctMgrTarget',
    'AcctMgrTargetDstr',
    'ActionCadence',
    'ActionCadenceStep',
    'ActionCadenceStepTracker',
    'ActionCadenceTracker',
    'ActionPlan',
    'ActionPlanBaseTemplateAsgn',
    'ActionPlanItem',
    'ActionPlanItemDependency',
    'ActionPlanTemplate',
    'ActionPlanTemplateAssignment',
    'ActionPlanTemplateItem',
    'ActionPlanTemplateItemValue',
    'ActionPlanTemplateVersion',
    'ActionPlanTmplItmAssessmentInd',
    'ActionPlnTmplItmDependency',
    'ActionVisibility',
    'ActionableList',
    'ActionableListColumn',
    'ActionableListMember',
    'ActionableListMemberStatus',
    'ActivationTarget',
    'ActiveScratchOrg',
    'ActivityMetric',
    'ActivityMetricRollup',
    'ActivityTiming',
    'AdBuyServerAccount',
    'AdCreativeSizeType',
    'AdOpportunity',
    'AdOrderItem',
    'AdOrderItemCreativeSizeType',
    'AdOrderItemPrintIssue',
    'AdOrderItemUnitsSplit',
    'AdOrderLineAdTarget',
    'AdPageLayoutType',
    'AdProductDefaultTargetCategory',
    'AdProductTargetCategory',
    'AdQuote',
    'AdQuoteLine',
    'AdQuoteLineAdTarget',
    'AdQuoteLineCreativeSizeType',
    'AdQuoteLinePrintIssue',
    'AdQuoteLineUnitsSplit',
    'AdServer',
    'AdServerAccount',
    'AdServerUser',
    'AdSpaceCreativeSizeType',
    'AdSpaceGroupMember',
    'AdSpaceSpecification',
    'AdSpecMediaPrintIssue',
    'AdTargetCategory',
    'AdTargetCategorySegment',
    'AdUsage',
    'AdUsageSummary',
    'AddOnDefinition',
    'Address',
    'AdvAccountForecastFact',
    'AdvAcctForecastSetPartner',
    'AdvAcctForecastSetUse',
    'AiDataset',
    'AiImageDetectedObject',
    'AiImageTrainingObject',
    'AiVisionModel',
    'AiVisionModelMetric',
    'AiVisionModelObjectMetric',
    'AiVisitRecommendRequest',
    'AiVisitRecommendation',
    'AiVisitSummary',
    'AiVisitTaskRcmd',
    'AiVisitTaskRcmdRequest',
    'AirTravelEmssnFctr',
    'AirTravelEnrgyUse',
    'AllergyIntolerance',
    'AlternativePaymentMethod',
    'AnnualEmssnInventory',
    'AnnualEmssnRdctnTarget',
    'AntiCorruptionInitSum',
    'ApiAnomalyEventStore',
    'AppAnalyticsDeliveryConfig',
    'AppAnalyticsQueryRequest',
    'AppExtension',
    'AppMenuItem',
    'AppUsageAssignment',
    'ApplicationCase',
    'ApplicationDecision',
    'ApplicationFormTemplate',
    'ApplicationRecommendation',
    'ApplicationRecommender',
    'ApplicationReview',
    'ApplicationTimeline',
    'AppointmentInvitation',
    'AppointmentInvitee',
    'AppointmentReason',
    'AppointmentTopicTimeSlot',
    'ApptBundleAggrDurDnscale',
    'ApptBundleAggrPolicy',
    'ApptBundleConfig',
    'ApptBundlePolicy',
    'ApptBundlePolicySvcTerr',
    'ApptBundlePropagatePolicy',
    'ApptBundleRestrictPolicy',
    'ApptBundleSortPolicy',
    'ApptReasonEngmtChannelType',
    'AsmtQstnRespRecommendation',
    'Assessment',
    'AssessmentEnvelope',
    'AssessmentEnvelopeItem',
    'AssessmentIndDefinedValue',
    'AssessmentIndValue',
    'AssessmentIndicatorDefinition',
    'AssessmentQuestion',
    'AssessmentQuestionAssignment',
    'AssessmentQuestionResponse',
    'AssessmentQuestionSet',
    'AssessmentQuestionVersion',
    'AssessmentSignature',
    'AssessmentTask',
    'AssessmentTaskContentDocument',
    'AssessmentTaskDefinition',
    'AssessmentTaskIndDefinition',
    'AssessmentTaskOrder',
    'Asset',
    'AssetAccountParticipant',
    'AssetAction',
    'AssetActionSource',
    'AssetAttribute',
    'AssetContactParticipant',
    'AssetDowntimePeriod',
    'AssetMilestone',
    'AssetRelationship',
    'AssetStatePeriod',
    'AssetWarranty',
    'AssignedResource',
    'AssistantText',
    'AssociatedLocation',
    'Assortment',
    'AssortmentProduct',
    'AsyncOperationLog',
    'AttachedContentNote',
    'AttributeCategory',
    'AttributeDefinition',
    'AttributePicklist',
    'AttributePicklistValue',
    'AuthApplicationAsset',
    'AuthApplicationPlace',
    'AuthFormRequestRecord',
    'AuthLocationAccessSchedule',
    'AuthorNote',
    'AuthorizationForm',
    'AuthorizationFormConsent',
    'AuthorizationFormDataUse',
    'AuthorizationFormText',
    'AuthorizedInsuranceLine',
    'AutomatedAction',
    'AutomatedActionCondition',
    'AutomatedActionParameter',
    'Award',
    'BCEntityPermission',
    'BCEntityPermissionSet',
    'BCFieldPermission',
    'BCParticipant',
    'BCParticipantAccess',
    'BCPermissionSet',
    'BCRecordAccess',
    'BCRecordAccessApproval',
    'BCRelatedParticipant',
    'BackgroundOperation',
    'Banker',
    'BatchJob',
    'BatchJobPartFailedRecord',
    'Benefit',
    'BenefitAssignment',
    'BenefitAssignmentAdjustment',
    'BenefitDisbursement',
    'BenefitDisbursementAdj',
    'BenefitParameterValue',
    'BenefitSchedule',
    'BenefitSession',
    'BenefitType',
    'BillingBatchFilterCriteria',
    'BillingBatchScheduler',
    'BillingPeriodItem',
    'BillingPolicy',
    'BillingSchedule',
    'BillingScheduleCreationStatus',
    'BillingScheduleGroup',
    'BillingTreatment',
    'BillingTreatmentItem',
    'BldgEnrgyIntensity',
    'BldgEnrgyIntensityVal',
    'BldgSizeCategory',
    'BlockchainAppMember',
    'BlockchainApplication',
    'BlockchainEntity',
    'BlockchainField',
    'BlockchainMember',
    'BoardCertification',
    'BotDefinition',
    'BranchUnit',
    'BranchUnitBusinessMember',
    'BranchUnitCustomer',
    'BranchUnitRelatedRecord',
    'BroadcastCommAudience',
    'BroadcastCommunication',
    'BroadcastTopic',
    'Budget',
    'BudgetAllocation',
    'BudgetCategory',
    'BudgetCategoryValue',
    'BudgetPeriod',
    'BundledCareFeeAgreement',
    'BusRegAuthTypeDependency',
    'BusRegAuthorizationType',
    'BusinessAlert',
    'BusinessAlertStatus',
    'BusinessBrand',
    'BusinessHours',
    'BusinessLicense',
    'BusinessLicenseApplication',
    'BusinessMilestone',
    'BusinessProfile',
    'BusinessType',
    'BuyerAccount',
    'BuyerGroup',
    'BuyerGroupPricebook',
    'CalcProcStepRelationship',
    'CalculationMatrix',
    'CalculationMatrixColumn',
    'CalculationMatrixRow',
    'CalculationMatrixVersion',
    'CalculationProcedure',
    'CalculationProcedureStep',
    'CalculationProcedureVariable',
    'CalculationProcedureVersion',
    'Campaign',
    'CampaignInfluence',
    'CampaignInsight',
    'CampaignMember',
    'CampaignMemberStatus',
    'CapitationCareFeeAgreement',
    'CardPaymentMethod',
    'CareBarrier',
    'CareBarrierDeterminant',
    'CareBarrierType',
    'CareBenefitVerifyRequest',
    'CareDeterminant',
    'CareDeterminantType',
    'CareDiagnosis',
    'CareEpisode',
    'CareEpisodeDetail',
    'CareFeeScheduleItem',
    'CareInterventionType',
    'CareLimitType',
    'CareMetricTarget',
    'CareObservation',
    'CareObservationComponent',
    'CarePerformer',
    'CarePgmEnrolleeWkOrdStep',
    'CarePgmEnrolleeWorkOrder',
    'CarePgmProvHealthcareProvider',
    'CarePlan',
    'CarePlanActivity',
    'CarePlanActivityDetail',
    'CarePlanDetail',
    'CarePlanTemplate',
    'CarePlanTemplateBenefit',
    'CarePlanTemplateGoal',
    'CarePlanTemplateProblem',
    'CarePractnFacilityAppt',
    'CarePreauth',
    'CarePreauthItem',
    'CareProgram',
    'CareProgramCampaign',
    'CareProgramEligibilityRule',
    'CareProgramEnrollee',
    'CareProgramEnrolleeProduct',
    'CareProgramEnrollmentCard',
    'CareProgramGoal',
    'CareProgramProduct',
    'CareProgramProvider',
    'CareProgramTeamMember',
    'CareProviderAdverseAction',
    'CareProviderFacilitySpecialty',
    'CareProviderSearchableField',
    'CareRegisteredDevice',
    'CareRequest',
    'CareRequestDrug',
    'CareRequestExtension',
    'CareRequestItem',
    'CareRequestReviewer',
    'CareSpecialty',
    'CareSpecialtyTaxonomy',
    'CareTaxonomy',
    'CartDeliveryGroup',
    'CartItem',
    'CartTax',
    'Case',
    'CaseArticle',
    'CaseComment',
    'CaseContactRole',
    'CaseMilestone',
    'CaseParticipant',
    'CaseProgram',
    'CaseRelatedIssue',
    'CategorizedCareFeeAgreement',
    'ChangeRequest',
    'ChangeRequestRelatedIssue',
    'ChangeRequestRelatedItem',
    'ChannelObjectLinkingRule',
    'ChannelProgram',
    'ChannelProgramLevel',
    'ChannelProgramMember',
    'Claim',
    'ClaimCase',
    'ClaimCovPaymentAdjustment',
    'ClaimCovReserveAdjustment',
    'ClaimCoverage',
    'ClaimCoveragePaymentDetail',
    'ClaimCoverageReserveDetail',
    'ClaimItem',
    'ClaimParticipant',
    'ClaimPaymentSummary',
    'ClaimPayoutPlan',
    'ClaimRecovery',
    'ClaimTeamMember',
    'ClauseCatgConfiguration',
    'ClinicalAlert',
    'ClinicalDetectedIssue',
    'ClinicalDetectedIssueDetail',
    'ClinicalEncounter',
    'ClinicalEncounterDiagnosis',
    'ClinicalEncounterFacility',
    'ClinicalEncounterIdentifier',
    'ClinicalEncounterProvider',
    'ClinicalEncounterReason',
    'ClinicalEncounterSvcRequest',
    'ClinicalServiceRequest',
    'ClinicalServiceRequestDetail',
    'CloudServiceProvider',
    'CodeSet',
    'CodeSetBundle',
    'CodeSetRelationship',
    'CollaborationRoom',
    'CommSubscription',
    'CommSubscriptionChannelType',
    'CommSubscriptionConsent',
    'CommSubscriptionTiming',
    'CommerceEntitlementPolicy',
    'CommissionSchedule',
    'CommissionScheduleAssignment',
    'CommsRegionDiscount',
    'CommsVolumeDiscount',
    'ComplaintCase',
    'ComplaintParticipant',
    'ConsentMetric',
    'ConsentUsageMetric',
    'ConstituentRole',
    'ConsumptionRate',
    'ConsumptionSchedule',
    'Contact',
    'ContactContactRelation',
    'ContactEncounter',
    'ContactEncounterParticipant',
    'ContactPointAddress',
    'ContactPointConsent',
    'ContactPointEmail',
    'ContactPointPhone',
    'ContactPointTypeConsent',
    'ContactProfile',
    'ContactRequest',
    'ContentDocument',
    'ContentDocumentLink',
    'ContentDocumentListViewMapping',
    'ContentFolderItem',
    'ContentFolderLink',
    'ContentNote',
    'ContentVersion',
    'ContentWorkspace',
    'Contract',
    'ContractContactRole',
    'ContractDocVerContentDoc',
    'ContractDocVersionSection',
    'ContractDocumentVersion',
    'ContractGroupPlan',
    'ContractGroupPlanGroupClass',
    'ContractLineItem',
    'ContractLineOutcome',
    'ContractLineOutcomeData',
    'ContractPaymentAgreement',
    'ContractType',
    'ContractTypeConfig',
    'ConversationBroadcast',
    'ConversationBroadcastEntry',
    'Coupon',
    'CourseOffering',
    'CourseOfferingParticipant',
    'CourseOfferingPtcpResult',
    'CourseOfferingSchedule',
    'CourseOfferingScheduleTmpl',
    'CoverageBenefit',
    'CoverageBenefitItem',
    'CoverageBenefitItemLimit',
    'CoverageLimit',
    'CoverageType',
    'CrbnCreditAlloc',
    'CrbnCreditAllocItem',
    'CrbnCreditDistribution',
    'CrbnCreditProject',
    'CrbnEmssnScopeAlloc',
    'CrbnEmssnScopeAllocVal',
    'CredentialStuffingEventStore',
    'CreditMemo',
    'CreditMemoAddressGroup',
    'CreditMemoInvApplication',
    'CreditMemoLine',
    'Crisis',
    'CryptoProdCatgWalletGroup',
    'CryptoProdtCatgWalletRole',
    'CryptoProduct',
    'CryptoTransEnvelopeChgLog',
    'CryptoTransaction',
    'CryptoTransactionEnvelope',
    'CryptoWallet',
    'CryptoWalletGroup',
    'CryptoWalletGroupItem',
    'CspTrustedSite',
    'CustomObjectParticipant',
    'Customer',
    'CustomerProperty',
    'DandBCompany',
    'DataAction',
    'DataActionTarget',
    'DataConnectorS3',
    'DataLakeObjectInstance',
    'DataStream',
    'DataUseLegalBasis',
    'DataUsePurpose',
    'DelegatedAccount',
    'DeleteEvent',
    'DeliveryTask',
    'DiagnosticSummary',
    'DiagnosticSummaryDetail',
    'DigitalSignature',
    'DigitalWallet',
    'Disclosure',
    'DisclosureDefinition',
    'DisclosureDefinitionVersion',
    'DisclosureType',
    'DisclsReportingPeriod',
    'DistributorAuthorization',
    'DivrsEquityInclSum',
    'DocTemplateSectionCondition',
    'DocumentChecklistItem',
    'DocumentClause',
    'DocumentClauseSet',
    'DocumentEnvelope',
    'DocumentGenerationProcess',
    'DocumentGenerationSetting',
    'DocumentRecipient',
    'DocumentTemplate',
    'DocumentTemplateContentDoc',
    'DocumentTemplateSection',
    'DocumentTemplateToken',
    'DrugDisplayTerm',
    'DsarPolicyLog',
    'DuplicateRecordItem',
    'DuplicateRecordSet',
    'ECart',
    'EconomicPerformanceSum',
    'EditionDefinition',
    'EducationalInfoRequest',
    'ElectricityEmssnFctrSet',
    'ElectronicMediaGroup',
    'EmailContent',
    'EmailMessage',
    'EmailMessageRelation',
    'EmissionsActivity',
    'EmissionsForecastFact',
    'EmpBenefitSummary',
    'EmpUserProvisionProcessErr',
    'EmpUserProvisioningProcess',
    'Employee',
    'EmployeeAsset',
    'EmployeeContact',
    'EmployeeCrisisAssessment',
    'EmployeeDemographicSum',
    'EmployeeDevelopmentSum',
    'EmployeeJob',
    'EmployeeJobPosition',
    'EmployeeOrganization',
    'EmssnRdctnCommitment',
    'EmssnReductionTarget',
    'EnablementProgram',
    'EnblPgmTaskMeasureProgress',
    'EnblProgramSection',
    'EnblProgramTaskDefinition',
    'EnblProgramTaskMeasure',
    'EnblProgramTaskProgress',
    'EngagementAttendee',
    'EngagementChannelType',
    'EngagementChannelWorkType',
    'EngagementInteraction',
    'EngagementProgram',
    'EngagementProgramVersion',
    'EngagementTopic',
    'EnhancedEmailTemplate',
    'EnhancedLetterhead',
    'EnrollmentEligibilityCriteria',
    'Entitlement',
    'EntitlementContact',
    'EntityArchivingException',
    'EntityArchivingJob',
    'EntityArchivingSetup',
    'EntityDefinition',
    'EntityMilestone',
    'EnvironmentHubMember',
    'EnvironmentalRisk',
    'Event',
    'Examination',
    'Expense',
    'ExpenseReport',
    'ExpenseReportEntry',
    'ExplainabilityMsgTemplate',
    'ExpressionSet',
    'ExpressionSetVersion',
    'ExtDataShare',
    'ExtDataShareTarget',
    'ExternalAccountHierarchy',
    'FTestVirtualBpoLookup',
    'FeeScheduleDefinition',
    'FeedItem',
    'FieldServiceMobileExtension',
    'FieldServiceMobileSettings',
    'FieldServiceOrgSettings',
    'FinanceBalanceSnapshot',
    'FinanceBook',
    'FinancePeriod',
    'FinanceTransaction',
    'FinanceTransactionErrorLog',
    'FinancialDeal',
    'FinancialDealAsset',
    'FinancialDealBid',
    'FinancialDealInteraction',
    'FinancialDealParticipant',
    'FinancialDealParty',
    'FinancialDealProduct',
    'FinclDealInteractionSummary',
    'FlowInterview',
    'FlowOrchestrationInstance',
    'FlowOrchestrationStageInstance',
    'FlowOrchestrationStepInstance',
    'FlowOrchestrationWorkItem',
    'ForecastingOwnerAdjustment',
    'FrgtHaulingEmssnFctr',
    'FrgtHaulingEnrgyUse',
    'FtestBigObjectLookup',
    'FtestConcrete',
    'FtestConcrete6',
    'FtestConcrete7',
    'FtestConcrete8',
    'FtestVirtualMain',
    'FtestZosUiPrototypeChild1',
    'FtestZosUiPrototypeChild2',
    'FtestZosUiPrototypeParent',
    'FulfillmentOrder',
    'FulfillmentOrderLineItem',
    'FundingAward',
    'FundingAwardAmendment',
    'FundingAwardRequirement',
    'FundingDisbursement',
    'FundingOpportunity',
    'GeneratedDocument',
    'GeneratedDocumentSection',
    'GeneratedWaste',
    'GenericVisitTask',
    'GenericVisitTaskContext',
    'GeoCountry',
    'GeoState',
    'GnrcVstKeyPerformanceInd',
    'GnrcVstTaskContextRelation',
    'GoalAssignment',
    'GoalAssignmentDetail',
    'GoalDefinition',
    'GoalLink',
    'GovtFinancialAsstSum',
    'GroundTravelEmssnFctr',
    'GroundTravelEnrgyUse',
    'Group',
    'GroupCensus',
    'GroupCensusMember',
    'GroupCensusMemberPlan',
    'GroupClass',
    'GroupClassContribution',
    'GroupMember',
    'GuestBuyerProfile',
    'HealthCareDiagnosis',
    'HealthCareProcedure',
    'HealthCondition',
    'HealthConditionDetail',
    'HealthScore',
    'HealthScoreActionLog',
    'HealthcareFacility',
    'HealthcareFacilityNetwork',
    'HealthcarePayerNetwork',
    'HealthcarePractitionerFacility',
    'HealthcareProvider',
    'HealthcareProviderNpi',
    'HealthcareProviderSpecialty',
    'HealthcareProviderTaxonomy',
    'Holiday',
    'HotelStayEmssnFctr',
    'HotelStayEnrgyUse',
    'IPAddressRange',
    'Identifier',
    'IdentityDocument',
    'IdentityResolution',
    'Image',
    'InStoreLocation',
    'Incident',
    'IncidentRelatedItem',
    'IncludedLicenseDefinition',
    'Individual',
    'IndividualApplication',
    'IndividualApplicationItem',
    'IndividualCrisisAssessment',
    'InflationRate',
    'InfoAuthRequestForm',
    'InfoAuthorizationRequest',
    'InsPolicyTransactionDetail',
    'InsightsExternalData',
    'InsightsExternalDataPart',
    'InspectionAssessmentInd',
    'InspectionType',
    'InsuranceClaimAsset',
    'InsuranceContract',
    'InsurancePolicy',
    'InsurancePolicyAsset',
    'InsurancePolicyCoverage',
    'InsurancePolicyMemberAsset',
    'InsurancePolicyOwner',
    'InsurancePolicyParticipant',
    'InsurancePolicySurcharge',
    'InsurancePolicyTransaction',
    'InsuranceProfile',
    'IntegrationProviderDef',
    'Interaction',
    'InteractionAttendee',
    'InteractionParticipant',
    'InteractionRelatedAccount',
    'InteractionSumDiscussedAccount',
    'InteractionSummary',
    'InteractionSummaryParticipant',
    'InterestTag',
    'InternalOrganizationUnit',
    'InventoryItemReservation',
    'InventoryReservation',
    'Invoice',
    'InvoiceAddressGroup',
    'InvoiceBatchRun',
    'InvoiceBatchRunCriteria',
    'InvoiceBatchRunRecovery',
    'InvoiceLine',
    'JobFamily',
    'JobProfile',
    'JournalSubType',
    'JournalType',
    'KnowledgeArticleVersion',
    'Lead',
    'LeadLineItem',
    'LeadPreferredSeller',
    'LearnerProgram',
    'LearnerProgramRequirement',
    'LearnerProgramRqmtProgress',
    'Learning',
    'LearningAchievement',
    'LearningCourse',
    'LearningFoundationItem',
    'LearningItem',
    'LearningItemAssignment',
    'LearningItemProgress',
    'LearningOutcomeItem',
    'LearningProgram',
    'LearningProgramPlan',
    'LearningProgramPlanRqmt',
    'LegalEntity',
    'LicensingError',
    'LicensingRequest',
    'LicensingRequestOrderItem',
    'LicensingSnapshotRequest',
    'LinkedArticle',
    'ListEmail',
    'LiveAgentSession',
    'LiveChatButton',
    'LiveChatDeployment',
    'LiveChatSensitiveDataRule',
    'LiveChatTranscript',
    'LiveChatVisitor',
    'LoanApplicant',
    'LoanApplicantAddress',
    'LoanApplicantAsset',
    'LoanApplicantDeclaration',
    'LoanApplicantEmployment',
    'LoanApplicantIncome',
    'LoanApplicantLiability',
    'LoanApplicationAsset',
    'LoanApplicationFinancial',
    'LoanApplicationLiability',
    'LoanApplicationProperty',
    'LoanApplicationTitleHolder',
    'LocWaitlistMsgTemplate',
    'Location',
    'LocationGroup',
    'LocationGroupAssignment',
    'LocationTrustMeasure',
    'LocationWaitlist',
    'LocationWaitlistedParty',
    'LoyaltyLedger',
    'LoyaltyMemberCurrency',
    'LoyaltyMemberTier',
    'LoyaltyMembershipLifecycle',
    'LoyaltyPartnerProduct',
    'LoyaltyPgmEngmtAttrProm',
    'LoyaltyPgmEngmtAttribute',
    'LoyaltyPgmGroupMbrRlnsp',
    'LoyaltyPgmMbrAttributeVal',
    'LoyaltyPgmPartnerCurrency',
    'LoyaltyPgmPartnerPromotion',
    'LoyaltyPgmPtnrLdgrSummary',
    'LoyaltyPgmPtnrPrepaidPack',
    'LoyaltyProgram',
    'LoyaltyProgramBadge',
    'LoyaltyProgramCurrency',
    'LoyaltyProgramMbrPromotion',
    'LoyaltyProgramMember',
    'LoyaltyProgramMemberBadge',
    'LoyaltyProgramMemberCase',
    'LoyaltyProgramMemberMerge',
    'LoyaltyProgramPartner',
    'LoyaltyProgramProcess',
    'LoyaltyProgramWidget',
    'LoyaltyTier',
    'LoyaltyTierBenefit',
    'LoyaltyTierGroup',
    'Macro',
    'MaintenanceAsset',
    'MaintenancePlan',
    'MaintenanceWorkRule',
    'ManagedContent',
    'ManagedContentVariant',
    'ManufacturingProgram',
    'MarketSegment',
    'MarketSegmentActivation',
    'MarketingAction',
    'MarketingForm',
    'MarketingLink',
    'MarketingLinkContent',
    'MarketingResource',
    'MedReconRecommendation',
    'MedReconStmtRecommendation',
    'MedTherapyStmtReviewIssue',
    'MediaChannel',
    'MediaContentTitle',
    'MediaPrintIssue',
    'MediaTitleAvailability',
    'MediaTitleReleaseDate',
    'MediaTitleRevenue',
    'Medication',
    'MedicationDispense',
    'MedicationReconciliation',
    'MedicationRequest',
    'MedicationStatement',
    'MedicationStatementDetail',
    'MedicationTherapyReview',
    'MedicationTherapyStmtReview',
    'MedicinalIngredient',
    'MemberBenefit',
    'MemberPlan',
    'MerchantAccount',
    'MessagingChannel',
    'MessagingDeliveryError',
    'MessagingEndUser',
    'MessagingSession',
    'Metric',
    'MfgProgramCpntFrcstFact',
    'MfgProgramForecastFact',
    'MfgProgramVariantFrcstFact',
    'MilestoneType',
    'MktAiPredictiveInsight',
    'MktCalculatedInsight',
    'MktDataTransform',
    'MktMLModel',
    'MobileSettingsAssignment',
    'MsgChannelLanguageKeyword',
    'MultipartyInfoAuthRequest',
    'NamespaceRegistry',
    'NetworkReferencedObject',
    'Note',
    'ObjectRelatedUrl',
    'ObjectStateActionDefinition',
    'ObjectStateDefinition',
    'ObjectStateTransition',
    'ObjectStateTransitionAction',
    'ObjectStateValue',
    'ObjectTerritory2Association',
    'OcrDocumentScanResult',
    'OmniAssessmentTask',
    'OmniDataPack',
    'OmniDataTransform',
    'OmniDataTransformItem',
    'OmniESignatureTemplate',
    'OmniProcess',
    'OmniProcessAsmtQuestionVer',
    'OmniProcessCompilation',
    'OmniProcessElement',
    'OmniProcessTransientData',
    'OmniScriptSavedSession',
    'OmniUiCard',
    'OperatingHours',
    'OperatingHoursHoliday',
    'Opportunity',
    'OpportunityContactRole',
    'OpportunityHistory',
    'OpportunityLineItem',
    'OpportunityLineItemSchedule',
    'OpportunityLineItemSplit',
    'OpportunityParticipant',
    'OpportunityPartner',
    'OpportunityPreferredSeller',
    'OpportunitySplit',
    'OpportunityTeamMember',
    'Order',
    'OrderAction',
    'OrderAdjustmentGroup',
    'OrderAdjustmentGroupSummary',
    'OrderChangeLog',
    'OrderDeliveryGroup',
    'OrderDeliveryGroupSummary',
    'OrderDeliveryMethod',
    'OrderItem',
    'OrderItemAdjustmentLineItem',
    'OrderItemAdjustmentLineSummary',
    'OrderItemConsumptionRate',
    'OrderItemConsumptionSchedule',
    'OrderItemRelationship',
    'OrderItemSummary',
    'OrderItemSummaryChange',
    'OrderItemTaxLineItem',
    'OrderItemTaxLineItemSummary',
    'OrderPaymentSummary',
    'OrderSummary',
    'OrderSummaryRoutingSchedule',
    'OrgIncidentSummary',
    'OrgMetric',
    'OrgMetricScanResult',
    'OrgMetricScanSummary',
    'Organization',
    'OtherComponentTask',
    'OtherEmssnFctrSet',
    'OtherEmssnFctrSetItem',
    'ParticipantRole',
    'Partner',
    'PartnerFundAllocation',
    'PartnerFundClaim',
    'PartnerFundRequest',
    'PartnerMarketingBudget',
    'PartyCertifiedCapacity',
    'PartyConsent',
    'PartyIdentityVerification',
    'PartyIdentityVerificationStep',
    'PartyIncome',
    'PartyProfile',
    'PartyProfileAddress',
    'PartyProfileRisk',
    'PartyRelationshipGroup',
    'PartyRoleRelation',
    'PartyScreeningStep',
    'PartyScreeningSummary',
    'PatientHealthReaction',
    'PatientImmunization',
    'PatientImmunizationProtocol',
    'PatientMedicalProcedure',
    'PatientMedicalProcedureDetail',
    'PatientMedicationDosage',
    'Payment',
    'PaymentAuthAdjustment',
    'PaymentBatchRun',
    'PaymentBatchRunCriteria',
    'PaymentGateway',
    'PaymentGatewayLog',
    'PaymentGatewayProvider',
    'PaymentIntent',
    'PaymentLineInvoice',
    'PaymentRequest',
    'PaymentRequestLine',
    'PaymentSchedule',
    'PaymentScheduleItem',
    'PaymentSchedulePolicy',
    'PaymentScheduleTreatment',
    'PaymentScheduleTreatmentDtl',
    'PaymentTerm',
    'PaymentTermItem',
    'PcmtEmssnFctrSet',
    'PcmtEmssnFctrSetItem',
    'PercentileBsdCareFeeAgreement',
    'Period',
    'PersonAccount',
    'PersonDisability',
    'PersonEducation',
    'PersonEmployment',
    'PersonExamination',
    'PersonLanguage',
    'PersonLifeEvent',
    'PersonList',
    'PersonName',
    'PgmRebateTypBnftMapping',
    'PickTicket',
    'PickTicketAssignment',
    'PickTicketProduct',
    'PlanBenefit',
    'PlanBenefitItem',
    'PlatformLicenseDefinition',
    'Polygon',
    'PreliminaryApplicationRef',
    'PreventiveCareAgreement',
    'PriceAdjustmentGroupShape',
    'PriceAdjustmentItemShape',
    'PriceAdjustmentSchedule',
    'PriceAdjustmentTier',
    'PriceList',
    'PriceRule',
    'PriceRuleAction',
    'PriceRuleActionItem',
    'PriceRuleCondition',
    'PriceRuleConditionFilter',
    'PriceRuleExecutionStage',
    'Pricebook2',
    'PricebookEntry',
    'PricingHeader',
    'PricingLineItem',
    'PricingProduct',
    'PrivacyHold',
    'PrivacyHoldReason',
    'PrivacyJobSession',
    'PrivacyPolicy',
    'PrivacyRequest',
    'Problem',
    'ProblemDefinition',
    'ProblemGoalDefinition',
    'ProblemIncident',
    'ProblemRelatedItem',
    'ProcessDefinition',
    'ProcessException',
    'ProcessInstance',
    'Producer',
    'ProducerCommission',
    'ProducerPolicyAssignment',
    'Product2',
    'Product2DataTranslation',
    'ProductAttribute',
    'ProductAttributeDefinition',
    'ProductAttributeSet',
    'ProductAttributeSetItem',
    'ProductAttributeSetProduct',
    'ProductAvailabilityProjection',
    'ProductCatalog',
    'ProductCategory',
    'ProductCategoryAttribute',
    'ProductCategoryDataTranslation',
    'ProductCategoryMedia',
    'ProductCategoryProduct',
    'ProductCategoryServiceProcess',
    'ProductComponentGroup',
    'ProductConsumed',
    'ProductConsumedState',
    'ProductConsumptionSchedule',
    'ProductCoverage',
    'ProductCoverageLimit',
    'ProductEmissionsFactor',
    'ProductFaultCode',
    'ProductFulfillmentLocation',
    'ProductItem',
    'ProductItemTransaction',
    'ProductLaborCode',
    'ProductLicenseMap',
    'ProductMedia',
    'ProductOverridePathItem',
    'ProductQuantityRule',
    'ProductRelComponentOverride',
    'ProductRelatedComponent',
    'ProductRelatedMaterial',
    'ProductRelationshipType',
    'ProductRequest',
    'ProductRequestLineItem',
    'ProductRequired',
    'ProductSellingModel',
    'ProductSellingModelOption',
    'ProductServiceCampaign',
    'ProductServiceCampaignItem',
    'ProductSpecificationType',
    'ProductTransfer',
    'ProductTransferState',
    'ProductWarrantyTerm',
    'Profile',
    'ProfileSkill',
    'ProfileSkillEndorsement',
    'ProfileSkillUser',
    'Program',
    'ProgramEnrollment',
    'ProgramProduct',
    'ProgramRebateTypPayoutSrc',
    'ProgramRebateType',
    'ProgramRebateTypeBenefit',
    'ProgramRebateTypeFilter',
    'ProgramRebateTypePayout',
    'ProgramRebateTypeProduct',
    'ProgramRebateTypeReference',
    'ProgramTermApplnTimeline',
    'Promotion',
    'PromotionChannel',
    'PromotionDataTranslation',
    'PromotionLoyaltyPtnrProdt',
    'PromotionMarketSegment',
    'PromotionProduct',
    'PromotionProductCategory',
    'PromotionQualifier',
    'PromotionSegment',
    'PromotionSegmentBuyerGroup',
    'PromotionSegmentSalesStore',
    'PromotionTarget',
    'PromotionTier',
    'ProrationPolicy',
    'ProviderNetworkContract',
    'ProviderNetworkTier',
    'ProviderSearchSyncLog',
    'ProvisioningRun',
    'ProvisioningRunEvent',
    'ProvisioningTargetGroup',
    'ProvisioningTargetItem',
    'ProvisioningTargetRole',
    'PublicApplicationParticipant',
    'PublicComplaint',
    'PublicProgram',
    'PurchaseQuantityRule',
    'PurchaserPlan',
    'PurchaserPlanAssn',
    'PymtSchdDistributionMethod',
    'QuickText',
    'Quote',
    'QuoteDocument',
    'QuoteItemTaxItem',
    'QuoteLineItem',
    'QuoteLineItemAttribute',
    'QuoteLinePriceAdjustment',
    'QuoteLineRelationship',
    'RebateClaim',
    'RebateMemberAggregateItem',
    'RebateMemberProductAggregate',
    'RebatePayment',
    'RebatePayoutAdjustment',
    'RebateProgram',
    'RebateProgramMember',
    'RebateProgramMemberPayout',
    'RebateProgramPayoutPeriod',
    'ReceivedDocument',
    'ReceivedDocumentType',
    'Recommendation',
    'RecordAction',
    'RecordAlert',
    'RecordType',
    'RecordsetFilterCriteria',
    'RecordsetFilterCriteriaRule',
    'RecordsetFltrCritMonitor',
    'RecurrenceSchedule',
    'ReferencedDashboard',
    'Referral',
    'RefrigerantEmssnFctr',
    'RefundLinePayment',
    'RegAuthorizationTypeProduct',
    'RegionStatusDiscount',
    'RegulatoryAuthority',
    'RegulatoryAuthorizationType',
    'RegulatoryCode',
    'RegulatoryCodeAssessmentInd',
    'RegulatoryCodeUse',
    'RegulatoryCodeViolation',
    'RegulatoryTrxnFee',
    'RegulatoryTrxnFeeItem',
    'ReinsAgreementLineItem',
    'ReinsPolicyBordereauFact',
    'ReinsProtocolProdtComponent',
    'ReinsuranceAgreement',
    'ReinsuranceProtocol',
    'ReinsuranceProtocolAgreement',
    'RentalCarEmssnFctr',
    'RentalCarEnrgyUse',
    'ReplyText',
    'Report',
    'ReportAnomalyEventStore',
    'ReportedConsumption',
    'ResidentialLoanApplication',
    'ResourceAbsence',
    'ResourcePreference',
    'RetailLocationGroup',
    'RetailStore',
    'RetailStoreGroupAssignment',
    'RetailStoreKpi',
    'RetailVisitKpi',
    'ReturnOrder',
    'ReturnOrderItemAdjustment',
    'ReturnOrderItemTax',
    'ReturnOrderLineItem',
    'RevRecogTreatmentItemGroup',
    'RevenueAsyncOperation',
    'RevenueDistributionMethod',
    'RevenueElement',
    'RevenueElementDistribution',
    'RevenueRecogTreatmentItem',
    'RevenueRecognitionPolicy',
    'RevenueRecognitionTreatment',
    'RevenueTransactionErrorLog',
    'RightsQuote',
    'RightsQuoteLineItem',
    'RightsQuoteLineMediaTitle',
    'SalesAgreement',
    'SalesAgreementProduct',
    'SalesAgreementProductSchedule',
    'SalesChannel',
    'SalesContractLine',
    'SalesTransactionItemShape',
    'SalesTransactionShape',
    'SalesTrxnItemRelationShape',
    'SalesforceContract',
    'SalesforceInvoice',
    'SalesforceQuote',
    'SchedulingConstraint',
    'Scope3CrbnFtprnt',
    'Scope3EmssnSrc',
    'Scope3PcmtItem',
    'Scope3PcmtSummary',
    'Scorecard',
    'ScorecardAssociation',
    'ScorecardMetric',
    'ScratchOrgInfo',
    'SearchPromotionRule',
    'SecuritiesHolding',
    'Seller',
    'SerializedProduct',
    'SerializedProductTransaction',
    'ServiceAppointment',
    'ServiceAppointmentCapacityUsage',
    'ServiceAppointmentGroup',
    'ServiceContract',
    'ServiceCrew',
    'ServiceCrewMember',
    'ServiceReport',
    'ServiceReportLayout',
    'ServiceResource',
    'ServiceResourceCapacity',
    'ServiceResourceDataTranslation',
    'ServiceResourcePreference',
    'ServiceResourceSkill',
    'ServiceTerritory',
    'ServiceTerritoryDataTranslation',
    'ServiceTerritoryLocation',
    'ServiceTerritoryMember',
    'ServiceTerritoryRelationship',
    'ServiceTerritoryWorkType',
    'SessionHijackingEventStore',
    'SettingUsageDefinition',
    'SettingUsageMap',
    'SetupAssistantStep',
    'SharedSavingPaymentAgreement',
    'SharingRecordCollection',
    'SharingRecordCollectionItem',
    'Shift',
    'ShiftEngagementChannel',
    'ShiftPattern',
    'ShiftPatternEntry',
    'ShiftSegment',
    'ShiftSegmentType',
    'ShiftTemplate',
    'ShiftWorkTopic',
    'Shipment',
    'ShipmentItem',
    'SignatureTask',
    'SignatureTaskLineItem',
    'Skill',
    'SkillLevelDefinition',
    'SkillRequirement',
    'Snippet',
    'SnippetAssignment',
    'SocialContributionSum',
    'SocialPersona',
    'SocialPost',
    'StandardCareFeeAgreement',
    'StandardPermissionSet',
    'StaticResource',
    'StnryAssetAnnualFact',
    'StnryAssetCrbnFtprnt',
    'StnryAssetCrbnFtprntItm',
    'StnryAssetEnrgyUse',
    'StnryAssetEnvrSrc',
    'StnryAssetWaterActvty',
    'StnryAssetWaterFtprnt',
    'StnryAssetWtrFtprntItm',
    'StoreActionPlanTemplate',
    'StoreAssortment',
    'StoreIntegratedService',
    'StoreProduct',
    'StreamingChannel',
    'SuccessTeam',
    'Supplier',
    'SupplierProduct',
    'Survey',
    'SurveyEmailBranding',
    'SurveyInvitation',
    'SurveyQuestion',
    'SurveyQuestionChoice',
    'SurveyQuestionResponse',
    'SurveyResponse',
    'SurveySubject',
    'SurveyVersion',
    'SustainabilityCntrLine',
    'SustainabilityCredit',
    'SustainabilityPurchase',
    'SustainabilityScorecard',
    'SvcCatalogCategory',
    'SvcCatalogCategoryItem',
    'SvcCatalogItemDef',
    'SvcCatalogReqExtdAttrVal',
    'SvcCatalogReqRelatedItem',
    'SvcCatalogRequest',
    'Swarm',
    'SwarmMember',
    'TagCategory',
    'TagCategoryAssignment',
    'Task',
    'TaxDisclosureSummary',
    'TaxEngine',
    'TaxEngineInteractionLog',
    'TaxEngineProvider',
    'TaxGeoConfig',
    'TaxPolicy',
    'TaxRate',
    'TaxTreatment',
    'Tenant',
    'TenantParameterMap',
    'TenantSecurityNotificationRule',
    'Territory2',
    'ThreatDetectionFeedback',
    'TimeSheet',
    'TimeSheetEntry',
    'TimeSlot',
    'Topic',
    'TopicAssignment',
    'TrackedCommunication',
    'TrackedCommunicationDetail',
    'TrainingCourseParticipant',
    'TransactionJournal',
    'Translation',
    'TravelMode',
    'TrialEnvironmentSignup',
    'TrnCourse',
    'UnitOfMeasure',
    'UnitOfMeasureConversion',
    'UsageEntitlement',
    'UsageEntitlementPeriod',
    'UsageEntitlementUsage',
    'UsageFactor',
    'UsageImpactFactor',
    'UsageImpactGroup',
    'UsageImpactGroupFactor',
    'UsageImpactGroupPgmMeasure',
    'UsageImpactGroupVersion',
    'User',
    'UserDefinedLabel',
    'UserDefinedLabelAssignment',
    'UserEsignVendorIdentifier',
    'UserFinancialAuthority',
    'UserLicenseDefinition',
    'UserLocationAssignment',
    'UserRole',
    'UserTerritory2AssocLog',
    'Vehicle',
    'VehicleAssetCrbnFtprnt',
    'VehicleAssetEmssnSrc',
    'VehicleAssetEnrgyUse',
    'VehicleDefinition',
    'VehicleUserAssignment',
    'VideoCall',
    'ViolationEnforcementAction',
    'ViolationType',
    'ViolationTypeAssessmentInd',
    'ViolationTypeUse',
    'Visit',
    'VisitedParty',
    'Visitor',
    'VoiceCall',
    'VolumeDiscount',
    'VolunteerProject',
    'Voucher',
    'VoucherDefinition',
    'WarrantyTerm',
    'WarrantyTermCoverage',
    'WasteFootprint',
    'WasteFootprintItem',
    'WaveAutoInstallRequest',
    'WebCart',
    'WebStore',
    'WebStoreBuyerGroup',
    'WebStoreCatalog',
    'WebStoreInventorySource',
    'WebStorePricebook',
    'WebStoreSearchProdSettings',
    'WorkCapacityLimit',
    'WorkCapacityUsage',
    'WorkCoaching',
    'WorkContract',
    'WorkOrder',
    'WorkOrderLineItem',
    'WorkPlan',
    'WorkPlanSelectionRule',
    'WorkPlanTemplate',
    'WorkPlanTemplateEntry',
    'WorkProcedure',
    'WorkProcedureStep',
    'WorkRewardFund',
    'WorkRewardFundType',
    'WorkStep',
    'WorkStepTemplate',
    'WorkType',
    'WorkTypeCareSpecialty',
    'WorkTypeCodeSetBundle',
    'WorkTypeExtension',
    'WorkTypeGroup',
    'WorkTypeGroupDataTranslation',
    'WorkTypeGroupMember',
    'WorkTypeGroupRole',
    'WorkerCompCoverageClass',
    'WstDispoEmssnFctrSet',
    'WstDispoEmssnFctrSetItm',
]);
/**
 * A set of the string names of known entities.
 *
 * Generated
 *     from: ui-services-private-object-deny-list.yaml
 *     API version: 63
 *     at: Wed, 21 Aug 2024 19:39:55 GMT
 */
const UIAPI_DENIED_ENTITY_API_NAMES = new Set([
    'AIProductOptimizedField',
    'AITenantProvisionedFeature',
    'ASEOrgSyncHealthStats',
    'ASEOrgSyncHealthTxns',
    'AbnExperimentCohortAttrVal',
    'ActionableOrchResponseEvent',
    'ActionableOrchSourceEvent',
    'ActnblListKeyPrfmIndAsgnt',
    'AiMetadataSyncStatus',
    'AnalyticsChangeEventLog',
    'AnalyticsDownloadEventLog',
    'AnalyticsGenerativeMetadata',
    'AnalyticsInteractEventLog',
    'AnalyticsPerfEventLog',
    'AnalyticsTaskStatusEvent',
    'ApexCalloutEventLog',
    'ApexExecutionEventLog',
    'ApexExtlCalloutEventLog',
    'ApexRestApiEventLog',
    'ApexSoapApiEventLog',
    'ApexTriggerEventLog',
    'ApexUnexpectedExcpEventLog',
    'ApiTotalUsageEventLog',
    'ApplnFormUsageTracking',
    'AssetThresholdUpdateEvent',
    'AsyncReportRunEventLog',
    'AuraRequestEventLog',
    'BulkApi2EventLog',
    'BulkApi2JobResultsEvent',
    'BulkApi2JobStatusEvent',
    'BulkApiEventLog',
    'BulkMessage',
    'CapabilityUserPreference',
    'CaseFileProcessDependency',
    'CaseFileProcessExecution',
    'CatalogListing',
    'CheckoutResetConfig',
    'CommerceJobStatus',
    'CommerceSearchIndexError',
    'CommerceSearchResultsRule',
    'CompiledProduct',
    'ConcurApexLimitEventLog',
    'ConsentUnsubscribeAllEvent',
    'ConsentUnsubscribeEvent',
    'ContentTaxonomyModel',
    'ContentTransferEventLog',
    'ContextPersistenceEvent',
    'ContractCreationEvent',
    'ConvIntelligenceVoiceCall',
    'ConvMessageSendRequest',
    'ConversationInsightEvent',
    'ConversationTranscriptSendRequest',
    'CuratedExpJobEvent',
    'CuratedExpPlanEvent',
    'DTRecordsetReplica',
    'DataActionJobStatusEvent',
    'DataCloudCurrencyConfig',
    'DataCloudFiscalCalendar',
    'DataKitDeployEvent',
    'DataMultiOrgServiceEvent',
    'DataShellTntUpgradeEvent',
    'DcsnTblSourceObjectRecord',
    'DecisionTableDataset',
    'DecisionTableRecordset',
    'DecisionTblSrcChangedEvent',
    'DiscoveryFrwrkSampleTemplate',
    'DiscoveryFrwrkTemplateMember',
    'DocGenBtchStsChgEvent',
    'DocGenProcStsChgEvent',
    'DocumentExtReviewerConsent',
    'EmailBounceEvent',
    'EnblMlstnProgQryTmotEvent',
    'EngagementSignalCmpndMetric',
    'EngagementSignalDistinct',
    'EngagementSignalFilter',
    'EngagementSignalFltrGrp',
    'EngagementSignalFltrVal',
    'EngagementSignalJoinDim',
    'EngagementSignalMetric',
    'ExtKAImportError',
    'ExtKAImportResult',
    'ExtKnowledgeIngestionRun',
    'ExtKnowledgeIngestionStatus',
    'ExtKnowledgeIngestionTask',
    'ExtKnowledgeOrgStatus',
    'ExtKnowledgePartnerOrg',
    'ExtKnowledgeXDSConnector',
    'ExternalDataChgEvent',
    'ExternalDocRefMapping',
    'ExternalEncryptionRootKey',
    'ExternalTrigger',
    'ExternalTriggerData',
    'ExternalTriggerSubscriber',
    'ExtlRecShrCnctAccnt',
    'ExtlRecShrEvent',
    'ExtlRecShrProcessEvent',
    'ExtlRecShrRecordMap',
    'ExtlRecShrResultEvent',
    'FirstBillPaymentSetupEvent',
    'FlowAutoSaveStsChngEvent',
    'FlowAutosaveInterviewStatus',
    'FlowDefDataActionMapping',
    'FlowNavMetricEventLog',
    'GenericHammerResult',
    'GuestUserAnomalyEvent',
    'InsufficientAccessEventLog',
    'InsuranceAsyncBulkRecordDetail',
    'InsuranceRatingInput',
    'InsuranceRatingOutput',
    'InsuranceRatingRequestEvent',
    'InsuranceRatingRequestItem',
    'InterviewItemWaitCondition',
    'KnowledgeArticleEventLog',
    'LightningLoggerEventLog',
    'LightningPageViewEventLog',
    'LoginAsEventLog',
    'LoginEventLog',
    'MLModelDataAlert',
    'ManagedContentJobBody',
    'ManagedContentOffCoreLocation',
    'ManagedContentSpaceFolderShare',
    'MerchantAccountEvent',
    'MessagingChannelUpdateEvent',
    'MetadataApiOpEventLog',
    'MetricsDeletionJobStatus',
    'MktMLModelPartitionRun',
    'MktMLModelSetupRun',
    'MktMLSetupRunChgEvent',
    'MngContentFormActionEvent',
    'ObjectDataImportResult',
    'ObjectUserTerritory2View',
    'OmniTrackingEvent',
    'OrderItemAssetizationState',
    'OrgDayZeroStatus',
    'OrgSharingEvent',
    'OvenSdbExperimentRequest',
    'PackageInstallEventLog',
    'PackagePropUpdateJob',
    'PackagePropUpdateRequest',
    'PackageSubscriberOrgInfo',
    'PaymentIntentEvent',
    'PaymentLinkEvent',
    'PersnlDecisionAttrValue',
    'PersonalizationAttribute',
    'PlatformEventUsage',
    'PriceBookPriceGuidance',
    'PriceSheetData',
    'PricingDecisionHashMap',
    'PricingLookupSyncStatus',
    'PricingWaterfallLog',
    'PushUpgradeCustomization',
    'QuoteSaveEvent',
    'RebatePayoutSnapshot',
    'RecommenderStatusChgEvent',
    'RelationshipGraphView',
    'ReminderRecord',
    'ReportEventLog',
    'RestApiEventLog',
    'Rule',
    'RuleAction',
    'RuleActionParameter',
    'RuleCondition',
    'RuleDeploymentRequestEvent',
    'RuleExpression',
    'RuleExpressionTerm',
    'RuleFilterCriteria',
    'RuleLibraryContextTag',
    'RuleLibraryVersionSnapshot',
    'RuleReferenceVariable',
    'RuleValue',
    'RuleVersion',
    'RuleVersionSnapshot',
    'Ruleset',
    'RulesetVersion',
    'RulesetVersionSnapshot',
    'RuntimeCatalogSnapshot',
    'RuntimeCatalogSnapshotIndex',
    'SalesTrxnItemPrcSht',
    'SalesTrxnItemPrcShtShape',
    'SalesforcePayment',
    'SandboxStatusEventLog',
    'SavedPaymentMethodEvent',
    'ScheduledReminder',
    'SearchBBRule',
    'SearchBBRuleCondition',
    'SearchClickEventLog',
    'SearchEventLog',
    'SearchIndexFieldConfig',
    'SearchIndexObjectConfig',
    'SearchRecencyIndexingJob',
    'ServiceAppointmentEvent',
    'ServiceAppointmentShift',
    'SiqOrgMigrationStatus',
    'SiteEventLog',
    'SoapApiEventLog',
    'StatsInvalidationEvent',
    'TenantBillingUsageEvent',
    'TransactionSecurityEventLog',
    'UnifiedAnalyticsMonEvent',
    'UnitOfMeasureUnit',
    'UriEventLog',
    'VisualforceRequestEventLog',
    'WebPushMessageSubscription',
    'WebStoreCMS',
    'WebStoreUserCreatedEvent',
    'YourAccountDataEvent',
]);

const MAX_RECORD_DEPTH = 5;
const FIELD_SEPARATOR = '.';
const SCALAR_VALUE_SELECTION = {
    kind: 'Scalar',
    name: 'value',
};
const DISPLAY_VALUE_SELECTION = {
    kind: 'Scalar',
    name: 'displayValue',
};
const FIELDS_SELECTION = {
    kind: 'Object',
    name: 'fields',
};
function convertRecordFieldsArrayToTrie(fields, optionalFields = []) {
    const root = {
        name: '<root>',
        optional: false,
        scalar: false,
        children: {},
    };
    insertFieldsIntoTrie(root, fields, false);
    insertFieldsIntoTrie(root, optionalFields, true);
    return root;
}
function createPathSelection(propertyName, fieldDefinition) {
    const fieldsSelection = [];
    const { children } = fieldDefinition;
    const childrenKeys = keys(children);
    for (let i = 0, len = childrenKeys.length; i < len; i += 1) {
        const childKey = childrenKeys[i];
        const childFieldDefinition = children[childKey];
        let fieldValueSelection;
        if (childFieldDefinition.scalar === true) {
            fieldValueSelection = SCALAR_VALUE_SELECTION;
        }
        else {
            fieldValueSelection = {
                kind: 'Link',
                name: 'value',
                nullable: true,
                fragment: {
                    kind: 'Fragment',
                    private: ['eTag', 'weakEtag'],
                    selections: createRecordSelection(childFieldDefinition),
                    version: VERSION$1g,
                },
            };
        }
        const fieldSelection = {
            kind: 'Link',
            name: childFieldDefinition.name,
            required: childFieldDefinition.optional === true ? false : undefined,
            fragment: {
                kind: 'Fragment',
                version: VERSION$1i,
                private: [],
                selections: [DISPLAY_VALUE_SELECTION, fieldValueSelection],
            },
        };
        push.call(fieldsSelection, fieldSelection);
    }
    return {
        kind: 'Object',
        name: propertyName,
        selections: fieldsSelection,
    };
}
/**
 * Convert a RecordRepresentationLike into its equivalent selection.
 */
function createPathSelectionFromValue(fields) {
    const fieldsSelection = [];
    const fieldNames = keys(fields);
    for (let i = 0, len = fieldNames.length; i < len; i++) {
        const fieldName = fieldNames[i];
        const { value: fieldValue } = fields[fieldName];
        let fieldValueSelection = SCALAR_VALUE_SELECTION;
        if (isSpanningRecord(fieldValue)) {
            fieldValueSelection = {
                kind: 'Link',
                name: 'value',
                nullable: true,
                fragment: {
                    kind: 'Fragment',
                    private: [],
                    selections: buildSelectionFromRecord(fieldValue),
                    version: VERSION$1g,
                },
            };
        }
        const fieldSelection = {
            kind: 'Link',
            name: fieldName,
            required: undefined,
            fragment: {
                kind: 'Fragment',
                version: VERSION$1i,
                private: [],
                selections: [DISPLAY_VALUE_SELECTION, fieldValueSelection],
            },
        };
        push.call(fieldsSelection, fieldSelection);
    }
    return {
        kind: 'Object',
        name: FIELDS_SELECTION.name,
        selections: fieldsSelection,
    };
}
function extractRecordFieldsRecursively(record) {
    const fields = [];
    const fieldNames = keys(record.fields);
    for (let i = 0, len = fieldNames.length; i < len; i++) {
        const fieldName = fieldNames[i];
        const { value: fieldValue } = record.fields[fieldName];
        if (isSpanningRecord(fieldValue)) {
            const spanningRecordFields = extractRecordFieldsRecursively(fieldValue);
            for (let j = 0, len = spanningRecordFields.length; j < len; j++) {
                spanningRecordFields[j] = `${fieldName}.${spanningRecordFields[j]}`;
            }
            push.apply(fields, spanningRecordFields);
        }
        else {
            push.call(fields, fieldName);
        }
    }
    return fields;
}
/**
 * Returns a list of fields for a RecordRepresentationLike.
 *
 * TODO [W-6900271]: Remove this function once getRelatedList don't depend on it anymore. Always prefer
 * generating a selection out of a record, than convert a record to a field list and back to a
 * selection.
 */
function extractFields(value) {
    const { apiName } = value;
    const fields = extractRecordFieldsRecursively(value);
    for (let i = 0, len = fields.length; i < len; i++) {
        fields[i] = `${apiName}.${fields[i]}`;
    }
    return fields;
}
function insertFieldsIntoTrie(root, fields, optional) {
    for (let i = 0, len = fields.length; i < len; i++) {
        const field = fields[i].split(FIELD_SEPARATOR);
        let current = root;
        for (let j = 1, len = field.length; j < len && j <= MAX_RECORD_DEPTH + 1; j++) {
            const fieldName = field[j];
            let next = current.children[fieldName];
            if (next === undefined) {
                // A field is scalar only if it is the last field name in the field.
                const scalar = j === len - 1;
                // LDS restricts the numbers of fields that can be traversed to MAX_RECORD_DEPTH,
                // however we still denormalize fields at MAX_RECORD_DEPTH + 1, only if they are
                // scalar fields.
                if (j <= MAX_RECORD_DEPTH || scalar === true) {
                    // We now know that there are children fields, so we can mark the parent
                    // as not a scalar
                    current.scalar = false;
                    next = {
                        name: fieldName,
                        scalar,
                        optional,
                        children: {},
                    };
                    current.children[fieldName] = next;
                }
            }
            current = next;
        }
    }
}

const CHILD_RELATIONSHIP_SELECTION = {
    // We don't support RecordRep.childRelationships because it has a nasty
    // degenerate case of multiple pages of child records
    kind: 'Object',
    name: 'childRelationships',
};
// This selection is a client-side only selection and will only
// be applied to a RecordRepresentation in environments configured with
// drafts when the record has draft changes applied to it
// TODO [W-8237087]: explore if this selection can only be added in environments where drafts are enabled
const DRAFTS_SELECTION = {
    kind: 'Object',
    opaque: true,
    name: 'drafts',
    required: false,
};
function isSpanningRecord(fieldValue) {
    return fieldValue !== null && typeof fieldValue === 'object';
}
function createRecordSelection(fieldDefinition) {
    const sel = dynamicSelect$8({
        childRelationships: CHILD_RELATIONSHIP_SELECTION,
        fields: createPathSelection('fields', fieldDefinition),
    });
    return [...sel.selections, DRAFTS_SELECTION];
}
/**
 * Convert a list of fields and optional fields into RecordRepresentation its equivalent
 * selection.
 */
function buildSelectionFromFields(fields, optionalFields = []) {
    return createRecordSelection(convertRecordFieldsArrayToTrie(fields, optionalFields));
}
/**
 * Convert a RecordRepresentationLike into its equivalent selection.
 */
function buildSelectionFromRecord(record) {
    const sel = dynamicSelect$8({
        childRelationships: CHILD_RELATIONSHIP_SELECTION,
        fields: createPathSelectionFromValue(record.fields),
    });
    return [...sel.selections, DRAFTS_SELECTION];
}

const CUSTOM_API_NAME_SUFFIX = '__c';
const DMO_API_NAME_SUFFIX = '__dlm';
const CUSTOM_EXTERNAL_OBJECT_FIELD_SUFFIX = '__x';
const RECORD_REPRESENTATION_ERROR_VERSION = 'RECORD_REPRESENTATION_ERROR_VERSION_1';
const RECORD_REPRESENTATION_ERROR_STORE_METADATA_PARAMS = {
    representationName: '',
    namespace: keyPrefix,
    ttl: TTL$z,
    version: RECORD_REPRESENTATION_ERROR_VERSION,
};
function isGraphNode(node) {
    return !!node && node.type === 'Node';
}
function addScalarFieldId(current) {
    addScalarField(current, 'Id');
}
function addScalarFieldName(current) {
    addScalarField(current, 'Name');
}
function addScalarField(current, leafNodeFieldKey) {
    if (current.children[leafNodeFieldKey] === undefined) {
        current.children[leafNodeFieldKey] = {
            name: leafNodeFieldKey,
            children: {},
        };
    }
}
function extractTrackedFieldsToTrie(recordId, node, root, config, visitedRecordIds = {}, depth = 0) {
    // Filter Error and null nodes
    if (!isGraphNode(node)) {
        return;
    }
    // Stop the traversal if the key has already been visited, since the fields for this record
    // have already been gathered at this point.
    if (hasOwnProperty.call(visitedRecordIds, recordId)) {
        return;
    }
    // The visitedRecordIds object passed to the spanning record is a copy of the original
    // visitedRecordIds + the current record id, since we want to detect circular references within
    // a given path.
    let spanningVisitedRecordIds = {
        ...visitedRecordIds,
        [recordId]: true,
    };
    const fields = node.object('fields');
    const keys$1 = fields.keys();
    let current = root;
    for (let i = 0, len = keys$1.length; i < len; i += 1) {
        const key = keys$1[i];
        const fieldValueRep = fields.link(key);
        let next = current.children[key];
        if (next === undefined) {
            next = {
                name: key,
                children: {},
            };
            if (fieldValueRep.isMissing()) {
                current.children[key] = next;
                continue;
            }
            const field = fieldValueRep.follow();
            // Filter Error and null nodes
            if (!isGraphNode(field)) {
                continue;
            }
            const { maxDepth, onlyFetchLeafNodeIdAndName } = config;
            if (field.isScalar('value') === false) {
                if (depth + 1 > maxDepth) {
                    if (onlyFetchLeafNodeIdAndName === true) {
                        addScalarFieldId(current);
                        addScalarFieldName(current);
                    }
                    continue;
                }
                const spanningLink = field.link('value');
                const spanning = spanningLink.follow();
                // W-8058425, do not include external lookups added by getTrackedFields
                if (isExternalLookupFieldKey(spanning)) {
                    // NOTE: the logic to get here is mimicked in RecordRepresentation/merge::mergePendingFields as of
                    // W-11899329 due to issues with external lookups being marked pending but never fetched
                    continue;
                }
                extractTrackedFieldsToTrie(spanningLink.data.__ref, spanning, next, config, spanningVisitedRecordIds, depth + 1);
                // For a spanning record that is detected to be a circular reference, we add the field along with Id and Name.
                // It's possible for spanning record lookup fields to sometimes be circular, and sometimes not - depending on the value of the lookup field.
                // For more information on scenarios that caused this fix: search "LDS Recursive Spanning Fields Problem" in Quip
                if (keys(next.children).length === 0) {
                    addScalarFieldId(next);
                    addScalarFieldName(next);
                }
                current.children[key] = next;
            }
            else {
                // Skip the field, if its value is null at the max level depth.
                // Ideally, it should only skip relationship field. However,
                // on the client, there is not a reliable way to determine the
                // the field type.
                if (depth === maxDepth) {
                    if (onlyFetchLeafNodeIdAndName === true) {
                        addScalarFieldId(current);
                        addScalarFieldName(current);
                        continue;
                    }
                    if (field.scalar('value') === null) {
                        continue;
                    }
                }
                const state = fieldValueRep.linkData();
                if (state !== undefined) {
                    const { fields } = state;
                    // W-8058425, do not include external lookups added by getTrackedFields
                    if (includes.call(fields, 'ExternalId')) {
                        // NOTE: the logic to get here is mimicked in RecordRepresentation/merge::mergePendingFields as of
                        // W-11899329 due to issues with external lookups being marked pending but never fetched
                        continue;
                    }
                    for (let s = 0, len = fields.length; s < len; s += 1) {
                        const childFieldName = fields[s];
                        next.children[childFieldName] = {
                            name: childFieldName,
                            children: {},
                        };
                    }
                }
            }
            current.children[key] = next;
        }
    }
}
function isExternalLookupFieldKey(spanningNode) {
    // The only way to know if a record is an external lookup is to look into its fields
    // list and find an "ExternalId" field.
    // Filter Error and null nodes
    if (!isGraphNode(spanningNode) || !spanningNode.isScalar('apiName')) {
        return false;
    }
    return endsWith.call(spanningNode.scalar('apiName'), CUSTOM_EXTERNAL_OBJECT_FIELD_SUFFIX);
}
function convertTrieToFields(root) {
    if (keys(root.children).length === 0) {
        return [];
    }
    return convertTrieToFieldsRecursively(root);
}
function convertTrieToFieldsRecursively(root) {
    const childKeys = keys(root.children);
    if (childKeys.length === 0) {
        if (root.name === '') {
            return [];
        }
        return [root.name];
    }
    return reduce.call(childKeys, (acc, cur) => concat.call(acc, convertTrieToFieldsRecursively(root.children[cur]).map((i) => `${root.name}.${i}`)), []);
}
const BLANK_RECORD_FIELDS_TRIE = freeze({
    name: '',
    children: {},
});
const convertFieldsToTrie = (fields = [], isOptional = false, objectName // This should be a required field.
) => {
    if (fields.length === 0) {
        return BLANK_RECORD_FIELDS_TRIE;
    }
    const name = objectName || getObjectNameFromField(fields[0]); // Pulling object name from first field is not a safe or correct operation
    const fieldsTrie = {
        name,
        children: {},
        optional: isOptional,
    };
    const filteredFields = fields.filter((field) => objectName !== undefined && isOptional ? field.startsWith(`${objectName}.`) : true);
    insertFieldsIntoTrie(fieldsTrie, filteredFields, isOptional);
    return fieldsTrie;
};
const getObjectNameFromField = (field) => {
    const fieldApiName = getFieldApiName(field);
    if (fieldApiName === undefined) {
        return '';
    }
    return splitQualifiedFieldApiName(fieldApiName)[0];
};
// merge all nodes in Trie B into Trie A
function mergeFieldsTries(rootA, rootB) {
    const rootAchildren = rootA.children;
    const rootBchildren = rootB.children;
    const childBKeys = keys(rootBchildren);
    for (let i = 0, len = childBKeys.length; i < len; i++) {
        const childBKey = childBKeys[i];
        if (rootAchildren[childBKey] === undefined) {
            rootAchildren[childBKey] = rootBchildren[childBKey];
        }
        else {
            mergeFieldsTries(rootAchildren[childBKey], rootBchildren[childBKey]);
        }
    }
}
function getTrackedFields(key, graphNode, config, fieldsFromConfig) {
    const fieldsList = fieldsFromConfig === undefined ? [] : [...fieldsFromConfig];
    if (!isGraphNode(graphNode)) {
        return fieldsList;
    }
    const name = graphNode.scalar('apiName');
    const root = {
        name,
        children: {},
    };
    extractTrackedFieldsToTrie(key, graphNode, root, config);
    const rootFromConfig = {
        name,
        children: {},
    };
    insertFieldsIntoTrie(rootFromConfig, fieldsList);
    mergeFieldsTries(root, rootFromConfig);
    return convertTrieToFields(root).sort();
}
function getRecordTypeId$2(record) {
    return record.recordTypeId === null ? MAIN_RECORD_TYPE_ID : record.recordTypeId;
}
// This function traverses through a record and marks missing
// optional fields as "missing"
function markMissingOptionalFields(record, optionalFields) {
    if (!isGraphNode(record)) {
        return;
    }
    const apiName = record.scalar('apiName');
    for (let a = 0, aLen = optionalFields.length; a < aLen; a++) {
        const parts = optionalFields[a].split('.');
        if (parts[0] === apiName) {
            _markMissingPath(record, parts.slice(1));
        }
    }
}
function markNulledOutPath(record, path) {
    if (!isGraphNode(record)) {
        return;
    }
    const fieldValueRepresentation = record.object('fields');
    const fieldName = path.shift();
    if (fieldValueRepresentation.isUndefined(fieldName)) {
        return;
    }
    const link = fieldValueRepresentation.link(fieldName);
    const resolved = link.follow();
    if (isGraphNode(resolved) &&
        resolved.isScalar('value') &&
        path.length > 0 && // TODO [W-14082782]: temporary fix
        !isFrozen(link.data)) {
        const linkState = link.linkData();
        const fields = linkState === undefined ? [] : linkState.fields;
        link.writeLinkData({
            fields: dedupe([...fields, path.join('.')]),
        });
    }
}
function markNulledOutRequiredFields(record, fields) {
    if (!isGraphNode(record)) {
        return;
    }
    const apiName = record.scalar('apiName');
    for (let a = 0, aLen = fields.length; a < aLen; a++) {
        const parts = fields[a].split('.');
        if (parts[0] === apiName) {
            markNulledOutPath(record, parts.slice(1));
        }
    }
}
function _markMissingPath(record, path) {
    // Filter out Error and null nodes
    if (!isGraphNode(record)) {
        return;
    }
    const fieldValueRepresentation = record.object('fields');
    const fieldName = path.shift();
    if (fieldValueRepresentation.isUndefined(fieldName) === true) {
        writeMissingFieldToStore(fieldValueRepresentation, fieldName);
        return;
    }
    const link = fieldValueRepresentation.link(fieldName);
    if (link.isPending()) {
        writeMissingFieldToStore(fieldValueRepresentation, fieldName);
    }
    else if (path.length > 0 && link.isMissing() === false) {
        const fieldValue = link.follow();
        // Filter out Error and null nodes
        if (!isGraphNode(fieldValue)) {
            return;
        }
        // if value is not a scalar, follow the link and mark it as missing
        if (fieldValue.isScalar('value') === false) {
            _markMissingPath(fieldValue
                .link('value')
                .follow(), path);
        }
    }
}
/**
 * Graph Node Directly modifies store entries, which is generally a non-starter.
 * Until we can refactor this mess, you need to use this function to safely mark the RecordRepresentation
 * as a seenId in the store when you perform this mutation.
 */
function writeMissingFieldToStore(field, fieldName) {
    // TODO [W-6900046]: remove cast, make RecordRepresentationNormalized['fields'] accept
    // an undefined/non-present __ref if isMissing is present
    field.write(fieldName, {
        __ref: undefined,
        isMissing: true,
    });
}
/**
 * Tells you if an objectApiName is supported by UI API or not.
 * Note: Luvio does not currently support all the entities, the list is limited to UI API supported entities
 * @param objectApiName the object API name from a record.
 * @return True if the provided objectApiName is supported in UI API.
 */
function isSupportedEntity(objectApiName) {
    return ((UIAPI_SUPPORTED_ENTITY_API_NAMES.has(objectApiName) ||
        endsWith.call(objectApiName, CUSTOM_API_NAME_SUFFIX) ||
        endsWith.call(objectApiName, DMO_API_NAME_SUFFIX)) &&
        !UIAPI_DENIED_ENTITY_API_NAMES.has(objectApiName));
}
/** Return true if a >= b */
function isSuperset(a, b) {
    if (b.length > a.length) {
        return false;
    }
    const aMap = {};
    // Put all keys from subset into a map
    // so we don't have to use subset.includes which will be slow
    for (let i = 0, len = a.length; i < len; i += 1) {
        aMap[a[i]] = true;
    }
    for (let i = 0, len = b.length; i < len; i += 1) {
        if (aMap[b[i]] === undefined) {
            return false;
        }
    }
    return true;
}
/** return true if a and b start with the same root name and a contains all nodes in b */
function isSuperRecordFieldTrie(a, b) {
    if (a.name !== b.name) {
        return false;
    }
    const childrenA = a.children;
    const childrenB = b.children;
    const childKeysA = keys(childrenA);
    const childKeysB = keys(childrenB);
    const childKeysBLength = childKeysB.length;
    if (childKeysBLength > childKeysA.length) {
        return false;
    }
    let ret = true;
    for (let i = 0; i < childKeysBLength; i++) {
        const childBKey = childKeysB[i];
        const childA = childrenA[childBKey];
        if (childA === undefined) {
            return false;
        }
        ret = ret && isSuperRecordFieldTrie(childA, childrenB[childBKey]);
    }
    return ret;
}
function ingestRecordResponse(luvio, response, recordId, recordIngest, conflictMap) {
    const { body } = response;
    const sel = buildSelectionFromRecord(body);
    const key = keyBuilder$29(luvio, {
        recordId,
    });
    luvio.storeIngest(key, recordIngest, body);
    resolveConflict(luvio, conflictMap);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: {
            kind: 'Fragment',
            private: [],
            selections: sel,
            version: VERSION$1g,
        },
        variables: {},
    });
    return snapshot;
}

// This function sets fields that we are refreshing to pending
// These values will go into the store
function mergePendingFields(newRecord, oldRecord, existingNode) {
    const mergedFields = { ...newRecord.fields };
    const merged = { ...newRecord, fields: mergedFields };
    const existingFields = keys(oldRecord.fields);
    for (let i = 0, len = existingFields.length; i < len; i += 1) {
        const spanningFieldName = existingFields[i];
        if (newRecord.fields[spanningFieldName] === undefined) {
            /*
             * Per W-8058425 external lookups fields are excluded from the tracked fields. However, as covered in
             * W-11899329, situations can arise in which a merge conflict occurs when the existing record has a
             * reference to an external lookup field.  The exclusion ultimately results in a snapshot stuck in the
             * pending state. This is an approach to prevent that situation.
             *
             * The same logic checks for W-8058425 to "continue" as it relates to not tracking external lookups is
             * mimicked here as it relates to not marking them as pending.
             */
            // make sure external lookups are NOT marked as pending when `existingNode` is provided
            if (isGraphNode(existingNode)) {
                // get the node for the spanning field
                const fieldValueRep = existingNode
                    .object('fields')
                    .link(spanningFieldName);
                const field = fieldValueRep.follow();
                if (isGraphNode(field)) {
                    if (field.isScalar('value') === false) {
                        const record = field
                            .link('value')
                            .follow();
                        if (isExternalLookupFieldKey(record)) {
                            continue;
                        }
                    }
                }
                // If the fields requested off of this spanning record are external fields, skip them to avoid creating request that exceed the SOQL limits on external data. https://developer.salesforce.com/docs/atlas.en-us.soql_sosl.meta/soql_sosl/sforce_api_calls_soql_limits.htm
                const state = fieldValueRep.linkData();
                if (state !== undefined) {
                    const { fields } = state;
                    if (includes.call(fields, 'ExternalId')) {
                        continue;
                    }
                }
            }
            // TODO [W-6900046]: fix above casting issue so we're not stuffing arbitrary things
            // into RecordRepresentationNormalized['fields']
            mergedFields[spanningFieldName] = {
                __ref: undefined,
                pending: true,
            };
        }
    }
    return merged;
}
// This method gets called
// when incoming record has a higher version
// than the record that is currently in the store
function mergeAndRefreshHigherVersionRecord(incoming, existing, incomingTrackedFieldsTrieRoot, existingTrackedFieldsTrieRoot, recordConflictMap, existingNode) {
    // If the higher version (incoming) does not contain a superset of fields as existing
    // then we need to refresh to get updated versions of fields in existing
    if (isSuperRecordFieldTrie(incomingTrackedFieldsTrieRoot, existingTrackedFieldsTrieRoot) ===
        false) {
        // If this is an unsupported entity, do NOT attempt to go to the network
        // Simply merge what we have and move on
        if (isSupportedEntity(incoming.apiName) === false) {
            return mergeRecordFields(incoming, existing);
        }
        // update the conflict map to resolve the record conflict in resolveConflict
        recordConflictMap.conflicts[incoming.id] = {
            recordId: incoming.id,
            trackedFields: existingTrackedFieldsTrieRoot,
        };
        // We want to mark fields in the store as pending
        // Because we don't want to emit any data to components
        return mergePendingFields(incoming, existing, existingNode);
    }
    return incoming;
}
// This method gets called
// when incoming record has a lower version
// than the record that is currently in the store
function mergeAndRefreshLowerVersionRecord(luvio, incoming, existing, incomingTrackedFieldsTrieRoot, existingTrackedFieldsTrieRoot, recordConflictMap, existingNode) {
    // If the higher version (existing) does not have a superset of fields as incoming
    // then we need to refresh to get updated versions of fields on incoming
    if (isSuperRecordFieldTrie(existingTrackedFieldsTrieRoot, incomingTrackedFieldsTrieRoot) ===
        false) {
        // If this is an unsupported entity, do NOT attempt to go to the network
        // Simply merge what we have and move on
        if (isSupportedEntity(incoming.apiName) === false) {
            return mergeRecordFields(existing, incoming);
        }
        const merged = mergePendingFields(existing, incoming, existingNode);
        // update the conflict map to resolve the record conflict in resolveConflict
        if (recordConflictMap) {
            recordConflictMap.conflicts[incoming.id] = {
                recordId: incoming.id,
                trackedFields: incomingTrackedFieldsTrieRoot,
            };
        }
        else {
            buildNetworkSnapshot$16(luvio, {
                recordId: incoming.id,
                optionalFields: convertTrieToFields(incomingTrackedFieldsTrieRoot),
            });
        }
        return merged;
    }
    return existing;
}
function mergeRecordConflict(luvio, incoming, existing, recordConflictMap) {
    const recordKey = keyBuilder$29(luvio, {
        recordId: incoming.id,
    });
    const incomingNode = luvio.wrapNormalizedGraphNode(incoming, recordKey);
    const existingNode = luvio.wrapNormalizedGraphNode(existing, recordKey);
    const incomingTrackedFieldsTrieRoot = {
        name: incoming.apiName,
        children: {},
    };
    const existingTrackedFieldsTrieRoot = {
        name: existing.apiName,
        children: {},
    };
    const trackedFieldsConfig = {
        maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMergeConflict(),
        onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
    };
    extractTrackedFieldsToTrie(recordKey, incomingNode, incomingTrackedFieldsTrieRoot, trackedFieldsConfig);
    extractTrackedFieldsToTrie(recordKey, existingNode, existingTrackedFieldsTrieRoot, trackedFieldsConfig);
    if (incoming.weakEtag > existing.weakEtag) {
        return mergeAndRefreshHigherVersionRecord(incoming, existing, incomingTrackedFieldsTrieRoot, existingTrackedFieldsTrieRoot, recordConflictMap, existingNode);
    }
    return mergeAndRefreshLowerVersionRecord(luvio, incoming, existing, incomingTrackedFieldsTrieRoot, existingTrackedFieldsTrieRoot, recordConflictMap);
}
function getNotNull(recordAValue, recordBValue) {
    return recordAValue === null ? recordBValue : recordAValue;
}
function mergeRecordFields(recordA, recordB) {
    const lastModifiedDate = getNotNull(recordA.lastModifiedDate, recordB.lastModifiedDate);
    const lastModifiedById = getNotNull(recordA.lastModifiedById, recordB.lastModifiedById);
    const systemModstamp = getNotNull(recordA.systemModstamp, recordB.systemModstamp);
    return {
        ...recordA,
        fields: {
            ...recordB.fields,
            ...recordA.fields,
        },
        lastModifiedDate,
        lastModifiedById,
        systemModstamp,
    };
}
function isErrorEntry(entry) {
    return entry.__type === 'error';
}
function merge$3(existing, incoming, luvio, _path, recordConflictMap) {
    if (existing === undefined || isErrorEntry(existing)) {
        return incoming;
    }
    // recordTypeId may get changed based on record state.
    // Evicts all dependencies from store.
    if (incoming.recordTypeId !== existing.recordTypeId) {
        if (incoming.recordTypeId === null ||
            incoming.recordTypeId === undefined ||
            existing.recordTypeId === null ||
            existing.recordTypeId === undefined) {
            instrumentation.recordTypeIdIsNull(incoming.apiName);
        }
        const recordDepKey = dependencyKeyBuilder({ recordId: existing.id });
        const node = luvio.getNode(recordDepKey);
        if (isGraphNode(node)) {
            const dependencies = node.retrieve();
            if (dependencies !== null) {
                const depKeys = keys(dependencies);
                for (let i = 0, len = depKeys.length; i < len; i++) {
                    luvio.storeEvict(depKeys[i]);
                }
            }
        }
    }
    // eslint-disable-next-line @salesforce/lds/no-invalid-todo
    // TODO - handle merging of records that change apiName
    // if (existing.apiName !== incoming.apiName) {
    //     if (process.env.NODE_ENV === 'production') {
    //         lds.log(`API Name changed from ${existing.apiName} to ${incoming.apiName}`);
    //     } else {
    //         throw new Error('API Name cannot be different for merging records.');
    //     }
    // }
    // Adding instrumentation to see how frequently this occurs
    if (existing.apiName !== incoming.apiName) {
        instrumentation.recordApiNameChanged(incoming.apiName, existing.apiName);
    }
    const incomingWeakEtagZero = incoming.weakEtag === 0;
    const existingWeakEtagZero = existing.weakEtag === 0;
    if (incomingWeakEtagZero || existingWeakEtagZero) {
        instrumentation.weakEtagZero(incomingWeakEtagZero, existingWeakEtagZero, incoming.apiName);
    }
    // TODO [W-6900085]: UIAPI returns weakEtag=0 when the record is >2 levels nested. For now
    // we treat the record as mergeable.
    if (!incomingWeakEtagZero && !existingWeakEtagZero && incoming.weakEtag !== existing.weakEtag) {
        return mergeRecordConflict(luvio, incoming, existing, recordConflictMap);
    }
    return mergeRecordFields(incoming, existing);
}
function dependencyKeyBuilder(config) {
    return `UiApi::RecordRepresentationDependency:${config.recordId}`;
}

function merge$2(existing, incoming, _luvio, path) {
    if (existing === undefined) {
        return incoming;
    }
    fixDisplayValue(existing, incoming, path);
    const { value } = incoming;
    if (value === null || value.__ref === undefined) {
        // Parent will never be null this field only exists in the context of a RecordRep.
        const parent = path.parent;
        // It may happen that a parent.exists is null, this is the case when the same field is
        // ingested multiple times in the same ingestion cycle. For example: when the same record
        // is present multiple time in the ingested payload.
        if (parent.existing === undefined) {
            return incoming;
        }
        const existingVersion = parent.existing.weakEtag;
        const incomingVersion = parent.data.weakEtag;
        if (existingVersion > incomingVersion) {
            return existing;
        }
    }
    return incoming;
}
function fixDisplayValue(existing, incoming, path) {
    // Temporary fix for the issue that non-null displayValue gets replaced by null in mistake. (W-8904195)
    // If displayValue and value are both null, it means the field is empty.
    //
    // Couple sources may emit incorrect null displayValue to LDS:
    //   1. ADS may receive records with incorrect null displayValue from RecordGvp and emit to LDS.
    //      This case may affect certain types of fields:
    //      a. Spanning record field.
    //      b. Formattable fields, such as date, currency.
    //   2. AggregateUi endpoint. For some fields, displayValue only gets populated when certain combination
    //      of fields are requested. Currently, LDS handles large record requests with aggregateUi endpoint.
    //      On the network layer, record fields get split into separate chunks. Potentially, when certain
    //      combination of fields gets split into separate chunks, it would result in displayValue getting set
    //      to null.
    //   3. Any resource that returns nested Records, like list-records and list-ui, potentially exhibits this behavior
    //
    // There might be more cases masked by this workaround. We need to be careful when removing this code.
    // It would be required to have some telemetries in prod to verify if any code hits this workaround.
    const incomingValue = incoming.value;
    if (existing.displayValue !== null &&
        incoming.displayValue === null &&
        incomingValue !== null) {
        incoming.displayValue = existing.displayValue;
        const isSpanningRecord = typeof incomingValue === 'object';
        instrumentation.nullDisplayValueConflict({
            entityName: path.parent.data.apiName,
            fieldName: path.propertyName,
            fieldType: isSpanningRecord ? 'spanning-record' : 'scalar',
            areValuesEqual: isSpanningRecord ? undefined : incomingValue === existing.value,
        });
    }
}

function normalize$O(input, existing, path, luvio, store, timestamp, fieldsTrie, optionalFieldsTrie, recordConflictMap) {
    const input_value = input.value;
    const input_value_id = path.fullPath + '__value';
    if (input_value !== null && typeof input_value === 'object') {
        const ingest = createRecordIngest(fieldsTrie, optionalFieldsTrie, recordConflictMap);
        input.value = ingest(input_value, {
            fullPath: input_value_id,
            propertyName: 'value',
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
        }, luvio, store, timestamp);
    }
    return input;
}

function makeIngest(fieldsTrie, optionalFieldsTrie, recordConflictMap) {
    return (input, path, luvio, store, timestamp) => {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$1Y(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        const key = path.fullPath;
        let existingRecord = store.readEntry(key);
        let incomingRecord = normalize$O(input, store.readEntry(key), {
            fullPath: key,
            parent: path.parent,
            propertyName: path.propertyName,
        }, luvio, store, timestamp, fieldsTrie, optionalFieldsTrie, recordConflictMap);
        // read again after children ingested in case of a circular ref
        existingRecord = store.readEntry(key);
        incomingRecord = merge$2(existingRecord, incomingRecord, luvio, path);
        if (existingRecord === undefined || equals$17(existingRecord, incomingRecord) === false) {
            luvio.storePublish(key, incomingRecord);
        }
        return createLink(key);
    };
}

/**
 * Adds fields listed in the two trie parameters into the store link.
 * Functionally analogous to markNulledOutRequiredFields.
 * @param fieldsTrie
 * @param optionalFieldsTrie
 * @param storeLink
 */
function addFieldsToStoreLink(fieldsTrie, optionalFieldsTrie, storeLink) {
    let fields = [];
    const fieldSubtries = [];
    if (fieldsTrie) {
        push.call(fieldSubtries, fieldsTrie);
    }
    if (optionalFieldsTrie) {
        push.call(fieldSubtries, optionalFieldsTrie);
    }
    for (let i = 0; i < fieldSubtries.length; i++) {
        const subtrie = fieldSubtries[i];
        const fieldNames = keys(subtrie.children);
        for (let i = 0; i < fieldNames.length; i++) {
            const fieldName = fieldNames[i];
            const childTrie = subtrie.children[fieldName];
            if (childTrie) {
                fields = [...fields, ...convertTrieToFieldsRecursively(childTrie)];
            }
        }
    }
    fields = dedupe(fields);
    if (fields.length > 0) {
        storeLink.data = {
            fields,
        };
    }
}

function getChildRecordFieldTrie(parent, key) {
    const value = parent.children[key];
    if (value === undefined) {
        return BLANK_RECORD_FIELDS_TRIE;
    }
    return value;
}
function createFieldsIngestion(fieldsTrie, optionalFieldsTrie, recordConflictMap) {
    return (data, path, luvio, store, timestamp) => {
        if (process.env.NODE_ENV !== 'production') {
            if (typeof path.propertyName !== 'string') {
                throw new Error('FieldValueRepresentation should always have a string propertyName value');
            }
        }
        const key = path.propertyName;
        const fieldsSubtrie = getChildRecordFieldTrie(fieldsTrie, key);
        const optionalFieldsSubtrie = getChildRecordFieldTrie(optionalFieldsTrie, key);
        const fieldValueLink = makeIngest(fieldsSubtrie, optionalFieldsSubtrie, recordConflictMap)(data, path, luvio, store, timestamp);
        // If a relationship field is null, memorize names of subordinate fields.
        // Spannning fields are specified in the dot notation.
        if (data.value === null) {
            addFieldsToStoreLink(fieldsSubtrie, optionalFieldsSubtrie, fieldValueLink);
        }
        return fieldValueLink;
    };
}
function createChildRecordNormalize(fieldsTrie, optionalFieldsTrie, recordConflictMap) {
    return dynamicNormalize$5({
        childRelationships: ingest$P,
        fields: createFieldsIngestion(fieldsTrie, optionalFieldsTrie, recordConflictMap),
    });
}
const createRecordIngest = (fieldsTrie, optionalFieldsTrie, recordConflictMap) => {
    const childNormalize = createChildRecordNormalize(fieldsTrie, optionalFieldsTrie, recordConflictMap);
    return (input, path, luvio, store, timestamp) => {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$1W(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        input.eTag = ''; //[W-13724550] Record Reps ALWAYS have '' etag, to be consistent with GraphQL, as it is not queryable via GraphQL.
        const key = keyBuilderFromType$E(luvio, input);
        let existingRecord = store.readEntry(key);
        const recordPath = {
            fullPath: key,
            parent: path.parent,
            propertyName: path.propertyName,
        };
        let incomingRecord = childNormalize(input, existingRecord, recordPath, luvio, store, timestamp);
        // read from the store again since it might have been ingested as a nested child ref
        existingRecord = store.readEntry(key);
        incomingRecord = merge$3(existingRecord, incomingRecord, luvio, path, recordConflictMap);
        if (existingRecord === undefined ||
            equals$15(existingRecord, incomingRecord) === false ||
            // always publish if existing record has drafts
            existingRecord.drafts !==
                undefined) {
            luvio.storePublish(key, incomingRecord);
        }
        luvio.publishStoreMetadata(key, {
            ttl: TTL$z,
            representationName: RepresentationType$V,
            namespace: keyPrefix,
            version: VERSION$1g,
            ingestionTimestamp: timestamp,
        });
        return createLink(key);
    };
};

function createFieldsIngestSuccess$3(params) {
    const { fields, optionalFields, trackedFields, serverRequestCount = 1 } = params;
    const recordConflictMap = {
        conflicts: {},
        serverRequestCount,
    };
    const ingest = createRecordIngest(fields, optionalFields, recordConflictMap);
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        resolveConflict(luvio, recordConflictMap);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}

function fulfill(existing, incoming) {
    // early out if incoming isn't a request only for fields and optionalFields
    const { queryParams, headers, basePath, baseUri, urlParams } = incoming;
    const { basePath: existingBasePath, baseUri: existingBaseUri, headers: existingHeaders, urlParams: existingUrlParams, } = existing;
    const path = `${baseUri}${basePath}`;
    const existingPath = `${existingBaseUri}${existingBasePath}`;
    if (queryParams.layoutTypes !== undefined) {
        return false;
    }
    if (existingPath !== path) {
        // W-11964675 - Correlate an incoming single record request to an existing batch record
        // request requesting the same single record
        const incomingUrlRecords = getRecordIdsFromUrlParams(urlParams);
        const existingUrlRecords = getRecordIdsFromUrlParams(existingUrlParams);
        const batchRequestWithSingleRequest = isSingleBatchRecordRequest(existingUrlParams) &&
            isSingleRecordRequest(urlParams) &&
            incomingUrlRecords[0] === existingUrlRecords[0];
        if (!batchRequestWithSingleRequest || isRestrictedPathCondition(existingPath, path)) {
            return false;
        }
    }
    const headersKeys = keys(headers);
    const headersKeyLength = headersKeys.length;
    if (headersKeyLength !== keys(existingHeaders).length) {
        return false;
    }
    for (let i = 0, len = headersKeyLength; i < len; i++) {
        let key = headersKeys[i];
        if (headers[key] !== existingHeaders[key]) {
            return false;
        }
    }
    // TODO [W-6900100]: handle when incoming.fields are only in existing.optionalFields, and
    // existing's response doesn't include those fields. We need to detect this then
    // re-issue the request to get the relevant error response.
    const existingFieldsUnion = unionFields(existing.queryParams.fields, existing.queryParams.optionalFields);
    const incomingFieldsUnion = unionFields(queryParams.fields, queryParams.optionalFields);
    return isSuperset(existingFieldsUnion, incomingFieldsUnion);
}
function unionFields(fields, optionalFields) {
    const fieldsArray = isArray(fields) ? fields : [];
    const optionalFieldsArray = isArray(optionalFields) ? optionalFields : [];
    return [...fieldsArray, ...optionalFieldsArray];
}
function getRecordIdsFromUrlParams(urlParams) {
    if (hasOwnProperty.call(urlParams, 'recordId')) {
        return [urlParams.recordId];
    }
    else if (hasOwnProperty.call(urlParams, 'recordIds')) {
        return urlParams.recordIds;
    }
    return [];
}
function isSingleBatchRecordRequest(urlParams) {
    return (hasOwnProperty.call(urlParams, 'recordIds') &&
        urlParams.recordIds.length === 1);
}
function isSingleRecordRequest(urlParams) {
    return hasOwnProperty.call(urlParams, 'recordId');
}
function isRestrictedPathCondition(existingPath, path) {
    // should not dedupe getRecordUi and getRecord as both of their representation is different
    // records call cannot digest response of getRecordUi
    return ((existingPath.includes('/record-ui') && path.includes('/records')) ||
        (existingPath.includes('/records') && path.includes('/record-ui')));
}

const createResourceRequest$1d = function getUiApiRecordsByRecordIdCreateResourceRequest(config) {
    return {
        ...createResourceRequest$1c(config),
        fulfill: fulfill,
    };
};

function keyBuilder$28(luvio, params) {
    return keyBuilder$29(luvio, {
        recordId: params.urlParams.recordId
    });
}
function getResponseCacheKeys$12(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$X(storeKeyMap, luvio, response);
}
function createResourceRequest$1c(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/' + config.urlParams.recordId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$11 = 'getRecord';
const oneOfConfigPropertiesIdentifier$1 = [
    'layoutTypes',
    'fields',
    'optionalFields'
];
const getRecord_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('childRelationships', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('forms', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('layoutTypes', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArrayTitleCase),
    generateParamConfigMetadata('modes', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('updateMru', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
const createResourceParams$12 = /*#__PURE__*/ createResourceParams$13(getRecord_ConfigPropertyMetadata);
function typeCheckConfig$16(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecord_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$18(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames, oneOfConfigPropertiesIdentifier$1);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecord_ConfigPropertyMetadata);
    const config = typeCheckConfig$16(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    if (config.layoutTypes === undefined &&
        config.fields === undefined &&
        config.optionalFields === undefined) {
        return null;
    }
    return config;
}

// used by getUiApiRecordsBatchByRecordIds#selectChildResourceParams
function buildRecordSelector(luvio, recordId, fields, optionalFields) {
    return {
        recordId: keyBuilder$29(luvio, { recordId }),
        node: {
            kind: 'Fragment',
            private: ['eTag', 'weakEtag'],
            selections: buildSelectionFromFields(fields, optionalFields),
            version: VERSION$1g,
        },
        variables: {},
    };
}
function buildSnapshotRefresh$5(luvio, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot$16(luvio, config),
    };
}
function prepareRequest$7(luvio, config) {
    const { recordId, fields } = config;
    // Should this go into the coersion logic?
    const key = keyBuilder$28(luvio, createResourceParams$12(config));
    const allTrackedFields = getTrackedFields(key, luvio.getNode(key), {
        maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMiss(),
        onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
    }, config.optionalFields);
    const optionalFields = fields === undefined ? allTrackedFields : difference(allTrackedFields, fields);
    const resourceParams = createResourceParams$12({
        recordId,
        fields,
        optionalFields: optionalFields.length > 0 ? optionalFields : undefined,
    });
    const request = createResourceRequest$1d(resourceParams);
    return { request, key, allTrackedFields, resourceParams };
}
function ingestSuccess$S(luvio, config, key, allTrackedFields, response, serverRequestCount) {
    const { body } = response;
    const fields = config.fields === undefined ? [] : config.fields;
    const optionalFields = config.optionalFields === undefined ? [] : config.optionalFields;
    const fieldTrie = convertFieldsToTrie(fields, false);
    luvio.storeIngest(key, createFieldsIngestSuccess$3({
        fields: fieldTrie,
        optionalFields: convertFieldsToTrie(optionalFields, true),
        trackedFields: convertFieldsToTrie(allTrackedFields, true),
        serverRequestCount,
    }), body);
    return luvio.storeLookup(buildRecordSelector(luvio, config.recordId, fields, optionalFields), buildSnapshotRefresh$5(luvio, config));
}
function onResourceSuccess(luvio, config, key, allTrackedFields, response, serverRequestCount) {
    const snapshot = ingestSuccess$S(luvio, config, key, allTrackedFields, response, serverRequestCount);
    return luvio.storeBroadcast().then(() => snapshot);
}
function ingestError$M(luvio, config, key, err) {
    const errorSnapshot = luvio.errorSnapshot(err, buildSnapshotRefresh$5(luvio, config));
    luvio.storeIngestError(key, errorSnapshot, RECORD_REPRESENTATION_ERROR_STORE_METADATA_PARAMS);
    return errorSnapshot;
}
function onResourceError(luvio, config, key, err) {
    const errorSnapshot = ingestError$M(luvio, config, key, err);
    return luvio.storeBroadcast().then(() => errorSnapshot);
}
function buildNetworkSnapshot$16(luvio, config, serverRequestCount = 0, options) {
    const { request, key, allTrackedFields, resourceParams } = prepareRequest$7(luvio, config);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        // W-11964675 - Condition to dedupe a very specific set of requests for
        // Komaci - a batch record request with a single record followed by a single
        // record request. The fulfill logic sends the same network response, so
        // there is some TypeScript massaging to extract the RecordRepresentation
        //
        // W-14381091 - Ensure hoisting the response body happens prior to
        // calling `luvio.handleSuccessResponse`, since both arguments capture
        // the response.
        if (isSingleBatchRecordResponse(response.body)) {
            response.body = response.body.results[0]
                .result;
        }
        return luvio.handleSuccessResponse(() => {
            return onResourceSuccess(luvio, config, key, allTrackedFields, response, serverRequestCount + 1);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$12(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return onResourceError(luvio, config, key, err);
        });
    });
}
// used by getRecordLayoutType#refresh
function buildCachedSnapshot$9(luvio, config, refresh) {
    const fields = config.fields === undefined ? [] : config.fields;
    const optionalFields = config.optionalFields === undefined ? [] : config.optionalFields;
    const sel = buildRecordSelector(luvio, config.recordId, fields, optionalFields);
    return luvio.storeLookup(sel, refresh ? refresh : buildSnapshotRefresh$5(luvio, config));
}
function buildCachedSnapshotCachePolicy$Q(context, storeLookup) {
    const { config, luvio } = context;
    const fields = config.fields === undefined ? [] : config.fields;
    const optionalFields = config.optionalFields === undefined ? [] : config.optionalFields;
    const sel = buildRecordSelector(luvio, config.recordId, fields, optionalFields);
    return storeLookup(sel, buildSnapshotRefresh$5(luvio, config));
}
function buildNetworkSnapshotCachePolicy$R(context, coercedAdapterRequestContext) {
    const { config, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$16(luvio, config, 0, dispatchOptions);
}
function getRecordByFields(luvio, config, requestContext) {
    return luvio.applyCachePolicy(requestContext || {}, { config, luvio }, buildCachedSnapshotCachePolicy$Q, buildNetworkSnapshotCachePolicy$R);
}
function isSingleBatchRecordResponse(response) {
    return (isArray(response.results) &&
        response.results.length === 1);
}

const VERSION$1f = "98cce53b8d13b1883d001bbdaab24383";

const nonCachedErrors$7 = ObjectCreate$1(null);
function ingestSuccessChildResourceParams$8(luvio, childResourceParamsArray, childEnvelopes, serverRequestCount = 0) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$28(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childTrackedFields = getTrackedFields(childKey, luvio.getNode(childKey), {
                maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMiss(),
                onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
            }, childResourceParams.queryParams.optionalFields);
            const childSnapshot = ingestSuccess$S(luvio, {
                recordId: childResourceParams.urlParams.recordId,
                fields: childResourceParams.queryParams.fields,
                optionalFields: childResourceParams.queryParams.optionalFields,
            }, childKey, childTrackedFields, childResponse, serverRequestCount + 1);
            if (childSnapshot.state === 'Stale') {
                snapshotState = 'Stale';
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: childStatusCode,
                result: childSnapshot.data,
            };
            childSnapshotDataResponses.push(childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(childStatusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse',
            };
            ingestError$M(luvio, {
                recordId: childResourceParams.urlParams.recordId,
                fields: childResourceParams.queryParams.fields,
                optionalFields: childResourceParams.queryParams.optionalFields,
            }, childKey, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            childSnapshotDataResponses.push(childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$7[childKey] = {
                expiration: now + TTL$z,
                response: childBody,
                status: childStatusCode,
            };
        }
        else {
            delete nonCachedErrors$7[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses,
    };
    deepFreeze(childSnapshotData);
    return {
        childSnapshotData,
        seenRecords,
        snapshotState,
    };
}

function selectChildResourceParams$7(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const compositeSnapshot = luvio.storeLookup({
                recordId: keyBuilder$27(luvio, resourceParams),
                node: {
                    kind: 'Fragment',
                    private: [],
                    version: VERSION$1f,
                },
                variables: {},
            });
            if (compositeSnapshot.state === 'Error' &&
                compositeSnapshot.error.errorType === 'fetchResponse' &&
                compositeSnapshot.error.status === 404) {
                return {
                    state: compositeSnapshot.state,
                    value: compositeSnapshot.error,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const timestamp = reader.getTimeStamp();
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$28(luvio, childResource);
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read(buildRecordSelector(luvio, childResource.urlParams.recordId, childResource.queryParams.fields || [], childResource.queryParams.optionalFields || []));
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    // eslint-disable-next-line no-fallthrough
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 
                        // child snapshots will always have FetchResponses
                        childSnapshot.error.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, 
                        // child snapshots will always have FetchResponses
                        childSnapshot.error.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$7[childKey];
                            if (nonCachedError === undefined ||
                                nonCachedError.expiration < timestamp) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            deepFreeze(sink);
            reader.exitPath();
            return sink;
        },
    };
}

ObjectCreate$1(null);
function createChildResourceParams$b(resourceParams) {
    let childConfigs = [];
    for (let index = 0, len = resourceParams.urlParams.recordIds.length; index < len; index += 1) {
        const item = resourceParams.urlParams.recordIds[index];
        childConfigs.push({
            urlParams: {
                recordId: item
            },
            queryParams: {
                fields: resourceParams.queryParams.fields,
                optionalFields: resourceParams.queryParams.optionalFields
            }
        });
    }
    return childConfigs;
}
function keyBuilder$27(luvio, params) {
    return keyPrefix + '::BatchRepresentation:(' + 'childRelationships:' + params.queryParams.childRelationships + ',' + 'fields:' + params.queryParams.fields + ',' + 'layoutTypes:' + params.queryParams.layoutTypes + ',' + 'modes:' + params.queryParams.modes + ',' + 'optionalFields:' + params.queryParams.optionalFields + ',' + 'pageSize:' + params.queryParams.pageSize + ',' + 'updateMru:' + params.queryParams.updateMru + ',' + 'recordIds:' + params.urlParams.recordIds + ')';
}
function getResponseCacheKeys$11(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$b(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$12(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$28(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$V,
                mergeable: false
            });
        }
    }
}
function ingestError$L(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$27(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$1b(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/batch/' + config.urlParams.recordIds + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function createResourceParams$11(config) {
    const { records: configRecords } = config;
    const recordIds = [];
    const resourceConfigFields = [];
    const resourceConfigOptionalFields = [];
    for (let index = 0, len = configRecords.length; index < len; index += 1) {
        const { recordIds: recordIdsFromConfig, fields = [], optionalFields = [], } = configRecords[index];
        ArrayPrototypePush.call(recordIds, ...recordIdsFromConfig);
        if (fields.length > 0) {
            ArrayPrototypePush.call(resourceConfigFields, ...fields);
        }
        if (optionalFields.length > 0) {
            ArrayPrototypePush.call(resourceConfigOptionalFields, ...optionalFields);
        }
    }
    return {
        urlParams: {
            recordIds,
        },
        queryParams: {
            fields: resourceConfigFields.length > 0 ? resourceConfigFields : undefined,
            optionalFields: resourceConfigOptionalFields.length > 0 ? resourceConfigOptionalFields : undefined,
        },
    };
}

function createChildResourceParams$a(config) {
    const childResources = [];
    const { records } = config;
    for (let outerIdx = 0, numOfRecordBatches = records.length; outerIdx < numOfRecordBatches; outerIdx += 1) {
        const currentRecordBatch = records[outerIdx];
        const { recordIds, fields, optionalFields } = currentRecordBatch;
        for (let innerIdx = 0, numOfRecordIds = recordIds.length; innerIdx < numOfRecordIds; innerIdx += 1) {
            const currentRecordId = recordIds[innerIdx];
            const queryParams = {};
            if (ArrayIsArray$1(fields)) {
                queryParams.fields = fields;
            }
            if (ArrayIsArray$1(optionalFields)) {
                queryParams.optionalFields = optionalFields;
            }
            childResources.push({
                urlParams: {
                    recordId: currentRecordId,
                },
                queryParams,
            });
        }
    }
    return childResources;
}

function adapterFragment$J(luvio, config) {
    const childResources = createChildResourceParams$a(config);
    const resourceParams = createResourceParams$11(config);
    return selectChildResourceParams$7(luvio, childResources, resourceParams);
}

function onFetchResponseSuccess$N(luvio, config, resourceParams, response, serverRequestCount = 0) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$a(config);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' +
                childResourceParamsArray.length +
                ' items, received ' +
                childEnvelopes.length);
        }
    }
    const snapshotStateFulfilled = 'Fulfilled';
    const key = keyBuilder$27(luvio, resourceParams);
    const { childSnapshotData, seenRecords } = ingestSuccessChildResourceParams$8(luvio, childResourceParamsArray, childEnvelopes, serverRequestCount);
    const snapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotStateFulfilled,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: adapterFragment$J(luvio, config),
            variables: {},
        },
        refresh: {
            config,
            resolve: () => buildNetworkSnapshot$15(luvio, config, serverRequestCount, snapshotRefreshOptions),
        },
        variables: {},
    };
    return luvio.storeBroadcast().then(() => snapshot);
}

function onFetchResponseError$O(luvio, config, resourceParams, response) {
    const snapshot = ingestError$L(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$15(luvio, config, 0, snapshotRefreshOptions),
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$15(luvio, config, serverRequestCount = 0, options) {
    const resourceParams = createResourceParams$11(config);
    const request = createResourceRequest$1b(resourceParams);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$N(luvio, config, resourceParams, response, serverRequestCount + 1), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$11(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$O(luvio, config, resourceParams, response));
    });
}

// iterate through the map to build configs for network calls
function resolveConflict(luvio, map) {
    const ids = keys(map.conflicts);
    if (ids.length === 0) {
        instrumentation.recordConflictsResolved(map.serverRequestCount);
        return;
    }
    if (ids.length === 1) {
        const recordId = ids[0];
        const config = {
            recordId,
            optionalFields: convertTrieToFields(map.conflicts[recordId].trackedFields),
        };
        buildNetworkSnapshot$16(luvio, config, map.serverRequestCount);
    }
    else {
        const records = reduce.call(ids, (acc, id) => {
            const { trackedFields } = map.conflicts[id];
            push.call(acc, {
                recordIds: [id],
                optionalFields: convertTrieToFields(trackedFields),
            });
            return acc;
        }, []);
        const config = { records };
        buildNetworkSnapshot$15(luvio, config, map.serverRequestCount);
    }
}

const createIngestRecordWithFields = (fields, optionalFields) => {
    return (input, path, luvio, store, timestamp) => {
        input.eTag = ''; //[W-13724550] Record Reps ALWAYS have '' etag, to be consistent with GraphQL, as it is not queryable via GraphQL.
        const conflictMap = {
            conflicts: {},
            serverRequestCount: 0,
        };
        const result = createRecordIngest(fields, optionalFields, conflictMap)(input, path, luvio, store, timestamp);
        resolveConflict(luvio, conflictMap);
        return result;
    };
};
const ingest$O = (input, path, luvio, store, timestamp) => {
    const conflictMap = {
        conflicts: {},
        serverRequestCount: 0,
    };
    input.eTag = ''; //[W-13724550] Record Reps ALWAYS have '' etag, to be consistent with GraphQL, as it is not queryable via GraphQL.
    const result = createRecordIngest(BLANK_RECORD_FIELDS_TRIE, BLANK_RECORD_FIELDS_TRIE, conflictMap)(input, path, luvio, store, timestamp);
    resolveConflict(luvio, conflictMap);
    return result;
};

const PAGINATION_VERSION$1 = "0.111.0";
const paginationStoreMetadata$1 = {
    ttl: Number.MAX_SAFE_INTEGER,
    namespace: '',
    representationName: '',
    version: PAGINATION_VERSION$1
};
function getPageTokenAndOffset$1(paginationMetadata, token) {
    if (token === undefined) {
        const startToken = tokenFromOffset(paginationMetadata, 0);
        if (startToken === undefined) {
            return;
        }
        return [startToken, 0];
    }
    const startOffset = offsetFromToken(paginationMetadata, token);
    if (startOffset < 0) {
        return;
    }
    return [token, startOffset];
}
function mergeMetadata$1(existingMetadata, incomingMetadata) {
    if (existingMetadata === undefined) {
        return incomingMetadata;
    }
    return {
        ...existingMetadata,
        ...incomingMetadata,
    };
}
function getNextPageToken(paginationMetadata, pageEndOffset) {
    const listEndOffset = paginationMetadata.__END__;
    if (listEndOffset === undefined || pageEndOffset < listEndOffset) {
        return tokenFromOffset(paginationMetadata, pageEndOffset);
    }
    return null;
}
function offsetFromToken(paginationMetadata, token) {
    if (token === undefined || token === null) {
        return 0;
    }
    const offset = paginationMetadata[token];
    return offset === undefined ? -1 : offset;
}
function pageEndOffset$1(paginationMetadata, startOffset, pageSize) {
    const listEndOffset = paginationMetadata.__END__;
    const nextPageOffset = startOffset + pageSize;
    if (listEndOffset === undefined) {
        return nextPageOffset;
    }
    return Math.min(nextPageOffset, listEndOffset);
}
function getPreviousPageToken(paginationMetadata, startOffset, pageSize) {
    const previousPageOffset = startOffset - pageSize;
    if (previousPageOffset < 0) {
        return null;
    }
    const listEndOffset = paginationMetadata.__END__;
    if (listEndOffset !== undefined && previousPageOffset >= listEndOffset) {
        return;
    }
    return tokenFromOffset(paginationMetadata, previousPageOffset);
}
function tokenFromOffset(paginationMetadata, offset) {
    const tokens = Object.keys(paginationMetadata);
    for (let i = 0, len = tokens.length; i < len; i++) {
        const token = tokens[i];
        if (paginationMetadata[token] === offset &&
            token !== '__END__') {
            return token;
        }
    }
}
function tokenForAtMost(paginationMetadata, maxOffset) {
    const tokens = Object.keys(paginationMetadata);
    let tokenResult = undefined;
    let offsetResult = -1;
    for (let i = 0, len = tokens.length; i < len; i++) {
        const token = tokens[i];
        const offset = paginationMetadata[token];
        if (token === '__END__' || offset === undefined) {
            continue;
        }
        if (offset === maxOffset) {
            return [token, offset];
        }
        if (offset < maxOffset && offset > offsetResult) {
            tokenResult = token;
            offsetResult = offset;
        }
    }
    return [tokenResult, offsetResult];
}

const keyBuilderFromType$C = function ListRecordCollectionRepresentationKeyBuilderFromType(luvio, object) {
    const keyParams = {
        objectApiName: object.listReference.objectApiName.toLowerCase(),
        searchTerm: object.searchTerm,
        sortBy: object.sortBy,
        where: object.where,
        listViewApiName: object.listReference.listViewApiName
            ? object.listReference.listViewApiName.toLowerCase()
            : object.listReference.listViewApiName,
    };
    return keyBuilder$26(luvio, keyParams);
};

const TTL$y = 30000;
const VERSION$1e = "e5c90c4081cd557f8ffec53028ede1e8";
function validate$1V(obj, path = 'ListRecordCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_count = obj.count;
        const path_count = path + '.count';
        if (typeof obj_count !== 'number' || (typeof obj_count === 'number' && Math.floor(obj_count) !== obj_count)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_count + '" (at "' + path_count + '")');
        }
        const obj_currentPageToken = obj.currentPageToken;
        const path_currentPageToken = path + '.currentPageToken';
        if (typeof obj_currentPageToken !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (!ArrayIsArray(obj_fields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        for (let i = 0; i < obj_fields.length; i++) {
            const obj_fields_item = obj_fields[i];
            const path_fields_item = path_fields + '[' + i + ']';
            if (typeof obj_fields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_fields_item + '" (at "' + path_fields_item + '")');
            }
        }
        const obj_listInfoETag = obj.listInfoETag;
        const path_listInfoETag = path + '.listInfoETag';
        let obj_listInfoETag_union0 = null;
        const obj_listInfoETag_union0_error = (() => {
            if (typeof obj_listInfoETag !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_listInfoETag + '" (at "' + path_listInfoETag + '")');
            }
        })();
        if (obj_listInfoETag_union0_error != null) {
            obj_listInfoETag_union0 = obj_listInfoETag_union0_error.message;
        }
        let obj_listInfoETag_union1 = null;
        const obj_listInfoETag_union1_error = (() => {
            if (obj_listInfoETag !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_listInfoETag + '" (at "' + path_listInfoETag + '")');
            }
        })();
        if (obj_listInfoETag_union1_error != null) {
            obj_listInfoETag_union1 = obj_listInfoETag_union1_error.message;
        }
        if (obj_listInfoETag_union0 && obj_listInfoETag_union1) {
            let message = 'Object doesn\'t match union (at "' + path_listInfoETag + '")';
            message += '\n' + obj_listInfoETag_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_listInfoETag_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_listReference = obj.listReference;
        const path_listReference = path + '.listReference';
        const referencepath_listReferenceValidationError = validate$29(obj_listReference, path_listReference);
        if (referencepath_listReferenceValidationError !== null) {
            let message = 'Object doesn\'t match ListReferenceRepresentation (at "' + path_listReference + '")\n';
            message += referencepath_listReferenceValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageToken = obj.nextPageToken;
        const path_nextPageToken = path + '.nextPageToken';
        let obj_nextPageToken_union0 = null;
        const obj_nextPageToken_union0_error = (() => {
            if (typeof obj_nextPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union0_error != null) {
            obj_nextPageToken_union0 = obj_nextPageToken_union0_error.message;
        }
        let obj_nextPageToken_union1 = null;
        const obj_nextPageToken_union1_error = (() => {
            if (obj_nextPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union1_error != null) {
            obj_nextPageToken_union1 = obj_nextPageToken_union1_error.message;
        }
        if (obj_nextPageToken_union0 && obj_nextPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageToken + '")';
            message += '\n' + obj_nextPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        let obj_nextPageUrl_union0 = null;
        const obj_nextPageUrl_union0_error = (() => {
            if (typeof obj_nextPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union0_error != null) {
            obj_nextPageUrl_union0 = obj_nextPageUrl_union0_error.message;
        }
        let obj_nextPageUrl_union1 = null;
        const obj_nextPageUrl_union1_error = (() => {
            if (obj_nextPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union1_error != null) {
            obj_nextPageUrl_union1 = obj_nextPageUrl_union1_error.message;
        }
        if (obj_nextPageUrl_union0 && obj_nextPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageUrl + '")';
            message += '\n' + obj_nextPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_optionalFields = obj.optionalFields;
        const path_optionalFields = path + '.optionalFields';
        if (!ArrayIsArray(obj_optionalFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_optionalFields + '" (at "' + path_optionalFields + '")');
        }
        for (let i = 0; i < obj_optionalFields.length; i++) {
            const obj_optionalFields_item = obj_optionalFields[i];
            const path_optionalFields_item = path_optionalFields + '[' + i + ']';
            if (typeof obj_optionalFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_optionalFields_item + '" (at "' + path_optionalFields_item + '")');
            }
        }
        const obj_pageSize = obj.pageSize;
        const path_pageSize = path + '.pageSize';
        if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
        }
        const obj_previousPageToken = obj.previousPageToken;
        const path_previousPageToken = path + '.previousPageToken';
        let obj_previousPageToken_union0 = null;
        const obj_previousPageToken_union0_error = (() => {
            if (typeof obj_previousPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union0_error != null) {
            obj_previousPageToken_union0 = obj_previousPageToken_union0_error.message;
        }
        let obj_previousPageToken_union1 = null;
        const obj_previousPageToken_union1_error = (() => {
            if (obj_previousPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union1_error != null) {
            obj_previousPageToken_union1 = obj_previousPageToken_union1_error.message;
        }
        if (obj_previousPageToken_union0 && obj_previousPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageToken + '")';
            message += '\n' + obj_previousPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_previousPageUrl = obj.previousPageUrl;
        const path_previousPageUrl = path + '.previousPageUrl';
        let obj_previousPageUrl_union0 = null;
        const obj_previousPageUrl_union0_error = (() => {
            if (typeof obj_previousPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union0_error != null) {
            obj_previousPageUrl_union0 = obj_previousPageUrl_union0_error.message;
        }
        let obj_previousPageUrl_union1 = null;
        const obj_previousPageUrl_union1_error = (() => {
            if (obj_previousPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union1_error != null) {
            obj_previousPageUrl_union1 = obj_previousPageUrl_union1_error.message;
        }
        if (obj_previousPageUrl_union0 && obj_previousPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageUrl + '")';
            message += '\n' + obj_previousPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (!ArrayIsArray(obj_records)) {
            return new TypeError('Expected "array" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
        for (let i = 0; i < obj_records.length; i++) {
            const obj_records_item = obj_records[i];
            const path_records_item = path_records + '[' + i + ']';
            if (typeof obj_records_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_records_item + '" (at "' + path_records_item + '")');
            }
        }
        const obj_searchTerm = obj.searchTerm;
        const path_searchTerm = path + '.searchTerm';
        let obj_searchTerm_union0 = null;
        const obj_searchTerm_union0_error = (() => {
            if (typeof obj_searchTerm !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_searchTerm + '" (at "' + path_searchTerm + '")');
            }
        })();
        if (obj_searchTerm_union0_error != null) {
            obj_searchTerm_union0 = obj_searchTerm_union0_error.message;
        }
        let obj_searchTerm_union1 = null;
        const obj_searchTerm_union1_error = (() => {
            if (obj_searchTerm !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_searchTerm + '" (at "' + path_searchTerm + '")');
            }
        })();
        if (obj_searchTerm_union1_error != null) {
            obj_searchTerm_union1 = obj_searchTerm_union1_error.message;
        }
        if (obj_searchTerm_union0 && obj_searchTerm_union1) {
            let message = 'Object doesn\'t match union (at "' + path_searchTerm + '")';
            message += '\n' + obj_searchTerm_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_searchTerm_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_sortBy = obj.sortBy;
        const path_sortBy = path + '.sortBy';
        let obj_sortBy_union0 = null;
        const obj_sortBy_union0_error = (() => {
            if (!ArrayIsArray(obj_sortBy)) {
                return new TypeError('Expected "array" but received "' + typeof obj_sortBy + '" (at "' + path_sortBy + '")');
            }
            for (let i = 0; i < obj_sortBy.length; i++) {
                const obj_sortBy_item = obj_sortBy[i];
                const path_sortBy_item = path_sortBy + '[' + i + ']';
                if (typeof obj_sortBy_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_sortBy_item + '" (at "' + path_sortBy_item + '")');
                }
            }
        })();
        if (obj_sortBy_union0_error != null) {
            obj_sortBy_union0 = obj_sortBy_union0_error.message;
        }
        let obj_sortBy_union1 = null;
        const obj_sortBy_union1_error = (() => {
            if (obj_sortBy !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_sortBy + '" (at "' + path_sortBy + '")');
            }
        })();
        if (obj_sortBy_union1_error != null) {
            obj_sortBy_union1 = obj_sortBy_union1_error.message;
        }
        if (obj_sortBy_union0 && obj_sortBy_union1) {
            let message = 'Object doesn\'t match union (at "' + path_sortBy + '")';
            message += '\n' + obj_sortBy_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_sortBy_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_where = obj.where;
        const path_where = path + '.where';
        let obj_where_union0 = null;
        const obj_where_union0_error = (() => {
            if (typeof obj_where !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_where + '" (at "' + path_where + '")');
            }
        })();
        if (obj_where_union0_error != null) {
            obj_where_union0 = obj_where_union0_error.message;
        }
        let obj_where_union1 = null;
        const obj_where_union1_error = (() => {
            if (obj_where !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_where + '" (at "' + path_where + '")');
            }
        })();
        if (obj_where_union1_error != null) {
            obj_where_union1 = obj_where_union1_error.message;
        }
        if (obj_where_union0 && obj_where_union1) {
            let message = 'Object doesn\'t match union (at "' + path_where + '")';
            message += '\n' + obj_where_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_where_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$U = 'ListRecordCollectionRepresentation';
function keyBuilder$26(luvio, config) {
    return keyPrefix + '::' + RepresentationType$U + ':' + config.objectApiName + ':' + (config.searchTerm === null ? '' : config.searchTerm) + ':' + (config.sortBy === null ? '' : '[' + config.sortBy.join(',') + ']') + ':' + (config.where === null ? '' : config.where) + ':' + (config.listViewApiName === null ? '' : config.listViewApiName);
}
function paginationKeyBuilder(luvio, config) {
    return keyBuilder$26(luvio, config) + '__pagination';
}
function normalize$N(input, existing, path, luvio, store, timestamp) {
    const input_records = input.records;
    const input_records_id = path.fullPath + '__records';
    for (let i = 0; i < input_records.length; i++) {
        const input_records_item = input_records[i];
        let input_records_item_id = input_records_id + '__' + i;
        input_records[i] = ingest$O(input_records_item, {
            fullPath: input_records_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1U = function ListRecordCollectionRepresentationSelect(paginationParams) {
    const { selections: ListReferenceRepresentation__selections, opaque: ListReferenceRepresentation__opaque, } = select$26();
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: false,
        version: VERSION$1e,
        read: (source, reader) => {
            const sink = {};
            if (paginationParams === undefined) {
                return sink;
            }
            const metadata = reader.resolveMetadata(source, PAGINATION_VERSION$1);
            const currentPageMetadata = getPageMetadata$3(metadata, paginationParams);
            const { startOffset, endOffset, metadataProperties } = currentPageMetadata;
            if (metadata !== undefined && startOffset !== undefined && endOffset !== undefined) {
                const itemsProperty = 'records';
                reader.enterPath(itemsProperty);
                const itemsSource = source[itemsProperty];
                const itemsSink = [];
                const allSink = [];
                for (let i = startOffset; i < endOffset; i++) {
                    reader.enterPath(i);
                    reader.readSingleLink(i, {
                        name: 'records',
                        kind: 'Link',
                        fragment: select$1V()
                    }, itemsSource, allSink, i - startOffset);
                    if (reader.getIsDataMissing() === false) {
                        itemsSink[i - startOffset] = allSink[i - startOffset];
                    }
                    reader.exitPath();
                }
                reader.exitPath();
                reader.assignNonScalar(sink, itemsProperty, itemsSink);
            }
            reader.enterPath('currentPageToken');
            reader.readScalar('currentPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('nextPageToken');
            reader.readScalar('nextPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('previousPageToken');
            reader.readScalar('previousPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('pageSize');
            reader.readScalar('pageSize', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('count');
            reader.readScalar('count', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('fields');
            reader.readScalarPlural('fields', source, sink, true);
            reader.exitPath();
            reader.enterPath('listInfoETag');
            reader.readScalar('listInfoETag', source, sink);
            reader.exitPath();
            reader.enterPath('listReference');
            reader.readObject('listReference', {
                name: 'listReference',
                kind: 'Object',
                selections: ListReferenceRepresentation__selections
            }, source, sink);
            reader.exitPath();
            reader.enterPath('optionalFields');
            reader.readScalarPlural('optionalFields', source, sink, true);
            reader.exitPath();
            reader.enterPath('searchTerm');
            reader.readScalar('searchTerm', source, sink);
            reader.exitPath();
            reader.enterPath('sortBy');
            if (source['sortBy'] === null) {
                reader.readScalar('sortBy', source, sink);
            }
            else {
                reader.readScalarPlural('sortBy', source, sink, true);
            }
            reader.exitPath();
            reader.enterPath('where');
            reader.readScalar('where', source, sink);
            reader.exitPath();
            return sink;
        },
    };
};
function getPageMetadata$3(paginationMetadata, paginationParams) {
    const metadataProperties = {};
    const sink = {
        metadataProperties
    };
    if (paginationMetadata === undefined) {
        return sink;
    }
    const { token, pageSize } = paginationParams;
    const pageTokenAndOffset = getPageTokenAndOffset$1(paginationMetadata, token);
    if (pageTokenAndOffset === undefined) {
        return sink;
    }
    const [pageToken, startOffset] = pageTokenAndOffset;
    const endOffset = pageEndOffset$1(paginationMetadata, startOffset, pageSize);
    sink.startOffset = startOffset;
    sink.endOffset = endOffset;
    metadataProperties.currentPageToken = pageToken;
    const nextToken = getNextPageToken(paginationMetadata, endOffset);
    if (nextToken !== undefined) {
        metadataProperties.nextPageToken = nextToken;
    }
    const previousToken = getPreviousPageToken(paginationMetadata, startOffset, pageSize);
    if (previousToken !== undefined) {
        metadataProperties.previousPageToken = previousToken;
    }
    metadataProperties.pageSize = pageSize;
    metadataProperties.count = endOffset - startOffset;
    return sink;
}
const dynamicSelect$7 = function dynamicListRecordCollectionRepresentationSelect(params, paginationParams) {
    const recordsPathSelection = params.records === undefined ? {
        name: 'records',
        kind: 'Link',
        fragment: select$1V()
    } : params.records;
    const { selections: ListReferenceRepresentation__selections, opaque: ListReferenceRepresentation__opaque, } = select$26();
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: false,
        version: VERSION$1e,
        read: (source, reader) => {
            const sink = {};
            if (paginationParams === undefined) {
                return sink;
            }
            const metadata = reader.resolveMetadata(source, PAGINATION_VERSION$1);
            const currentPageMetadata = getPageMetadata$3(metadata, paginationParams);
            const { startOffset, endOffset, metadataProperties } = currentPageMetadata;
            if (metadata !== undefined && startOffset !== undefined && endOffset !== undefined) {
                const itemsProperty = 'records';
                reader.enterPath(itemsProperty);
                const itemsSource = source[itemsProperty];
                const itemsSink = [];
                const allSink = [];
                for (let i = startOffset; i < endOffset; i++) {
                    reader.enterPath(i);
                    reader.readSingleLink(i, recordsPathSelection, itemsSource, allSink, i - startOffset);
                    if (reader.getIsDataMissing() === false) {
                        itemsSink[i - startOffset] = allSink[i - startOffset];
                    }
                    reader.exitPath();
                }
                reader.exitPath();
                reader.assignNonScalar(sink, itemsProperty, itemsSink);
            }
            reader.enterPath('currentPageToken');
            reader.readScalar('currentPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('nextPageToken');
            reader.readScalar('nextPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('previousPageToken');
            reader.readScalar('previousPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('pageSize');
            reader.readScalar('pageSize', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('count');
            reader.readScalar('count', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('fields');
            reader.readScalarPlural('fields', source, sink, true);
            reader.exitPath();
            reader.enterPath('listInfoETag');
            reader.readScalar('listInfoETag', source, sink);
            reader.exitPath();
            reader.enterPath('listReference');
            reader.readObject('listReference', {
                name: 'listReference',
                kind: 'Object',
                selections: ListReferenceRepresentation__selections
            }, source, sink);
            reader.exitPath();
            reader.enterPath('optionalFields');
            reader.readScalarPlural('optionalFields', source, sink, true);
            reader.exitPath();
            reader.enterPath('searchTerm');
            reader.readScalar('searchTerm', source, sink);
            reader.exitPath();
            reader.enterPath('sortBy');
            if (source['sortBy'] === null) {
                reader.readScalar('sortBy', source, sink);
            }
            else {
                reader.readScalarPlural('sortBy', source, sink, true);
            }
            reader.exitPath();
            reader.enterPath('where');
            reader.readScalar('where', source, sink);
            reader.exitPath();
            return sink;
        },
    };
};
function equals$14(existing, incoming) {
    const existing_count = existing.count;
    const incoming_count = incoming.count;
    if (!(existing_count === incoming_count)) {
        return false;
    }
    const existing_pageSize = existing.pageSize;
    const incoming_pageSize = incoming.pageSize;
    if (!(existing_pageSize === incoming_pageSize)) {
        return false;
    }
    const existing_currentPageToken = existing.currentPageToken;
    const incoming_currentPageToken = incoming.currentPageToken;
    if (!(existing_currentPageToken === incoming_currentPageToken)) {
        return false;
    }
    const existing_currentPageUrl = existing.currentPageUrl;
    const incoming_currentPageUrl = incoming.currentPageUrl;
    if (!(existing_currentPageUrl === incoming_currentPageUrl)) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_items = equalsArray(existing_fields, incoming_fields, (existing_fields_item, incoming_fields_item) => {
        if (!(existing_fields_item === incoming_fields_item)) {
            return false;
        }
    });
    if (equals_fields_items === false) {
        return false;
    }
    const existing_listInfoETag = existing.listInfoETag;
    const incoming_listInfoETag = incoming.listInfoETag;
    if (!(existing_listInfoETag === incoming_listInfoETag)) {
        return false;
    }
    const existing_listReference = existing.listReference;
    const incoming_listReference = incoming.listReference;
    if (!(equals$1c(existing_listReference, incoming_listReference))) {
        return false;
    }
    const existing_nextPageToken = existing.nextPageToken;
    const incoming_nextPageToken = incoming.nextPageToken;
    if (!(existing_nextPageToken === incoming_nextPageToken)) {
        return false;
    }
    const existing_nextPageUrl = existing.nextPageUrl;
    const incoming_nextPageUrl = incoming.nextPageUrl;
    if (!(existing_nextPageUrl === incoming_nextPageUrl)) {
        return false;
    }
    const existing_optionalFields = existing.optionalFields;
    const incoming_optionalFields = incoming.optionalFields;
    const equals_optionalFields_items = equalsArray(existing_optionalFields, incoming_optionalFields, (existing_optionalFields_item, incoming_optionalFields_item) => {
        if (!(existing_optionalFields_item === incoming_optionalFields_item)) {
            return false;
        }
    });
    if (equals_optionalFields_items === false) {
        return false;
    }
    const existing_previousPageToken = existing.previousPageToken;
    const incoming_previousPageToken = incoming.previousPageToken;
    if (!(existing_previousPageToken === incoming_previousPageToken)) {
        return false;
    }
    const existing_previousPageUrl = existing.previousPageUrl;
    const incoming_previousPageUrl = incoming.previousPageUrl;
    if (!(existing_previousPageUrl === incoming_previousPageUrl)) {
        return false;
    }
    const existing_records = existing.records;
    const incoming_records = incoming.records;
    const equals_records_items = equalsArray(existing_records, incoming_records, (existing_records_item, incoming_records_item) => {
        if (!(existing_records_item.__ref === incoming_records_item.__ref)) {
            return false;
        }
    });
    if (equals_records_items === false) {
        return false;
    }
    const existing_searchTerm = existing.searchTerm;
    const incoming_searchTerm = incoming.searchTerm;
    if (!(existing_searchTerm === incoming_searchTerm)) {
        return false;
    }
    const existing_sortBy = existing.sortBy;
    const incoming_sortBy = incoming.sortBy;
    if (!((() => {
        if (existing_sortBy === null || incoming_sortBy === null) {
            return existing_sortBy === incoming_sortBy;
        }
        const equals_sortBy_items = equalsArray(existing_sortBy, incoming_sortBy, (existing_sortBy_item, incoming_sortBy_item) => {
            if (!(existing_sortBy_item === incoming_sortBy_item)) {
                return false;
            }
        });
        if (equals_sortBy_items === false) {
            return false;
        }
    })())) {
        return false;
    }
    const existing_where = existing.where;
    const incoming_where = incoming.where;
    if (!(existing_where === incoming_where)) {
        return false;
    }
    return true;
}
const ingest$N = function ListRecordCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1V(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$C(luvio, input);
    const existingRecord = store.readEntry(key);
    const ttlToUse = TTL$y;
    let incomingRecord = normalize$N(input, store.readEntry(key), {
        fullPath: key,
        parent: path.parent,
        propertyName: path.propertyName,
        ttl: ttlToUse
    }, luvio, store, timestamp);
    const paginationKey = key + '__pagination';
    const existingPaginationMetadata = store.readEntry(paginationKey);
    const { count: count, currentPageToken: token, nextPageToken: nextToken, pageSize: pageSize, previousPageToken: previousToken, records: items } = input;
    const startOffset = existingPaginationMetadata === undefined ? 0 : offsetFromToken(existingPaginationMetadata, token);
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0 ||
            (existingRecord && existingRecord.records && existingRecord.records.length < startOffset)) {
            throw new RangeError('currentPageToken value ' + token + ' is not recognized');
        }
    }
    const incomingPaginationMetadata = {
        [token]: startOffset,
    };
    const nextOffset = startOffset + items.length;
    if (nextToken === null) {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    else {
        incomingPaginationMetadata[nextToken] = nextOffset;
        if (existingPaginationMetadata !== undefined) {
            const listEndOffset = existingPaginationMetadata.__END__;
            if (listEndOffset !== undefined && nextOffset >= listEndOffset) {
                incomingPaginationMetadata.__END__ = undefined;
            }
        }
    }
    if (previousToken !== null) {
        incomingPaginationMetadata[previousToken] = Math.max(startOffset - pageSize, 0);
    }
    const mergedPaginationMetadata = mergeMetadata$1(existingPaginationMetadata, incomingPaginationMetadata);
    if (existingPaginationMetadata === undefined ||
        equalsObject(existingPaginationMetadata, mergedPaginationMetadata, (existingProp, incomingProp) => {
            return existingProp === incomingProp;
        }) === false) {
        luvio.storePublish(paginationKey, mergedPaginationMetadata);
        luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata$1);
    }
    assignMetadataLink(incomingRecord, paginationKey);
    if (existingRecord !== undefined && existingRecord.records !== undefined) {
        incomingRecord.records = [
            ...existingRecord.records.slice(0, startOffset),
            ...incomingRecord.records,
            ...existingRecord.records.slice(nextOffset),
        ];
    }
    if (existingRecord === undefined || equals$14(existingRecord, incomingRecord) === false) {
        luvio.storePublish(key, incomingRecord);
    }
    {
        const storeMetadataParams = {
            ttl: ttlToUse,
            namespace: "UiApi",
            version: VERSION$1e,
            representationName: RepresentationType$U,
            ingestionTimestamp: timestamp,
        };
        luvio.publishStoreMetadata(key, storeMetadataParams);
    }
    return createLink(key);
};
function getTypeCacheKeys$U(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$C(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$U,
        mergeable: true
    });
    rootKeySet.set(rootKey + '__pagination', {
        namespace: keyPrefix,
        representationName: RepresentationType$U,
        mergeable: true
    });
    const input_records_length = input.records.length;
    for (let i = 0; i < input_records_length; i++) {
        getTypeCacheKeys$X(rootKeySet, luvio, input.records[i]);
    }
}
const notifyUpdateAvailableFactory$4 = (luvio) => {
    return function notifyListRecordCollectionUpdateAvailable(configs) {
        if (process.env.NODE_ENV !== 'production') {
            const requiredKeyParams = ['objectApiName', 'searchTerm', 'sortBy', 'where', 'listViewApiName'];
            configs.forEach(config => {
                if (false === requiredKeyParams.every(req => req in config)) {
                    throw new Error(`one of the configs did not contain all required parameters: ${JSONStringify(ObjectKeys(config))}`);
                }
            });
        }
        const keys = configs.map(c => keyBuilder$26(luvio, c));
        return luvio.notifyStoreUpdateAvailable(keys);
    };
};

const VERSION$1d = "cf8d2eb042188974da26ffe6618cfd07";
function validate$1U(obj, path = 'ListUiRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_info = obj.info;
        const path_info = path + '.info';
        if (typeof obj_info !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_info + '" (at "' + path_info + '")');
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (typeof obj_records !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$T = 'ListUiRepresentation';
function keyBuilder$25(luvio, config) {
    return keyPrefix + '::' + RepresentationType$T + ':' + (config.listViewApiName === null ? '' : config.listViewApiName) + ':' + config.objectApiName + ':' + config.type + ':' + (config.sortBy === null ? '' : '[' + config.sortBy.join(',') + ']');
}
function keyBuilderFromType$B(luvio, object) {
    const keyParams = {
        listViewApiName: object.info.listReference.listViewApiName,
        objectApiName: object.info.listReference.objectApiName,
        type: object.info.listReference.type,
        sortBy: object.records.sortBy
    };
    return keyBuilder$25(luvio, keyParams);
}
function normalize$M(input, existing, path, luvio, store, timestamp) {
    const input_info = input.info;
    const input_info_id = path.fullPath + '__info';
    input.info = ingest$R(input_info, {
        fullPath: input_info_id,
        propertyName: 'info',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    const input_records = input.records;
    const input_records_id = path.fullPath + '__records';
    input.records = ingest$N(input_records, {
        fullPath: input_records_id,
        propertyName: 'records',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    return input;
}
const dynamicSelect$6 = function dynamicListUiRepresentationSelect(params, paginationParams) {
    const infoPathSelection = params.info === undefined ? {
        name: 'info',
        kind: 'Link',
        fragment: select$1Z()
    } : params.info;
    const recordsPathSelection = params.records === undefined ? {
        name: 'records',
        kind: 'Link',
        fragment: select$1U(paginationParams)
    } : params.records;
    return {
        kind: 'Fragment',
        version: VERSION$1d,
        private: [
            'eTag'
        ],
        selections: [
            infoPathSelection,
            recordsPathSelection
        ]
    };
};
function equals$13(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_info = existing.info;
    const incoming_info = incoming.info;
    if (!(existing_info.__ref === incoming_info.__ref)) {
        return false;
    }
    const existing_records = existing.records;
    const incoming_records = incoming.records;
    if (!(existing_records.__ref === incoming_records.__ref)) {
        return false;
    }
    return true;
}
const ingest$M = function ListUiRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1U(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$B(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$M, "UiApi", VERSION$1d, RepresentationType$T, equals$13);
    return createLink(key);
};
function getTypeCacheKeys$T(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$B(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$T,
        mergeable: false
    });
    getTypeCacheKeys$Z(rootKeySet, luvio, input.info);
    getTypeCacheKeys$U(rootKeySet, luvio, input.records);
}

function createPaginationParams$6(params) {
    const { queryParams } = params;
    return {
        token: queryParams.pageToken,
        pageSize: queryParams.pageSize === undefined ? 50 : queryParams.pageSize
    };
}
function createResourceRequest$1a(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-ui/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$10 = 'getListUiByApiName';
const getListUiByApiName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
];
const getListUiByApiName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$10, getListUiByApiName_ConfigPropertyMetadata);
const createResourceParams$10 = /*#__PURE__*/ createResourceParams$13(getListUiByApiName_ConfigPropertyMetadata);
function typeCheckConfig$15(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListUiByApiName_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$17(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getListUiByApiName_ConfigPropertyMetadata);
    const config = typeCheckConfig$15(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

function createPaginationParams$5(params) {
    const { queryParams } = params;
    return {
        token: queryParams.pageToken,
        pageSize: queryParams.pageSize === undefined ? 50 : queryParams.pageSize
    };
}
function createResourceRequest$19(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-ui/' + config.urlParams.listViewId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$$ = 'getListUiByListViewId';
const getListUiByListViewId_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
];
const getListUiByListViewId_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$$, getListUiByListViewId_ConfigPropertyMetadata);
const createResourceParams$$ = /*#__PURE__*/ createResourceParams$13(getListUiByListViewId_ConfigPropertyMetadata);
function typeCheckConfig$14(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListUiByListViewId_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$16(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getListUiByListViewId_ConfigPropertyMetadata);
    const config = typeCheckConfig$14(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

function createResourceRequest$18(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-records/' + config.urlParams.listViewId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const VERSION$1c = "0b29241fd9ed04bb61fde26b3f558ac4";
function validate$1T(obj, path = 'ListInfoSummaryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$S = 'ListInfoSummaryRepresentation';
function keyBuilder$24(luvio, config) {
    return keyPrefix + '::' + RepresentationType$S + ':' + (config.id === null ? '' : config.id);
}
function keyBuilderFromType$A(luvio, object) {
    const keyParams = {
        id: object.id
    };
    return keyBuilder$24(luvio, keyParams);
}
function normalize$L(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1T = function ListInfoSummaryRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1c,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'url',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$12(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_url = existing.url;
    const incoming_url = incoming.url;
    if (!(existing_url === incoming_url)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    return true;
}
const ingest$L = function ListInfoSummaryRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1T(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$A(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$L, "UiApi", VERSION$1c, RepresentationType$S, equals$12);
    return createLink(key);
};
function getTypeCacheKeys$S(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$A(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$S,
        mergeable: false
    });
}

const VERSION$1b = "d0cadb0927f908b5b64694e1cff0b2d7";
function validate$1S(obj, path = 'ListInfoSummaryCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_count = obj.count;
        const path_count = path + '.count';
        if (typeof obj_count !== 'number' || (typeof obj_count === 'number' && Math.floor(obj_count) !== obj_count)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_count + '" (at "' + path_count + '")');
        }
        const obj_currentPageToken = obj.currentPageToken;
        const path_currentPageToken = path + '.currentPageToken';
        if (typeof obj_currentPageToken !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_lists = obj.lists;
        const path_lists = path + '.lists';
        if (!ArrayIsArray(obj_lists)) {
            return new TypeError('Expected "array" but received "' + typeof obj_lists + '" (at "' + path_lists + '")');
        }
        for (let i = 0; i < obj_lists.length; i++) {
            const obj_lists_item = obj_lists[i];
            const path_lists_item = path_lists + '[' + i + ']';
            if (typeof obj_lists_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_lists_item + '" (at "' + path_lists_item + '")');
            }
        }
        const obj_nextPageToken = obj.nextPageToken;
        const path_nextPageToken = path + '.nextPageToken';
        let obj_nextPageToken_union0 = null;
        const obj_nextPageToken_union0_error = (() => {
            if (typeof obj_nextPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union0_error != null) {
            obj_nextPageToken_union0 = obj_nextPageToken_union0_error.message;
        }
        let obj_nextPageToken_union1 = null;
        const obj_nextPageToken_union1_error = (() => {
            if (obj_nextPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union1_error != null) {
            obj_nextPageToken_union1 = obj_nextPageToken_union1_error.message;
        }
        if (obj_nextPageToken_union0 && obj_nextPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageToken + '")';
            message += '\n' + obj_nextPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        let obj_nextPageUrl_union0 = null;
        const obj_nextPageUrl_union0_error = (() => {
            if (typeof obj_nextPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union0_error != null) {
            obj_nextPageUrl_union0 = obj_nextPageUrl_union0_error.message;
        }
        let obj_nextPageUrl_union1 = null;
        const obj_nextPageUrl_union1_error = (() => {
            if (obj_nextPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union1_error != null) {
            obj_nextPageUrl_union1 = obj_nextPageUrl_union1_error.message;
        }
        if (obj_nextPageUrl_union0 && obj_nextPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageUrl + '")';
            message += '\n' + obj_nextPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_pageSize = obj.pageSize;
        const path_pageSize = path + '.pageSize';
        if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
        }
        const obj_previousPageToken = obj.previousPageToken;
        const path_previousPageToken = path + '.previousPageToken';
        let obj_previousPageToken_union0 = null;
        const obj_previousPageToken_union0_error = (() => {
            if (typeof obj_previousPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union0_error != null) {
            obj_previousPageToken_union0 = obj_previousPageToken_union0_error.message;
        }
        let obj_previousPageToken_union1 = null;
        const obj_previousPageToken_union1_error = (() => {
            if (obj_previousPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union1_error != null) {
            obj_previousPageToken_union1 = obj_previousPageToken_union1_error.message;
        }
        if (obj_previousPageToken_union0 && obj_previousPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageToken + '")';
            message += '\n' + obj_previousPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_previousPageUrl = obj.previousPageUrl;
        const path_previousPageUrl = path + '.previousPageUrl';
        let obj_previousPageUrl_union0 = null;
        const obj_previousPageUrl_union0_error = (() => {
            if (typeof obj_previousPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union0_error != null) {
            obj_previousPageUrl_union0 = obj_previousPageUrl_union0_error.message;
        }
        let obj_previousPageUrl_union1 = null;
        const obj_previousPageUrl_union1_error = (() => {
            if (obj_previousPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union1_error != null) {
            obj_previousPageUrl_union1 = obj_previousPageUrl_union1_error.message;
        }
        if (obj_previousPageUrl_union0 && obj_previousPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageUrl + '")';
            message += '\n' + obj_previousPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_queryString = obj.queryString;
        const path_queryString = path + '.queryString';
        let obj_queryString_union0 = null;
        const obj_queryString_union0_error = (() => {
            if (typeof obj_queryString !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_queryString + '" (at "' + path_queryString + '")');
            }
        })();
        if (obj_queryString_union0_error != null) {
            obj_queryString_union0 = obj_queryString_union0_error.message;
        }
        let obj_queryString_union1 = null;
        const obj_queryString_union1_error = (() => {
            if (obj_queryString !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_queryString + '" (at "' + path_queryString + '")');
            }
        })();
        if (obj_queryString_union1_error != null) {
            obj_queryString_union1 = obj_queryString_union1_error.message;
        }
        if (obj_queryString_union0 && obj_queryString_union1) {
            let message = 'Object doesn\'t match union (at "' + path_queryString + '")';
            message += '\n' + obj_queryString_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_queryString_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recentListsOnly = obj.recentListsOnly;
        const path_recentListsOnly = path + '.recentListsOnly';
        if (typeof obj_recentListsOnly !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_recentListsOnly + '" (at "' + path_recentListsOnly + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$R = 'ListInfoSummaryCollectionRepresentation';
function keyBuilder$23(luvio, config) {
    return keyPrefix + '::' + RepresentationType$R + ':' + config.objectApiName + ':' + (config.queryString === null ? '' : config.queryString) + ':' + config.recentListsOnly;
}
function keyBuilderFromType$z(luvio, object) {
    const keyParams = {
        objectApiName: object.objectApiName,
        queryString: object.queryString,
        recentListsOnly: object.recentListsOnly
    };
    return keyBuilder$23(luvio, keyParams);
}
function normalize$K(input, existing, path, luvio, store, timestamp) {
    const input_lists = input.lists;
    const input_lists_id = path.fullPath + '__lists';
    for (let i = 0; i < input_lists.length; i++) {
        const input_lists_item = input_lists[i];
        let input_lists_item_id = input_lists_id + '__' + i;
        input_lists[i] = ingest$L(input_lists_item, {
            fullPath: input_lists_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1S = function ListInfoSummaryCollectionRepresentationSelect(paginationParams) {
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: false,
        version: VERSION$1b,
        read: (source, reader) => {
            const sink = {};
            if (paginationParams === undefined) {
                return sink;
            }
            const metadata = reader.resolveMetadata(source, PAGINATION_VERSION$1);
            const currentPageMetadata = getPageMetadata$2(metadata, paginationParams);
            const { startOffset, endOffset, metadataProperties } = currentPageMetadata;
            if (metadata !== undefined && startOffset !== undefined && endOffset !== undefined) {
                const itemsProperty = 'lists';
                reader.enterPath(itemsProperty);
                const itemsSource = source[itemsProperty];
                const itemsSink = [];
                const allSink = [];
                for (let i = startOffset; i < endOffset; i++) {
                    reader.enterPath(i);
                    reader.readSingleLink(i, {
                        name: 'lists',
                        kind: 'Link',
                        fragment: select$1T()
                    }, itemsSource, allSink, i - startOffset);
                    if (reader.getIsDataMissing() === false) {
                        itemsSink[i - startOffset] = allSink[i - startOffset];
                    }
                    reader.exitPath();
                }
                reader.exitPath();
                reader.assignNonScalar(sink, itemsProperty, itemsSink);
            }
            reader.enterPath('currentPageToken');
            reader.readScalar('currentPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('nextPageToken');
            reader.readScalar('nextPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('previousPageToken');
            reader.readScalar('previousPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('pageSize');
            reader.readScalar('pageSize', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('count');
            reader.readScalar('count', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('objectApiName');
            reader.readScalar('objectApiName', source, sink);
            reader.exitPath();
            reader.enterPath('queryString');
            reader.readScalar('queryString', source, sink);
            reader.exitPath();
            reader.enterPath('recentListsOnly');
            reader.readScalar('recentListsOnly', source, sink);
            reader.exitPath();
            return sink;
        },
    };
};
function getPageMetadata$2(paginationMetadata, paginationParams) {
    const metadataProperties = {};
    const sink = {
        metadataProperties
    };
    if (paginationMetadata === undefined) {
        return sink;
    }
    const { token, pageSize } = paginationParams;
    const pageTokenAndOffset = getPageTokenAndOffset$1(paginationMetadata, token);
    if (pageTokenAndOffset === undefined) {
        return sink;
    }
    const [pageToken, startOffset] = pageTokenAndOffset;
    const endOffset = pageEndOffset$1(paginationMetadata, startOffset, pageSize);
    sink.startOffset = startOffset;
    sink.endOffset = endOffset;
    metadataProperties.currentPageToken = pageToken;
    const nextToken = getNextPageToken(paginationMetadata, endOffset);
    if (nextToken !== undefined) {
        metadataProperties.nextPageToken = nextToken;
    }
    const previousToken = getPreviousPageToken(paginationMetadata, startOffset, pageSize);
    if (previousToken !== undefined) {
        metadataProperties.previousPageToken = previousToken;
    }
    metadataProperties.pageSize = pageSize;
    metadataProperties.count = endOffset - startOffset;
    return sink;
}
function equals$11(existing, incoming) {
    const existing_recentListsOnly = existing.recentListsOnly;
    const incoming_recentListsOnly = incoming.recentListsOnly;
    if (!(existing_recentListsOnly === incoming_recentListsOnly)) {
        return false;
    }
    const existing_count = existing.count;
    const incoming_count = incoming.count;
    if (!(existing_count === incoming_count)) {
        return false;
    }
    const existing_pageSize = existing.pageSize;
    const incoming_pageSize = incoming.pageSize;
    if (!(existing_pageSize === incoming_pageSize)) {
        return false;
    }
    const existing_currentPageToken = existing.currentPageToken;
    const incoming_currentPageToken = incoming.currentPageToken;
    if (!(existing_currentPageToken === incoming_currentPageToken)) {
        return false;
    }
    const existing_currentPageUrl = existing.currentPageUrl;
    const incoming_currentPageUrl = incoming.currentPageUrl;
    if (!(existing_currentPageUrl === incoming_currentPageUrl)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_lists = existing.lists;
    const incoming_lists = incoming.lists;
    const equals_lists_items = equalsArray(existing_lists, incoming_lists, (existing_lists_item, incoming_lists_item) => {
        if (!(existing_lists_item.__ref === incoming_lists_item.__ref)) {
            return false;
        }
    });
    if (equals_lists_items === false) {
        return false;
    }
    const existing_nextPageToken = existing.nextPageToken;
    const incoming_nextPageToken = incoming.nextPageToken;
    if (!(existing_nextPageToken === incoming_nextPageToken)) {
        return false;
    }
    const existing_nextPageUrl = existing.nextPageUrl;
    const incoming_nextPageUrl = incoming.nextPageUrl;
    if (!(existing_nextPageUrl === incoming_nextPageUrl)) {
        return false;
    }
    const existing_previousPageToken = existing.previousPageToken;
    const incoming_previousPageToken = incoming.previousPageToken;
    if (!(existing_previousPageToken === incoming_previousPageToken)) {
        return false;
    }
    const existing_previousPageUrl = existing.previousPageUrl;
    const incoming_previousPageUrl = incoming.previousPageUrl;
    if (!(existing_previousPageUrl === incoming_previousPageUrl)) {
        return false;
    }
    const existing_queryString = existing.queryString;
    const incoming_queryString = incoming.queryString;
    if (!(existing_queryString === incoming_queryString)) {
        return false;
    }
    return true;
}
const ingest$K = function ListInfoSummaryCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1S(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$z(luvio, input);
    const existingRecord = store.readEntry(key);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    let incomingRecord = normalize$K(input, store.readEntry(key), {
        fullPath: key,
        parent: path.parent,
        propertyName: path.propertyName,
        ttl: ttlToUse
    }, luvio, store, timestamp);
    const paginationKey = key + '__pagination';
    const existingPaginationMetadata = store.readEntry(paginationKey);
    const { count: count, currentPageToken: token, nextPageToken: nextToken, pageSize: pageSize, previousPageToken: previousToken, lists: items } = input;
    const startOffset = existingPaginationMetadata === undefined ? 0 : offsetFromToken(existingPaginationMetadata, token);
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0 ||
            (existingRecord && existingRecord.lists && existingRecord.lists.length < startOffset)) {
            throw new RangeError('currentPageToken value ' + token + ' is not recognized');
        }
    }
    const incomingPaginationMetadata = {
        [token]: startOffset,
    };
    const nextOffset = startOffset + items.length;
    if (nextToken === null) {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    else {
        incomingPaginationMetadata[nextToken] = nextOffset;
        if (existingPaginationMetadata !== undefined) {
            const listEndOffset = existingPaginationMetadata.__END__;
            if (listEndOffset !== undefined && nextOffset >= listEndOffset) {
                incomingPaginationMetadata.__END__ = undefined;
            }
        }
    }
    if (previousToken !== null) {
        incomingPaginationMetadata[previousToken] = Math.max(startOffset - pageSize, 0);
    }
    const mergedPaginationMetadata = mergeMetadata$1(existingPaginationMetadata, incomingPaginationMetadata);
    if (existingPaginationMetadata === undefined ||
        equalsObject(existingPaginationMetadata, mergedPaginationMetadata, (existingProp, incomingProp) => {
            return existingProp === incomingProp;
        }) === false) {
        luvio.storePublish(paginationKey, mergedPaginationMetadata);
        luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata$1);
    }
    assignMetadataLink(incomingRecord, paginationKey);
    if (existingRecord !== undefined && existingRecord.lists !== undefined) {
        incomingRecord.lists = [
            ...existingRecord.lists.slice(0, startOffset),
            ...incomingRecord.lists,
            ...existingRecord.lists.slice(nextOffset),
        ];
    }
    if (existingRecord === undefined || equals$11(existingRecord, incomingRecord) === false) {
        luvio.storePublish(key, incomingRecord);
    }
    if (ttlToUse !== undefined) {
        const storeMetadataParams = {
            ttl: ttlToUse,
            namespace: "UiApi",
            version: VERSION$1b,
            representationName: RepresentationType$R,
            ingestionTimestamp: timestamp,
        };
        luvio.publishStoreMetadata(key, storeMetadataParams);
    }
    return createLink(key);
};
function getTypeCacheKeys$R(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$z(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$R,
        mergeable: true
    });
    rootKeySet.set(rootKey + '__pagination', {
        namespace: keyPrefix,
        representationName: RepresentationType$R,
        mergeable: true
    });
    const input_lists_length = input.lists.length;
    for (let i = 0; i < input_lists_length; i++) {
        getTypeCacheKeys$S(rootKeySet, luvio, input.lists[i]);
    }
}
const notifyUpdateAvailableFactory$3 = (luvio) => {
    return function notifyListInfoSummaryUpdateAvailable(configs) {
        if (process.env.NODE_ENV !== 'production') {
            const requiredKeyParams = ['objectApiName', 'queryString', 'recentListsOnly'];
            configs.forEach(config => {
                if (false === requiredKeyParams.every(req => req in config)) {
                    throw new Error(`one of the configs did not contain all required parameters: ${JSONStringify(ObjectKeys(config))}`);
                }
            });
        }
        const keys = configs.map(c => keyBuilder$23(luvio, c));
        return luvio.notifyStoreUpdateAvailable(keys);
    };
};

const LIST_RECORDS_PREFIX = keyPrefix + '::' + RepresentationType$U;
const LIST_SUMMARY_PREFIX = keyPrefix + '::' + RepresentationType$R;
/**
 * Watch a Luvio instance for ListRecordCollection and ListInfoSummaryCollection cache entries.
 */
let listRecordCollectionCache = new Map();
let listSummaryCollectionCache = new Map();
function getListRecordCollectionKeys(objectApiName, listViewApiName) {
    const cacheEntriesByObjectApiName = listRecordCollectionCache.get(objectApiName.toLowerCase()) || new Map();
    const keys = cacheEntriesByObjectApiName.get(listViewApiName.toLowerCase()) || [];
    return [...keys];
}
function getListSummaryCollectionKeys(objectApiName, recentLists = undefined) {
    const cacheEntriesByObjectApiName = listSummaryCollectionCache.get(objectApiName) || new Map();
    const keys = cacheEntriesByObjectApiName.get(recentLists ? 'true' : 'false') || [];
    const allKeys = recentLists === undefined ? cacheEntriesByObjectApiName.get('true') || [] : [];
    return [...keys, ...allKeys];
}
function addListRecordCollectionKey(objectApiName, listViewApiName, key) {
    const cacheEntryByObjectName = listRecordCollectionCache.get(objectApiName) || new Map();
    if (!cacheEntryByObjectName.size) {
        listRecordCollectionCache.set(objectApiName, cacheEntryByObjectName);
    }
    const keys = cacheEntryByObjectName.get(listViewApiName) || new Set();
    if (!keys.size) {
        cacheEntryByObjectName.set(listViewApiName, keys);
    }
    keys.add(key);
}
function addListSummaryCollectionKey(objectApiName, recentLists, key) {
    const cacheEntryByObjectName = listSummaryCollectionCache.get(objectApiName) || new Map();
    if (!cacheEntryByObjectName.size) {
        listSummaryCollectionCache.set(objectApiName, cacheEntryByObjectName);
    }
    const keys = cacheEntryByObjectName.get(recentLists) || new Set();
    if (!keys.size) {
        cacheEntryByObjectName.set(recentLists, keys);
    }
    keys.add(key);
}
function splitListRecordCollectionKey(key) {
    const keyElements = key.split(':');
    return {
        objectApiName: keyElements[3],
        listViewApiName: keyElements[7],
    };
}
function splitListSummaryCollectionKey(key) {
    const keyElements = key.split(':');
    return {
        objectApiName: keyElements[3],
        recentLists: keyElements[5],
    };
}
function setupListRecordCollectionStoreWatcher(luvio) {
    luvio.storeWatch(LIST_RECORDS_PREFIX, (entries) => {
        for (let i = 0, len = entries.length; i < len; i++) {
            const entry = entries[i];
            if (entry.id.endsWith('__pagination')) {
                continue;
            }
            const { objectApiName, listViewApiName } = splitListRecordCollectionKey(entry.id);
            addListRecordCollectionKey(objectApiName, listViewApiName, entry.id);
        }
    });
}
function setupListSummaryCollectionStoreWatcher(luvio) {
    luvio.storeWatch(LIST_SUMMARY_PREFIX, (entries) => {
        for (let i = 0, len = entries.length; i < len; i++) {
            const entry = entries[i];
            if (entry.id.endsWith('__pagination')) {
                continue;
            }
            const { objectApiName, recentLists } = splitListSummaryCollectionKey(entry.id);
            addListSummaryCollectionKey(objectApiName, recentLists, entry.id);
        }
    });
}

function buildListRefByIdContextKey(listViewId) {
    return `listReferenceById::${listViewId}`;
}
function buildListRefByApiNameContextKey(objectApiName, listViewApiName) {
    return `listReferenceByApiName::${objectApiName.toLowerCase()}:${listViewApiName.toLowerCase()}`;
}
/**
 * Adds a list reference so it can be retrieved with #getListReference later.
 *
 * @param listRef list reference
 */
function addListReference(listRef, context) {
    addListReferenceWithId(listRef, context, listRef.id);
}
/**
 * Adds a list reference with some specified key so it can be retrieved with #getListReference later.
 *
 * @param listRef
 * @param context
 * @param id - Specified Id to use in the context key
 */
function addListReferenceWithId(listRef, context, id) {
    // Add listReference by id if present
    if (id) {
        context.set(buildListRefByIdContextKey(id), listRef);
    }
    // Add listReference by objectApiName & listViewApiName
    context.set(buildListRefByApiNameContextKey(listRef.objectApiName, listRef.listViewApiName || ''), listRef);
}
/**
 * Returns a list reference from the store if it's present.
 *
 * @param query list view to look for
 * @param luvio Luvio
 */
function getListReference(query, context) {
    return query.listViewId
        ? context.get(buildListRefByIdContextKey(query.listViewId))
        : context.get(buildListRefByApiNameContextKey(query.objectApiName || '', query.listViewApiName || ''));
}
/**
 * Reader selections to copy a list info
 */
const LIST_INFO_SELECTIONS = select$1Z().selections;
/**
 * List info private memebers
 */
select$1Z().private;
const LIST_INFO_SELECTIONS_ETAG = [
    ...LIST_INFO_SELECTIONS,
    { kind: 'Scalar', name: 'eTag' },
];
/**
 * Retrieves the snapshot of the list info corresponding to the specified list
 * reference from the store.
 *
 * @param listRef list reference
 * @param luvio Luvio
 */
function getListInfo(luvio, listRef, storeLookup) {
    let mutatedListRef = { ...listRef };
    mutatedListRef.objectApiName = mutatedListRef.objectApiName.toLowerCase();
    mutatedListRef.listViewApiName = mutatedListRef.listViewApiName
        ? mutatedListRef.listViewApiName.toLowerCase()
        : mutatedListRef.listViewApiName;
    const key = keyBuilder$2a(luvio, { ...mutatedListRef });
    return storeLookup({
        recordId: key,
        node: {
            kind: 'Fragment',
            selections: LIST_INFO_SELECTIONS_ETAG,
            private: [],
            version: VERSION$1k,
        },
        variables: {},
    });
}
function buildDefaultsKey(listRef) {
    const { objectApiName, listViewApiName } = listRef;
    return `defaults::${objectApiName.toLowerCase()}:${listViewApiName ? listViewApiName.toLowerCase() : listViewApiName}`;
}
/**
 * Update the default values based on a server response.
 *
 * @param config getListUi config
 * @param serverResponse ListUiRepresentation from the server
 */
function addServerDefaults(config, records, listReference, context) {
    // If the request already contains the potential default information,
    // or the response does not come back with a default or comes back wih an empty array []
    if ((config.sortBy !== undefined && config.sortBy.length > 0) || records.sortBy === null) {
        return;
    }
    const key = buildDefaultsKey(listReference);
    const currentDefaults = context.get(key) || {};
    context.set(key, { ...currentDefaults, sortBy: records.sortBy });
}
/**
 * Returns default values observed on previous requests for a list.
 *
 * @param config getListUi config
 * @returns defaults from previous requests for this list, or {} if no defaults are known
 */
function getServerDefaults(config, context) {
    const listRef = getListReference(config, context);
    if (listRef === undefined) {
        return {};
    }
    const key = buildDefaultsKey(listRef);
    return context.get(key) || {};
}
// Logic to deal with fields on the list view. This would be reasonably straightforward
// except that the server sometimes adds 5 well-known fields to every record & nested
// record in its responses.
// hardcoded fields that the server adds
const DEFAULT_SERVER_FIELDS = [
    'CreatedDate',
    'Id',
    'LastModifiedById',
    'LastModifiedDate',
    'SystemModstamp',
];
/**
 * Adds default fields for every record referenced in a given field name. E.g. if field
 * is "Opportunity.Account.Name" then add default fields "Opportunity.CreatedDate",
 * "Opportunity.Id", ..., "Opportunity.Account.CreatedDate", "Opportunity.Account.Id", ... .
 *
 * @param field explicitly included field
 * @param defaultFields fields object to be updated with the fields that the server will
 *    implicitly add
 */
function addDefaultFields(field, defaultFields) {
    const fieldParts = field.split('.');
    for (let i = 1; i < fieldParts.length; ++i) {
        const fieldPrefix = fieldParts.slice(0, i).join('.');
        for (let j = 0; j < DEFAULT_SERVER_FIELDS.length; ++j) {
            defaultFields[`${fieldPrefix}.${DEFAULT_SERVER_FIELDS[j]}`] = true;
        }
    }
}
/**
 * Indicates if a RecordRepresentation contains a specified field.
 *
 * @param record record
 * @param field field to check for, split on '.'s, with the leading object api name omitted.
 *    E.g. if searching an Opportunity for "Opportunity.Account.Name" this parameter should
 *    be ['Account','Name'].
 */
function recordContainsField(record, field) {
    // make sure it looks like a record and the first piece of the field path has a value
    if (!record ||
        !record.fields ||
        !record.fields[field[0]] ||
        record.fields[field[0]].value === undefined) {
        return false;
    }
    // recurse if nested record
    else if (field.length > 1) {
        return recordContainsField(record.fields[field[0]].value, field.slice(1));
    }
    // found it
    return true;
}
function listFields(luvio, { fields = [], optionalFields = [], sortBy, }, listInfo) {
    const { displayColumns, listReference: { objectApiName }, } = listInfo;
    let fields_ = {}, optionalFields_ = {}, defaultFields_ = {};
    // all the fields in the list info are required
    for (let i = 0, len = displayColumns.length; i < len; ++i) {
        const qualifiedField = `${objectApiName}.${displayColumns[i].fieldApiName}`;
        fields_[qualifiedField] = true;
        addDefaultFields(qualifiedField, defaultFields_);
    }
    // required fields from the component
    for (let i = 0, len = fields.length; i < len; ++i) {
        const qualifiedField = fields[i].startsWith(`${objectApiName}.`)
            ? fields[i]
            : `${objectApiName}.${fields[i]}`;
        if (!fields_[qualifiedField]) {
            fields_[qualifiedField] = true;
            addDefaultFields(qualifiedField, defaultFields_);
        }
    }
    // optional fields from the component
    for (let i = 0, len = optionalFields.length; i < len; ++i) {
        const qualifiedField = optionalFields[i].startsWith(`${objectApiName}.`)
            ? optionalFields[i]
            : `${objectApiName}.${optionalFields[i]}`;
        if (!fields_[qualifiedField]) {
            optionalFields_[qualifiedField] = true;
            addDefaultFields(qualifiedField, defaultFields_);
        }
    }
    const key = keyBuilder$26(luvio, {
        listViewId: listInfo.eTag,
        sortBy: sortBy || null,
        searchTerm: null,
        where: null,
        objectApiName: listInfo.listReference.objectApiName,
        listViewApiName: listInfo.listReference.listViewApiName,
    }) + '__fieldstatus';
    const node = luvio.getNode(key);
    const defaultServerFieldStatus = isGraphNode(node)
        ? node.retrieve()
        : { missingFields: { ...defaultFields_ } };
    return {
        getRecordSelectionFieldSets() {
            const optionalPlusDefaultFields = { ...optionalFields_ };
            const fields = keys(defaultFields_);
            for (let i = 0; i < fields.length; ++i) {
                const field = fields[i];
                if (!fields_[field] && !defaultServerFieldStatus.missingFields[field]) {
                    optionalPlusDefaultFields[field] = true;
                }
            }
            return [keys(fields_).sort(), keys(optionalPlusDefaultFields).sort()];
        },
        processRecords(records) {
            const { missingFields } = defaultServerFieldStatus;
            const fields = keys(missingFields);
            for (let i = 0; i < fields.length; ++i) {
                const field = fields[i], splitField = field.split('.').slice(1);
                for (let i = 0; i < records.length; ++i) {
                    if (recordContainsField(records[i], splitField)) {
                        delete missingFields[field];
                        break;
                    }
                }
            }
            luvio.storePublish(key, defaultServerFieldStatus);
            // snapshots do not subscribe to this key, so no need to broadcast
            return this;
        },
    };
}
function setupNotifyAllListRecordUpdateAvailable(luvio) {
    return (notifyInput) => {
        const keys = getListRecordCollectionKeys(notifyInput.objectApiName, notifyInput.listViewApiName);
        // W-16311716 - Bug is happening because we are removing keys from the cache when
        // the actual data has not changed. This causes a mismatch in this notifyAll cache
        // vs the actual LDS cache. Not removing these keys from the notifyAll cache has
        // no forseen drawbacks
        //removeListRecordCollectionKeys(notifyInput.objectApiName, notifyInput.listViewApiName);
        return luvio.notifyStoreUpdateAvailable(keys);
    };
}
function setupNotifyAllListInfoSummaryUpdateAvailable(luvio) {
    return (notifyInput) => {
        const keys = getListSummaryCollectionKeys(notifyInput.objectApiName, notifyInput.recentLists);
        // W-16311716 - Bug is happening because we are removing keys from the cache when
        // the actual data has not changed. This causes a mismatch in this notifyAll cache
        // vs the actual LDS cache. Not removing these keys from the notifyAll cache has
        // no forseen drawbacks
        //removeListSummaryCollectionKeys(notifyInput.objectApiName, notifyInput.recentLists);
        return luvio.notifyStoreUpdateAvailable(keys);
    };
}

let context$1;
function setContext$1(adapterContext) {
    context$1 = adapterContext;
}
function keyBuilder$22(luvio, params) {
    // lists data can now be fetched using case insensitive urlParams therefore
    // also changing contextStore to use lowercase caching
    const query = {
        objectApiName: params.urlParams.objectApiName.toLowerCase(),
        listViewApiName: params.urlParams.listViewApiName.toLowerCase(),
    };
    // Fetch listReference from internal store to better ensure a cache hit regardless of listViewApiName or listViewId
    const listReference = getListReference(query, context$1);
    if (listReference !== undefined) {
        // Check and use any default values returned from the server (i.e. sortBy)
        const config = { ...params.urlParams, ...params.body };
        const defaults = getServerDefaults(config, context$1);
        // Use default values when sortBy is undefined or an empty Array []
        return keyBuilder$26(luvio, {
            objectApiName: listReference.objectApiName.toLowerCase(),
            listViewApiName: listReference.listViewApiName
                ? listReference.listViewApiName.toLowerCase()
                : listReference.listViewApiName,
            // # removing listViewId from key only supporing getting records using api name
            // listViewId: listReference.id,
            searchTerm: params.body.searchTerm || null,
            where: params.body.where || null,
            sortBy: params.body.sortBy !== undefined && params.body.sortBy.length <= 0
                ? defaults.sortBy || params.body.sortBy || []
                : params.body.sortBy || defaults.sortBy || [],
        });
    }
    // If there are no matching entries in the store, then we haven't fetched any data for this list view yet.
    // Assuming that listViewId is empty and continue on
    return keyBuilder$26(luvio, {
        objectApiName: params.urlParams.objectApiName.toLowerCase(),
        listViewApiName: params.urlParams.listViewApiName.toLowerCase(),
        // # removing listViewId from key only supporing getting records using api name
        // listViewId: '',
        searchTerm: params.body.searchTerm || null,
        where: params.body.where || null,
        sortBy: params.body.sortBy || [],
    });
}

function select$1R(luvio, params) {
    const { fields = [], optionalFields = [] } = params.body;
    return dynamicSelect$7({
        records: {
            name: 'records',
            kind: 'Link',
            fragment: {
                kind: 'Fragment',
                private: ['eTag', 'weakEtag'],
                selections: buildSelectionFromFields(fields, optionalFields),
                version: VERSION$1g
            },
        },
    }, createPaginationParams$4(params));
}
function ingestSuccess$R(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$22(luvio, resourceParams);
    luvio.storeIngest(key, ingest$N, body);
    const optionalFields = resourceParams.body.optionalFields;
    if (optionalFields && optionalFields.length > 0) {
        const normalized = body;
        markMissingOptionalFieldsOnRecords$1(luvio, normalized, optionalFields);
    }
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1R(luvio, resourceParams),
        variables: {},
    }, snapshotRefresh);
    return snapshot;
}
function markMissingOptionalFieldsOnRecords$1(luvio, nomalized, optionalFields) {
    const records = nomalized.records;
    for (let i = 0; i < records.length; i++) {
        const record = records[i];
        const recordKey = record.__ref;
        if (recordKey !== undefined) {
            const node = luvio.getNode(recordKey);
            markMissingOptionalFields(node, optionalFields);
        }
    }
}

function createPaginationParams$4(params) {
    const { body } = params;
    return {
        token: body.pageToken,
        pageSize: body.pageSize === undefined ? 50 : body.pageSize
    };
}
function getResponseCacheKeys$10(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$U(storeKeyMap, luvio, response);
}
function ingestError$K(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$22(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$y,
        namespace: keyPrefix,
        version: VERSION$1e,
        representationName: RepresentationType$U
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$17(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-records/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

/**
 * Examines a set of paginated data & metadata from an UnfulfilledSnapshot and computes a
 * pageToken and pageSize that will minimize the amount of data requested while still
 * satisfying the original request.
 *
 * @param config.name name of the field within data that contains the items
 * @param conifg.data paginated data/metadata from an UnfulfilledSnapshot
 * @param config.pageSize requested pageSize
 * @param config.pagination pagination data/functions from engine
 * @returns pageToken & pageSize to fill in the missing data
 */
function minimizeRequest(config) {
    // the only way to handle missing current or previous token is to ask for the full set of requested records
    if (!config.data || !config.data[config.name] || config.data.previousPageToken === undefined) {
        return {
            pageSize: config.pageSize,
            pageToken: config.pageToken,
        };
    }
    else {
        // compute the offset of the last record that was found
        const { offsetFromToken, tokenForAtMost, paginationMetadata } = config.pagination;
        const pageTokenOffset = offsetFromToken(paginationMetadata, config.data.currentPageToken);
        if (pageTokenOffset < 0) {
            return {
                pageSize: config.pageSize,
                pageToken: config.pageToken,
            };
        }
        const lastFoundOffset = pageTokenOffset + config.data[config.name].length;
        // backup to the nearest offset for which we have a token
        const [newToken, newOffset] = tokenForAtMost(paginationMetadata, lastFoundOffset);
        // recompute pageToken and pageSize for query based on new starting token
        return {
            pageSize: pageTokenOffset - newOffset + config.pageSize,
            pageToken: newToken,
        };
    }
}

function isFulfilledSnapshot(snapshot) {
    return snapshot.state === 'Fulfilled';
}
function isUnfulfilledSnapshot(snapshot) {
    return snapshot.state === 'Unfulfilled';
}
function isStaleSnapshot(snapshot) {
    return snapshot.state === 'Stale';
}
function isErrorSnapshot(snapshot) {
    return snapshot.state === 'Error';
}

const VERSION$1a = "3529c5f7d0eb2206c90a52c6d9f721d4";
function validate$1R(obj, path = 'ListViewSummaryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_listUiUrl = obj.listUiUrl;
        const path_listUiUrl = path + '.listUiUrl';
        if (typeof obj_listUiUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_listUiUrl + '" (at "' + path_listUiUrl + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$Q = 'ListViewSummaryRepresentation';
function keyBuilder$21(luvio, config) {
    return keyPrefix + '::' + RepresentationType$Q + ':' + (config.id === null ? '' : config.id);
}
function keyBuilderFromType$y(luvio, object) {
    const keyParams = {
        id: object.id
    };
    return keyBuilder$21(luvio, keyParams);
}
function normalize$J(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1Q = function ListViewSummaryRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$1a,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'listUiUrl',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$10(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_listUiUrl = existing.listUiUrl;
    const incoming_listUiUrl = incoming.listUiUrl;
    if (!(existing_listUiUrl === incoming_listUiUrl)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    return true;
}
const ingest$J = function ListViewSummaryRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1R(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$y(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$J, "UiApi", VERSION$1a, RepresentationType$Q, equals$10);
    return createLink(key);
};
function getTypeCacheKeys$Q(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$y(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$Q,
        mergeable: false
    });
}

const VERSION$19 = "f4c79fe066da3558499d5ee88c72abcd";
function validate$1Q(obj, path = 'ListViewSummaryCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_count = obj.count;
        const path_count = path + '.count';
        if (typeof obj_count !== 'number' || (typeof obj_count === 'number' && Math.floor(obj_count) !== obj_count)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_count + '" (at "' + path_count + '")');
        }
        const obj_currentPageToken = obj.currentPageToken;
        const path_currentPageToken = path + '.currentPageToken';
        if (typeof obj_currentPageToken !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_lists = obj.lists;
        const path_lists = path + '.lists';
        if (!ArrayIsArray(obj_lists)) {
            return new TypeError('Expected "array" but received "' + typeof obj_lists + '" (at "' + path_lists + '")');
        }
        for (let i = 0; i < obj_lists.length; i++) {
            const obj_lists_item = obj_lists[i];
            const path_lists_item = path_lists + '[' + i + ']';
            if (typeof obj_lists_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_lists_item + '" (at "' + path_lists_item + '")');
            }
        }
        const obj_nextPageToken = obj.nextPageToken;
        const path_nextPageToken = path + '.nextPageToken';
        let obj_nextPageToken_union0 = null;
        const obj_nextPageToken_union0_error = (() => {
            if (typeof obj_nextPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union0_error != null) {
            obj_nextPageToken_union0 = obj_nextPageToken_union0_error.message;
        }
        let obj_nextPageToken_union1 = null;
        const obj_nextPageToken_union1_error = (() => {
            if (obj_nextPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union1_error != null) {
            obj_nextPageToken_union1 = obj_nextPageToken_union1_error.message;
        }
        if (obj_nextPageToken_union0 && obj_nextPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageToken + '")';
            message += '\n' + obj_nextPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        let obj_nextPageUrl_union0 = null;
        const obj_nextPageUrl_union0_error = (() => {
            if (typeof obj_nextPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union0_error != null) {
            obj_nextPageUrl_union0 = obj_nextPageUrl_union0_error.message;
        }
        let obj_nextPageUrl_union1 = null;
        const obj_nextPageUrl_union1_error = (() => {
            if (obj_nextPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union1_error != null) {
            obj_nextPageUrl_union1 = obj_nextPageUrl_union1_error.message;
        }
        if (obj_nextPageUrl_union0 && obj_nextPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageUrl + '")';
            message += '\n' + obj_nextPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_pageSize = obj.pageSize;
        const path_pageSize = path + '.pageSize';
        if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
        }
        const obj_previousPageToken = obj.previousPageToken;
        const path_previousPageToken = path + '.previousPageToken';
        let obj_previousPageToken_union0 = null;
        const obj_previousPageToken_union0_error = (() => {
            if (typeof obj_previousPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union0_error != null) {
            obj_previousPageToken_union0 = obj_previousPageToken_union0_error.message;
        }
        let obj_previousPageToken_union1 = null;
        const obj_previousPageToken_union1_error = (() => {
            if (obj_previousPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union1_error != null) {
            obj_previousPageToken_union1 = obj_previousPageToken_union1_error.message;
        }
        if (obj_previousPageToken_union0 && obj_previousPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageToken + '")';
            message += '\n' + obj_previousPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_previousPageUrl = obj.previousPageUrl;
        const path_previousPageUrl = path + '.previousPageUrl';
        let obj_previousPageUrl_union0 = null;
        const obj_previousPageUrl_union0_error = (() => {
            if (typeof obj_previousPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union0_error != null) {
            obj_previousPageUrl_union0 = obj_previousPageUrl_union0_error.message;
        }
        let obj_previousPageUrl_union1 = null;
        const obj_previousPageUrl_union1_error = (() => {
            if (obj_previousPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union1_error != null) {
            obj_previousPageUrl_union1 = obj_previousPageUrl_union1_error.message;
        }
        if (obj_previousPageUrl_union0 && obj_previousPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageUrl + '")';
            message += '\n' + obj_previousPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_queryString = obj.queryString;
        const path_queryString = path + '.queryString';
        let obj_queryString_union0 = null;
        const obj_queryString_union0_error = (() => {
            if (typeof obj_queryString !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_queryString + '" (at "' + path_queryString + '")');
            }
        })();
        if (obj_queryString_union0_error != null) {
            obj_queryString_union0 = obj_queryString_union0_error.message;
        }
        let obj_queryString_union1 = null;
        const obj_queryString_union1_error = (() => {
            if (obj_queryString !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_queryString + '" (at "' + path_queryString + '")');
            }
        })();
        if (obj_queryString_union1_error != null) {
            obj_queryString_union1 = obj_queryString_union1_error.message;
        }
        if (obj_queryString_union0 && obj_queryString_union1) {
            let message = 'Object doesn\'t match union (at "' + path_queryString + '")';
            message += '\n' + obj_queryString_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_queryString_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recentListsOnly = obj.recentListsOnly;
        const path_recentListsOnly = path + '.recentListsOnly';
        if (typeof obj_recentListsOnly !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_recentListsOnly + '" (at "' + path_recentListsOnly + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$P = 'ListViewSummaryCollectionRepresentation';
function keyBuilder$20(luvio, config) {
    return keyPrefix + '::' + RepresentationType$P + ':' + config.objectApiName + ':' + (config.queryString === null ? '' : config.queryString) + ':' + config.recentListsOnly;
}
function keyBuilderFromType$x(luvio, object) {
    const keyParams = {
        objectApiName: object.objectApiName,
        queryString: object.queryString,
        recentListsOnly: object.recentListsOnly
    };
    return keyBuilder$20(luvio, keyParams);
}
function normalize$I(input, existing, path, luvio, store, timestamp) {
    const input_lists = input.lists;
    const input_lists_id = path.fullPath + '__lists';
    for (let i = 0; i < input_lists.length; i++) {
        const input_lists_item = input_lists[i];
        let input_lists_item_id = input_lists_id + '__' + i;
        input_lists[i] = ingest$J(input_lists_item, {
            fullPath: input_lists_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1P = function ListViewSummaryCollectionRepresentationSelect(paginationParams) {
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: false,
        version: VERSION$19,
        read: (source, reader) => {
            const sink = {};
            if (paginationParams === undefined) {
                return sink;
            }
            const metadata = reader.resolveMetadata(source, PAGINATION_VERSION$1);
            const currentPageMetadata = getPageMetadata$1(metadata, paginationParams);
            const { startOffset, endOffset, metadataProperties } = currentPageMetadata;
            if (metadata !== undefined && startOffset !== undefined && endOffset !== undefined) {
                const itemsProperty = 'lists';
                reader.enterPath(itemsProperty);
                const itemsSource = source[itemsProperty];
                const itemsSink = [];
                const allSink = [];
                for (let i = startOffset; i < endOffset; i++) {
                    reader.enterPath(i);
                    reader.readSingleLink(i, {
                        name: 'lists',
                        kind: 'Link',
                        fragment: select$1Q()
                    }, itemsSource, allSink, i - startOffset);
                    if (reader.getIsDataMissing() === false) {
                        itemsSink[i - startOffset] = allSink[i - startOffset];
                    }
                    reader.exitPath();
                }
                reader.exitPath();
                reader.assignNonScalar(sink, itemsProperty, itemsSink);
            }
            reader.enterPath('currentPageToken');
            reader.readScalar('currentPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('nextPageToken');
            reader.readScalar('nextPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('previousPageToken');
            reader.readScalar('previousPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('pageSize');
            reader.readScalar('pageSize', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('count');
            reader.readScalar('count', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('objectApiName');
            reader.readScalar('objectApiName', source, sink);
            reader.exitPath();
            reader.enterPath('queryString');
            reader.readScalar('queryString', source, sink);
            reader.exitPath();
            reader.enterPath('recentListsOnly');
            reader.readScalar('recentListsOnly', source, sink);
            reader.exitPath();
            return sink;
        },
    };
};
function getPageMetadata$1(paginationMetadata, paginationParams) {
    const metadataProperties = {};
    const sink = {
        metadataProperties
    };
    if (paginationMetadata === undefined) {
        return sink;
    }
    const { token, pageSize } = paginationParams;
    const pageTokenAndOffset = getPageTokenAndOffset$1(paginationMetadata, token);
    if (pageTokenAndOffset === undefined) {
        return sink;
    }
    const [pageToken, startOffset] = pageTokenAndOffset;
    const endOffset = pageEndOffset$1(paginationMetadata, startOffset, pageSize);
    sink.startOffset = startOffset;
    sink.endOffset = endOffset;
    metadataProperties.currentPageToken = pageToken;
    const nextToken = getNextPageToken(paginationMetadata, endOffset);
    if (nextToken !== undefined) {
        metadataProperties.nextPageToken = nextToken;
    }
    const previousToken = getPreviousPageToken(paginationMetadata, startOffset, pageSize);
    if (previousToken !== undefined) {
        metadataProperties.previousPageToken = previousToken;
    }
    metadataProperties.pageSize = pageSize;
    metadataProperties.count = endOffset - startOffset;
    return sink;
}
function equals$$(existing, incoming) {
    const existing_recentListsOnly = existing.recentListsOnly;
    const incoming_recentListsOnly = incoming.recentListsOnly;
    if (!(existing_recentListsOnly === incoming_recentListsOnly)) {
        return false;
    }
    const existing_count = existing.count;
    const incoming_count = incoming.count;
    if (!(existing_count === incoming_count)) {
        return false;
    }
    const existing_pageSize = existing.pageSize;
    const incoming_pageSize = incoming.pageSize;
    if (!(existing_pageSize === incoming_pageSize)) {
        return false;
    }
    const existing_currentPageToken = existing.currentPageToken;
    const incoming_currentPageToken = incoming.currentPageToken;
    if (!(existing_currentPageToken === incoming_currentPageToken)) {
        return false;
    }
    const existing_currentPageUrl = existing.currentPageUrl;
    const incoming_currentPageUrl = incoming.currentPageUrl;
    if (!(existing_currentPageUrl === incoming_currentPageUrl)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_lists = existing.lists;
    const incoming_lists = incoming.lists;
    const equals_lists_items = equalsArray(existing_lists, incoming_lists, (existing_lists_item, incoming_lists_item) => {
        if (!(existing_lists_item.__ref === incoming_lists_item.__ref)) {
            return false;
        }
    });
    if (equals_lists_items === false) {
        return false;
    }
    const existing_nextPageToken = existing.nextPageToken;
    const incoming_nextPageToken = incoming.nextPageToken;
    if (!(existing_nextPageToken === incoming_nextPageToken)) {
        return false;
    }
    const existing_nextPageUrl = existing.nextPageUrl;
    const incoming_nextPageUrl = incoming.nextPageUrl;
    if (!(existing_nextPageUrl === incoming_nextPageUrl)) {
        return false;
    }
    const existing_previousPageToken = existing.previousPageToken;
    const incoming_previousPageToken = incoming.previousPageToken;
    if (!(existing_previousPageToken === incoming_previousPageToken)) {
        return false;
    }
    const existing_previousPageUrl = existing.previousPageUrl;
    const incoming_previousPageUrl = incoming.previousPageUrl;
    if (!(existing_previousPageUrl === incoming_previousPageUrl)) {
        return false;
    }
    const existing_queryString = existing.queryString;
    const incoming_queryString = incoming.queryString;
    if (!(existing_queryString === incoming_queryString)) {
        return false;
    }
    return true;
}
const ingest$I = function ListViewSummaryCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1Q(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$x(luvio, input);
    const existingRecord = store.readEntry(key);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    let incomingRecord = normalize$I(input, store.readEntry(key), {
        fullPath: key,
        parent: path.parent,
        propertyName: path.propertyName,
        ttl: ttlToUse
    }, luvio, store, timestamp);
    const paginationKey = key + '__pagination';
    const existingPaginationMetadata = store.readEntry(paginationKey);
    const { count: count, currentPageToken: token, nextPageToken: nextToken, pageSize: pageSize, previousPageToken: previousToken, lists: items } = input;
    const startOffset = existingPaginationMetadata === undefined ? 0 : offsetFromToken(existingPaginationMetadata, token);
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0 ||
            (existingRecord && existingRecord.lists && existingRecord.lists.length < startOffset)) {
            throw new RangeError('currentPageToken value ' + token + ' is not recognized');
        }
    }
    const incomingPaginationMetadata = {
        [token]: startOffset,
    };
    const nextOffset = startOffset + items.length;
    if (nextToken === null) {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    else {
        incomingPaginationMetadata[nextToken] = nextOffset;
        if (existingPaginationMetadata !== undefined) {
            const listEndOffset = existingPaginationMetadata.__END__;
            if (listEndOffset !== undefined && nextOffset >= listEndOffset) {
                incomingPaginationMetadata.__END__ = undefined;
            }
        }
    }
    if (previousToken !== null) {
        incomingPaginationMetadata[previousToken] = Math.max(startOffset - pageSize, 0);
    }
    const mergedPaginationMetadata = mergeMetadata$1(existingPaginationMetadata, incomingPaginationMetadata);
    if (existingPaginationMetadata === undefined ||
        equalsObject(existingPaginationMetadata, mergedPaginationMetadata, (existingProp, incomingProp) => {
            return existingProp === incomingProp;
        }) === false) {
        luvio.storePublish(paginationKey, mergedPaginationMetadata);
        luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata$1);
    }
    assignMetadataLink(incomingRecord, paginationKey);
    if (existingRecord !== undefined && existingRecord.lists !== undefined) {
        incomingRecord.lists = [
            ...existingRecord.lists.slice(0, startOffset),
            ...incomingRecord.lists,
            ...existingRecord.lists.slice(nextOffset),
        ];
    }
    if (existingRecord === undefined || equals$$(existingRecord, incomingRecord) === false) {
        luvio.storePublish(key, incomingRecord);
    }
    if (ttlToUse !== undefined) {
        const storeMetadataParams = {
            ttl: ttlToUse,
            namespace: "UiApi",
            version: VERSION$19,
            representationName: RepresentationType$P,
            ingestionTimestamp: timestamp,
        };
        luvio.publishStoreMetadata(key, storeMetadataParams);
    }
    return createLink(key);
};
function getTypeCacheKeys$P(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$x(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$P,
        mergeable: true
    });
    rootKeySet.set(rootKey + '__pagination', {
        namespace: keyPrefix,
        representationName: RepresentationType$P,
        mergeable: true
    });
    const input_lists_length = input.lists.length;
    for (let i = 0; i < input_lists_length; i++) {
        getTypeCacheKeys$Q(rootKeySet, luvio, input.lists[i]);
    }
}
const notifyUpdateAvailableFactory$2 = (luvio) => {
    return function notifyListViewSummaryUpdateAvailable(configs) {
        if (process.env.NODE_ENV !== 'production') {
            const requiredKeyParams = ['objectApiName', 'queryString', 'recentListsOnly'];
            configs.forEach(config => {
                if (false === requiredKeyParams.every(req => req in config)) {
                    throw new Error(`one of the configs did not contain all required parameters: ${JSONStringify(ObjectKeys(config))}`);
                }
            });
        }
        const keys = configs.map(c => keyBuilder$20(luvio, c));
        return luvio.notifyStoreUpdateAvailable(keys);
    };
};

function createPaginationParams$3(params) {
    const { queryParams } = params;
    return {
        token: queryParams.pageToken,
        pageSize: queryParams.pageSize === undefined ? 20 : queryParams.pageSize
    };
}
function select$1O(luvio, params) {
    const paginationParams = createPaginationParams$3(params);
    return select$1P(paginationParams);
}
function keyBuilder$1$(luvio, params) {
    return keyBuilder$20(luvio, {
        objectApiName: params.urlParams.objectApiName,
        queryString: params.queryParams.q || null,
        recentListsOnly: params.queryParams.recentListsOnly || false
    });
}
function getResponseCacheKeys$$(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$P(storeKeyMap, luvio, response);
}
function ingestSuccess$Q(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1$(luvio, resourceParams);
    luvio.storeIngest(key, ingest$I, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1O(luvio, resourceParams),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$J(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1$(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$16(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-ui/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$_ = 'getListViewSummaryCollection';
const getListViewSummaryCollection_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('q', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('recentListsOnly', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
const getListViewSummaryCollection_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$_, getListViewSummaryCollection_ConfigPropertyMetadata);
const createResourceParams$_ = /*#__PURE__*/ createResourceParams$13(getListViewSummaryCollection_ConfigPropertyMetadata);
function keyBuilder$1_(luvio, config) {
    const resourceParams = createResourceParams$_(config);
    return keyBuilder$1$(luvio, resourceParams);
}
function typeCheckConfig$13(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListViewSummaryCollection_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$15(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getListViewSummaryCollection_ConfigPropertyMetadata);
    const config = typeCheckConfig$13(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$I(luvio, config) {
    const resourceParams = createResourceParams$_(config);
    return select$1O(luvio, resourceParams);
}
function onFetchResponseSuccess$M(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$Q(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$14(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$N(luvio, config, resourceParams, response) {
    const snapshot = ingestError$J(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$14(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function prepareRequest$6(luvio, config, resourceParams, cacheSnapshot) {
    if (cacheSnapshot === undefined) {
        return createResourceRequest$16(resourceParams);
    }
    const [newToken, newPageSize] = minimizePaginationParams$2(luvio, resourceParams, cacheSnapshot);
    if (newToken === undefined) {
        return createResourceRequest$16(resourceParams);
    }
    return createResourceRequest$16(createResourceParams$_({
        ...config,
        pageSize: newPageSize,
        pageToken: newToken
    }));
}
function minimizePaginationParams$2(luvio, resourceParams, cacheSnapshot) {
    const num = getCachedItemsNumber$3(cacheSnapshot);
    if (num > 0) {
        const paginationMetadata = getPaginationMetadata$3(luvio, resourceParams);
        if (paginationMetadata !== undefined) {
            const { token: configToken, pageSize: configPageSize } = createPaginationParams$3(resourceParams);
            const configTokenOffset = offsetFromToken(paginationMetadata, configToken);
            if (configTokenOffset < 0) {
                return [undefined, -1];
            }
            const maxOffset = configTokenOffset + num;
            const [token, offset] = tokenForAtMost(paginationMetadata, maxOffset);
            if (token !== undefined) {
                return [token, configPageSize - (offset - configTokenOffset)];
            }
        }
    }
    return [undefined, -1];
}
function getCachedItemsNumber$3(cacheSnapshot) {
    const { data } = cacheSnapshot;
    if (data === undefined || !data.lists) {
        return 0;
    }
    const items = data.lists;
    for (let i = 0; i < items.length; i++) {
        if (items[i] === undefined) {
            return i;
        }
    }
    return items.length;
}
function getPaginationMetadata$3(luvio, resourceParams) {
    const key = keyBuilder$1$(luvio, resourceParams);
    const selector = {
        recordId: key,
        node: {
            kind: 'Fragment',
            version: VERSION$19,
            private: [],
            selections: [
                {
                    kind: 'Link',
                    name: '__metadata',
                    fragment: {
                        kind: 'Fragment',
                        version: PAGINATION_VERSION$1,
                        opaque: true,
                        private: [],
                    },
                },
            ],
        },
        variables: {}
    };
    const node = luvio.storeLookup(selector);
    if (node.state !== 'Fulfilled') {
        return;
    }
    return node.data.__metadata;
}
function buildNetworkSnapshot$14(luvio, config, options, cacheSnapshot) {
    const resourceParams = createResourceParams$_(config);
    const request = prepareRequest$6(luvio, config, resourceParams, cacheSnapshot);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$M(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$$(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$N(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$Q(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$14, undefined, true);
}
function buildCachedSnapshotCachePolicy$P(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1_(luvio, config),
        node: adapterFragment$I(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$14(luvio, config, snapshotRefreshOptions)
    });
    if (isUnfulfilledSnapshot$1(cacheSnapshot) && cacheSnapshot.data !== undefined) {
        context.cacheSnapshot = cacheSnapshot;
    }
    return cacheSnapshot;
}
const getListViewSummaryCollectionAdapterFactory = (luvio) => function UiApi__getListViewSummaryCollection(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$15(untrustedConfig, getListViewSummaryCollection_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$P, buildNetworkSnapshotCachePolicy$Q);
};

function createPaginationParams$2(params) {
    const { queryParams } = params;
    return {
        token: queryParams.pageToken,
        pageSize: queryParams.pageSize === undefined ? 50 : queryParams.pageSize
    };
}
function keyBuilder$1Z(luvio, params) {
    return keyBuilder$25(luvio, {
        listViewApiName: null,
        objectApiName: params.urlParams.objectApiName,
        type: "mru",
        sortBy: params.queryParams.sortBy || null
    });
}
function createResourceRequest$15(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/mru-list-ui/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$Z = 'getMruListUi';
const getMruListUi_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
];
const getMruListUi_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$Z, getMruListUi_ConfigPropertyMetadata);
const createResourceParams$Z = /*#__PURE__*/ createResourceParams$13(getMruListUi_ConfigPropertyMetadata);
function typeCheckConfig$12(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getMruListUi_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$14(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getMruListUi_ConfigPropertyMetadata);
    const config = typeCheckConfig$12(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

function createResourceRequest$14(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/mru-list-records/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

/**
 * Returns a BuildNetworkSnapshot function that always returns a Promise<ErrorSnapshot>.
 *
 * @param luvio Luvio instance
 * @param status status code for ErrorSnapshot, defaults to 400
 * @param statusText status text for ErrorSnapshot, defaults to 'data is not fetchable'
 * @returns BuildNetworkSnapshot that always returns Promise<ErrorSnapshot>
 */
function buildNotFetchableNetworkSnapshot(luvio, status = 400, statusText = 'data is not fetchable') {
    return (_context) => Promise.resolve(luvio.errorSnapshot({
        status,
        statusText,
        ok: false,
        body: undefined,
        headers: {},
        errorType: 'fetchResponse',
    }));
}

function isPromise(value) {
    return value.then !== undefined;
}

// eslint-disable-next-line @salesforce/lds/no-invalid-todo
// TODO RAML - this more properly goes in the generated resource files
const DEFAULT_PAGE_SIZE$1 = 50;
// make local copies of the adapter configs so we can ignore other getListUi config parameters to match
// lds222 behavior
const getMruListUi_ConfigPropertyNames_augmented = {
    ...getMruListUi_ConfigPropertyNames,
    parameters: {
        ...getMruListUi_ConfigPropertyNames.parameters,
        optional: [
            ...getMruListUi_ConfigPropertyNames.parameters.optional,
            'listViewApiName',
            'listViewId',
        ],
    },
};
function buildListUiFragment$1(config, fields) {
    const resourceParams = createResourceParams$Z(config);
    const paginationParams = createPaginationParams$2(resourceParams);
    const recordSelectParams = {
        records: {
            name: 'records',
            kind: 'Link',
            fragment: {
                kind: 'Fragment',
                private: ['eTag', 'weakEtag'],
                selections: buildSelectionFromFields(...fields.getRecordSelectionFieldSets()),
                version: VERSION$1g,
            },
        },
    };
    const listRecordCollectionSelect = dynamicSelect$7(recordSelectParams, paginationParams);
    const listRecordCollectionSelectParams = {
        records: {
            name: 'records',
            kind: 'Link',
            fragment: listRecordCollectionSelect,
        },
    };
    return dynamicSelect$6(listRecordCollectionSelectParams, paginationParams);
}
function buildSnapshotRefresh_getMruListUi(luvio, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot_getMruListUi(luvio, config),
    };
}
function onResourceSuccess_getMruListUi(luvio, config, response) {
    const { body } = response;
    const listInfo = body.info;
    const listUiKey = keyBuilder$25(luvio, {
        ...listInfo.listReference,
        sortBy: body.records.sortBy,
    });
    // grab relevant bits before ingest destroys the structure
    const fields = listFields(luvio, config, listInfo);
    fields.processRecords(body.records.records);
    // build the selector while the list info is still easily accessible
    const fragment = buildListUiFragment$1(config, fields);
    luvio.storeIngest(listUiKey, ingest$M, body);
    const snapshot = luvio.storeLookup({
        recordId: listUiKey,
        node: fragment,
        variables: {},
    }, buildSnapshotRefresh_getMruListUi(luvio, config));
    return luvio.storeBroadcast().then(() => snapshot);
}
function onResourceError_getMruListUi(luvio, config, err) {
    return Promise.resolve(luvio.errorSnapshot(err, buildSnapshotRefresh_getMruListUi(luvio, config)));
}
function buildCachedSnapshot$8(luvio, storeLookup, config, listInfo, fields) {
    const listFields_ = fields || listFields(luvio, config, listInfo);
    const resourceParams = createResourceParams$Z(config);
    const selector = {
        recordId: keyBuilder$1Z(luvio, resourceParams),
        node: buildListUiFragment$1(config, listFields_),
        variables: {},
    };
    return storeLookup(selector, buildSnapshotRefresh_getMruListUi(luvio, config));
}
/**
 * Builds, sends, and processes the result of a mru-list-ui request, ignoring any cached
 * data for the list.
 *
 * @param luvio Luvio engine
 * @param config wire config
 */
function buildNetworkSnapshot_getMruListUi(luvio, config, dispatchOptions) {
    const params = createResourceParams$Z(config);
    const request = createResourceRequest$15(params);
    return luvio.dispatchResourceRequest(request, dispatchOptions).then((response) => {
        const { body } = response;
        // response might have records.sortBy in csv format but keyBuilder/ingestion
        // functions expect it to be an array so coerce it here if needed
        const sortBy = body.records.sortBy;
        if (sortBy && typeof sortBy === 'string') {
            body.records.sortBy = sortBy.split(',');
        }
        return luvio.handleSuccessResponse(() => onResourceSuccess_getMruListUi(luvio, config, response), () => {
            const cache = new StoreKeyMap();
            getTypeCacheKeys$T(cache, luvio, body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => onResourceError_getMruListUi(luvio, config, err));
    });
}
function prepareRequest_getMruListRecords(luvio, config, listInfo, snapshot) {
    const { fields, optionalFields, pageSize, pageToken, sortBy } = config;
    const queryParams = {
        fields,
        optionalFields,
        pageSize,
        pageToken,
        sortBy,
    };
    const request = createResourceRequest$14({
        urlParams: {
            objectApiName: config.objectApiName,
        },
        queryParams,
    });
    if (snapshot) {
        const paginationKey = paginationKeyBuilder(luvio, {
            listViewId: listInfo.eTag,
            searchTerm: null,
            where: null,
            sortBy: config.sortBy === undefined ? null : config.sortBy,
            objectApiName: listInfo.listReference.objectApiName.toLowerCase(),
            listViewApiName: listInfo.listReference.listViewApiName
                ? listInfo.listReference.listViewApiName.toLowerCase()
                : listInfo.listReference.listViewApiName,
        });
        const selector = {
            recordId: paginationKey,
            node: {
                kind: 'Fragment',
                private: [],
                opaque: true,
                version: PAGINATION_VERSION$1,
            },
            variables: {},
        };
        const metadataSnapshot = luvio.storeLookup(selector);
        const paginationMetadata = metadataSnapshot.state === 'Fulfilled' ? metadataSnapshot.data : {};
        // compute the minimum number of records we need to request
        const { pageSize, pageToken } = minimizeRequest({
            data: snapshot.data ? snapshot.data.records : null,
            name: 'records',
            pageSize: config.pageSize || DEFAULT_PAGE_SIZE$1,
            pageToken: config.pageToken,
            pagination: {
                offsetFromToken,
                tokenForAtMost,
                paginationMetadata,
            },
        });
        // update request, but don't harden default values unless they were already present
        if (pageSize !== DEFAULT_PAGE_SIZE$1 || request.queryParams.pageSize !== undefined) {
            request.queryParams.pageSize = pageSize;
        }
        if (pageToken !== undefined || request.queryParams.pageToken !== undefined) {
            request.queryParams.pageToken = pageToken;
        }
    }
    return request;
}
// Only call this function if you are certain the list view hasn't changed (ie:
// the listInfoEtag in the body is the same as the cached listInfo.eTag)
function onResourceSuccess_getMruListRecords(luvio, config, listInfo, response) {
    const { body } = response;
    const { listInfoETag } = body;
    const fields = listFields(luvio, config, listInfo).processRecords(body.records);
    luvio.storeIngest(keyBuilder$26(luvio, {
        listViewId: listInfoETag,
        searchTerm: null,
        where: null,
        sortBy: body.sortBy,
        objectApiName: listInfo.listReference.objectApiName.toLowerCase(),
        listViewApiName: listInfo.listReference.listViewApiName
            ? listInfo.listReference.listViewApiName.toLowerCase()
            : listInfo.listReference.listViewApiName,
    }), ingest$N, body);
    const snapshot = buildCachedSnapshot$8(luvio, luvio.storeLookup.bind(luvio), config, listInfo, fields);
    return luvio.storeBroadcast().then(() => snapshot);
}
function onResourceError_getMruListRecords(luvio, config, listInfo, err) {
    const errorSnapshot = luvio.errorSnapshot(err, buildSnapshotRefresh_getMruListUi(luvio, config));
    luvio.storeIngestError(keyBuilder$25(luvio, {
        ...listInfo.listReference,
        sortBy: config.sortBy === undefined ? null : config.sortBy,
    }), errorSnapshot);
    return luvio.storeBroadcast().then(() => errorSnapshot);
}
function buildNetworkSnapshot_getMruListRecords(luvio, config, listInfo, dispatchOptions, snapshot) {
    const request = prepareRequest_getMruListRecords(luvio, config, listInfo, snapshot);
    return luvio
        .dispatchResourceRequest(request, dispatchOptions)
        .then((response) => {
        const { body } = response;
        // fall back to mru-list-ui if list view has changed
        if (body.listInfoETag !== listInfo.eTag) {
            return buildNetworkSnapshot_getMruListUi(luvio, config, dispatchOptions);
        }
        // response might have records.sortBy in csv format but keyBuilder/ingestion
        // functions expect it to be an array so coerce it here if needed
        const { sortBy } = body;
        if (sortBy && typeof sortBy === 'string') {
            body.sortBy = sortBy.split(',');
        }
        // else ingest
        return luvio.handleSuccessResponse(() => onResourceSuccess_getMruListRecords(luvio, config, listInfo, response), () => {
            const cache = new StoreKeyMap();
            getTypeCacheKeys$U(cache, luvio, body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return onResourceError_getMruListRecords(luvio, config, listInfo, err);
        });
    });
}
function buildCachedListInfoSnapshot$1(context, storeLookup, luvio) {
    const { config } = context;
    // try to get a list reference and a list info for the list; this should come back
    // non-null if we have the list info cached
    return getListInfo(luvio, {
        id: null,
        listViewApiName: null,
        objectApiName: config.objectApiName.toLowerCase(),
        type: 'mru',
    }, storeLookup);
}
function buildCachedListUiSnapshot$1(context, storeLookup) {
    const { config, listInfo, luvio } = context;
    if (listInfo !== undefined) {
        context.listUi = buildCachedSnapshot$8(luvio, storeLookup, config, listInfo);
        return context.listUi;
    }
}
function buildNetworkListUiSnapshot$1(context, coercedAdapterRequestContext) {
    const { config, listInfo, listUi, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    // make the full list ui request if any of the following is true:
    //
    // - the list info was not found
    // - we couldn't build enough of the list ui to locate any record data
    // - we found the complete cached list ui; this is somewhat counterintuitive,
    //   but it happens when the cache policy has decided to refetch cached data
    if (!listInfo ||
        !listUi ||
        !listUi.data ||
        isFulfilledSnapshot(listUi) ||
        isStaleSnapshot(listUi)) {
        return buildNetworkSnapshot_getMruListUi(luvio, config, dispatchOptions);
    }
    // we *should* only be missing records and/or tokens at this point; send a list-records
    // request to fill them in
    return buildNetworkSnapshot_getMruListRecords(luvio, config, listInfo, dispatchOptions, listUi);
}
const factory$i = (luvio) => function getMruListUi(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$14(untrustedConfig, getMruListUi_ConfigPropertyNames_augmented);
    if (config === null) {
        return null;
    }
    const definedRequestContext = requestContext || {};
    // try to find a cached ListInfoRepresentation
    const listInfoPromiseOrSnapshot = luvio.applyCachePolicy(definedRequestContext, { config, luvio }, buildCachedListInfoSnapshot$1, buildNotFetchableNetworkSnapshot(luvio));
    // build the ListUiRepresentation from the cached ListInfoRepresentation (if any)
    const processListInfo = (listInfoSnapshot) => {
        const listInfo = isFulfilledSnapshot(listInfoSnapshot) || isStaleSnapshot(listInfoSnapshot)
            ? listInfoSnapshot.data
            : undefined;
        return luvio.applyCachePolicy(definedRequestContext, { config, listInfo, luvio }, buildCachedListUiSnapshot$1, buildNetworkListUiSnapshot$1);
    };
    return isPromise(listInfoPromiseOrSnapshot)
        ? listInfoPromiseOrSnapshot.then(processListInfo)
        : processListInfo(listInfoPromiseOrSnapshot);
};

const contextId$5 = `${keyPrefix}__getListUi`;
// eslint-disable-next-line @salesforce/lds/no-invalid-todo
// TODO RAML - this more properly goes in the generated resource files
const DEFAULT_PAGE_SIZE = 50;
// make local copies of the adapter configs so we can have them ignore each other's config parameters
// to match lds222 behavior
const getListUiByApiName_ConfigPropertyNames_augmented = {
    ...getListUiByApiName_ConfigPropertyNames,
    parameters: {
        ...getListUiByApiName_ConfigPropertyNames.parameters,
        optional: [...getListUiByApiName_ConfigPropertyNames.parameters.optional, 'listViewId'],
    },
};
const getListUiByListViewId_ConfigPropertyNames_augmented = {
    ...getListUiByListViewId_ConfigPropertyNames,
    parameters: {
        ...getListUiByListViewId_ConfigPropertyNames.parameters,
        optional: [
            ...getListUiByListViewId_ConfigPropertyNames.parameters.optional,
            'listViewApiName',
            'objectApiName',
        ],
    },
};
function getSortBy(config, context) {
    if (config.sortBy !== undefined) {
        return config.sortBy;
    }
    const defaults = getServerDefaults(config, context);
    if (defaults.sortBy !== undefined) {
        return defaults.sortBy;
    }
    return null;
}
function buildListUiFragment(config, context, fields) {
    const defaultedConfig = { ...getServerDefaults(config, context), ...config };
    let paginationParams;
    if (isGetListUiByListViewIdConfig(defaultedConfig)) {
        const resourceParams = createResourceParams$$(defaultedConfig);
        paginationParams = createPaginationParams$5(resourceParams);
    }
    else if (isGetListUiByApiNameConfig(defaultedConfig)) {
        const resourceParams = createResourceParams$10(defaultedConfig);
        paginationParams =
            createPaginationParams$6(resourceParams);
    }
    const recordSelectParams = {
        records: {
            name: 'records',
            kind: 'Link',
            fragment: {
                kind: 'Fragment',
                private: ['eTag', 'weakEtag'],
                selections: buildSelectionFromFields(...fields.getRecordSelectionFieldSets()),
                version: VERSION$1g,
            },
        },
    };
    const listRecordCollectionSelect = dynamicSelect$7(recordSelectParams, paginationParams);
    const listRecordCollectionSelectParams = {
        records: {
            name: 'records',
            kind: 'Link',
            fragment: listRecordCollectionSelect,
        },
    };
    return dynamicSelect$6(listRecordCollectionSelectParams, paginationParams);
}
function buildCachedSnapshot$7(luvio, storeLookup, context, config, listInfo, fields) {
    const listUiKey = keyBuilder$25(luvio, {
        ...listInfo.listReference,
        sortBy: getSortBy(config, context),
    });
    // ok to pass luvio here since listFields() ignores TTL when getting cached field information
    const listFields_ = fields || listFields(luvio, config, listInfo);
    const selector = {
        recordId: listUiKey,
        node: buildListUiFragment(config, context, listFields_),
        variables: {},
    };
    return storeLookup(selector, buildSnapshotRefresh_getListUi(luvio, context, config));
}
function buildSnapshotRefresh_getListUi(luvio, context, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot_getListUi(luvio, context, config, undefined),
    };
}
function prepareRequest_getListUi(config) {
    const { fields, optionalFields, pageSize, pageToken, sortBy } = config;
    const queryParams = {
        fields,
        optionalFields,
        pageSize,
        pageToken,
        sortBy,
    };
    let request;
    if (isGetListUiByApiNameConfig(config)) {
        request = createResourceRequest$1a({
            urlParams: {
                listViewApiName: config.listViewApiName,
                objectApiName: config.objectApiName,
            },
            queryParams,
        });
    }
    else if (isGetListUiByListViewIdConfig(config)) {
        request = createResourceRequest$19({
            urlParams: { listViewId: config.listViewId },
            queryParams,
        });
    }
    else {
        // eslint-disable-next-line @salesforce/lds/no-error-in-production
        throw new Error('unrecognized config');
    }
    return request;
}
function onResourceSuccess_getListUi(luvio, context, config, response) {
    const { body } = response, listInfo = body.info, { listReference } = listInfo;
    const listUiKey = keyBuilder$25(luvio, {
        ...listReference,
        sortBy: body.records.sortBy,
    });
    // grab relevant bits before ingest destroys the structure
    const fields = listFields(luvio, config, listInfo);
    fields.processRecords(body.records.records);
    // remember the id/name of this list
    addListReference(listReference, context);
    // remember any default values that the server filled in
    addServerDefaults(config, body.records, listReference, context);
    // build the selector while the list info is still easily accessible
    const fragment = buildListUiFragment(config, context, fields);
    luvio.storeIngest(listUiKey, ingest$M, body);
    const snapshot = luvio.storeLookup({
        recordId: listUiKey,
        node: fragment,
        variables: {},
    }, buildSnapshotRefresh_getListUi(luvio, context, config));
    return luvio.storeBroadcast().then(() => snapshot);
}
function onResourceError_getListUi(luvio, context, config, err) {
    return Promise.resolve(luvio.errorSnapshot(err, buildSnapshotRefresh_getListUi(luvio, context, config)));
}
/**
 * Builds, sends, and processes the result of a list-ui request, ignoring any cached
 * data for the list view.
 *
 * @param luvio Luvio engine
 * @param config wire config
 */
function buildNetworkSnapshot_getListUi(luvio, context, config, dispatchOptions) {
    const request = prepareRequest_getListUi(config);
    return luvio.dispatchResourceRequest(request, dispatchOptions).then((response) => {
        const { body } = response;
        // response might have records.sortBy in csv format but keyBuilder/ingestion
        // functions expect it to be an array so coerce it here if needed
        const sortBy = body.records.sortBy;
        if (sortBy && typeof sortBy === 'string') {
            body.records.sortBy = sortBy.split(',');
        }
        return luvio.handleSuccessResponse(() => onResourceSuccess_getListUi(luvio, context, config, response), () => {
            const cache = new StoreKeyMap();
            getTypeCacheKeys$T(cache, luvio, body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return onResourceError_getListUi(luvio, context, config, err);
        });
    });
}
function prepareRequest_getListRecords(luvio, context, config, listInfo, snapshot) {
    const { fields, optionalFields, pageSize, pageToken, sortBy } = config;
    const queryParams = {
        fields,
        optionalFields,
        pageSize,
        pageToken,
        sortBy,
    };
    const body = {
        fields,
        optionalFields,
        pageSize,
        pageToken,
        sortBy,
    };
    let request;
    if (isGetListUiByApiNameConfig(config)) {
        request = createResourceRequest$17({
            urlParams: {
                listViewApiName: config.listViewApiName,
                objectApiName: config.objectApiName,
            },
            body,
        });
    }
    else if (isGetListUiByListViewIdConfig(config)) {
        request = createResourceRequest$18({
            urlParams: { listViewId: config.listViewId },
            queryParams,
        });
    }
    else {
        // eslint-disable-next-line @salesforce/lds/no-error-in-production
        throw new Error('how did MRU config get here?');
    }
    let releaseKeys = () => { };
    if (snapshot) {
        if (snapshot.state !== 'Error') {
            const { recordId, seenRecords } = snapshot;
            const snapshotRetainedIds = seenRecords === undefined ? [recordId] : [recordId, ...seenRecords.keysAsArray()];
            const snapshotKeys = [];
            snapshotRetainedIds.forEach((key) => snapshotKeys.push(key));
            releaseKeys = luvio.storeRetain(snapshotKeys);
        }
        const paginationKey = paginationKeyBuilder(luvio, {
            listViewId: listInfo.eTag,
            searchTerm: null,
            where: null,
            sortBy: getSortBy(config, context),
            objectApiName: listInfo.listReference.objectApiName.toLowerCase(),
            listViewApiName: listInfo.listReference.listViewApiName
                ? listInfo.listReference.listViewApiName.toLowerCase()
                : listInfo.listReference.listViewApiName,
        });
        const selector = {
            recordId: paginationKey,
            node: {
                kind: 'Fragment',
                private: [],
                opaque: true,
                version: PAGINATION_VERSION$1,
            },
            variables: {},
        };
        const metadataSnapshot = luvio.storeLookup(selector);
        const paginationMetadata = metadataSnapshot.state === 'Fulfilled' ? metadataSnapshot.data : {};
        // compute the minimum number of records we need to request
        const { pageSize, pageToken } = minimizeRequest({
            data: snapshot.data ? snapshot.data.records : null,
            name: 'records',
            pageSize: config.pageSize || DEFAULT_PAGE_SIZE,
            pageToken: config.pageToken,
            pagination: {
                offsetFromToken,
                tokenForAtMost,
                paginationMetadata,
            },
        });
        // update request, but don't harden default values unless they were already present
        if (pageSize !== DEFAULT_PAGE_SIZE || request.queryParams.pageSize !== undefined) {
            request.queryParams.pageSize = pageSize;
        }
        if (pageToken || request.queryParams.pageToken !== undefined) {
            request.queryParams.pageToken = pageToken;
        }
    }
    return {
        request: request,
        releaseKeys: releaseKeys,
    };
}
// Only call this function if you are certain the list view hasn't changed (ie:
// the listInfoEtag in the body is the same as the cached listInfo.eTag)
function onResourceSuccess_getListRecords(luvio, context, config, listInfo, response, releaseKeys) {
    const { body } = response;
    const { listInfoETag } = body;
    const fields = listFields(luvio, config, listInfo).processRecords(body.records);
    luvio.storeIngest(keyBuilder$26(luvio, {
        listViewId: listInfoETag,
        searchTerm: null,
        where: null,
        sortBy: body.sortBy,
        objectApiName: listInfo.listReference.objectApiName.toLowerCase(),
        listViewApiName: listInfo.listReference.listViewApiName
            ? listInfo.listReference.listViewApiName.toLowerCase()
            : listInfo.listReference.listViewApiName,
    }), ingest$N, body);
    const snapshot = buildCachedSnapshot$7(luvio, luvio.storeLookup.bind(luvio), context, config, listInfo, fields);
    releaseKeys();
    return luvio.storeBroadcast().then(() => snapshot);
}
function onResourceError_getListRecords(luvio, context, config, listInfo, err, releaseKeys) {
    const errorSnapshot = luvio.errorSnapshot(err);
    luvio.storeIngestError(keyBuilder$25(luvio, {
        ...listInfo.listReference,
        sortBy: getSortBy(config, context),
    }), errorSnapshot);
    releaseKeys();
    return luvio.storeBroadcast().then(() => errorSnapshot);
}
function buildNetworkSnapshot_getListRecords(luvio, context, config, listInfo, dispatchOptions, snapshot) {
    const { request, releaseKeys } = prepareRequest_getListRecords(luvio, context, config, listInfo, snapshot);
    return luvio.dispatchResourceRequest(request).then((response) => {
        const { body } = response;
        // fall back to list-ui if list view has changed
        if (body.listInfoETag !== listInfo.eTag) {
            return buildNetworkSnapshot_getListUi(luvio, context, config, dispatchOptions);
        }
        // response might have records.sortBy in csv format but keyBuilder/ingestion
        // functions expect it to be an array so coerce it here if needed
        const { sortBy } = body;
        if (sortBy && typeof sortBy === 'string') {
            body.sortBy = sortBy.split(',');
        }
        // else ingest
        return luvio.handleSuccessResponse(() => onResourceSuccess_getListRecords(luvio, context, config, listInfo, response, releaseKeys), () => {
            const cache = new StoreKeyMap();
            getTypeCacheKeys$U(cache, luvio, body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return onResourceError_getListRecords(luvio, context, config, listInfo, err, releaseKeys);
        });
    });
}
function buildCachedListInfoSnapshot(context, storeLookup, luvio) {
    const { adapterContext, config } = context;
    // try to get a list reference and a list info for the list; this should come back
    // non-null if we have the list info cached
    const listRef = getListReference(config, adapterContext);
    // no listRef means we can't even attempt to build a cached snapshot
    // so make a full list-ui request
    if (listRef === undefined) {
        return;
    }
    return getListInfo(luvio, listRef, storeLookup);
}
function buildCachedListUiSnapshot(context, storeLookup) {
    const { adapterContext, config, listInfo, luvio } = context;
    if (listInfo !== undefined) {
        context.listUi = buildCachedSnapshot$7(luvio, storeLookup, adapterContext, config, listInfo);
        return context.listUi;
    }
}
function buildNetworkListUiSnapshot(context, coercedAdapterRequestContext) {
    const { adapterContext, config, listInfo, listUi, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    // make the full list ui request if any of the following is true:
    //
    // - the list info was not found
    // - we couldn't build enough of the list ui to locate any record data
    // - we found the complete cached list ui; this is somewhat counterintuitive,
    //   but it happens when the cache policy has decided to refetch cached data
    if (!listInfo ||
        !listUi ||
        !listUi.data ||
        isFulfilledSnapshot(listUi) ||
        isStaleSnapshot(listUi)) {
        return buildNetworkSnapshot_getListUi(luvio, adapterContext, config, dispatchOptions);
    }
    // we *should* only be missing records and/or tokens at this point; send a list-records
    // request to fill them in
    return buildNetworkSnapshot_getListRecords(luvio, adapterContext, config, listInfo, dispatchOptions, listUi);
}
// functions to discern config variations
function isGetListUiByApiNameConfig(config) {
    return config.listViewApiName !== undefined;
}
function looksLikeGetListUiByApiNameConfig(untrustedConfig) {
    return (untrustedIsObject(untrustedConfig) &&
        untrustedConfig.objectApiName &&
        untrustedConfig.listViewApiName);
}
function isGetListUiByListViewIdConfig(config) {
    return !!config.listViewId;
}
function looksLikeGetListUiByListViewIdConfig(untrustedConfig) {
    return (untrustedIsObject(untrustedConfig) &&
        untrustedConfig.listViewId);
}
function looksLikeGetListViewSummaryCollectionConfig(untrustedConfig) {
    return (untrustedIsObject(untrustedConfig) &&
        untrustedConfig.objectApiName &&
        !untrustedConfig.listViewId &&
        !untrustedConfig.listViewApiName);
}
function looksLikeGetMruListUiConfig(untrustedConfig) {
    // the MRU symbol is a carryover hack from 222 and doesn't show up in any
    // of the generated config types, so we cast to any in order to check for it
    return untrustedIsObject(untrustedConfig) && untrustedConfig.listViewApiName === MRU;
}
function validateGetListUiConfig(untrustedConfig) {
    return looksLikeGetListUiByApiNameConfig(untrustedConfig)
        ? validateAdapterConfig$17(untrustedConfig, getListUiByApiName_ConfigPropertyNames_augmented)
        : looksLikeGetListUiByListViewIdConfig(untrustedConfig)
            ? validateAdapterConfig$16(untrustedConfig, getListUiByListViewId_ConfigPropertyNames_augmented)
            : null;
}
// the listViewApiName value to pass to getListUi() to request the MRU list
const MRU = Symbol.for('MRU');
const factory$h = (luvio) => {
    // adapter implementation for getListUiBy*
    const listUiAdapter = (untrustedConfig, adapterContext, requestContext) => {
        const config = validateGetListUiConfig(untrustedConfig);
        if (config === null) {
            return null;
        }
        const definedRequestContext = requestContext || {};
        // try to find a cached ListInfoRepresentation
        const listInfoPromiseOrSnapshot = luvio.applyCachePolicy(definedRequestContext, { adapterContext, config, luvio }, buildCachedListInfoSnapshot, buildNotFetchableNetworkSnapshot(luvio));
        // build the ListUiRepresentation from the cached ListInfoRepresentation (if any)
        const processListInfo = (listInfoSnapshot) => {
            const listInfo = isFulfilledSnapshot(listInfoSnapshot) || isStaleSnapshot(listInfoSnapshot)
                ? listInfoSnapshot.data
                : undefined;
            return luvio.applyCachePolicy(definedRequestContext, { adapterContext, config, listInfo, luvio }, buildCachedListUiSnapshot, buildNetworkListUiSnapshot);
        };
        return isPromise(listInfoPromiseOrSnapshot)
            ? listInfoPromiseOrSnapshot.then(processListInfo)
            : processListInfo(listInfoPromiseOrSnapshot);
    };
    let listViewSummaryCollectionAdapter = null;
    let mruAdapter = null;
    // delegate to various other adapter based on what config looks like; note that the adapters
    // we delegate to are responsible for returning refreshable results
    return luvio.withContext(function UiApi__custom_getListUi(untrustedConfig, adapterContext, requestContext) {
        // if the MRU symbol is there then just return the getMruListUi adapter
        if (looksLikeGetMruListUiConfig(untrustedConfig)) {
            if (mruAdapter === null) {
                mruAdapter = factory$i(luvio);
            }
            // the symbol in the listViewApiName is just a hack so we can recognize the request as MRU
            const mruConfig = { ...untrustedConfig };
            delete mruConfig.listViewApiName;
            return mruAdapter(mruConfig, requestContext);
        }
        // if config has objectApiName but no listViewId or listViewApiName then hand off
        // to listViewSummaryCollectionAdapter
        if (looksLikeGetListViewSummaryCollectionConfig(untrustedConfig)) {
            if (listViewSummaryCollectionAdapter === null) {
                listViewSummaryCollectionAdapter =
                    getListViewSummaryCollectionAdapterFactory(luvio);
            }
            return listViewSummaryCollectionAdapter(untrustedConfig, requestContext);
        }
        // see if config looks like a listViewId or listViewApiName request
        if (looksLikeGetListUiByApiNameConfig(untrustedConfig) ||
            looksLikeGetListUiByListViewIdConfig(untrustedConfig)) {
            return listUiAdapter(untrustedConfig, adapterContext, requestContext);
        }
        return null;
    }, { contextId: contextId$5 });
};

function validate$1P(obj, path = 'ChildRelationshipRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_childObjectApiName = obj.childObjectApiName;
        const path_childObjectApiName = path + '.childObjectApiName';
        if (typeof obj_childObjectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_childObjectApiName + '" (at "' + path_childObjectApiName + '")');
        }
        const obj_fieldName = obj.fieldName;
        const path_fieldName = path + '.fieldName';
        if (typeof obj_fieldName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldName + '" (at "' + path_fieldName + '")');
        }
        const obj_junctionIdListNames = obj.junctionIdListNames;
        const path_junctionIdListNames = path + '.junctionIdListNames';
        if (!ArrayIsArray(obj_junctionIdListNames)) {
            return new TypeError('Expected "array" but received "' + typeof obj_junctionIdListNames + '" (at "' + path_junctionIdListNames + '")');
        }
        for (let i = 0; i < obj_junctionIdListNames.length; i++) {
            const obj_junctionIdListNames_item = obj_junctionIdListNames[i];
            const path_junctionIdListNames_item = path_junctionIdListNames + '[' + i + ']';
            if (typeof obj_junctionIdListNames_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_junctionIdListNames_item + '" (at "' + path_junctionIdListNames_item + '")');
            }
        }
        const obj_junctionReferenceTo = obj.junctionReferenceTo;
        const path_junctionReferenceTo = path + '.junctionReferenceTo';
        if (!ArrayIsArray(obj_junctionReferenceTo)) {
            return new TypeError('Expected "array" but received "' + typeof obj_junctionReferenceTo + '" (at "' + path_junctionReferenceTo + '")');
        }
        for (let i = 0; i < obj_junctionReferenceTo.length; i++) {
            const obj_junctionReferenceTo_item = obj_junctionReferenceTo[i];
            const path_junctionReferenceTo_item = path_junctionReferenceTo + '[' + i + ']';
            if (typeof obj_junctionReferenceTo_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_junctionReferenceTo_item + '" (at "' + path_junctionReferenceTo_item + '")');
            }
        }
        const obj_relationshipName = obj.relationshipName;
        const path_relationshipName = path + '.relationshipName';
        if (typeof obj_relationshipName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_relationshipName + '" (at "' + path_relationshipName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1O(obj, path = 'FilteredLookupInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_controllingFields = obj.controllingFields;
        const path_controllingFields = path + '.controllingFields';
        if (!ArrayIsArray(obj_controllingFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_controllingFields + '" (at "' + path_controllingFields + '")');
        }
        for (let i = 0; i < obj_controllingFields.length; i++) {
            const obj_controllingFields_item = obj_controllingFields[i];
            const path_controllingFields_item = path_controllingFields + '[' + i + ']';
            if (typeof obj_controllingFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_controllingFields_item + '" (at "' + path_controllingFields_item + '")');
            }
        }
        const obj_dependent = obj.dependent;
        const path_dependent = path + '.dependent';
        if (typeof obj_dependent !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_dependent + '" (at "' + path_dependent + '")');
        }
        const obj_optionalFilter = obj.optionalFilter;
        const path_optionalFilter = path + '.optionalFilter';
        if (typeof obj_optionalFilter !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_optionalFilter + '" (at "' + path_optionalFilter + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1N(obj, path = 'ReferenceToInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_nameFields = obj.nameFields;
        const path_nameFields = path + '.nameFields';
        if (!ArrayIsArray(obj_nameFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_nameFields + '" (at "' + path_nameFields + '")');
        }
        for (let i = 0; i < obj_nameFields.length; i++) {
            const obj_nameFields_item = obj_nameFields[i];
            const path_nameFields_item = path_nameFields + '[' + i + ']';
            if (typeof obj_nameFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nameFields_item + '" (at "' + path_nameFields_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1M(obj, path = 'FieldRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_calculated = obj.calculated;
        const path_calculated = path + '.calculated';
        if (typeof obj_calculated !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_calculated + '" (at "' + path_calculated + '")');
        }
        const obj_compound = obj.compound;
        const path_compound = path + '.compound';
        if (typeof obj_compound !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_compound + '" (at "' + path_compound + '")');
        }
        const obj_compoundComponentName = obj.compoundComponentName;
        const path_compoundComponentName = path + '.compoundComponentName';
        let obj_compoundComponentName_union0 = null;
        const obj_compoundComponentName_union0_error = (() => {
            if (typeof obj_compoundComponentName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_compoundComponentName + '" (at "' + path_compoundComponentName + '")');
            }
        })();
        if (obj_compoundComponentName_union0_error != null) {
            obj_compoundComponentName_union0 = obj_compoundComponentName_union0_error.message;
        }
        let obj_compoundComponentName_union1 = null;
        const obj_compoundComponentName_union1_error = (() => {
            if (obj_compoundComponentName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_compoundComponentName + '" (at "' + path_compoundComponentName + '")');
            }
        })();
        if (obj_compoundComponentName_union1_error != null) {
            obj_compoundComponentName_union1 = obj_compoundComponentName_union1_error.message;
        }
        if (obj_compoundComponentName_union0 && obj_compoundComponentName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_compoundComponentName + '")';
            message += '\n' + obj_compoundComponentName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_compoundComponentName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_compoundFieldName = obj.compoundFieldName;
        const path_compoundFieldName = path + '.compoundFieldName';
        let obj_compoundFieldName_union0 = null;
        const obj_compoundFieldName_union0_error = (() => {
            if (typeof obj_compoundFieldName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_compoundFieldName + '" (at "' + path_compoundFieldName + '")');
            }
        })();
        if (obj_compoundFieldName_union0_error != null) {
            obj_compoundFieldName_union0 = obj_compoundFieldName_union0_error.message;
        }
        let obj_compoundFieldName_union1 = null;
        const obj_compoundFieldName_union1_error = (() => {
            if (obj_compoundFieldName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_compoundFieldName + '" (at "' + path_compoundFieldName + '")');
            }
        })();
        if (obj_compoundFieldName_union1_error != null) {
            obj_compoundFieldName_union1 = obj_compoundFieldName_union1_error.message;
        }
        if (obj_compoundFieldName_union0 && obj_compoundFieldName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_compoundFieldName + '")';
            message += '\n' + obj_compoundFieldName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_compoundFieldName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_controllerName = obj.controllerName;
        const path_controllerName = path + '.controllerName';
        let obj_controllerName_union0 = null;
        const obj_controllerName_union0_error = (() => {
            if (typeof obj_controllerName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_controllerName + '" (at "' + path_controllerName + '")');
            }
        })();
        if (obj_controllerName_union0_error != null) {
            obj_controllerName_union0 = obj_controllerName_union0_error.message;
        }
        let obj_controllerName_union1 = null;
        const obj_controllerName_union1_error = (() => {
            if (obj_controllerName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_controllerName + '" (at "' + path_controllerName + '")');
            }
        })();
        if (obj_controllerName_union1_error != null) {
            obj_controllerName_union1 = obj_controllerName_union1_error.message;
        }
        if (obj_controllerName_union0 && obj_controllerName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_controllerName + '")';
            message += '\n' + obj_controllerName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_controllerName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_controllingFields = obj.controllingFields;
        const path_controllingFields = path + '.controllingFields';
        if (!ArrayIsArray(obj_controllingFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_controllingFields + '" (at "' + path_controllingFields + '")');
        }
        for (let i = 0; i < obj_controllingFields.length; i++) {
            const obj_controllingFields_item = obj_controllingFields[i];
            const path_controllingFields_item = path_controllingFields + '[' + i + ']';
            if (typeof obj_controllingFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_controllingFields_item + '" (at "' + path_controllingFields_item + '")');
            }
        }
        const obj_createable = obj.createable;
        const path_createable = path + '.createable';
        if (typeof obj_createable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_createable + '" (at "' + path_createable + '")');
        }
        const obj_custom = obj.custom;
        const path_custom = path + '.custom';
        if (typeof obj_custom !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_custom + '" (at "' + path_custom + '")');
        }
        const obj_dataType = obj.dataType;
        const path_dataType = path + '.dataType';
        if (typeof obj_dataType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
        }
        const obj_externalId = obj.externalId;
        const path_externalId = path + '.externalId';
        if (typeof obj_externalId !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_externalId + '" (at "' + path_externalId + '")');
        }
        const obj_extraTypeInfo = obj.extraTypeInfo;
        const path_extraTypeInfo = path + '.extraTypeInfo';
        let obj_extraTypeInfo_union0 = null;
        const obj_extraTypeInfo_union0_error = (() => {
            if (typeof obj_extraTypeInfo !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_extraTypeInfo + '" (at "' + path_extraTypeInfo + '")');
            }
        })();
        if (obj_extraTypeInfo_union0_error != null) {
            obj_extraTypeInfo_union0 = obj_extraTypeInfo_union0_error.message;
        }
        let obj_extraTypeInfo_union1 = null;
        const obj_extraTypeInfo_union1_error = (() => {
            if (obj_extraTypeInfo !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_extraTypeInfo + '" (at "' + path_extraTypeInfo + '")');
            }
        })();
        if (obj_extraTypeInfo_union1_error != null) {
            obj_extraTypeInfo_union1 = obj_extraTypeInfo_union1_error.message;
        }
        if (obj_extraTypeInfo_union0 && obj_extraTypeInfo_union1) {
            let message = 'Object doesn\'t match union (at "' + path_extraTypeInfo + '")';
            message += '\n' + obj_extraTypeInfo_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_extraTypeInfo_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_filterable = obj.filterable;
        const path_filterable = path + '.filterable';
        if (typeof obj_filterable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_filterable + '" (at "' + path_filterable + '")');
        }
        const obj_filteredLookupInfo = obj.filteredLookupInfo;
        const path_filteredLookupInfo = path + '.filteredLookupInfo';
        let obj_filteredLookupInfo_union0 = null;
        const obj_filteredLookupInfo_union0_error = (() => {
            const referencepath_filteredLookupInfoValidationError = validate$1O(obj_filteredLookupInfo, path_filteredLookupInfo);
            if (referencepath_filteredLookupInfoValidationError !== null) {
                let message = 'Object doesn\'t match FilteredLookupInfoRepresentation (at "' + path_filteredLookupInfo + '")\n';
                message += referencepath_filteredLookupInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_filteredLookupInfo_union0_error != null) {
            obj_filteredLookupInfo_union0 = obj_filteredLookupInfo_union0_error.message;
        }
        let obj_filteredLookupInfo_union1 = null;
        const obj_filteredLookupInfo_union1_error = (() => {
            if (obj_filteredLookupInfo !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_filteredLookupInfo + '" (at "' + path_filteredLookupInfo + '")');
            }
        })();
        if (obj_filteredLookupInfo_union1_error != null) {
            obj_filteredLookupInfo_union1 = obj_filteredLookupInfo_union1_error.message;
        }
        if (obj_filteredLookupInfo_union0 && obj_filteredLookupInfo_union1) {
            let message = 'Object doesn\'t match union (at "' + path_filteredLookupInfo + '")';
            message += '\n' + obj_filteredLookupInfo_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_filteredLookupInfo_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_highScaleNumber = obj.highScaleNumber;
        const path_highScaleNumber = path + '.highScaleNumber';
        if (typeof obj_highScaleNumber !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_highScaleNumber + '" (at "' + path_highScaleNumber + '")');
        }
        const obj_htmlFormatted = obj.htmlFormatted;
        const path_htmlFormatted = path + '.htmlFormatted';
        if (typeof obj_htmlFormatted !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_htmlFormatted + '" (at "' + path_htmlFormatted + '")');
        }
        const obj_inlineHelpText = obj.inlineHelpText;
        const path_inlineHelpText = path + '.inlineHelpText';
        let obj_inlineHelpText_union0 = null;
        const obj_inlineHelpText_union0_error = (() => {
            if (typeof obj_inlineHelpText !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_inlineHelpText + '" (at "' + path_inlineHelpText + '")');
            }
        })();
        if (obj_inlineHelpText_union0_error != null) {
            obj_inlineHelpText_union0 = obj_inlineHelpText_union0_error.message;
        }
        let obj_inlineHelpText_union1 = null;
        const obj_inlineHelpText_union1_error = (() => {
            if (obj_inlineHelpText !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_inlineHelpText + '" (at "' + path_inlineHelpText + '")');
            }
        })();
        if (obj_inlineHelpText_union1_error != null) {
            obj_inlineHelpText_union1 = obj_inlineHelpText_union1_error.message;
        }
        if (obj_inlineHelpText_union0 && obj_inlineHelpText_union1) {
            let message = 'Object doesn\'t match union (at "' + path_inlineHelpText + '")';
            message += '\n' + obj_inlineHelpText_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_inlineHelpText_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_length = obj.length;
        const path_length = path + '.length';
        if (typeof obj_length !== 'number' || (typeof obj_length === 'number' && Math.floor(obj_length) !== obj_length)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_length + '" (at "' + path_length + '")');
        }
        const obj_maskType = obj.maskType;
        const path_maskType = path + '.maskType';
        let obj_maskType_union0 = null;
        const obj_maskType_union0_error = (() => {
            if (typeof obj_maskType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_maskType + '" (at "' + path_maskType + '")');
            }
        })();
        if (obj_maskType_union0_error != null) {
            obj_maskType_union0 = obj_maskType_union0_error.message;
        }
        let obj_maskType_union1 = null;
        const obj_maskType_union1_error = (() => {
            if (obj_maskType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_maskType + '" (at "' + path_maskType + '")');
            }
        })();
        if (obj_maskType_union1_error != null) {
            obj_maskType_union1 = obj_maskType_union1_error.message;
        }
        if (obj_maskType_union0 && obj_maskType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_maskType + '")';
            message += '\n' + obj_maskType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_maskType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nameField = obj.nameField;
        const path_nameField = path + '.nameField';
        if (typeof obj_nameField !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_nameField + '" (at "' + path_nameField + '")');
        }
        const obj_polymorphicForeignKey = obj.polymorphicForeignKey;
        const path_polymorphicForeignKey = path + '.polymorphicForeignKey';
        if (typeof obj_polymorphicForeignKey !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_polymorphicForeignKey + '" (at "' + path_polymorphicForeignKey + '")');
        }
        const obj_precision = obj.precision;
        const path_precision = path + '.precision';
        if (typeof obj_precision !== 'number' || (typeof obj_precision === 'number' && Math.floor(obj_precision) !== obj_precision)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_precision + '" (at "' + path_precision + '")');
        }
        const obj_reference = obj.reference;
        const path_reference = path + '.reference';
        if (typeof obj_reference !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_reference + '" (at "' + path_reference + '")');
        }
        const obj_referenceTargetField = obj.referenceTargetField;
        const path_referenceTargetField = path + '.referenceTargetField';
        let obj_referenceTargetField_union0 = null;
        const obj_referenceTargetField_union0_error = (() => {
            if (typeof obj_referenceTargetField !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_referenceTargetField + '" (at "' + path_referenceTargetField + '")');
            }
        })();
        if (obj_referenceTargetField_union0_error != null) {
            obj_referenceTargetField_union0 = obj_referenceTargetField_union0_error.message;
        }
        let obj_referenceTargetField_union1 = null;
        const obj_referenceTargetField_union1_error = (() => {
            if (obj_referenceTargetField !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_referenceTargetField + '" (at "' + path_referenceTargetField + '")');
            }
        })();
        if (obj_referenceTargetField_union1_error != null) {
            obj_referenceTargetField_union1 = obj_referenceTargetField_union1_error.message;
        }
        if (obj_referenceTargetField_union0 && obj_referenceTargetField_union1) {
            let message = 'Object doesn\'t match union (at "' + path_referenceTargetField + '")';
            message += '\n' + obj_referenceTargetField_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_referenceTargetField_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_referenceToInfos = obj.referenceToInfos;
        const path_referenceToInfos = path + '.referenceToInfos';
        if (!ArrayIsArray(obj_referenceToInfos)) {
            return new TypeError('Expected "array" but received "' + typeof obj_referenceToInfos + '" (at "' + path_referenceToInfos + '")');
        }
        for (let i = 0; i < obj_referenceToInfos.length; i++) {
            const obj_referenceToInfos_item = obj_referenceToInfos[i];
            const path_referenceToInfos_item = path_referenceToInfos + '[' + i + ']';
            const referencepath_referenceToInfos_itemValidationError = validate$1N(obj_referenceToInfos_item, path_referenceToInfos_item);
            if (referencepath_referenceToInfos_itemValidationError !== null) {
                let message = 'Object doesn\'t match ReferenceToInfoRepresentation (at "' + path_referenceToInfos_item + '")\n';
                message += referencepath_referenceToInfos_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_relationshipName = obj.relationshipName;
        const path_relationshipName = path + '.relationshipName';
        let obj_relationshipName_union0 = null;
        const obj_relationshipName_union0_error = (() => {
            if (typeof obj_relationshipName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_relationshipName + '" (at "' + path_relationshipName + '")');
            }
        })();
        if (obj_relationshipName_union0_error != null) {
            obj_relationshipName_union0 = obj_relationshipName_union0_error.message;
        }
        let obj_relationshipName_union1 = null;
        const obj_relationshipName_union1_error = (() => {
            if (obj_relationshipName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_relationshipName + '" (at "' + path_relationshipName + '")');
            }
        })();
        if (obj_relationshipName_union1_error != null) {
            obj_relationshipName_union1 = obj_relationshipName_union1_error.message;
        }
        if (obj_relationshipName_union0 && obj_relationshipName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_relationshipName + '")';
            message += '\n' + obj_relationshipName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_relationshipName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_required = obj.required;
        const path_required = path + '.required';
        if (typeof obj_required !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_required + '" (at "' + path_required + '")');
        }
        const obj_scale = obj.scale;
        const path_scale = path + '.scale';
        if (typeof obj_scale !== 'number' || (typeof obj_scale === 'number' && Math.floor(obj_scale) !== obj_scale)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_scale + '" (at "' + path_scale + '")');
        }
        const obj_searchPrefilterable = obj.searchPrefilterable;
        const path_searchPrefilterable = path + '.searchPrefilterable';
        if (typeof obj_searchPrefilterable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_searchPrefilterable + '" (at "' + path_searchPrefilterable + '")');
        }
        const obj_sortable = obj.sortable;
        const path_sortable = path + '.sortable';
        if (typeof obj_sortable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_sortable + '" (at "' + path_sortable + '")');
        }
        const obj_unique = obj.unique;
        const path_unique = path + '.unique';
        if (typeof obj_unique !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_unique + '" (at "' + path_unique + '")');
        }
        const obj_updateable = obj.updateable;
        const path_updateable = path + '.updateable';
        if (typeof obj_updateable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_updateable + '" (at "' + path_updateable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1L(obj, path = 'ThemeInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_color = obj.color;
        const path_color = path + '.color';
        if (typeof obj_color !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_color + '" (at "' + path_color + '")');
        }
        const obj_iconUrl = obj.iconUrl;
        const path_iconUrl = path + '.iconUrl';
        let obj_iconUrl_union0 = null;
        const obj_iconUrl_union0_error = (() => {
            if (typeof obj_iconUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union0_error != null) {
            obj_iconUrl_union0 = obj_iconUrl_union0_error.message;
        }
        let obj_iconUrl_union1 = null;
        const obj_iconUrl_union1_error = (() => {
            if (obj_iconUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union1_error != null) {
            obj_iconUrl_union1 = obj_iconUrl_union1_error.message;
        }
        if (obj_iconUrl_union0 && obj_iconUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_iconUrl + '")';
            message += '\n' + obj_iconUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_iconUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$x = 900000;
const VERSION$18 = "2302a71ca718abb60353eb88dedb1c12";
function validate$1K(obj, path = 'ObjectInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_associateEntityType = obj.associateEntityType;
        const path_associateEntityType = path + '.associateEntityType';
        let obj_associateEntityType_union0 = null;
        const obj_associateEntityType_union0_error = (() => {
            if (typeof obj_associateEntityType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_associateEntityType + '" (at "' + path_associateEntityType + '")');
            }
        })();
        if (obj_associateEntityType_union0_error != null) {
            obj_associateEntityType_union0 = obj_associateEntityType_union0_error.message;
        }
        let obj_associateEntityType_union1 = null;
        const obj_associateEntityType_union1_error = (() => {
            if (obj_associateEntityType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_associateEntityType + '" (at "' + path_associateEntityType + '")');
            }
        })();
        if (obj_associateEntityType_union1_error != null) {
            obj_associateEntityType_union1 = obj_associateEntityType_union1_error.message;
        }
        if (obj_associateEntityType_union0 && obj_associateEntityType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_associateEntityType + '")';
            message += '\n' + obj_associateEntityType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_associateEntityType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_associateParentEntity = obj.associateParentEntity;
        const path_associateParentEntity = path + '.associateParentEntity';
        let obj_associateParentEntity_union0 = null;
        const obj_associateParentEntity_union0_error = (() => {
            if (typeof obj_associateParentEntity !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_associateParentEntity + '" (at "' + path_associateParentEntity + '")');
            }
        })();
        if (obj_associateParentEntity_union0_error != null) {
            obj_associateParentEntity_union0 = obj_associateParentEntity_union0_error.message;
        }
        let obj_associateParentEntity_union1 = null;
        const obj_associateParentEntity_union1_error = (() => {
            if (obj_associateParentEntity !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_associateParentEntity + '" (at "' + path_associateParentEntity + '")');
            }
        })();
        if (obj_associateParentEntity_union1_error != null) {
            obj_associateParentEntity_union1 = obj_associateParentEntity_union1_error.message;
        }
        if (obj_associateParentEntity_union0 && obj_associateParentEntity_union1) {
            let message = 'Object doesn\'t match union (at "' + path_associateParentEntity + '")';
            message += '\n' + obj_associateParentEntity_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_associateParentEntity_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_childRelationships = obj.childRelationships;
        const path_childRelationships = path + '.childRelationships';
        if (!ArrayIsArray(obj_childRelationships)) {
            return new TypeError('Expected "array" but received "' + typeof obj_childRelationships + '" (at "' + path_childRelationships + '")');
        }
        for (let i = 0; i < obj_childRelationships.length; i++) {
            const obj_childRelationships_item = obj_childRelationships[i];
            const path_childRelationships_item = path_childRelationships + '[' + i + ']';
            const referencepath_childRelationships_itemValidationError = validate$1P(obj_childRelationships_item, path_childRelationships_item);
            if (referencepath_childRelationships_itemValidationError !== null) {
                let message = 'Object doesn\'t match ChildRelationshipRepresentation (at "' + path_childRelationships_item + '")\n';
                message += referencepath_childRelationships_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_compactLayoutable = obj.compactLayoutable;
        const path_compactLayoutable = path + '.compactLayoutable';
        if (typeof obj_compactLayoutable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_compactLayoutable + '" (at "' + path_compactLayoutable + '")');
        }
        const obj_createable = obj.createable;
        const path_createable = path + '.createable';
        if (typeof obj_createable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_createable + '" (at "' + path_createable + '")');
        }
        const obj_custom = obj.custom;
        const path_custom = path + '.custom';
        if (typeof obj_custom !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_custom + '" (at "' + path_custom + '")');
        }
        const obj_defaultRecordTypeId = obj.defaultRecordTypeId;
        const path_defaultRecordTypeId = path + '.defaultRecordTypeId';
        let obj_defaultRecordTypeId_union0 = null;
        const obj_defaultRecordTypeId_union0_error = (() => {
            if (typeof obj_defaultRecordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_defaultRecordTypeId + '" (at "' + path_defaultRecordTypeId + '")');
            }
        })();
        if (obj_defaultRecordTypeId_union0_error != null) {
            obj_defaultRecordTypeId_union0 = obj_defaultRecordTypeId_union0_error.message;
        }
        let obj_defaultRecordTypeId_union1 = null;
        const obj_defaultRecordTypeId_union1_error = (() => {
            if (obj_defaultRecordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_defaultRecordTypeId + '" (at "' + path_defaultRecordTypeId + '")');
            }
        })();
        if (obj_defaultRecordTypeId_union1_error != null) {
            obj_defaultRecordTypeId_union1 = obj_defaultRecordTypeId_union1_error.message;
        }
        if (obj_defaultRecordTypeId_union0 && obj_defaultRecordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_defaultRecordTypeId + '")';
            message += '\n' + obj_defaultRecordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_defaultRecordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_deletable = obj.deletable;
        const path_deletable = path + '.deletable';
        if (typeof obj_deletable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_deletable + '" (at "' + path_deletable + '")');
        }
        const obj_dependentFields = obj.dependentFields;
        const path_dependentFields = path + '.dependentFields';
        if (typeof obj_dependentFields !== 'object' || ArrayIsArray(obj_dependentFields) || obj_dependentFields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_dependentFields + '" (at "' + path_dependentFields + '")');
        }
        const obj_dependentFields_keys = ObjectKeys(obj_dependentFields);
        for (let i = 0; i < obj_dependentFields_keys.length; i++) {
            const key = obj_dependentFields_keys[i];
            const obj_dependentFields_prop = obj_dependentFields[key];
            const path_dependentFields_prop = path_dependentFields + '["' + key + '"]';
            if (typeof obj_dependentFields_prop !== 'object' || ArrayIsArray(obj_dependentFields_prop) || obj_dependentFields_prop === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_dependentFields_prop + '" (at "' + path_dependentFields_prop + '")');
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_feedEnabled = obj.feedEnabled;
        const path_feedEnabled = path + '.feedEnabled';
        if (typeof obj_feedEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_feedEnabled + '" (at "' + path_feedEnabled + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            const referencepath_fields_propValidationError = validate$1M(obj_fields_prop, path_fields_prop);
            if (referencepath_fields_propValidationError !== null) {
                let message = 'Object doesn\'t match FieldRepresentation (at "' + path_fields_prop + '")\n';
                message += referencepath_fields_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_keyPrefix = obj.keyPrefix;
        const path_keyPrefix = path + '.keyPrefix';
        let obj_keyPrefix_union0 = null;
        const obj_keyPrefix_union0_error = (() => {
            if (typeof obj_keyPrefix !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_keyPrefix + '" (at "' + path_keyPrefix + '")');
            }
        })();
        if (obj_keyPrefix_union0_error != null) {
            obj_keyPrefix_union0 = obj_keyPrefix_union0_error.message;
        }
        let obj_keyPrefix_union1 = null;
        const obj_keyPrefix_union1_error = (() => {
            if (obj_keyPrefix !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_keyPrefix + '" (at "' + path_keyPrefix + '")');
            }
        })();
        if (obj_keyPrefix_union1_error != null) {
            obj_keyPrefix_union1 = obj_keyPrefix_union1_error.message;
        }
        if (obj_keyPrefix_union0 && obj_keyPrefix_union1) {
            let message = 'Object doesn\'t match union (at "' + path_keyPrefix + '")';
            message += '\n' + obj_keyPrefix_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_keyPrefix_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_labelPlural = obj.labelPlural;
        const path_labelPlural = path + '.labelPlural';
        if (typeof obj_labelPlural !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_labelPlural + '" (at "' + path_labelPlural + '")');
        }
        const obj_layoutable = obj.layoutable;
        const path_layoutable = path + '.layoutable';
        if (typeof obj_layoutable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_layoutable + '" (at "' + path_layoutable + '")');
        }
        const obj_mruEnabled = obj.mruEnabled;
        const path_mruEnabled = path + '.mruEnabled';
        if (typeof obj_mruEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_mruEnabled + '" (at "' + path_mruEnabled + '")');
        }
        const obj_nameFields = obj.nameFields;
        const path_nameFields = path + '.nameFields';
        if (!ArrayIsArray(obj_nameFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_nameFields + '" (at "' + path_nameFields + '")');
        }
        for (let i = 0; i < obj_nameFields.length; i++) {
            const obj_nameFields_item = obj_nameFields[i];
            const path_nameFields_item = path_nameFields + '[' + i + ']';
            if (typeof obj_nameFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nameFields_item + '" (at "' + path_nameFields_item + '")');
            }
        }
        const obj_queryable = obj.queryable;
        const path_queryable = path + '.queryable';
        if (typeof obj_queryable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_queryable + '" (at "' + path_queryable + '")');
        }
        const obj_recordTypeInfos = obj.recordTypeInfos;
        const path_recordTypeInfos = path + '.recordTypeInfos';
        if (typeof obj_recordTypeInfos !== 'object' || ArrayIsArray(obj_recordTypeInfos) || obj_recordTypeInfos === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_recordTypeInfos + '" (at "' + path_recordTypeInfos + '")');
        }
        const obj_recordTypeInfos_keys = ObjectKeys(obj_recordTypeInfos);
        for (let i = 0; i < obj_recordTypeInfos_keys.length; i++) {
            const key = obj_recordTypeInfos_keys[i];
            const obj_recordTypeInfos_prop = obj_recordTypeInfos[key];
            const path_recordTypeInfos_prop = path_recordTypeInfos + '["' + key + '"]';
            const referencepath_recordTypeInfos_propValidationError = validate$1Z(obj_recordTypeInfos_prop, path_recordTypeInfos_prop);
            if (referencepath_recordTypeInfos_propValidationError !== null) {
                let message = 'Object doesn\'t match RecordTypeInfoRepresentation (at "' + path_recordTypeInfos_prop + '")\n';
                message += referencepath_recordTypeInfos_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_searchLayoutable = obj.searchLayoutable;
        const path_searchLayoutable = path + '.searchLayoutable';
        if (typeof obj_searchLayoutable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_searchLayoutable + '" (at "' + path_searchLayoutable + '")');
        }
        const obj_searchable = obj.searchable;
        const path_searchable = path + '.searchable';
        if (typeof obj_searchable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_searchable + '" (at "' + path_searchable + '")');
        }
        const obj_themeInfo = obj.themeInfo;
        const path_themeInfo = path + '.themeInfo';
        let obj_themeInfo_union0 = null;
        const obj_themeInfo_union0_error = (() => {
            const referencepath_themeInfoValidationError = validate$1L(obj_themeInfo, path_themeInfo);
            if (referencepath_themeInfoValidationError !== null) {
                let message = 'Object doesn\'t match ThemeInfoRepresentation (at "' + path_themeInfo + '")\n';
                message += referencepath_themeInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_themeInfo_union0_error != null) {
            obj_themeInfo_union0 = obj_themeInfo_union0_error.message;
        }
        let obj_themeInfo_union1 = null;
        const obj_themeInfo_union1_error = (() => {
            if (obj_themeInfo !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_themeInfo + '" (at "' + path_themeInfo + '")');
            }
        })();
        if (obj_themeInfo_union1_error != null) {
            obj_themeInfo_union1 = obj_themeInfo_union1_error.message;
        }
        if (obj_themeInfo_union0 && obj_themeInfo_union1) {
            let message = 'Object doesn\'t match union (at "' + path_themeInfo + '")';
            message += '\n' + obj_themeInfo_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_themeInfo_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_updateable = obj.updateable;
        const path_updateable = path + '.updateable';
        if (typeof obj_updateable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_updateable + '" (at "' + path_updateable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$O = 'ObjectInfoRepresentation';
function keyBuilder$1Y(luvio, config) {
    return keyPrefix + '::' + RepresentationType$O + ':' + config.apiName;
}
function keyBuilderFromType$w(luvio, object) {
    const keyParams = {
        apiName: object.apiName
    };
    return keyBuilder$1Y(luvio, keyParams);
}
function normalize$H(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1N = function ObjectInfoRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$18,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'associateEntityType',
                kind: 'Scalar'
            },
            {
                name: 'associateParentEntity',
                kind: 'Scalar'
            },
            {
                name: 'childRelationships',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'compactLayoutable',
                kind: 'Scalar'
            },
            {
                name: 'createable',
                kind: 'Scalar'
            },
            {
                name: 'custom',
                kind: 'Scalar'
            },
            {
                name: 'defaultRecordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'deletable',
                kind: 'Scalar'
            },
            {
                name: 'dependentFields',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'feedEnabled',
                kind: 'Scalar'
            },
            {
                name: 'fields',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'keyPrefix',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'labelPlural',
                kind: 'Scalar'
            },
            {
                name: 'layoutable',
                kind: 'Scalar'
            },
            {
                name: 'mruEnabled',
                kind: 'Scalar'
            },
            {
                name: 'nameFields',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'queryable',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeInfos',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'searchLayoutable',
                kind: 'Scalar'
            },
            {
                name: 'searchable',
                kind: 'Scalar'
            },
            {
                name: 'themeInfo',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'updateable',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$_(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$H = function ObjectInfoRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1K(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$w(luvio, input);
    const ttlToUse = TTL$x;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$H, "UiApi", VERSION$18, RepresentationType$O, equals$_);
    return createLink(key);
};
function getTypeCacheKeys$O(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$w(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$O,
        mergeable: false
    });
}

function select$1M(luvio, params) {
    return select$1N();
}
function keyBuilder$1X(luvio, params) {
    return keyBuilder$1Y(luvio, {
        apiName: params.urlParams.objectApiName
    });
}
function getResponseCacheKeys$_(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$O(storeKeyMap, luvio, response);
}
function ingestSuccess$P(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1X(luvio, resourceParams);
    luvio.storeIngest(key, ingest$H, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1M(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$I(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1X(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$x,
        namespace: keyPrefix,
        version: VERSION$18,
        representationName: RepresentationType$O
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$13(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/object-info/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$Y = 'getObjectInfo';
const getObjectInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
];
const getObjectInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$Y, getObjectInfo_ConfigPropertyMetadata);
const createResourceParams$Y = /*#__PURE__*/ createResourceParams$13(getObjectInfo_ConfigPropertyMetadata);
function keyBuilder$1W(luvio, config) {
    const resourceParams = createResourceParams$Y(config);
    return keyBuilder$1X(luvio, resourceParams);
}
function typeCheckConfig$11(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getObjectInfo_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$13(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getObjectInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$11(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$H(luvio, config) {
    createResourceParams$Y(config);
    return select$1M();
}
function onFetchResponseSuccess$L(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$P(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$13(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$M(luvio, config, resourceParams, response) {
    const snapshot = ingestError$I(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$13(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$13(luvio, config, options) {
    const resourceParams = createResourceParams$Y(config);
    const request = createResourceRequest$13(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$L(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$_(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$M(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$P(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$13, undefined, false);
}
function buildCachedSnapshotCachePolicy$O(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1W(luvio, config),
        node: adapterFragment$H(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$13(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getObjectInfoAdapterFactory = (luvio) => function UiApi__getObjectInfo(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$13(untrustedConfig, getObjectInfo_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$O, buildNetworkSnapshotCachePolicy$P);
};

function validate$1J(obj, path = 'RecordLayoutSaveOptionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_defaultValue = obj.defaultValue;
        const path_defaultValue = path + '.defaultValue';
        if (typeof obj_defaultValue !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_defaultValue + '" (at "' + path_defaultValue + '")');
        }
        const obj_isDisplayed = obj.isDisplayed;
        const path_isDisplayed = path + '.isDisplayed';
        if (typeof obj_isDisplayed !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isDisplayed + '" (at "' + path_isDisplayed + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_restHeaderName = obj.restHeaderName;
        const path_restHeaderName = path + '.restHeaderName';
        if (typeof obj_restHeaderName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_restHeaderName + '" (at "' + path_restHeaderName + '")');
        }
        const obj_soapHeaderName = obj.soapHeaderName;
        const path_soapHeaderName = path + '.soapHeaderName';
        if (typeof obj_soapHeaderName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_soapHeaderName + '" (at "' + path_soapHeaderName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

var DiscriminatorValues$5;
(function (DiscriminatorValues) {
    DiscriminatorValues["EmptySpace"] = "EmptySpace";
    DiscriminatorValues["ReportChart"] = "ReportChart";
    DiscriminatorValues["VisualforcePage"] = "VisualforcePage";
    DiscriminatorValues["Canvas"] = "Canvas";
    DiscriminatorValues["Field"] = "Field";
    DiscriminatorValues["CustomLink"] = "CustomLink";
})(DiscriminatorValues$5 || (DiscriminatorValues$5 = {}));
function validate$1I(obj, path = 'AbstractRecordLayoutComponentRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        let obj_apiName_union0 = null;
        const obj_apiName_union0_error = (() => {
            if (typeof obj_apiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
            }
        })();
        if (obj_apiName_union0_error != null) {
            obj_apiName_union0 = obj_apiName_union0_error.message;
        }
        let obj_apiName_union1 = null;
        const obj_apiName_union1_error = (() => {
            if (obj_apiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
            }
        })();
        if (obj_apiName_union1_error != null) {
            obj_apiName_union1 = obj_apiName_union1_error.message;
        }
        if (obj_apiName_union0 && obj_apiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_apiName + '")';
            message += '\n' + obj_apiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_apiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_componentType = obj.componentType;
        const path_componentType = path + '.componentType';
        if (typeof obj_componentType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_componentType + '" (at "' + path_componentType + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1H(obj, path = 'RecordLayoutItemRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_editableForNew = obj.editableForNew;
        const path_editableForNew = path + '.editableForNew';
        if (typeof obj_editableForNew !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_editableForNew + '" (at "' + path_editableForNew + '")');
        }
        const obj_editableForUpdate = obj.editableForUpdate;
        const path_editableForUpdate = path + '.editableForUpdate';
        if (typeof obj_editableForUpdate !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_editableForUpdate + '" (at "' + path_editableForUpdate + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_layoutComponents = obj.layoutComponents;
        const path_layoutComponents = path + '.layoutComponents';
        if (!ArrayIsArray(obj_layoutComponents)) {
            return new TypeError('Expected "array" but received "' + typeof obj_layoutComponents + '" (at "' + path_layoutComponents + '")');
        }
        for (let i = 0; i < obj_layoutComponents.length; i++) {
            const obj_layoutComponents_item = obj_layoutComponents[i];
            const path_layoutComponents_item = path_layoutComponents + '[' + i + ']';
            const referencepath_layoutComponents_itemValidationError = validate$1I(obj_layoutComponents_item, path_layoutComponents_item);
            if (referencepath_layoutComponents_itemValidationError !== null) {
                let message = 'Object doesn\'t match AbstractRecordLayoutComponentRepresentation (at "' + path_layoutComponents_item + '")\n';
                message += referencepath_layoutComponents_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_lookupIdApiName = obj.lookupIdApiName;
        const path_lookupIdApiName = path + '.lookupIdApiName';
        let obj_lookupIdApiName_union0 = null;
        const obj_lookupIdApiName_union0_error = (() => {
            if (typeof obj_lookupIdApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lookupIdApiName + '" (at "' + path_lookupIdApiName + '")');
            }
        })();
        if (obj_lookupIdApiName_union0_error != null) {
            obj_lookupIdApiName_union0 = obj_lookupIdApiName_union0_error.message;
        }
        let obj_lookupIdApiName_union1 = null;
        const obj_lookupIdApiName_union1_error = (() => {
            if (obj_lookupIdApiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lookupIdApiName + '" (at "' + path_lookupIdApiName + '")');
            }
        })();
        if (obj_lookupIdApiName_union1_error != null) {
            obj_lookupIdApiName_union1 = obj_lookupIdApiName_union1_error.message;
        }
        if (obj_lookupIdApiName_union0 && obj_lookupIdApiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lookupIdApiName + '")';
            message += '\n' + obj_lookupIdApiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lookupIdApiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_required = obj.required;
        const path_required = path + '.required';
        if (typeof obj_required !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_required + '" (at "' + path_required + '")');
        }
        const obj_sortable = obj.sortable;
        const path_sortable = path + '.sortable';
        if (typeof obj_sortable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_sortable + '" (at "' + path_sortable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1G(obj, path = 'RecordLayoutRowRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_layoutItems = obj.layoutItems;
        const path_layoutItems = path + '.layoutItems';
        if (!ArrayIsArray(obj_layoutItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_layoutItems + '" (at "' + path_layoutItems + '")');
        }
        for (let i = 0; i < obj_layoutItems.length; i++) {
            const obj_layoutItems_item = obj_layoutItems[i];
            const path_layoutItems_item = path_layoutItems + '[' + i + ']';
            const referencepath_layoutItems_itemValidationError = validate$1H(obj_layoutItems_item, path_layoutItems_item);
            if (referencepath_layoutItems_itemValidationError !== null) {
                let message = 'Object doesn\'t match RecordLayoutItemRepresentation (at "' + path_layoutItems_item + '")\n';
                message += referencepath_layoutItems_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1F(obj, path = 'RecordLayoutSectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_collapsible = obj.collapsible;
        const path_collapsible = path + '.collapsible';
        if (typeof obj_collapsible !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_collapsible + '" (at "' + path_collapsible + '")');
        }
        const obj_columns = obj.columns;
        const path_columns = path + '.columns';
        if (typeof obj_columns !== 'number' || (typeof obj_columns === 'number' && Math.floor(obj_columns) !== obj_columns)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_columns + '" (at "' + path_columns + '")');
        }
        const obj_heading = obj.heading;
        const path_heading = path + '.heading';
        let obj_heading_union0 = null;
        const obj_heading_union0_error = (() => {
            if (typeof obj_heading !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_heading + '" (at "' + path_heading + '")');
            }
        })();
        if (obj_heading_union0_error != null) {
            obj_heading_union0 = obj_heading_union0_error.message;
        }
        let obj_heading_union1 = null;
        const obj_heading_union1_error = (() => {
            if (obj_heading !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_heading + '" (at "' + path_heading + '")');
            }
        })();
        if (obj_heading_union1_error != null) {
            obj_heading_union1 = obj_heading_union1_error.message;
        }
        if (obj_heading_union0 && obj_heading_union1) {
            let message = 'Object doesn\'t match union (at "' + path_heading + '")';
            message += '\n' + obj_heading_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_heading_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_layoutRows = obj.layoutRows;
        const path_layoutRows = path + '.layoutRows';
        if (!ArrayIsArray(obj_layoutRows)) {
            return new TypeError('Expected "array" but received "' + typeof obj_layoutRows + '" (at "' + path_layoutRows + '")');
        }
        for (let i = 0; i < obj_layoutRows.length; i++) {
            const obj_layoutRows_item = obj_layoutRows[i];
            const path_layoutRows_item = path_layoutRows + '[' + i + ']';
            const referencepath_layoutRows_itemValidationError = validate$1G(obj_layoutRows_item, path_layoutRows_item);
            if (referencepath_layoutRows_itemValidationError !== null) {
                let message = 'Object doesn\'t match RecordLayoutRowRepresentation (at "' + path_layoutRows_item + '")\n';
                message += referencepath_layoutRows_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_rows = obj.rows;
        const path_rows = path + '.rows';
        if (typeof obj_rows !== 'number' || (typeof obj_rows === 'number' && Math.floor(obj_rows) !== obj_rows)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_rows + '" (at "' + path_rows + '")');
        }
        const obj_useHeading = obj.useHeading;
        const path_useHeading = path + '.useHeading';
        if (typeof obj_useHeading !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_useHeading + '" (at "' + path_useHeading + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$w = 900000;
const VERSION$17 = "fb515e25a89ca1ec154dc865e72b913a";
function validate$1E(obj, path = 'RecordLayoutRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_layoutType = obj.layoutType;
        const path_layoutType = path + '.layoutType';
        if (typeof obj_layoutType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_layoutType + '" (at "' + path_layoutType + '")');
        }
        const obj_mode = obj.mode;
        const path_mode = path + '.mode';
        if (typeof obj_mode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_mode + '" (at "' + path_mode + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        let obj_objectApiName_union0 = null;
        const obj_objectApiName_union0_error = (() => {
            if (typeof obj_objectApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
            }
        })();
        if (obj_objectApiName_union0_error != null) {
            obj_objectApiName_union0 = obj_objectApiName_union0_error.message;
        }
        let obj_objectApiName_union1 = null;
        const obj_objectApiName_union1_error = (() => {
            if (obj_objectApiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
            }
        })();
        if (obj_objectApiName_union1_error != null) {
            obj_objectApiName_union1 = obj_objectApiName_union1_error.message;
        }
        if (obj_objectApiName_union0 && obj_objectApiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_objectApiName + '")';
            message += '\n' + obj_objectApiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_objectApiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        let obj_recordTypeId_union0 = null;
        const obj_recordTypeId_union0_error = (() => {
            if (typeof obj_recordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union0_error != null) {
            obj_recordTypeId_union0 = obj_recordTypeId_union0_error.message;
        }
        let obj_recordTypeId_union1 = null;
        const obj_recordTypeId_union1_error = (() => {
            if (obj_recordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union1_error != null) {
            obj_recordTypeId_union1 = obj_recordTypeId_union1_error.message;
        }
        if (obj_recordTypeId_union0 && obj_recordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeId + '")';
            message += '\n' + obj_recordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_saveOptions = obj.saveOptions;
        const path_saveOptions = path + '.saveOptions';
        if (!ArrayIsArray(obj_saveOptions)) {
            return new TypeError('Expected "array" but received "' + typeof obj_saveOptions + '" (at "' + path_saveOptions + '")');
        }
        for (let i = 0; i < obj_saveOptions.length; i++) {
            const obj_saveOptions_item = obj_saveOptions[i];
            const path_saveOptions_item = path_saveOptions + '[' + i + ']';
            const referencepath_saveOptions_itemValidationError = validate$1J(obj_saveOptions_item, path_saveOptions_item);
            if (referencepath_saveOptions_itemValidationError !== null) {
                let message = 'Object doesn\'t match RecordLayoutSaveOptionRepresentation (at "' + path_saveOptions_item + '")\n';
                message += referencepath_saveOptions_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_sections = obj.sections;
        const path_sections = path + '.sections';
        if (!ArrayIsArray(obj_sections)) {
            return new TypeError('Expected "array" but received "' + typeof obj_sections + '" (at "' + path_sections + '")');
        }
        for (let i = 0; i < obj_sections.length; i++) {
            const obj_sections_item = obj_sections[i];
            const path_sections_item = path_sections + '[' + i + ']';
            const referencepath_sections_itemValidationError = validate$1F(obj_sections_item, path_sections_item);
            if (referencepath_sections_itemValidationError !== null) {
                let message = 'Object doesn\'t match RecordLayoutSectionRepresentation (at "' + path_sections_item + '")\n';
                message += referencepath_sections_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$N = 'RecordLayoutRepresentation';
function keyBuilder$1V(luvio, config) {
    return keyPrefix + '::' + RepresentationType$N + ':' + (config.recordTypeId === null ? '' : config.recordTypeId) + ':' + (config.objectApiName === null ? '' : config.objectApiName) + ':' + config.layoutType + ':' + config.mode;
}
function keyBuilderFromType$v(luvio, object) {
    const keyParams = {
        recordTypeId: object.recordTypeId,
        objectApiName: object.objectApiName,
        layoutType: object.layoutType,
        mode: object.mode
    };
    return keyBuilder$1V(luvio, keyParams);
}
function normalize$G(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1L = function RecordLayoutRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$17,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'layoutType',
                kind: 'Scalar'
            },
            {
                name: 'mode',
                kind: 'Scalar'
            },
            {
                name: 'objectApiName',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'saveOptions',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'sections',
                kind: 'Object',
                opaque: true
            }
        ]
    };
};
function equals$Z(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$G = function RecordLayoutRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1E(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$v(luvio, input);
    const ttlToUse = TTL$w;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$G, "UiApi", VERSION$17, RepresentationType$N, equals$Z);
    return createLink(key);
};
function getTypeCacheKeys$N(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$v(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$N,
        mergeable: false
    });
}

/**
 * Returns the object API name.
 * @param value The value from which to get the object API name.
 * @returns The object API name.
 */
function getRecordId18Array(value) {
    const valueArray = isArray(value) ? value : [value];
    const array = [];
    for (let i = 0, len = valueArray.length; i < len; i += 1) {
        const item = valueArray[i];
        const apiName = getRecordId18(item);
        if (apiName === undefined) {
            return undefined;
        }
        push.call(array, apiName);
    }
    if (array.length === 0) {
        return undefined;
    }
    return dedupe(array).sort();
}

function validate$1D(obj, path = 'RecordLayoutSectionUserStateRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_collapsed = obj.collapsed;
        const path_collapsed = path + '.collapsed';
        if (typeof obj_collapsed !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_collapsed + '" (at "' + path_collapsed + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$v = 900000;
const VERSION$16 = "12123f1aca1b5a48303b1d099f9f5629";
function validate$1C(obj, path = 'RecordLayoutUserStateRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_layoutType = obj.layoutType;
        const path_layoutType = path + '.layoutType';
        if (typeof obj_layoutType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_layoutType + '" (at "' + path_layoutType + '")');
        }
        const obj_mode = obj.mode;
        const path_mode = path + '.mode';
        if (typeof obj_mode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_mode + '" (at "' + path_mode + '")');
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        if (typeof obj_recordTypeId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
        }
        const obj_sectionUserStates = obj.sectionUserStates;
        const path_sectionUserStates = path + '.sectionUserStates';
        if (typeof obj_sectionUserStates !== 'object' || ArrayIsArray(obj_sectionUserStates) || obj_sectionUserStates === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_sectionUserStates + '" (at "' + path_sectionUserStates + '")');
        }
        const obj_sectionUserStates_keys = ObjectKeys(obj_sectionUserStates);
        for (let i = 0; i < obj_sectionUserStates_keys.length; i++) {
            const key = obj_sectionUserStates_keys[i];
            const obj_sectionUserStates_prop = obj_sectionUserStates[key];
            const path_sectionUserStates_prop = path_sectionUserStates + '["' + key + '"]';
            const referencepath_sectionUserStates_propValidationError = validate$1D(obj_sectionUserStates_prop, path_sectionUserStates_prop);
            if (referencepath_sectionUserStates_propValidationError !== null) {
                let message = 'Object doesn\'t match RecordLayoutSectionUserStateRepresentation (at "' + path_sectionUserStates_prop + '")\n';
                message += referencepath_sectionUserStates_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$M = 'RecordLayoutUserStateRepresentation';
function keyBuilder$1U(luvio, config) {
    return keyPrefix + '::' + RepresentationType$M + ':' + config.recordTypeId + ':' + config.apiName + ':' + config.layoutType + ':' + config.mode;
}
function keyBuilderFromType$u(luvio, object) {
    const keyParams = {
        recordTypeId: object.recordTypeId,
        apiName: object.apiName,
        layoutType: object.layoutType,
        mode: object.mode
    };
    return keyBuilder$1U(luvio, keyParams);
}
function normalize$F(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1K = function RecordLayoutUserStateRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$16,
        private: [
            'apiName',
            'recordTypeId',
            'layoutType',
            'mode'
        ],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'sectionUserStates',
                kind: 'Object',
                opaque: true
            }
        ]
    };
};
function equals$Y(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$F = function RecordLayoutUserStateRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1C(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$u(luvio, input);
    const ttlToUse = TTL$v;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$F, "UiApi", VERSION$16, RepresentationType$M, equals$Y);
    return createLink(key);
};
function getTypeCacheKeys$M(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$u(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$M,
        mergeable: false
    });
}

const TTL$u = 900000;
const VERSION$15 = "49cdd4bc235a6094c3559cc7735b3b6d";
function validate$1B(obj, path = 'RecordUiRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_layoutUserStates = obj.layoutUserStates;
        const path_layoutUserStates = path + '.layoutUserStates';
        if (typeof obj_layoutUserStates !== 'object' || ArrayIsArray(obj_layoutUserStates) || obj_layoutUserStates === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_layoutUserStates + '" (at "' + path_layoutUserStates + '")');
        }
        const obj_layoutUserStates_keys = ObjectKeys(obj_layoutUserStates);
        for (let i = 0; i < obj_layoutUserStates_keys.length; i++) {
            const key = obj_layoutUserStates_keys[i];
            const obj_layoutUserStates_prop = obj_layoutUserStates[key];
            const path_layoutUserStates_prop = path_layoutUserStates + '["' + key + '"]';
            if (typeof obj_layoutUserStates_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_layoutUserStates_prop + '" (at "' + path_layoutUserStates_prop + '")');
            }
        }
        const obj_layouts = obj.layouts;
        const path_layouts = path + '.layouts';
        if (typeof obj_layouts !== 'object' || ArrayIsArray(obj_layouts) || obj_layouts === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_layouts + '" (at "' + path_layouts + '")');
        }
        const obj_layouts_keys = ObjectKeys(obj_layouts);
        for (let i = 0; i < obj_layouts_keys.length; i++) {
            const key = obj_layouts_keys[i];
            const obj_layouts_prop = obj_layouts[key];
            const path_layouts_prop = path_layouts + '["' + key + '"]';
            if (typeof obj_layouts_prop !== 'object' || ArrayIsArray(obj_layouts_prop) || obj_layouts_prop === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_layouts_prop + '" (at "' + path_layouts_prop + '")');
            }
            const obj_layouts_prop_keys = ObjectKeys(obj_layouts_prop);
            for (let i = 0; i < obj_layouts_prop_keys.length; i++) {
                const key = obj_layouts_prop_keys[i];
                const obj_layouts_prop_prop = obj_layouts_prop[key];
                const path_layouts_prop_prop = path_layouts_prop + '["' + key + '"]';
                if (typeof obj_layouts_prop_prop !== 'object' || ArrayIsArray(obj_layouts_prop_prop) || obj_layouts_prop_prop === null) {
                    return new TypeError('Expected "object" but received "' + typeof obj_layouts_prop_prop + '" (at "' + path_layouts_prop_prop + '")');
                }
                const obj_layouts_prop_prop_keys = ObjectKeys(obj_layouts_prop_prop);
                for (let i = 0; i < obj_layouts_prop_prop_keys.length; i++) {
                    const key = obj_layouts_prop_prop_keys[i];
                    const obj_layouts_prop_prop_prop = obj_layouts_prop_prop[key];
                    const path_layouts_prop_prop_prop = path_layouts_prop_prop + '["' + key + '"]';
                    if (typeof obj_layouts_prop_prop_prop !== 'object' || ArrayIsArray(obj_layouts_prop_prop_prop) || obj_layouts_prop_prop_prop === null) {
                        return new TypeError('Expected "object" but received "' + typeof obj_layouts_prop_prop_prop + '" (at "' + path_layouts_prop_prop_prop + '")');
                    }
                    const obj_layouts_prop_prop_prop_keys = ObjectKeys(obj_layouts_prop_prop_prop);
                    for (let i = 0; i < obj_layouts_prop_prop_prop_keys.length; i++) {
                        const key = obj_layouts_prop_prop_prop_keys[i];
                        const obj_layouts_prop_prop_prop_prop = obj_layouts_prop_prop_prop[key];
                        const path_layouts_prop_prop_prop_prop = path_layouts_prop_prop_prop + '["' + key + '"]';
                        if (typeof obj_layouts_prop_prop_prop_prop !== 'object') {
                            return new TypeError('Expected "object" but received "' + typeof obj_layouts_prop_prop_prop_prop + '" (at "' + path_layouts_prop_prop_prop_prop + '")');
                        }
                    }
                }
            }
        }
        const obj_objectInfos = obj.objectInfos;
        const path_objectInfos = path + '.objectInfos';
        if (typeof obj_objectInfos !== 'object' || ArrayIsArray(obj_objectInfos) || obj_objectInfos === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_objectInfos + '" (at "' + path_objectInfos + '")');
        }
        const obj_objectInfos_keys = ObjectKeys(obj_objectInfos);
        for (let i = 0; i < obj_objectInfos_keys.length; i++) {
            const key = obj_objectInfos_keys[i];
            const obj_objectInfos_prop = obj_objectInfos[key];
            const path_objectInfos_prop = path_objectInfos + '["' + key + '"]';
            if (typeof obj_objectInfos_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_objectInfos_prop + '" (at "' + path_objectInfos_prop + '")');
            }
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (typeof obj_records !== 'object' || ArrayIsArray(obj_records) || obj_records === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
        const obj_records_keys = ObjectKeys(obj_records);
        for (let i = 0; i < obj_records_keys.length; i++) {
            const key = obj_records_keys[i];
            const obj_records_prop = obj_records[key];
            const path_records_prop = path_records + '["' + key + '"]';
            if (typeof obj_records_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_records_prop + '" (at "' + path_records_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$L = 'RecordUiRepresentation';
function normalize$E(input, existing, path, luvio, store, timestamp) {
    const input_layoutUserStates = input.layoutUserStates;
    const input_layoutUserStates_id = path.fullPath + '__layoutUserStates';
    const input_layoutUserStates_keys = Object.keys(input_layoutUserStates);
    const input_layoutUserStates_length = input_layoutUserStates_keys.length;
    for (let i = 0; i < input_layoutUserStates_length; i++) {
        const key = input_layoutUserStates_keys[i];
        const input_layoutUserStates_prop = input_layoutUserStates[key];
        const input_layoutUserStates_prop_id = input_layoutUserStates_id + '__' + key;
        input_layoutUserStates[key] = ingest$F(input_layoutUserStates_prop, {
            fullPath: input_layoutUserStates_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_layouts = input.layouts;
    const input_layouts_id = path.fullPath + '__layouts';
    const input_layouts_keys = Object.keys(input_layouts);
    const input_layouts_length = input_layouts_keys.length;
    for (let i = 0; i < input_layouts_length; i++) {
        const key = input_layouts_keys[i];
        const input_layouts_prop = input_layouts[key];
        const input_layouts_prop_id = input_layouts_id + '__' + key;
        const input_layouts_prop_keys = Object.keys(input_layouts_prop);
        const input_layouts_prop_length = input_layouts_prop_keys.length;
        for (let i = 0; i < input_layouts_prop_length; i++) {
            const key = input_layouts_prop_keys[i];
            const input_layouts_prop_prop = input_layouts_prop[key];
            const input_layouts_prop_prop_id = input_layouts_prop_id + '__' + key;
            const input_layouts_prop_prop_keys = Object.keys(input_layouts_prop_prop);
            const input_layouts_prop_prop_length = input_layouts_prop_prop_keys.length;
            for (let i = 0; i < input_layouts_prop_prop_length; i++) {
                const key = input_layouts_prop_prop_keys[i];
                const input_layouts_prop_prop_prop = input_layouts_prop_prop[key];
                const input_layouts_prop_prop_prop_id = input_layouts_prop_prop_id + '__' + key;
                const input_layouts_prop_prop_prop_keys = Object.keys(input_layouts_prop_prop_prop);
                const input_layouts_prop_prop_prop_length = input_layouts_prop_prop_prop_keys.length;
                for (let i = 0; i < input_layouts_prop_prop_prop_length; i++) {
                    const key = input_layouts_prop_prop_prop_keys[i];
                    const input_layouts_prop_prop_prop_prop = input_layouts_prop_prop_prop[key];
                    const input_layouts_prop_prop_prop_prop_id = input_layouts_prop_prop_prop_id + '__' + key;
                    input_layouts_prop_prop_prop[key] = ingest$G(input_layouts_prop_prop_prop_prop, {
                        fullPath: input_layouts_prop_prop_prop_prop_id,
                        propertyName: key,
                        parent: {
                            data: input,
                            key: path.fullPath,
                            existing: existing,
                        },
                        ttl: path.ttl
                    }, luvio, store, timestamp);
                }
            }
        }
    }
    const input_objectInfos = input.objectInfos;
    const input_objectInfos_id = path.fullPath + '__objectInfos';
    const input_objectInfos_keys = Object.keys(input_objectInfos);
    const input_objectInfos_length = input_objectInfos_keys.length;
    for (let i = 0; i < input_objectInfos_length; i++) {
        const key = input_objectInfos_keys[i];
        const input_objectInfos_prop = input_objectInfos[key];
        const input_objectInfos_prop_id = input_objectInfos_id + '__' + key;
        input_objectInfos[key] = ingest$H(input_objectInfos_prop, {
            fullPath: input_objectInfos_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_records = input.records;
    const input_records_id = path.fullPath + '__records';
    const input_records_keys = Object.keys(input_records);
    const input_records_length = input_records_keys.length;
    for (let i = 0; i < input_records_length; i++) {
        const key = input_records_keys[i];
        const input_records_prop = input_records[key];
        const input_records_prop_id = input_records_id + '__' + key;
        input_records[key] = ingest$O(input_records_prop, {
            fullPath: input_records_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
function equals$X(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_layoutUserStates = existing.layoutUserStates;
    const incoming_layoutUserStates = incoming.layoutUserStates;
    const equals_layoutUserStates_props = equalsObject(existing_layoutUserStates, incoming_layoutUserStates, (existing_layoutUserStates_prop, incoming_layoutUserStates_prop) => {
        if (!(existing_layoutUserStates_prop.__ref === incoming_layoutUserStates_prop.__ref)) {
            return false;
        }
    });
    if (equals_layoutUserStates_props === false) {
        return false;
    }
    const existing_layouts = existing.layouts;
    const incoming_layouts = incoming.layouts;
    const equals_layouts_props = equalsObject(existing_layouts, incoming_layouts, (existing_layouts_prop, incoming_layouts_prop) => {
        const equals_layouts_props = equalsObject(existing_layouts_prop, incoming_layouts_prop, (existing_layouts_prop_prop, incoming_layouts_prop_prop) => {
            const equals_layouts_props = equalsObject(existing_layouts_prop_prop, incoming_layouts_prop_prop, (existing_layouts_prop_prop_prop, incoming_layouts_prop_prop_prop) => {
                const equals_layouts_props = equalsObject(existing_layouts_prop_prop_prop, incoming_layouts_prop_prop_prop, (existing_layouts_prop_prop_prop_prop, incoming_layouts_prop_prop_prop_prop) => {
                    if (!(existing_layouts_prop_prop_prop_prop.__ref === incoming_layouts_prop_prop_prop_prop.__ref)) {
                        return false;
                    }
                });
                if (equals_layouts_props === false) {
                    return false;
                }
            });
            if (equals_layouts_props === false) {
                return false;
            }
        });
        if (equals_layouts_props === false) {
            return false;
        }
    });
    if (equals_layouts_props === false) {
        return false;
    }
    const existing_objectInfos = existing.objectInfos;
    const incoming_objectInfos = incoming.objectInfos;
    const equals_objectInfos_props = equalsObject(existing_objectInfos, incoming_objectInfos, (existing_objectInfos_prop, incoming_objectInfos_prop) => {
        if (!(existing_objectInfos_prop.__ref === incoming_objectInfos_prop.__ref)) {
            return false;
        }
    });
    if (equals_objectInfos_props === false) {
        return false;
    }
    const existing_records = existing.records;
    const incoming_records = incoming.records;
    const equals_records_props = equalsObject(existing_records, incoming_records, (existing_records_prop, incoming_records_prop) => {
        if (!(existing_records_prop.__ref === incoming_records_prop.__ref)) {
            return false;
        }
    });
    if (equals_records_props === false) {
        return false;
    }
    return true;
}
const ingest$E = function RecordUiRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1B(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$u;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$E, "UiApi", VERSION$15, RepresentationType$L, equals$X);
    return createLink(key);
};

function createResourceRequest$12(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/record-ui/' + config.urlParams.recordIds + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const getRecordUi_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('childRelationships', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('layoutTypes', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArrayTitleCase),
    generateParamConfigMetadata('modes', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('updateMru', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
function typeCheckConfig$10(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordUi_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$12(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordUi_ConfigPropertyMetadata);
    const config = typeCheckConfig$10(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const layoutSelections$2 = select$1L();
const objectInfoPathSelection = select$1N();
const layoutUserStatePathSelector = select$1K();
function buildRecordUiSelector(recordDefs, layoutTypes, modes, recordOptionalFields) {
    const layoutTypeSelections = [];
    for (let i = 0, len = layoutTypes.length; i < len; i += 1) {
        const layoutType = layoutTypes[i];
        const modeSelections = [];
        const sel = {
            kind: 'Object',
            name: layoutType,
            selections: modeSelections,
        };
        for (let m = 0; m < modes.length; m += 1) {
            const mode = modes[m];
            const modeSel = {
                kind: 'Link',
                name: mode,
                fragment: layoutSelections$2,
            };
            push.call(modeSelections, modeSel);
        }
        push.call(layoutTypeSelections, sel);
    }
    const recordLayoutSelections = [];
    const recordSelections = [];
    for (let i = 0, len = recordDefs.length; i < len; i += 1) {
        const { recordId, recordData } = recordDefs[i];
        push.call(recordLayoutSelections, {
            kind: 'Object',
            name: recordData.apiName,
            required: false,
            map: true,
            selections: layoutTypeSelections,
        });
        const optionalFields = recordOptionalFields[recordId];
        const fields = extractFields(recordData);
        push.call(recordSelections, {
            kind: 'Link',
            name: recordId,
            fragment: {
                kind: 'Fragment',
                selections: buildSelectionFromFields(fields, optionalFields),
                private: ['eTag', 'weakEtag'],
            },
        });
    }
    return {
        kind: 'Fragment',
        private: ['eTag'],
        version: VERSION$15,
        selections: [
            {
                kind: 'Link',
                name: 'layoutUserStates',
                map: true,
                fragment: layoutUserStatePathSelector,
            },
            {
                kind: 'Object',
                name: 'layouts',
                selections: recordLayoutSelections,
            },
            {
                kind: 'Link',
                name: 'objectInfos',
                map: true,
                fragment: objectInfoPathSelection,
            },
            {
                name: 'records',
                kind: 'Object',
                selections: recordSelections,
            },
        ],
    };
}

const FIELD_ID = 'Id';
const FIELD_NAME = 'Name';
const COMPONENT_TYPE_FIELD = 'Field';
function isFieldAReferenceWithRelationshipName(objectInfo, fieldApiName) {
    const field = objectInfo.fields[fieldApiName];
    if (field === undefined) {
        return false;
    }
    // eslint-disable-next-line @salesforce/lds/no-invalid-todo
    // TODO - can reference===true and relationshipName===null?
    return field.reference === true && field.relationshipName !== null;
}
function getRelationshipName(objectInfo, fieldApiName) {
    // eslint-disable-next-line @salesforce/lds/no-invalid-todo
    // TODO RAML - fix typing so isFieldAReferenceWithRelationshipName enables calling this without `relationshipName!`
    return objectInfo.fields[fieldApiName].relationshipName;
}
function getNameField(objectInfo, fieldApiName) {
    // eslint-disable-next-line @salesforce/lds/no-invalid-todo
    // TODO - this logic is adopted from lds222. It searches
    // ObjectInfoRep.ReferenceToInfoRep[].nameFields[]:
    // 1. If any of the arrays are empty returns `Name`
    // 2. If `Name` is found in any array position then returns it
    // 3. If the field has more than 1 references(polymorphic), return `Name`
    // 4. Else returns ObjectInfoRep.ReferenceToInfoRep[0].nameFields[0]
    // Rationale for this is unclear and needs clarification.
    const referenceToInfos = objectInfo.fields[fieldApiName].referenceToInfos;
    if (referenceToInfos.length !== 1) {
        return FIELD_NAME;
    }
    const firstReferenceNameFields = referenceToInfos[0].nameFields;
    if (firstReferenceNameFields.length < 1) {
        return FIELD_NAME;
    }
    for (let a = 0, alen = referenceToInfos.length; a < alen; a++) {
        const nameFields = referenceToInfos[a].nameFields;
        for (let b = 0, blen = nameFields.length; b < blen; b++) {
            const nameField = nameFields[b];
            if (nameField === FIELD_NAME) {
                return nameField;
            }
        }
    }
    return firstReferenceNameFields[0];
}
function getQualifiedFieldApiNamesFromLayout(layout, objectInfo) {
    const qualifiedFieldNames = [];
    const qualifiedOptionalFieldNames = [];
    for (let a = 0, alen = layout.sections.length; a < alen; a++) {
        const section = layout.sections[a];
        for (let b = 0, blen = section.layoutRows.length; b < blen; b++) {
            const row = section.layoutRows[b];
            for (let c = 0, clen = row.layoutItems.length; c < clen; c++) {
                const item = row.layoutItems[c];
                for (let d = 0, dlen = item.layoutComponents.length; d < dlen; d++) {
                    const component = item.layoutComponents[d];
                    const { apiName } = component;
                    if (apiName && component.componentType === COMPONENT_TYPE_FIELD) {
                        if (isFieldAReferenceWithRelationshipName(objectInfo, apiName)) {
                            const relationshipFieldApiName = getRelationshipName(objectInfo, apiName);
                            // By default, include the "Id" field on spanning records that are on the layout.
                            qualifiedFieldNames.push(`${objectInfo.apiName}.${relationshipFieldApiName}.${FIELD_ID}`);
                            const nameField = getNameField(objectInfo, apiName);
                            // W-15692973: Name field of referenced entites are moved to optionalFields since the Name field may not exist for few entites.
                            qualifiedOptionalFieldNames.push(`${objectInfo.apiName}.${relationshipFieldApiName}.${nameField}`);
                        }
                        qualifiedFieldNames.push(`${objectInfo.apiName}.${component.apiName}`);
                    }
                }
            }
        }
    }
    return {
        fields: qualifiedFieldNames,
        optionalFields: qualifiedOptionalFieldNames,
    };
}

function getMissingRecordLookupFields(record, objectInfo) {
    const lookupFields = {};
    const { apiName, fields: recordFields } = record;
    const { fields: objectInfoFields } = objectInfo;
    const objectInfoFieldNames = keys(objectInfoFields);
    for (let i = 0, len = objectInfoFieldNames.length; i < len; i += 1) {
        const fieldName = objectInfoFieldNames[i];
        const field = objectInfoFields[fieldName];
        const { relationshipName } = field;
        if (relationshipName === null) {
            continue;
        }
        const recordFieldValue = recordFields[relationshipName];
        // Only interested in record fields that are present and that are null
        if (recordFieldValue === undefined || recordFieldValue.value !== null) {
            continue;
        }
        // Include the Id field. Ex: Opportunity.Account.Id, Opportunity.relation1__r.Id
        const idFieldName = `${apiName}.${relationshipName}.Id`;
        lookupFields[idFieldName] = true;
        const nameField = `${apiName}.${relationshipName}.${getNameField(objectInfo, fieldName)}`;
        lookupFields[nameField] = true;
    }
    return keys(lookupFields);
}
function getRecordUiMissingRecordLookupFields(recordUi) {
    const { records, objectInfos } = recordUi;
    const recordLookupFields = {};
    const recordIds = keys(records);
    for (let i = 0, len = recordIds.length; i < len; i += 1) {
        const recordId = recordIds[i];
        const recordData = records[recordId];
        const { apiName } = recordData;
        const objectInfo = objectInfos[apiName];
        recordLookupFields[recordId] = getMissingRecordLookupFields(recordData, objectInfo);
    }
    return recordLookupFields;
}

// Custom adapter config due to `unsupported` items
const GET_RECORDUI_ADAPTER_CONFIG = {
    displayName: 'getRecordUi',
    parameters: {
        required: ['recordIds', 'layoutTypes', 'modes'],
        optional: ['optionalFields'],
        unsupported: [
            'formFactor',
            'childRelationships',
            'pageSize',
            'updateMru',
        ],
    },
};
const RECORD_UI_ERROR_STORE_METADATA_PARAMS_VERSION = 'RECORD_UI_ERROR_STORE_METADATA_PARAMS_VERSION_1';
const RECORD_UI_ERROR_STORE_METADATA_PARAMS = {
    ttl: TTL$u,
    representationName: '',
    namespace: keyPrefix,
    version: RECORD_UI_ERROR_STORE_METADATA_PARAMS_VERSION,
};
const RECORD_UI_CACHED_SELECTOR_VERSION = 'RECORD_UI_CACHED_SELECTOR_VERSION_1';
function buildCachedSelectorKey(key) {
    return `${key}__selector`;
}
function eachLayout(recordUi, cb) {
    const { layouts } = recordUi;
    const layoutApiNames = keys(layouts);
    for (let a = 0, len = layoutApiNames.length; a < len; a += 1) {
        const apiName = layoutApiNames[a];
        const apiNameData = layouts[apiName];
        const recordTypeIds = keys(apiNameData);
        for (let b = 0, recordTypeIdsLen = recordTypeIds.length; b < recordTypeIdsLen; b += 1) {
            const recordTypeId = recordTypeIds[b];
            const recordTypeData = apiNameData[recordTypeId];
            const layoutTypes = keys(recordTypeData);
            for (let c = 0, layoutTypesLen = layoutTypes.length; c < layoutTypesLen; c += 1) {
                const layoutType = layoutTypes[c];
                const layoutTypeData = recordTypeData[layoutType];
                const modes = keys(layoutTypeData);
                for (let d = 0, modesLen = modes.length; d < modesLen; d += 1) {
                    const mode = modes[d];
                    const layout = layoutTypeData[mode];
                    cb(apiName, recordTypeId, layout);
                }
            }
        }
    }
}
function collectRecordDefs(resp, recordIds) {
    const recordDefs = [];
    for (let i = 0, len = recordIds.length; i < len; i += 1) {
        const recordId = recordIds[i];
        const recordData = resp.records[recordId];
        push.call(recordDefs, {
            recordId,
            recordData,
            recordTypeId: getRecordTypeId$2(recordData),
        });
    }
    return recordDefs;
}
function keyBuilder$1T(recordIds, layoutTypes, modes, optionalFields) {
    const joinedRecordIds = recordIds.sort().join(',');
    const joinedOptionalFields = optionalFields.sort().join(',');
    const joinedLayoutTypes = layoutTypes.sort().join(',');
    const joinedModes = modes.sort().join(',');
    return `${keyPrefix}::RecordUiRepresentation:${joinedRecordIds}:${joinedLayoutTypes}:${joinedModes}:${joinedOptionalFields}`;
}
function buildSnapshotRefresh$4(luvio, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot$12(luvio, config),
    };
}
function markRecordUiNulledOutLookupFields(recordLookupFields, recordNodes) {
    for (let i = 0, len = recordNodes.length; i < len; i++) {
        const recordId = recordNodes[i].data.id;
        if (recordLookupFields[recordId] !== undefined) {
            markNulledOutRequiredFields(recordNodes[i], recordLookupFields[recordId]);
        }
    }
}
function markRecordUiOptionalFields(optionalFields, recordLookupFields, recordNodes) {
    for (let i = 0, len = recordNodes.length; i < len; i++) {
        const recordId = recordNodes[i].data.id;
        if (optionalFields.length > 0 || recordLookupFields[recordId] !== undefined) {
            markMissingOptionalFields(recordNodes[i], [
                ...optionalFields,
                ...recordLookupFields[recordId],
            ]);
        }
    }
}
function prepareRequest$5(luvio, config) {
    const { recordIds, layoutTypes, modes, optionalFields } = config;
    const key = keyBuilder$1T(recordIds, layoutTypes, modes, optionalFields);
    const selectorKey = buildCachedSelectorKey(key);
    const resourceRequest = createResourceRequest$12({
        urlParams: {
            recordIds,
        },
        queryParams: {
            layoutTypes,
            modes,
            optionalFields: dedupe(optionalFields).sort(),
        },
    });
    return { key, selectorKey, resourceRequest };
}
// NOTE: getRecordUi is special and we can't use the generated getResponseCacheKeys
// (just like we don't use the generated ingestSuccess).  To get the cache keys
// we have to run ingest code and look at the resulting snapshot's seenRecords.
function getCacheKeys(keySet, luvio, config, key, originalResponseBody) {
    const { recordIds, layoutTypes, modes } = config;
    const responseBody = parse(stringify(originalResponseBody));
    eachLayout(responseBody, (apiName, recordTypeId, layout) => {
        if (layout.id === null) {
            return;
        }
        const layoutUserState = responseBody.layoutUserStates[layout.id];
        // Temporary hack since we can't match keys from getLayoutUserState response
        // to record ui's layout users states.
        if (layoutUserState === undefined) {
            return;
        }
        layoutUserState.apiName = apiName;
        layoutUserState.recordTypeId = recordTypeId;
        layoutUserState.mode = layout.mode;
        layoutUserState.layoutType = layout.layoutType;
    });
    const recordLookupFields = getRecordUiMissingRecordLookupFields(responseBody);
    const selPath = buildRecordUiSelector(collectRecordDefs(responseBody, recordIds), layoutTypes, modes, recordLookupFields);
    const sel = {
        recordId: key,
        node: selPath,
        variables: {},
    };
    luvio.storeIngest(key, ingest$E, responseBody);
    const snapshot = luvio.storeLookup(sel, buildSnapshotRefresh$4(luvio, config));
    if (snapshot.state === 'Error') {
        return new StoreKeyMap();
    }
    const keys = [...snapshot.seenRecords.keysAsArray(), snapshot.recordId];
    for (let i = 0, len = keys.length; i < len; i++) {
        const key = keys[i];
        const namespace = key.split('::')[0];
        const representationName = key.split('::')[1].split(':')[0];
        keySet.set(key, {
            namespace,
            representationName,
            mergeable: representationName === RepresentationType$V,
        });
    }
}
function onFetchResponseSuccess$K(luvio, config, selectorKey, key, responseBody) {
    const { recordIds, layoutTypes, modes, optionalFields } = config;
    // eslint-disable-next-line @salesforce/lds/no-invalid-todo
    // TODO fix API so we don't have to augment the response with request details in order
    // to support refresh. these are never emitted out per (private).
    eachLayout(responseBody, (apiName, recordTypeId, layout) => {
        if (layout.id === null) {
            return;
        }
        const layoutUserState = responseBody.layoutUserStates[layout.id];
        // Temporary hack since we can't match keys from getLayoutUserState response
        // to record ui's layout users states.
        if (layoutUserState === undefined) {
            return;
        }
        layoutUserState.apiName = apiName;
        layoutUserState.recordTypeId = recordTypeId;
        layoutUserState.mode = layout.mode;
        layoutUserState.layoutType = layout.layoutType;
    });
    const recordLookupFields = getRecordUiMissingRecordLookupFields(responseBody);
    const selPath = buildRecordUiSelector(collectRecordDefs(responseBody, recordIds), layoutTypes, modes, recordLookupFields);
    const sel = {
        recordId: key,
        node: selPath,
        variables: {},
    };
    luvio.storePublish(selectorKey, sel);
    luvio.storeIngest(key, ingest$E, responseBody);
    // During ingestion, only valid records are stored.
    const recordNodes = [];
    const validRecordIds = [];
    for (let i = 0, len = recordIds.length; i < len; i += 1) {
        const recordId = recordIds[i];
        const recordKey = keyBuilder$29(luvio, { recordId });
        const node = luvio.getNode(recordKey);
        if (isGraphNode(node)) {
            recordNodes.push(node);
            validRecordIds.push(recordId);
        }
    }
    markRecordUiNulledOutLookupFields(recordLookupFields, recordNodes);
    markRecordUiOptionalFields(optionalFields, recordLookupFields, recordNodes);
    publishDependencies(luvio, validRecordIds, [key, selectorKey]);
    const snapshot = luvio.storeLookup(sel, buildSnapshotRefresh$4(luvio, config));
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$L(luvio, config, selectorKey, key, err) {
    const errorSnapshot = luvio.errorSnapshot(err, buildSnapshotRefresh$4(luvio, config));
    luvio.storeIngestError(key, errorSnapshot, RECORD_UI_ERROR_STORE_METADATA_PARAMS);
    return luvio.storeBroadcast().then(() => {
        if (err.errorType === 'fetchResponse') {
            const { status } = err;
            if (status === 404) {
                const sel = {
                    recordId: key,
                    node: {
                        kind: 'Fragment',
                        private: [],
                        opaque: true,
                        version: RECORD_UI_CACHED_SELECTOR_VERSION,
                    },
                    variables: {},
                };
                luvio.storePublish(selectorKey, sel);
                return luvio.storeLookup(sel, buildSnapshotRefresh$4(luvio, config));
            }
        }
        return errorSnapshot;
    });
}
function buildNetworkSnapshot$12(luvio, config, dispatchContext) {
    const { key, resourceRequest, selectorKey } = prepareRequest$5(luvio, config);
    return luvio
        .dispatchResourceRequest(resourceRequest, dispatchContext)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$K(luvio, config, selectorKey, key, response.body), () => {
            const cache = new StoreKeyMap();
            getCacheKeys(cache, luvio, config, key, response.body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return onFetchResponseError$L(luvio, config, selectorKey, key, err);
        });
    });
}
function publishDependencies(luvio, recordIds, depKeys) {
    for (let i = 0, len = recordIds.length; i < len; i += 1) {
        const recordDepKey = dependencyKeyBuilder({ recordId: recordIds[i] });
        const dependencies = create(null);
        for (let j = 0, len = depKeys.length; j < len; j++) {
            dependencies[depKeys[j]] = true;
        }
        const node = luvio.getNode(recordDepKey);
        if (isGraphNode(node)) {
            const recordDeps = node.retrieve();
            assign(dependencies, recordDeps);
        }
        luvio.storePublish(recordDepKey, dependencies);
    }
}
function buildCachedSelectorSnapshot(context, storeLookup) {
    const { config } = context;
    const { recordIds, layoutTypes, modes, optionalFields } = config;
    const key = keyBuilder$1T(recordIds, layoutTypes, modes, optionalFields);
    const cachedSelectorKey = buildCachedSelectorKey(key);
    return storeLookup({
        recordId: cachedSelectorKey,
        node: {
            kind: 'Fragment',
            private: [],
            opaque: true,
            version: RECORD_UI_CACHED_SELECTOR_VERSION,
        },
        variables: {},
    });
}
function buildCachedRecordUiRepresentationSnapshot(context, storeLookup) {
    const { config, luvio, selector } = context;
    // try to resolve RecordUiRepresentation selector if previous steps were able to find one
    if (selector !== undefined) {
        return storeLookup(selector, buildSnapshotRefresh$4(luvio, config));
    }
}
function buildNetworkRecordUiRepresentationSnapshot(context, coercedAdapterRequestContext) {
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$12(context.luvio, context.config, dispatchOptions);
}
function coerceConfigWithDefaults$3(untrustedConfig) {
    const config = validateAdapterConfig$12(untrustedConfig, GET_RECORDUI_ADAPTER_CONFIG);
    if (config === null) {
        return null;
    }
    const { layoutTypes, modes } = config;
    // custom config validation
    if (layoutTypes === undefined || modes === undefined) {
        return null;
    }
    return {
        ...config,
        layoutTypes: layoutTypes,
        modes: modes,
        optionalFields: config.optionalFields === undefined ? [] : config.optionalFields,
    };
}
const factory$g = (luvio) => function UiApi__getRecordUi(untrustedConfig, requestContext) {
    // standard config validation and coercion
    const config = coerceConfigWithDefaults$3(untrustedConfig);
    if (config === null) {
        return null;
    }
    const definedRequestContext = requestContext || {};
    const selectorPromiseOrSnapshot = luvio.applyCachePolicy(definedRequestContext, { config, luvio }, buildCachedSelectorSnapshot, buildNotFetchableNetworkSnapshot(luvio));
    const resolveSelector = (selectorSnapshot) => {
        const selector = isFulfilledSnapshot(selectorSnapshot) || isStaleSnapshot(selectorSnapshot)
            ? selectorSnapshot.data
            : undefined;
        return luvio.applyCachePolicy(definedRequestContext, { config, luvio, selector }, buildCachedRecordUiRepresentationSnapshot, buildNetworkRecordUiRepresentationSnapshot);
    };
    return isPromise(selectorPromiseOrSnapshot)
        ? selectorPromiseOrSnapshot.then(resolveSelector)
        : resolveSelector(selectorPromiseOrSnapshot);
};

var LayoutMode;
(function (LayoutMode) {
    LayoutMode["View"] = "View";
    LayoutMode["Edit"] = "Edit";
    LayoutMode["Create"] = "Create";
})(LayoutMode || (LayoutMode = {}));

const DEFAULT_MODE = LayoutMode.View;
const layoutSelections$1 = select$1L();
function buildSnapshotRefresh$3(luvio, config) {
    return {
        config,
        resolve: () => refresh$1(luvio, config),
    };
}
function buildObjectInfoSelectorKey(luvio, objectInfo) {
    const key = keyBuilderFromType$w(luvio, objectInfo);
    return `${key}__implicit__fields__selector`;
}
function refresh$1(luvio, config) {
    const { recordId, layoutTypes, modes: configModes, optionalFields: configOptionalFields, } = config;
    const modes = configModes === undefined ? [DEFAULT_MODE] : configModes;
    const optionalFields = configOptionalFields === undefined ? [] : configOptionalFields;
    const recordUiConfig = {
        recordIds: [recordId],
        layoutTypes,
        modes,
        optionalFields,
    };
    return buildNetworkSnapshot$12(luvio, recordUiConfig).then((snapshot) => {
        const refresh = buildSnapshotRefresh$3(luvio, config);
        if (isErrorSnapshot(snapshot)) {
            var recordKey = keyBuilder$29(luvio, { recordId });
            luvio.storeIngestError(recordKey, snapshot);
            return luvio.storeBroadcast().then(() => luvio.errorSnapshot(snapshot.error, refresh));
        }
        if (isUnfulfilledSnapshot(snapshot)) {
            if (process.env.NODE_ENV !== 'production') {
                throw new Error(`RecordUi adapter resolved with a snapshot with missing data, missingPaths: ${keys(snapshot.missingPaths)}`);
            }
        }
        const { data } = snapshot;
        if (data === undefined) {
            // eslint-disable-next-line @salesforce/lds/no-error-in-production
            throw new Error(`RecordUi adapter resolved with a ${snapshot.state} snapshot with undefined data`);
        }
        const { layoutMap, objectInfo } = getLayoutMapAndObjectInfo(recordId, data);
        // W-15692973: Name field of referenced entites are moved to optionalFields since the Name field may not exist for few entites.
        const { fields, optionalFields: layoutOptionalFields } = getFieldsFromLayoutMap(layoutMap, objectInfo);
        const mergedOptionalFields = dedupe(optionalFields.concat(layoutOptionalFields));
        return buildCachedSnapshot$9(luvio, {
            recordId,
            fields,
            optionalFields: mergedOptionalFields,
        }, refresh);
    });
}
function getLayoutMapAndObjectInfo(recordId, data) {
    const { objectInfos, layouts, records } = data;
    const record = records[recordId];
    const { apiName } = record;
    const objectInfo = objectInfos[apiName];
    const recordTypeId = getRecordTypeId$2(record);
    // W-12697744 - Return an empty layoutMap if the entity does not have a layout.
    // Temp fix until we can mimic the server behavior for non-layoutable entities.
    let layoutMap = {};
    if (hasOwnProperty.call(layouts, apiName)) {
        layoutMap = layouts[apiName][recordTypeId] || {};
    }
    return {
        layoutMap,
        objectInfo,
    };
}
function getFields(recordId, data) {
    const { records } = data;
    const record = records[recordId];
    const { fields } = record;
    return fields;
}
function processRecordUiRepresentation(luvio, refresh, recordId, modes, snapshot, adapterContext, optionalFields) {
    if (isErrorSnapshot(snapshot)) {
        return luvio.errorSnapshot(snapshot.error, refresh);
    }
    if (isUnfulfilledSnapshot(snapshot)) {
        if (process.env.NODE_ENV !== 'production') {
            throw new Error(`RecordUi adapter resolved with a snapshot with missing data, missingPaths: ${keys(snapshot.missingPaths)}`);
        }
    }
    const { data } = snapshot;
    if (data === undefined) {
        // eslint-disable-next-line @salesforce/lds/no-error-in-production
        throw new Error(`RecordUi adapter resolved with a ${snapshot.state} snapshot with undefined data`);
    }
    const { layoutMap, objectInfo } = getLayoutMapAndObjectInfo(recordId, data);
    if (objectInfo.layoutable) {
        return getRecordForLayoutableEntities(luvio, refresh, recordId, layoutMap, objectInfo, optionalFields);
    }
    else {
        return getRecordForNonLayoutableEntities(luvio, adapterContext, refresh, recordId, objectInfo, optionalFields, getFields(recordId, data));
    }
}
const recordLayoutFragmentSelector = [
    {
        name: 'apiName',
        kind: 'Scalar',
    },
    {
        name: 'recordTypeId',
        kind: 'Scalar',
    },
];
function getFieldsFromLayoutMap(layoutMap, objectInfo) {
    let fields = [];
    let optionalFields = [];
    const layoutTypes = keys(layoutMap);
    for (let i = 0, layoutTypesLen = layoutTypes.length; i < layoutTypesLen; i += 1) {
        const layoutType = layoutTypes[i];
        const modesMap = layoutMap[layoutType];
        const modes = keys(modesMap);
        for (let m = 0, modesLen = modes.length; m < modesLen; m += 1) {
            const mode = modes[m];
            const { fields: modeFields, optionalFields: modeOptionalFields } = getQualifiedFieldApiNamesFromLayout(modesMap[mode], objectInfo);
            fields = fields.concat(modeFields);
            optionalFields = optionalFields.concat(modeOptionalFields);
        }
    }
    return {
        fields: dedupe(fields).sort(),
        optionalFields: dedupe(optionalFields).sort(),
    };
}
/**
 * W-14696113
 * Merge fields into optionalFields and return the whole list.
 * @param {string[]} fields
 * @param {string[]} [optionalFields]
 */
function convertToImplicitFields(fields, optionalFields) {
    const implicitFields = optionalFields || [];
    fields.forEach((field) => {
        if (!(field in implicitFields))
            implicitFields.push(field);
    });
    return implicitFields;
}
function getRecordForLayoutableEntities(luvio, refresh, recordId, layoutMap, objectInfo, configOptionalFields) {
    // W-15692973: Name field of referenced entites are moved to optionalFields since the Name field may not exist for few entites.
    let { fields, optionalFields } = getFieldsFromLayoutMap(layoutMap, objectInfo);
    if (configOptionalFields && configOptionalFields.length > 0) {
        optionalFields = dedupe(optionalFields.concat(configOptionalFields));
    }
    const implicitFields = convertToImplicitFields(fields, optionalFields);
    return getRecord$1(luvio, refresh, recordId, [], implicitFields);
}
function getRecordForNonLayoutableEntities(luvio, adapterContext, refresh, recordId, objectInfo, configOptionalFields, configFields) {
    const fields = keys(configFields ? configFields : {}).map((key) => `${objectInfo.apiName}.${key}`);
    // W-12697744
    // Set the implicit fields received from the server in adapter context
    // This ensures that the implicit fields are available when data is read locally or from durable store
    const selectorKey = buildObjectInfoSelectorKey(luvio, objectInfo);
    adapterContext.set(selectorKey, fields);
    return getRecord$1(luvio, refresh, recordId, fields, configOptionalFields);
}
function getRecord$1(luvio, refresh, recordId, fields, configOptionalFields) {
    const optionalFields = configOptionalFields === undefined ? [] : dedupe(configOptionalFields).sort();
    // We know what fields we need so delegate to getRecordByFields
    // This should be a cache hit because we just fetched the record-ui
    const recordSnapshotOrPromise = getRecordByFields(luvio, {
        recordId,
        fields,
        optionalFields,
    });
    // attach a record layout refresh
    if (isPromise(recordSnapshotOrPromise)) {
        recordSnapshotOrPromise.then((snapshot) => {
            snapshot.refresh = refresh;
            return snapshot;
        });
    }
    else {
        recordSnapshotOrPromise.refresh = refresh;
    }
    return recordSnapshotOrPromise;
}
function buildNetworkSnapshot$11(context, coercedAdapterRequestContext) {
    const { config, luvio, adapterContext } = context;
    const { recordId } = config;
    const optionalFields = config.optionalFields === undefined ? [] : dedupe(config.optionalFields).sort();
    const refresh = buildSnapshotRefresh$3(luvio, config);
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    // if we were able to map the layouts to a set of fields then use GetRecordFields
    // to send a request for just those fields
    if (context.fields !== undefined) {
        const recordConfig = {
            recordId,
            fields: context.fields,
            optionalFields,
        };
        return buildNetworkSnapshot$16(luvio, recordConfig, 0, coercedAdapterRequestContext).then((snapshot) => {
            snapshot.refresh = refresh;
            return snapshot;
        });
    }
    // otherwise fallback to getRecordUi to get the full set of information
    const modes = config.modes !== undefined ? config.modes : [DEFAULT_MODE];
    const recordUiConfig = {
        recordIds: [recordId],
        layoutTypes: config.layoutTypes,
        modes,
        optionalFields,
    };
    return buildNetworkSnapshot$12(luvio, recordUiConfig, dispatchOptions).then((snapshot) => processRecordUiRepresentation(luvio, refresh, recordId, modes, snapshot, adapterContext, optionalFields));
}
function buildRecordLayoutCachedSnapshot(context, storeLookup) {
    const { config, luvio } = context;
    // get cached copy of the record
    const { recordId } = config;
    const storeKey = keyBuilder$29(luvio, { recordId });
    const recordSnapshot = storeLookup({
        recordId: storeKey,
        node: {
            kind: 'Fragment',
            private: [],
            selections: recordLayoutFragmentSelector,
            version: VERSION$1g,
        },
        variables: {},
    });
    return recordSnapshot;
}
const buildObjectInfoCacheSnapshot = (recordLayoutSnapshot) => (context, storeLookup) => {
    const { luvio } = context;
    if (recordLayoutSnapshot.data === undefined) {
        return;
    }
    return buildCachedSnapshotCachePolicy$O({
        config: {
            objectApiName: recordLayoutSnapshot.data.apiName,
        },
        luvio,
    }, storeLookup);
};
const buildLayoutModeCacheSnapshot = (apiName, recordTypeId, layoutType, mode) => (context, storeLookup) => {
    const { luvio } = context;
    const key = keyBuilder$1V(luvio, {
        objectApiName: apiName,
        recordTypeId,
        layoutType,
        mode,
    });
    return storeLookup({
        recordId: key,
        node: layoutSelections$1,
        variables: {},
    });
};
/**
 * Create a snapshot that will only attempt to build from cache
 * These are intermediate lookups to check if the record is in the L2 cache
 * @param  {Luvio} luvio
 * @param  {GetRecordLayoutTypeConfig} config
 * @param  {BuildCachedSnapshot<BuildSnapshotContext>} cachedSnapshot
 */
function makeCacheOnlySnapshot(luvio, config, adapterContext, cachedSnapshot) {
    return luvio.applyCachePolicy(
    // Pass empty context so environment will use its default cache-policy
    {}, { config, luvio, adapterContext }, cachedSnapshot, 
    // disallow hitting the network by returning a gateway timeout
    () => {
        return new Promise((resolve) => {
            resolve({
                state: 'Error',
                data: undefined,
                error: {
                    body: undefined,
                    headers: {},
                    ok: false,
                    status: 504,
                    statusText: 'Gateway Timeout',
                    errorType: 'fetchResponse',
                },
            });
        });
    });
}
/**
 * Create a snapshot that will fail to pull from the cache
 * and force a network call
 * @param  {Luvio} luvio
 * @param  {GetRecordLayoutTypeConfig} config
 * @param  {AdapterRequestContext} requestContext?
 */
function makeNetworkOnlySnapshot(luvio, config, adapterContext, requestContext) {
    return luvio.applyCachePolicy(requestContext || {}, { config, luvio, adapterContext }, () => {
        return undefined;
    }, buildNetworkSnapshot$11);
}
function getRecordLayoutType(luvio, config, adapterContext, requestContext) {
    // lookup record layout
    const recordLayoutSnapshotOrPromise = makeCacheOnlySnapshot(luvio, config, adapterContext, buildRecordLayoutCachedSnapshot);
    return runSnapshotOrPromise(recordLayoutSnapshotOrPromise, (recordLayoutSnapshot) => {
        // if record layout is not fulfulled or data is undefined send to the network
        if (recordLayoutSnapshot.state === 'Unfulfilled' ||
            recordLayoutSnapshot.state === 'Error' ||
            recordLayoutSnapshot.data === undefined) {
            return makeNetworkOnlySnapshot(luvio, config, adapterContext, requestContext);
        }
        // lookup object info
        const objectInfoSnapshotOrPromise = makeCacheOnlySnapshot(luvio, config, adapterContext, buildObjectInfoCacheSnapshot(recordLayoutSnapshot));
        return runSnapshotOrPromise(objectInfoSnapshotOrPromise, (objectInfoSnapshot) => {
            const { layoutTypes } = config;
            // if not fulfilled or missing data send to the network
            if (objectInfoSnapshot.state === 'Unfulfilled' ||
                objectInfoSnapshot.state === 'Error' ||
                objectInfoSnapshot.data === undefined) {
                return makeNetworkOnlySnapshot(luvio, config, adapterContext, requestContext);
            }
            const { data: record } = recordLayoutSnapshot;
            // try to load all the requested layouts from cache
            const recordTypeId = getRecordTypeId$2(record);
            const modes = config.modes === undefined ? [DEFAULT_MODE] : config.modes;
            // W-12697744
            // For non-layoutable entities, use the implicit fields as the fields are not available in layout
            // Fields can be fetched from adapter context if the server request was already made at some point in the past
            // If fields are not available in adapter context, make a network request to get the data
            // and store implicit fields in adapter context.
            if (!objectInfoSnapshot.data.layoutable) {
                const selectorKey = buildObjectInfoSelectorKey(luvio, objectInfoSnapshot.data);
                const fields = adapterContext.get(selectorKey);
                if (!fields) {
                    return makeNetworkOnlySnapshot(luvio, config, adapterContext, requestContext);
                }
                return luvio.applyCachePolicy(requestContext || {}, { config, luvio, adapterContext }, buildRecordSnapshot(luvio, config, recordLayoutSnapshot, objectInfoSnapshot, fields), buildNetworkSnapshot$11);
            }
            return makeRecordLayoutMap(luvio, config, objectInfoSnapshot.data.apiName, recordTypeId, layoutTypes, modes, adapterContext).then((recordLayoutMap) => {
                return luvio.applyCachePolicy(requestContext || {}, { config, luvio, adapterContext }, buildRecordLayoutSnapshot(recordLayoutMap, luvio, config, recordLayoutSnapshot, objectInfoSnapshot), buildNetworkSnapshot$11);
            });
        });
    });
}
/**
 * Takes a views layout types and modes and returns the snapshot of a RecordLayoutRepresentation
 * for each type/mode
 * @param  {Luvio} luvio
 * @param  {GetRecordLayoutTypeConfig} config
 * @param  {string} apiName
 * @param  {string} recordTypeId
 * @param  {LayoutType[]} layoutTypes
 * @param  {LayoutMode[]} modes
 */
function makeRecordLayoutMap(luvio, config, apiName, recordTypeId, layoutTypes, modes, adapterContext) {
    let promises = [];
    for (let i = 0; i < layoutTypes.length; i++) {
        const layoutType = layoutTypes[i];
        for (let m = 0; m < modes.length; m++) {
            const mode = modes[m];
            promises.push(Promise.resolve(makeCacheOnlySnapshot(luvio, config, adapterContext, buildLayoutModeCacheSnapshot(apiName, recordTypeId, layoutType, mode))).then((snapshot) => {
                return {
                    layoutType,
                    mode,
                    snapshot,
                };
            }));
        }
    }
    return Promise.all(promises).then((containers) => {
        let wrapper = {
            isStale: false,
        };
        for (let i = 0; i < containers.length; i++) {
            const container = containers[i];
            if (container.snapshot.data === undefined) {
                wrapper.isStale = false;
                wrapper.layoutMap = undefined;
                //if we have no data then break and force the adapter to go to the network
                break;
            }
            if (wrapper.layoutMap === undefined) {
                wrapper.layoutMap = {};
            }
            const { layoutType, mode, snapshot } = container;
            if (wrapper.layoutMap[layoutType] === undefined) {
                wrapper.layoutMap = assign({}, wrapper.layoutMap, {
                    [layoutType]: {},
                });
            }
            if (snapshot.data !== undefined) {
                wrapper.layoutMap[layoutType][mode] = snapshot.data;
            }
            wrapper.isStale = wrapper.isStale || isStaleSnapshot(snapshot);
        }
        return wrapper;
    });
}
function buildRecordLayoutSnapshot(recordLayout, luvio, config, recordLayoutSnapshot, objectInfoSnapshot) {
    return (context, storeLookup) => {
        const { layoutMap, isStale: isRecordLayoutStale } = recordLayout;
        if (layoutMap === undefined || objectInfoSnapshot.data === undefined) {
            return;
        }
        // transform the layouts & object info into a set of fields
        // // W-15692973: Name field of referenced entites are moved to optionalFields since the Name field may not exist for few entites.
        const { fields, optionalFields } = getFieldsFromLayoutMap(layoutMap, objectInfoSnapshot.data);
        let configWithModifiedOptionalFields = {
            ...config,
            optionalFields: config.optionalFields
                ? dedupe(config.optionalFields.concat(optionalFields)).sort()
                : optionalFields,
        };
        return getRecordRepSnapshot(luvio, configWithModifiedOptionalFields, recordLayoutSnapshot, objectInfoSnapshot, fields, isRecordLayoutStale, context, storeLookup);
    };
}
function buildRecordSnapshot(luvio, config, recordLayoutSnapshot, objectInfoSnapshot, fields) {
    return (context, storeLookup) => {
        return getRecordRepSnapshot(luvio, config, recordLayoutSnapshot, objectInfoSnapshot, fields, false, context, storeLookup);
    };
}
function getRecordRepSnapshot(luvio, config, recordLayoutSnapshot, objectInfoSnapshot, fields, isRecordLayoutStale, context, storeLookup) {
    if (objectInfoSnapshot.data === undefined) {
        return;
    }
    // transform the layouts & object info into a set of fields
    const optionalFields = config.optionalFields === undefined ? [] : dedupe(config.optionalFields).sort();
    const { recordId } = config;
    // borrow GetRecordFields' logic to construct the RecordRepresentation with the necessary fields
    const sel = buildRecordSelector(luvio, recordId, fields, optionalFields);
    const recordRepSnapshot = storeLookup(sel, buildSnapshotRefresh$3(luvio, config));
    if (isFulfilledSnapshot(recordRepSnapshot)) {
        // mark snapshot as stale if any of the information used to construct it was stale
        if (isStaleSnapshot(objectInfoSnapshot) ||
            isStaleSnapshot(recordLayoutSnapshot) ||
            isRecordLayoutStale) {
            recordRepSnapshot.state = 'Stale';
        }
    }
    // allow buildNetworkSnapshot() to use GetRecordFields if we were just missing some fields in L1
    else if (isUnfulfilledSnapshot(recordRepSnapshot)) {
        context.fields = fields;
        // W-15692973: Update optionalFields of config as the optional fields may have Name fields of referenced entities
        context.config.optionalFields = optionalFields;
    }
    // return however much of the record we were able to find in L1; cache policy decides if we
    // should consult L2 or go to network
    return recordRepSnapshot;
}
function runSnapshotOrPromise(promiseOrSnapshot, next) {
    if (isPromise(promiseOrSnapshot)) {
        return promiseOrSnapshot.then(next);
    }
    else {
        return next(promiseOrSnapshot);
    }
}

const contextId$4 = `${keyPrefix}__${adapterName$11}`;
// Custom adapter config due to `unsupported` items
const GET_RECORD_ADAPTER_CONFIG = {
    displayName: 'getRecord',
    parameters: {
        required: ['recordId'],
        optional: ['fields', 'layoutTypes', 'modes', 'optionalFields'],
        unsupported: [
            'childRelationships',
            'pageSize',
            'updateMru',
        ],
    },
};
function hasLayoutTypes(config) {
    return 'layoutTypes' in config;
}
function hasFieldsOrOptionalFields(config) {
    return 'fields' in config || 'optionalFields' in config;
}
function createResourceRequestFromRepresentation(representation, optionalFields) {
    const config = {
        urlParams: {
            recordId: representation.id,
        },
        queryParams: {
            optionalFields,
        },
    };
    return createResourceRequest$1d(config);
}
// eslint-disable-next-line @salesforce/lds/no-invalid-todo
// TODO: this should probably be code generated in RecordRepresentation
function coerceKeyParams(config) {
    const coercedConfig = {};
    const recordId = getRecordId18(config.recordId);
    if (recordId !== undefined) {
        coercedConfig.recordId = recordId;
    }
    return coercedConfig;
}
const notifyChangeFactory = (luvio) => {
    return function getUiApiRecordsByRecordIdNotifyChange(configs) {
        const keys = configs.map((c) => keyBuilder$29(luvio, coerceKeyParams(c)));
        luvio.getNotifyChangeStoreEntries(keys).then((entries) => {
            const responsePromises = [];
            for (let i = 0, len = entries.length; i < len; i++) {
                const { key, record } = entries[i];
                const node = luvio.wrapNormalizedGraphNode(record, key);
                const optionalFields = getTrackedFields(key, node, {
                    maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnNotifyChange(),
                    onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
                });
                const refreshRequest = createResourceRequestFromRepresentation(record, optionalFields);
                const existingWeakEtag = record.weakEtag;
                const fieldTrie = convertFieldsToTrie([], false);
                const optionalFieldTrie = convertFieldsToTrie(optionalFields, true);
                const dispatchResourceRequestPromise = luvio
                    .dispatchResourceRequest(refreshRequest)
                    .then((response) => {
                    return luvio.handleSuccessResponse(() => {
                        const { body } = response;
                        luvio.storeIngest(key, createFieldsIngestSuccess$3({
                            fields: fieldTrie,
                            optionalFields: optionalFieldTrie,
                            trackedFields: optionalFieldTrie,
                            serverRequestCount: 1,
                        }), body);
                        const result = luvio.storeBroadcast();
                        instrumentation.getRecordNotifyChangeNetworkResult(existingWeakEtag !== body.weakEtag);
                        return result;
                    }, () => {
                        const cache = new StoreKeyMap();
                        getTypeCacheKeys$V(cache, luvio, response.body);
                        return cache;
                    });
                }, (error) => {
                    return luvio.handleErrorResponse(() => {
                        const errorSnapshot = luvio.errorSnapshot(error);
                        luvio.storeIngestError(key, errorSnapshot, RECORD_REPRESENTATION_ERROR_STORE_METADATA_PARAMS);
                        const result = luvio.storeBroadcast();
                        instrumentation.getRecordNotifyChangeNetworkResult(null, true);
                        return result.then(() => errorSnapshot);
                    });
                });
                responsePromises.push(dispatchResourceRequestPromise);
            }
            return Promise.all(responsePromises);
        });
    };
};
const factory$f = (luvio) => {
    return luvio.withContext(function getRecord(untrustedConfig, adapterContext, requestContext) {
        // standard config validation and coercion
        const config = validateAdapterConfig$18(untrustedConfig, GET_RECORD_ADAPTER_CONFIG);
        if (config === null) {
            return null;
        }
        if (hasLayoutTypes(config)) {
            return getRecordLayoutType(luvio, config, adapterContext, requestContext);
        }
        else if (hasFieldsOrOptionalFields(config)) {
            return getRecordByFields(luvio, config, requestContext);
        }
        return null;
    }, { contextId: contextId$4 });
};

const notifyUpdateAvailableFactory$1 = (luvio) => {
    return function notifyListInfoUpdateAvailable(configs) {
        const generated_notifyUpdateAvailable = notifyUpdateAvailableFactory$6(luvio);
        // Taken from getUiApiListInfoByListViewApiNameAndObjectApiName/keyBuilder artifact
        // We automatically set the type based on the listViewApiName, and we need to do the same
        // here for key matching and validation
        configs.forEach((config) => {
            config.listViewApiName = config.listViewApiName
                ? config.listViewApiName.toLowerCase()
                : config.listViewApiName;
            config.objectApiName = config.objectApiName
                ? config.objectApiName.toLowerCase()
                : config.objectApiName;
            if (!config.type) {
                config.type = config.listViewApiName === '__recent' ? 'mru' : 'listView';
            }
        });
        return generated_notifyUpdateAvailable(configs);
    };
};

const VERSION$14 = "4aa37812ee37c752a099b29026217c85";
function validate$1A(obj, path = 'ObjectInfoDirectoryEntryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_keyPrefix = obj.keyPrefix;
        const path_keyPrefix = path + '.keyPrefix';
        let obj_keyPrefix_union0 = null;
        const obj_keyPrefix_union0_error = (() => {
            if (typeof obj_keyPrefix !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_keyPrefix + '" (at "' + path_keyPrefix + '")');
            }
        })();
        if (obj_keyPrefix_union0_error != null) {
            obj_keyPrefix_union0 = obj_keyPrefix_union0_error.message;
        }
        let obj_keyPrefix_union1 = null;
        const obj_keyPrefix_union1_error = (() => {
            if (obj_keyPrefix !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_keyPrefix + '" (at "' + path_keyPrefix + '")');
            }
        })();
        if (obj_keyPrefix_union1_error != null) {
            obj_keyPrefix_union1 = obj_keyPrefix_union1_error.message;
        }
        if (obj_keyPrefix_union0 && obj_keyPrefix_union1) {
            let message = 'Object doesn\'t match union (at "' + path_keyPrefix + '")';
            message += '\n' + obj_keyPrefix_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_keyPrefix_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_labelPlural = obj.labelPlural;
        const path_labelPlural = path + '.labelPlural';
        if (typeof obj_labelPlural !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_labelPlural + '" (at "' + path_labelPlural + '")');
        }
        const obj_nameFields = obj.nameFields;
        const path_nameFields = path + '.nameFields';
        if (!ArrayIsArray(obj_nameFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_nameFields + '" (at "' + path_nameFields + '")');
        }
        for (let i = 0; i < obj_nameFields.length; i++) {
            const obj_nameFields_item = obj_nameFields[i];
            const path_nameFields_item = path_nameFields + '[' + i + ']';
            if (typeof obj_nameFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nameFields_item + '" (at "' + path_nameFields_item + '")');
            }
        }
        const obj_objectInfoUrl = obj.objectInfoUrl;
        const path_objectInfoUrl = path + '.objectInfoUrl';
        if (typeof obj_objectInfoUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectInfoUrl + '" (at "' + path_objectInfoUrl + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$K = 'ObjectInfoDirectoryEntryRepresentation';
function keyBuilder$1S(luvio, config) {
    return keyPrefix + '::' + RepresentationType$K + ':' + config.objectInfoUrl;
}
function keyBuilderFromType$t(luvio, object) {
    const keyParams = {
        objectInfoUrl: object.objectInfoUrl
    };
    return keyBuilder$1S(luvio, keyParams);
}
function normalize$D(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1J = function ObjectInfoDirectoryEntryRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$14,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'keyPrefix',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'labelPlural',
                kind: 'Scalar'
            },
            {
                name: 'nameFields',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'objectInfoUrl',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$W(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_labelPlural = existing.labelPlural;
    const incoming_labelPlural = incoming.labelPlural;
    if (!(existing_labelPlural === incoming_labelPlural)) {
        return false;
    }
    const existing_objectInfoUrl = existing.objectInfoUrl;
    const incoming_objectInfoUrl = incoming.objectInfoUrl;
    if (!(existing_objectInfoUrl === incoming_objectInfoUrl)) {
        return false;
    }
    const existing_keyPrefix = existing.keyPrefix;
    const incoming_keyPrefix = incoming.keyPrefix;
    if (!(existing_keyPrefix === incoming_keyPrefix)) {
        return false;
    }
    const existing_nameFields = existing.nameFields;
    const incoming_nameFields = incoming.nameFields;
    const equals_nameFields_items = equalsArray(existing_nameFields, incoming_nameFields, (existing_nameFields_item, incoming_nameFields_item) => {
        if (!(existing_nameFields_item === incoming_nameFields_item)) {
            return false;
        }
    });
    if (equals_nameFields_items === false) {
        return false;
    }
    return true;
}
const ingest$D = function ObjectInfoDirectoryEntryRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1A(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$t(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$D, "UiApi", VERSION$14, RepresentationType$K, equals$W);
    return createLink(key);
};
function getTypeCacheKeys$L(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$t(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$K,
        mergeable: false
    });
}

const VERSION$13 = "37fd8c0154ee743c9defbf03e9b4b067";
function validate$1z(obj, path = 'ObjectInfoDirectoryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_objects = obj.objects;
        const path_objects = path + '.objects';
        if (typeof obj_objects !== 'object' || ArrayIsArray(obj_objects) || obj_objects === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_objects + '" (at "' + path_objects + '")');
        }
        const obj_objects_keys = ObjectKeys(obj_objects);
        for (let i = 0; i < obj_objects_keys.length; i++) {
            const key = obj_objects_keys[i];
            const obj_objects_prop = obj_objects[key];
            const path_objects_prop = path_objects + '["' + key + '"]';
            if (typeof obj_objects_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_objects_prop + '" (at "' + path_objects_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$J = 'ObjectInfoDirectoryRepresentation';
function normalize$C(input, existing, path, luvio, store, timestamp) {
    const input_objects = input.objects;
    const input_objects_id = path.fullPath + '__objects';
    const input_objects_keys = Object.keys(input_objects);
    const input_objects_length = input_objects_keys.length;
    for (let i = 0; i < input_objects_length; i++) {
        const key = input_objects_keys[i];
        const input_objects_prop = input_objects[key];
        const input_objects_prop_id = input_objects_id + '__' + key;
        input_objects[key] = ingest$D(input_objects_prop, {
            fullPath: input_objects_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1I = function ObjectInfoDirectoryRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$13,
        private: [],
        selections: [
            {
                name: 'objects',
                kind: 'Link',
                map: true,
                fragment: select$1J()
            }
        ]
    };
};
function equals$V(existing, incoming) {
    const existing_objects = existing.objects;
    const incoming_objects = incoming.objects;
    const equals_objects_props = equalsObject(existing_objects, incoming_objects, (existing_objects_prop, incoming_objects_prop) => {
        if (!(existing_objects_prop.__ref === incoming_objects_prop.__ref)) {
            return false;
        }
    });
    if (equals_objects_props === false) {
        return false;
    }
    return true;
}
const ingest$C = function ObjectInfoDirectoryRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1z(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$C, "UiApi", VERSION$13, RepresentationType$J, equals$V);
    return createLink(key);
};
function getTypeCacheKeys$K(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$J,
        mergeable: false
    });
    const input_objects = input.objects;
    const input_objects_keys = ObjectKeys(input_objects);
    const input_objects_length = input_objects_keys.length;
    for (let i = 0; i < input_objects_length; i++) {
        const key = input_objects_keys[i];
        getTypeCacheKeys$L(rootKeySet, luvio, input_objects[key]);
    }
}

const VERSION$12 = "7e00c51105cbf56a79ab8fcddf462c1e";
function validate$1y(obj, path = 'QuickActionExecutionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_contextId = obj.contextId;
        const path_contextId = path + '.contextId';
        let obj_contextId_union0 = null;
        const obj_contextId_union0_error = (() => {
            if (typeof obj_contextId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_contextId + '" (at "' + path_contextId + '")');
            }
        })();
        if (obj_contextId_union0_error != null) {
            obj_contextId_union0 = obj_contextId_union0_error.message;
        }
        let obj_contextId_union1 = null;
        const obj_contextId_union1_error = (() => {
            if (obj_contextId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_contextId + '" (at "' + path_contextId + '")');
            }
        })();
        if (obj_contextId_union1_error != null) {
            obj_contextId_union1 = obj_contextId_union1_error.message;
        }
        if (obj_contextId_union0 && obj_contextId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_contextId + '")';
            message += '\n' + obj_contextId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_contextId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_feedItemId = obj.feedItemId;
        const path_feedItemId = path + '.feedItemId';
        let obj_feedItemId_union0 = null;
        const obj_feedItemId_union0_error = (() => {
            if (typeof obj_feedItemId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_feedItemId + '" (at "' + path_feedItemId + '")');
            }
        })();
        if (obj_feedItemId_union0_error != null) {
            obj_feedItemId_union0 = obj_feedItemId_union0_error.message;
        }
        let obj_feedItemId_union1 = null;
        const obj_feedItemId_union1_error = (() => {
            if (obj_feedItemId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_feedItemId + '" (at "' + path_feedItemId + '")');
            }
        })();
        if (obj_feedItemId_union1_error != null) {
            obj_feedItemId_union1 = obj_feedItemId_union1_error.message;
        }
        if (obj_feedItemId_union0 && obj_feedItemId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_feedItemId + '")';
            message += '\n' + obj_feedItemId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_feedItemId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_isCreated = obj.isCreated;
        const path_isCreated = path + '.isCreated';
        if (typeof obj_isCreated !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isCreated + '" (at "' + path_isCreated + '")');
        }
        const obj_isSuccess = obj.isSuccess;
        const path_isSuccess = path + '.isSuccess';
        if (typeof obj_isSuccess !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isSuccess + '" (at "' + path_isSuccess + '")');
        }
        const obj_successMessage = obj.successMessage;
        const path_successMessage = path + '.successMessage';
        if (typeof obj_successMessage !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_successMessage + '" (at "' + path_successMessage + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$I = 'QuickActionExecutionRepresentation';
function keyBuilder$1R(luvio, config) {
    return keyPrefix + '::' + RepresentationType$I + ':' + config.id;
}
function keyBuilderFromType$s(luvio, object) {
    const keyParams = {
        id: object.id
    };
    return keyBuilder$1R(luvio, keyParams);
}
function normalize$B(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1H = function QuickActionExecutionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$12,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'contextId',
                kind: 'Scalar'
            },
            {
                name: 'feedItemId',
                kind: 'Scalar'
            },
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'isCreated',
                kind: 'Scalar'
            },
            {
                name: 'isSuccess',
                kind: 'Scalar'
            },
            {
                name: 'successMessage',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$U(existing, incoming) {
    const existing_isCreated = existing.isCreated;
    const incoming_isCreated = incoming.isCreated;
    if (!(existing_isCreated === incoming_isCreated)) {
        return false;
    }
    const existing_isSuccess = existing.isSuccess;
    const incoming_isSuccess = incoming.isSuccess;
    if (!(existing_isSuccess === incoming_isSuccess)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_successMessage = existing.successMessage;
    const incoming_successMessage = incoming.successMessage;
    if (!(existing_successMessage === incoming_successMessage)) {
        return false;
    }
    const existing_contextId = existing.contextId;
    const incoming_contextId = incoming.contextId;
    if (!(existing_contextId === incoming_contextId)) {
        return false;
    }
    const existing_feedItemId = existing.feedItemId;
    const incoming_feedItemId = incoming.feedItemId;
    if (!(existing_feedItemId === incoming_feedItemId)) {
        return false;
    }
    return true;
}
const ingest$B = function QuickActionExecutionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1y(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$s(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$B, "UiApi", VERSION$12, RepresentationType$I, equals$U);
    return createLink(key);
};
function getTypeCacheKeys$J(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$s(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$I,
        mergeable: false
    });
}

const TTL$t = 900000;
const VERSION$11 = "993b0a7bce6056c4f57ed300ec153d9c";
function validate$1x(obj, path = 'QuickActionDefaultsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actionApiName = obj.actionApiName;
        const path_actionApiName = path + '.actionApiName';
        if (typeof obj_actionApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionApiName + '" (at "' + path_actionApiName + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            if (typeof obj_fields_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
            }
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$H = 'QuickActionDefaultsRepresentation';
function keyBuilder$1Q(luvio, config) {
    return keyPrefix + '::' + RepresentationType$H + ':' + config.actionApiName;
}
function keyBuilderFromType$r(luvio, object) {
    const keyParams = {
        actionApiName: object.actionApiName
    };
    return keyBuilder$1Q(luvio, keyParams);
}
function dynamicNormalize$4(ingestParams) {
    return function normalize_dynamic(input, existing, path, luvio, store, timestamp) {
        const input_fields = input.fields;
        const input_fields_id = path.fullPath + '__fields';
        const input_fields_keys = Object.keys(input_fields);
        const input_fields_length = input_fields_keys.length;
        for (let i = 0; i < input_fields_length; i++) {
            const key = input_fields_keys[i];
            const input_fields_prop = input_fields[key];
            const input_fields_prop_id = input_fields_id + '__' + key;
            input_fields[key] = ingestParams.fields(input_fields_prop, {
                fullPath: input_fields_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        return input;
    };
}
const dynamicSelect$5 = function dynamicQuickActionDefaultsRepresentationSelect(params) {
    const fieldsPathSelection = params.fields === undefined ? {
        name: 'fields',
        kind: 'Link',
        map: true,
        fragment: select$1X()
    } : params.fields;
    return {
        kind: 'Fragment',
        version: VERSION$11,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'actionApiName',
                kind: 'Scalar'
            },
            fieldsPathSelection,
            {
                name: 'objectApiName',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$T(existing, incoming) {
    const existing_actionApiName = existing.actionApiName;
    const incoming_actionApiName = incoming.actionApiName;
    if (!(existing_actionApiName === incoming_actionApiName)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_props = equalsObject(existing_fields, incoming_fields, (existing_fields_prop, incoming_fields_prop) => {
        if (!(existing_fields_prop.__ref === incoming_fields_prop.__ref)) {
            return false;
        }
    });
    if (equals_fields_props === false) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$I(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$r(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$H,
        mergeable: false
    });
    const input_fields = input.fields;
    const input_fields_keys = ObjectKeys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$Y(rootKeySet, luvio, input_fields[key], () => rootKey + "__fields" + "__" + key);
    }
}
const notifyUpdateAvailableFactory = (luvio) => {
    return function notifyQuickActionDefaultsUpdateAvailable(configs) {
        if (process.env.NODE_ENV !== 'production') {
            const requiredKeyParams = ['actionApiName'];
            configs.forEach(config => {
                if (false === requiredKeyParams.every(req => req in config)) {
                    throw new Error(`one of the configs did not contain all required parameters: ${JSONStringify(ObjectKeys(config))}`);
                }
            });
        }
        const keys = configs.map(c => keyBuilder$1Q(luvio, c));
        return luvio.notifyStoreUpdateAvailable(keys);
    };
};

function toSortedStringArrayAllowEmpty(value) {
    const valueArray = isArray(value) ? value : [value];
    if (valueArray.length === 0) {
        return valueArray;
    }
    return toSortedStringArray(valueArray);
}

var FormFactor;
(function (FormFactor) {
    FormFactor["Large"] = "Large";
    FormFactor["Medium"] = "Medium";
    FormFactor["Small"] = "Small";
})(FormFactor || (FormFactor = {}));

function coerceFormFactor(form) {
    if (form === FormFactor.Large || form === FormFactor.Medium || form === FormFactor.Small) {
        return form;
    }
    return undefined;
}

const VERSION$10 = "3f49d751896cf66e6e29788d8880e2cc";
function validate$1w(obj, path = 'PlatformActionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actionListContext = obj.actionListContext;
        const path_actionListContext = path + '.actionListContext';
        if (typeof obj_actionListContext !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionListContext + '" (at "' + path_actionListContext + '")');
        }
        const obj_actionTarget = obj.actionTarget;
        const path_actionTarget = path + '.actionTarget';
        let obj_actionTarget_union0 = null;
        const obj_actionTarget_union0_error = (() => {
            if (typeof obj_actionTarget !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_actionTarget + '" (at "' + path_actionTarget + '")');
            }
        })();
        if (obj_actionTarget_union0_error != null) {
            obj_actionTarget_union0 = obj_actionTarget_union0_error.message;
        }
        let obj_actionTarget_union1 = null;
        const obj_actionTarget_union1_error = (() => {
            if (obj_actionTarget !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_actionTarget + '" (at "' + path_actionTarget + '")');
            }
        })();
        if (obj_actionTarget_union1_error != null) {
            obj_actionTarget_union1 = obj_actionTarget_union1_error.message;
        }
        if (obj_actionTarget_union0 && obj_actionTarget_union1) {
            let message = 'Object doesn\'t match union (at "' + path_actionTarget + '")';
            message += '\n' + obj_actionTarget_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_actionTarget_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_actionTargetType = obj.actionTargetType;
        const path_actionTargetType = path + '.actionTargetType';
        let obj_actionTargetType_union0 = null;
        const obj_actionTargetType_union0_error = (() => {
            if (typeof obj_actionTargetType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_actionTargetType + '" (at "' + path_actionTargetType + '")');
            }
        })();
        if (obj_actionTargetType_union0_error != null) {
            obj_actionTargetType_union0 = obj_actionTargetType_union0_error.message;
        }
        let obj_actionTargetType_union1 = null;
        const obj_actionTargetType_union1_error = (() => {
            if (obj_actionTargetType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_actionTargetType + '" (at "' + path_actionTargetType + '")');
            }
        })();
        if (obj_actionTargetType_union1_error != null) {
            obj_actionTargetType_union1 = obj_actionTargetType_union1_error.message;
        }
        if (obj_actionTargetType_union0 && obj_actionTargetType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_actionTargetType + '")';
            message += '\n' + obj_actionTargetType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_actionTargetType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_externalId = obj.externalId;
        const path_externalId = path + '.externalId';
        if (typeof obj_externalId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_externalId + '" (at "' + path_externalId + '")');
        }
        const obj_iconUrl = obj.iconUrl;
        const path_iconUrl = path + '.iconUrl';
        let obj_iconUrl_union0 = null;
        const obj_iconUrl_union0_error = (() => {
            if (typeof obj_iconUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union0_error != null) {
            obj_iconUrl_union0 = obj_iconUrl_union0_error.message;
        }
        let obj_iconUrl_union1 = null;
        const obj_iconUrl_union1_error = (() => {
            if (obj_iconUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union1_error != null) {
            obj_iconUrl_union1 = obj_iconUrl_union1_error.message;
        }
        if (obj_iconUrl_union0 && obj_iconUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_iconUrl + '")';
            message += '\n' + obj_iconUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_iconUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_isMassAction = obj.isMassAction;
        const path_isMassAction = path + '.isMassAction';
        if (typeof obj_isMassAction !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_isMassAction + '" (at "' + path_isMassAction + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_lwcComponent = obj.lwcComponent;
        const path_lwcComponent = path + '.lwcComponent';
        let obj_lwcComponent_union0 = null;
        const obj_lwcComponent_union0_error = (() => {
            if (typeof obj_lwcComponent !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lwcComponent + '" (at "' + path_lwcComponent + '")');
            }
        })();
        if (obj_lwcComponent_union0_error != null) {
            obj_lwcComponent_union0 = obj_lwcComponent_union0_error.message;
        }
        let obj_lwcComponent_union1 = null;
        const obj_lwcComponent_union1_error = (() => {
            if (obj_lwcComponent !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lwcComponent + '" (at "' + path_lwcComponent + '")');
            }
        })();
        if (obj_lwcComponent_union1_error != null) {
            obj_lwcComponent_union1 = obj_lwcComponent_union1_error.message;
        }
        if (obj_lwcComponent_union0 && obj_lwcComponent_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lwcComponent + '")';
            message += '\n' + obj_lwcComponent_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lwcComponent_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_primaryColor = obj.primaryColor;
        const path_primaryColor = path + '.primaryColor';
        let obj_primaryColor_union0 = null;
        const obj_primaryColor_union0_error = (() => {
            if (typeof obj_primaryColor !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_primaryColor + '" (at "' + path_primaryColor + '")');
            }
        })();
        if (obj_primaryColor_union0_error != null) {
            obj_primaryColor_union0 = obj_primaryColor_union0_error.message;
        }
        let obj_primaryColor_union1 = null;
        const obj_primaryColor_union1_error = (() => {
            if (obj_primaryColor !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_primaryColor + '" (at "' + path_primaryColor + '")');
            }
        })();
        if (obj_primaryColor_union1_error != null) {
            obj_primaryColor_union1 = obj_primaryColor_union1_error.message;
        }
        if (obj_primaryColor_union0 && obj_primaryColor_union1) {
            let message = 'Object doesn\'t match union (at "' + path_primaryColor + '")';
            message += '\n' + obj_primaryColor_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_primaryColor_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_relatedListRecordId = obj.relatedListRecordId;
        const path_relatedListRecordId = path + '.relatedListRecordId';
        let obj_relatedListRecordId_union0 = null;
        const obj_relatedListRecordId_union0_error = (() => {
            if (typeof obj_relatedListRecordId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_relatedListRecordId + '" (at "' + path_relatedListRecordId + '")');
            }
        })();
        if (obj_relatedListRecordId_union0_error != null) {
            obj_relatedListRecordId_union0 = obj_relatedListRecordId_union0_error.message;
        }
        let obj_relatedListRecordId_union1 = null;
        const obj_relatedListRecordId_union1_error = (() => {
            if (obj_relatedListRecordId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_relatedListRecordId + '" (at "' + path_relatedListRecordId + '")');
            }
        })();
        if (obj_relatedListRecordId_union1_error != null) {
            obj_relatedListRecordId_union1 = obj_relatedListRecordId_union1_error.message;
        }
        if (obj_relatedListRecordId_union0 && obj_relatedListRecordId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_relatedListRecordId + '")';
            message += '\n' + obj_relatedListRecordId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_relatedListRecordId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_relatedSourceObject = obj.relatedSourceObject;
        const path_relatedSourceObject = path + '.relatedSourceObject';
        let obj_relatedSourceObject_union0 = null;
        const obj_relatedSourceObject_union0_error = (() => {
            if (typeof obj_relatedSourceObject !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_relatedSourceObject + '" (at "' + path_relatedSourceObject + '")');
            }
        })();
        if (obj_relatedSourceObject_union0_error != null) {
            obj_relatedSourceObject_union0 = obj_relatedSourceObject_union0_error.message;
        }
        let obj_relatedSourceObject_union1 = null;
        const obj_relatedSourceObject_union1_error = (() => {
            if (obj_relatedSourceObject !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_relatedSourceObject + '" (at "' + path_relatedSourceObject + '")');
            }
        })();
        if (obj_relatedSourceObject_union1_error != null) {
            obj_relatedSourceObject_union1 = obj_relatedSourceObject_union1_error.message;
        }
        if (obj_relatedSourceObject_union0 && obj_relatedSourceObject_union1) {
            let message = 'Object doesn\'t match union (at "' + path_relatedSourceObject + '")';
            message += '\n' + obj_relatedSourceObject_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_relatedSourceObject_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_section = obj.section;
        const path_section = path + '.section';
        let obj_section_union0 = null;
        const obj_section_union0_error = (() => {
            if (typeof obj_section !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_section + '" (at "' + path_section + '")');
            }
        })();
        if (obj_section_union0_error != null) {
            obj_section_union0 = obj_section_union0_error.message;
        }
        let obj_section_union1 = null;
        const obj_section_union1_error = (() => {
            if (obj_section !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_section + '" (at "' + path_section + '")');
            }
        })();
        if (obj_section_union1_error != null) {
            obj_section_union1 = obj_section_union1_error.message;
        }
        if (obj_section_union0 && obj_section_union1) {
            let message = 'Object doesn\'t match union (at "' + path_section + '")';
            message += '\n' + obj_section_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_section_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_sourceObject = obj.sourceObject;
        const path_sourceObject = path + '.sourceObject';
        if (typeof obj_sourceObject !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_sourceObject + '" (at "' + path_sourceObject + '")');
        }
        const obj_subtype = obj.subtype;
        const path_subtype = path + '.subtype';
        let obj_subtype_union0 = null;
        const obj_subtype_union0_error = (() => {
            if (typeof obj_subtype !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_subtype + '" (at "' + path_subtype + '")');
            }
        })();
        if (obj_subtype_union0_error != null) {
            obj_subtype_union0 = obj_subtype_union0_error.message;
        }
        let obj_subtype_union1 = null;
        const obj_subtype_union1_error = (() => {
            if (obj_subtype !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_subtype + '" (at "' + path_subtype + '")');
            }
        })();
        if (obj_subtype_union1_error != null) {
            obj_subtype_union1 = obj_subtype_union1_error.message;
        }
        if (obj_subtype_union0 && obj_subtype_union1) {
            let message = 'Object doesn\'t match union (at "' + path_subtype + '")';
            message += '\n' + obj_subtype_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_subtype_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_targetObject = obj.targetObject;
        const path_targetObject = path + '.targetObject';
        let obj_targetObject_union0 = null;
        const obj_targetObject_union0_error = (() => {
            if (typeof obj_targetObject !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_targetObject + '" (at "' + path_targetObject + '")');
            }
        })();
        if (obj_targetObject_union0_error != null) {
            obj_targetObject_union0 = obj_targetObject_union0_error.message;
        }
        let obj_targetObject_union1 = null;
        const obj_targetObject_union1_error = (() => {
            if (obj_targetObject !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_targetObject + '" (at "' + path_targetObject + '")');
            }
        })();
        if (obj_targetObject_union1_error != null) {
            obj_targetObject_union1 = obj_targetObject_union1_error.message;
        }
        if (obj_targetObject_union0 && obj_targetObject_union1) {
            let message = 'Object doesn\'t match union (at "' + path_targetObject + '")';
            message += '\n' + obj_targetObject_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_targetObject_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_targetUrl = obj.targetUrl;
        const path_targetUrl = path + '.targetUrl';
        let obj_targetUrl_union0 = null;
        const obj_targetUrl_union0_error = (() => {
            if (typeof obj_targetUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_targetUrl + '" (at "' + path_targetUrl + '")');
            }
        })();
        if (obj_targetUrl_union0_error != null) {
            obj_targetUrl_union0 = obj_targetUrl_union0_error.message;
        }
        let obj_targetUrl_union1 = null;
        const obj_targetUrl_union1_error = (() => {
            if (obj_targetUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_targetUrl + '" (at "' + path_targetUrl + '")');
            }
        })();
        if (obj_targetUrl_union1_error != null) {
            obj_targetUrl_union1 = obj_targetUrl_union1_error.message;
        }
        if (obj_targetUrl_union0 && obj_targetUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_targetUrl + '")';
            message += '\n' + obj_targetUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_targetUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$G = 'PlatformActionRepresentation';
function keyBuilder$1P(luvio, config) {
    return keyPrefix + '::' + RepresentationType$G + ':' + config.externalId + ':' + (config.relatedSourceObject === null ? '' : config.relatedSourceObject) + ':' + (config.relatedListRecordId === null ? '' : config.relatedListRecordId);
}
function keyBuilderFromType$q(luvio, object) {
    const keyParams = {
        externalId: object.externalId,
        relatedSourceObject: object.relatedSourceObject,
        relatedListRecordId: object.relatedListRecordId
    };
    return keyBuilder$1P(luvio, keyParams);
}
function normalize$A(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1G = function PlatformActionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$10,
        private: [
            'id'
        ],
        selections: [
            {
                name: 'actionListContext',
                kind: 'Scalar'
            },
            {
                name: 'actionTarget',
                kind: 'Scalar'
            },
            {
                name: 'actionTargetType',
                kind: 'Scalar'
            },
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'externalId',
                kind: 'Scalar'
            },
            {
                name: 'iconUrl',
                kind: 'Scalar'
            },
            {
                name: 'isMassAction',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'lwcComponent',
                kind: 'Scalar'
            },
            {
                name: 'primaryColor',
                kind: 'Scalar'
            },
            {
                name: 'relatedListRecordId',
                kind: 'Scalar'
            },
            {
                name: 'relatedSourceObject',
                kind: 'Scalar'
            },
            {
                name: 'section',
                kind: 'Scalar'
            },
            {
                name: 'sourceObject',
                kind: 'Scalar'
            },
            {
                name: 'subtype',
                kind: 'Scalar'
            },
            {
                name: 'targetObject',
                kind: 'Scalar'
            },
            {
                name: 'targetUrl',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$S(existing, incoming) {
    const existing_actionListContext = existing.actionListContext;
    const incoming_actionListContext = incoming.actionListContext;
    if (!(existing_actionListContext === incoming_actionListContext)) {
        return false;
    }
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_externalId = existing.externalId;
    const incoming_externalId = incoming.externalId;
    if (!(existing_externalId === incoming_externalId)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_isMassAction = existing.isMassAction;
    const incoming_isMassAction = incoming.isMassAction;
    if (!(existing_isMassAction === incoming_isMassAction)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_sourceObject = existing.sourceObject;
    const incoming_sourceObject = incoming.sourceObject;
    if (!(existing_sourceObject === incoming_sourceObject)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_actionTarget = existing.actionTarget;
    const incoming_actionTarget = incoming.actionTarget;
    if (!(existing_actionTarget === incoming_actionTarget)) {
        return false;
    }
    const existing_actionTargetType = existing.actionTargetType;
    const incoming_actionTargetType = incoming.actionTargetType;
    if (!(existing_actionTargetType === incoming_actionTargetType)) {
        return false;
    }
    const existing_iconUrl = existing.iconUrl;
    const incoming_iconUrl = incoming.iconUrl;
    if (!(existing_iconUrl === incoming_iconUrl)) {
        return false;
    }
    const existing_lwcComponent = existing.lwcComponent;
    const incoming_lwcComponent = incoming.lwcComponent;
    if (!(existing_lwcComponent === incoming_lwcComponent)) {
        return false;
    }
    const existing_primaryColor = existing.primaryColor;
    const incoming_primaryColor = incoming.primaryColor;
    if (!(existing_primaryColor === incoming_primaryColor)) {
        return false;
    }
    const existing_relatedListRecordId = existing.relatedListRecordId;
    const incoming_relatedListRecordId = incoming.relatedListRecordId;
    if (!(existing_relatedListRecordId === incoming_relatedListRecordId)) {
        return false;
    }
    const existing_relatedSourceObject = existing.relatedSourceObject;
    const incoming_relatedSourceObject = incoming.relatedSourceObject;
    if (!(existing_relatedSourceObject === incoming_relatedSourceObject)) {
        return false;
    }
    const existing_section = existing.section;
    const incoming_section = incoming.section;
    if (!(existing_section === incoming_section)) {
        return false;
    }
    const existing_subtype = existing.subtype;
    const incoming_subtype = incoming.subtype;
    if (!(existing_subtype === incoming_subtype)) {
        return false;
    }
    const existing_targetObject = existing.targetObject;
    const incoming_targetObject = incoming.targetObject;
    if (!(existing_targetObject === incoming_targetObject)) {
        return false;
    }
    const existing_targetUrl = existing.targetUrl;
    const incoming_targetUrl = incoming.targetUrl;
    if (!(existing_targetUrl === incoming_targetUrl)) {
        return false;
    }
    return true;
}
const ingest$A = function PlatformActionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1w(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$q(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$A, "UiApi", VERSION$10, RepresentationType$G, equals$S);
    return createLink(key);
};
function getTypeCacheKeys$H(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$q(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$G,
        mergeable: false
    });
}

const VERSION$$ = "378d506f563a4bd724b322d440df33d1";
function validate$1v(obj, path = 'EntityActionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actions = obj.actions;
        const path_actions = path + '.actions';
        if (!ArrayIsArray(obj_actions)) {
            return new TypeError('Expected "array" but received "' + typeof obj_actions + '" (at "' + path_actions + '")');
        }
        for (let i = 0; i < obj_actions.length; i++) {
            const obj_actions_item = obj_actions[i];
            const path_actions_item = path_actions + '[' + i + ']';
            if (typeof obj_actions_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_actions_item + '" (at "' + path_actions_item + '")');
            }
        }
        const obj_links = obj.links;
        const path_links = path + '.links';
        if (!ArrayIsArray(obj_links)) {
            return new TypeError('Expected "array" but received "' + typeof obj_links + '" (at "' + path_links + '")');
        }
        for (let i = 0; i < obj_links.length; i++) {
            const obj_links_item = obj_links[i];
            const path_links_item = path_links + '[' + i + ']';
            if (typeof obj_links_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_links_item + '" (at "' + path_links_item + '")');
            }
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$F = 'EntityActionRepresentation';
function keyBuilder$1O(luvio, config) {
    return keyPrefix + '::' + RepresentationType$F + ':' + config.url;
}
function keyBuilderFromType$p(luvio, object) {
    const keyParams = {
        url: object.url
    };
    return keyBuilder$1O(luvio, keyParams);
}
function normalize$z(input, existing, path, luvio, store, timestamp) {
    const input_actions = input.actions;
    const input_actions_id = path.fullPath + '__actions';
    for (let i = 0; i < input_actions.length; i++) {
        const input_actions_item = input_actions[i];
        let input_actions_item_id = input_actions_id + '__' + i;
        input_actions[i] = ingest$A(input_actions_item, {
            fullPath: input_actions_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1F = function EntityActionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$$,
        private: [
            'links',
            'url'
        ],
        selections: [
            {
                name: 'actions',
                kind: 'Link',
                plural: true,
                fragment: select$1G()
            }
        ]
    };
};
function equals$R(existing, incoming) {
    const existing_url = existing.url;
    const incoming_url = incoming.url;
    if (!(existing_url === incoming_url)) {
        return false;
    }
    const existing_actions = existing.actions;
    const incoming_actions = incoming.actions;
    const equals_actions_items = equalsArray(existing_actions, incoming_actions, (existing_actions_item, incoming_actions_item) => {
        if (!(existing_actions_item.__ref === incoming_actions_item.__ref)) {
            return false;
        }
    });
    if (equals_actions_items === false) {
        return false;
    }
    const existing_links = existing.links;
    const incoming_links = incoming.links;
    const equals_links_items = equalsArray(existing_links, incoming_links, (existing_links_item, incoming_links_item) => {
        if (!(existing_links_item === incoming_links_item)) {
            return false;
        }
    });
    if (equals_links_items === false) {
        return false;
    }
    return true;
}
const ingest$z = function EntityActionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1v(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$p(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$z, "UiApi", VERSION$$, RepresentationType$F, equals$R);
    return createLink(key);
};
function getTypeCacheKeys$G(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$p(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$F,
        mergeable: false
    });
    const input_actions_length = input.actions.length;
    for (let i = 0; i < input_actions_length; i++) {
        getTypeCacheKeys$H(rootKeySet, luvio, input.actions[i]);
    }
}

const TTL$s = 300000;
const VERSION$_ = "e485d96c1402a9ca2f56e56485af0216";
function validate$1u(obj, path = 'ActionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actions = obj.actions;
        const path_actions = path + '.actions';
        if (typeof obj_actions !== 'object' || ArrayIsArray(obj_actions) || obj_actions === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_actions + '" (at "' + path_actions + '")');
        }
        const obj_actions_keys = ObjectKeys(obj_actions);
        for (let i = 0; i < obj_actions_keys.length; i++) {
            const key = obj_actions_keys[i];
            const obj_actions_prop = obj_actions[key];
            const path_actions_prop = path_actions + '["' + key + '"]';
            if (typeof obj_actions_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_actions_prop + '" (at "' + path_actions_prop + '")');
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$E = 'ActionRepresentation';
function normalize$y(input, existing, path, luvio, store, timestamp) {
    const input_actions = input.actions;
    const input_actions_id = path.fullPath + '__actions';
    const input_actions_keys = Object.keys(input_actions);
    const input_actions_length = input_actions_keys.length;
    for (let i = 0; i < input_actions_length; i++) {
        const key = input_actions_keys[i];
        const input_actions_prop = input_actions[key];
        const input_actions_prop_id = input_actions_id + '__' + key;
        input_actions[key] = ingest$z(input_actions_prop, {
            fullPath: input_actions_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1E = function ActionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$_,
        private: [
            'eTag',
            'url'
        ],
        selections: [
            {
                name: 'actions',
                kind: 'Link',
                map: true,
                fragment: select$1F()
            }
        ]
    };
};
function equals$Q(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_url = existing.url;
    const incoming_url = incoming.url;
    if (!(existing_url === incoming_url)) {
        return false;
    }
    const existing_actions = existing.actions;
    const incoming_actions = incoming.actions;
    const equals_actions_props = equalsObject(existing_actions, incoming_actions, (existing_actions_prop, incoming_actions_prop) => {
        if (!(existing_actions_prop.__ref === incoming_actions_prop.__ref)) {
            return false;
        }
    });
    if (equals_actions_props === false) {
        return false;
    }
    return true;
}
const ingest$y = function ActionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1u(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$s;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$y, "UiApi", VERSION$_, RepresentationType$E, equals$Q);
    return createLink(key);
};
function getTypeCacheKeys$F(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$E,
        mergeable: false
    });
    const input_actions = input.actions;
    const input_actions_keys = ObjectKeys(input_actions);
    const input_actions_length = input_actions_keys.length;
    for (let i = 0; i < input_actions_length; i++) {
        const key = input_actions_keys[i];
        getTypeCacheKeys$G(rootKeySet, luvio, input_actions[key]);
    }
}

function select$1D(luvio, params) {
    return select$1E();
}
function keyBuilder$1N(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'actionTypes:' + params.queryParams.actionTypes + ',' + 'apiNames:' + params.queryParams.apiNames + ',' + 'formFactor:' + params.queryParams.formFactor + ',' + 'retrievalMode:' + params.queryParams.retrievalMode + ',' + 'sections:' + params.queryParams.sections + ')';
}
function getResponseCacheKeys$Z(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1N(luvio, resourceParams));
}
function ingestSuccess$O(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1N(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1D(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$H(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1N(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$11(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/global',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$X = 'getGlobalActions';
const getGlobalActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionTypes', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('apiNames', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArrayAllowEmpty),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('retrievalMode', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sections', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getGlobalActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$X, getGlobalActions_ConfigPropertyMetadata);
const createResourceParams$X = /*#__PURE__*/ createResourceParams$13(getGlobalActions_ConfigPropertyMetadata);
function keyBuilder$1M(luvio, config) {
    const resourceParams = createResourceParams$X(config);
    return keyBuilder$1N(luvio, resourceParams);
}
function typeCheckConfig$$(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getGlobalActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$11(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getGlobalActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$$(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$G(luvio, config) {
    createResourceParams$X(config);
    return select$1D();
}
function onFetchResponseSuccess$J(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$O(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$10(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$K(luvio, config, resourceParams, response) {
    const snapshot = ingestError$H(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$10(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$10(luvio, config, options) {
    const resourceParams = createResourceParams$X(config);
    const request = createResourceRequest$11(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$J(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$Z(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$K(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$O(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$10, undefined, false);
}
function buildCachedSnapshotCachePolicy$N(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1M(luvio, config),
        node: adapterFragment$G(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$10(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getGlobalActionsAdapterFactory = (luvio) => function UiApi__getGlobalActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$11(untrustedConfig, getGlobalActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$N, buildNetworkSnapshotCachePolicy$O);
};

const TTL$r = 900000;
const VERSION$Z = "35f3eec8ce7f6001c6d5d17821b75bb9";
function validate$1t(obj, path = 'QuickActionLayoutRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actionApiName = obj.actionApiName;
        const path_actionApiName = path + '.actionApiName';
        if (typeof obj_actionApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionApiName + '" (at "' + path_actionApiName + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_layout = obj.layout;
        const path_layout = path + '.layout';
        const referencepath_layoutValidationError = validate$1E(obj_layout, path_layout);
        if (referencepath_layoutValidationError !== null) {
            let message = 'Object doesn\'t match RecordLayoutRepresentation (at "' + path_layout + '")\n';
            message += referencepath_layoutValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$D = 'QuickActionLayoutRepresentation';
function keyBuilder$1L(luvio, config) {
    return keyPrefix + '::' + RepresentationType$D + ':' + config.actionApiName;
}
function keyBuilderFromType$o(luvio, object) {
    const keyParams = {
        actionApiName: object.actionApiName
    };
    return keyBuilder$1L(luvio, keyParams);
}
function normalize$x(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1C = function QuickActionLayoutRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$Z,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'actionApiName',
                kind: 'Scalar'
            },
            {
                name: 'layout',
                kind: 'Object',
                opaque: true
            }
        ]
    };
};
function equals$P(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$x = function QuickActionLayoutRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1t(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$o(luvio, input);
    const ttlToUse = TTL$r;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$x, "UiApi", VERSION$Z, RepresentationType$D, equals$P);
    return createLink(key);
};
function getTypeCacheKeys$E(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$o(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$D,
        mergeable: false
    });
}

function select$1B(luvio, params) {
    return select$1C();
}
function keyBuilder$1K(luvio, params) {
    return keyBuilder$1L(luvio, {
        actionApiName: params.urlParams.actionApiName
    });
}
function getResponseCacheKeys$Y(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$E(storeKeyMap, luvio, response);
}
function ingestSuccess$N(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1K(luvio, resourceParams);
    luvio.storeIngest(key, ingest$x, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1B(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$G(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1K(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$r,
        namespace: keyPrefix,
        version: VERSION$Z,
        representationName: RepresentationType$D
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$10(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/layout/' + config.urlParams.actionApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$W = 'getQuickActionLayout';
const getQuickActionLayout_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getQuickActionLayout_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$W, getQuickActionLayout_ConfigPropertyMetadata);
const createResourceParams$W = /*#__PURE__*/ createResourceParams$13(getQuickActionLayout_ConfigPropertyMetadata);
function keyBuilder$1J(luvio, config) {
    const resourceParams = createResourceParams$W(config);
    return keyBuilder$1K(luvio, resourceParams);
}
function typeCheckConfig$_(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getQuickActionLayout_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$10(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$_(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$F(luvio, config) {
    createResourceParams$W(config);
    return select$1B();
}
function onFetchResponseSuccess$I(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$N(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$$(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$J(luvio, config, resourceParams, response) {
    const snapshot = ingestError$G(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$$(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$$(luvio, config, options) {
    const resourceParams = createResourceParams$W(config);
    const request = createResourceRequest$10(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$I(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$Y(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$J(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$N(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$$, undefined, false);
}
function buildCachedSnapshotCachePolicy$M(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1J(luvio, config),
        node: adapterFragment$F(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$$(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getQuickActionLayoutAdapterFactory = (luvio) => function UiApi__getQuickActionLayout(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$10(untrustedConfig, getQuickActionLayout_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$M, buildNetworkSnapshotCachePolicy$N);
};

/**
 * Returns the object API name.
 * @param value The value from which to get the object API name.
 * @returns The object API name.
 */
function getObjectApiNamesArray(value) {
    const valueArray = isArray(value) ? value : [value];
    const array = [];
    for (let i = 0, len = valueArray.length; i < len; i += 1) {
        const item = valueArray[i];
        const apiName = getObjectApiName$1(item);
        if (apiName === undefined) {
            return undefined;
        }
        push.call(array, apiName);
    }
    if (array.length === 0) {
        return undefined;
    }
    return dedupe(array);
}

/**
 * Returns the object API name.
 * @param value The value from which to get the object API name.
 * @returns The object API name.
 */
function getSortedObjectApiNamesArray(value) {
    const unsortedArray = getObjectApiNamesArray(value);
    return unsortedArray === undefined ? undefined : unsortedArray.sort();
}

function select$1A(luvio, params) {
    return select$1E();
}
function keyBuilder$1I(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'actionTypes:' + params.queryParams.actionTypes + ',' + 'formFactor:' + params.queryParams.formFactor + ',' + 'sections:' + params.queryParams.sections + ',' + 'objectApiNames:' + params.urlParams.objectApiNames + ')';
}
function getResponseCacheKeys$X(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1I(luvio, resourceParams));
}
function ingestSuccess$M(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1I(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1A(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$F(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1I(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$$(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/lookup/' + config.urlParams.objectApiNames + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$V = 'getLookupActions';
const getLookupActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiNames', true, 0 /* UrlParameter */, 0 /* String */, true, getSortedObjectApiNamesArray),
    generateParamConfigMetadata('actionTypes', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('sections', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getLookupActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$V, getLookupActions_ConfigPropertyMetadata);
const createResourceParams$V = /*#__PURE__*/ createResourceParams$13(getLookupActions_ConfigPropertyMetadata);
function keyBuilder$1H(luvio, config) {
    const resourceParams = createResourceParams$V(config);
    return keyBuilder$1I(luvio, resourceParams);
}
function typeCheckConfig$Z(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getLookupActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$$(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getLookupActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$Z(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$E(luvio, config) {
    createResourceParams$V(config);
    return select$1A();
}
function onFetchResponseSuccess$H(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$M(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$_(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$I(luvio, config, resourceParams, response) {
    const snapshot = ingestError$F(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$_(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$_(luvio, config, options) {
    const resourceParams = createResourceParams$V(config);
    const request = createResourceRequest$$(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$H(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$X(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$I(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$M(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$_, undefined, false);
}
function buildCachedSnapshotCachePolicy$L(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1H(luvio, config),
        node: adapterFragment$E(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$_(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getLookupActionsAdapterFactory = (luvio) => function UiApi__getLookupActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$$(untrustedConfig, getLookupActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$L, buildNetworkSnapshotCachePolicy$M);
};

function select$1z(luvio, params) {
    return select$1E();
}
function keyBuilder$1G(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'actionTypes:' + params.queryParams.actionTypes + ',' + 'formFactor:' + params.queryParams.formFactor + ',' + 'sections:' + params.queryParams.sections + ',' + 'objectApiName:' + params.urlParams.objectApiName + ')';
}
function getResponseCacheKeys$W(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1G(luvio, resourceParams));
}
function ingestSuccess$L(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1G(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1z(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$E(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1G(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$_(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/object/' + config.urlParams.objectApiName + '/record-create',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$U = 'getObjectCreateActions';
const getObjectCreateActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('actionTypes', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('sections', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getObjectCreateActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$U, getObjectCreateActions_ConfigPropertyMetadata);
const createResourceParams$U = /*#__PURE__*/ createResourceParams$13(getObjectCreateActions_ConfigPropertyMetadata);
function keyBuilder$1F(luvio, config) {
    const resourceParams = createResourceParams$U(config);
    return keyBuilder$1G(luvio, resourceParams);
}
function typeCheckConfig$Y(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getObjectCreateActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$_(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getObjectCreateActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$Y(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$D(luvio, config) {
    createResourceParams$U(config);
    return select$1z();
}
function onFetchResponseSuccess$G(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$L(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$Z(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$H(luvio, config, resourceParams, response) {
    const snapshot = ingestError$E(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$Z(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$Z(luvio, config, options) {
    const resourceParams = createResourceParams$U(config);
    const request = createResourceRequest$_(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$G(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$W(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$H(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$L(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$Z, undefined, false);
}
function buildCachedSnapshotCachePolicy$K(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1F(luvio, config),
        node: adapterFragment$D(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$Z(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getObjectCreateActionsAdapterFactory = (luvio) => function UiApi__getObjectCreateActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$_(untrustedConfig, getObjectCreateActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$K, buildNetworkSnapshotCachePolicy$L);
};

const VERSION$Y = "fecd80e9e24a1c1e75fd5395cd34ff2e";
function validate$1s(obj, path = 'ActionOverrideRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (typeof obj_records !== 'object' || ArrayIsArray(obj_records) || obj_records === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$C = 'ActionOverrideRepresentation';
function normalize$w(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1y = function ActionOverrideRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$Y,
        private: [],
        opaque: true
    };
};
function equals$O(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$w = function ActionOverrideRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1s(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$w, "UiApi", VERSION$Y, RepresentationType$C, equals$O);
    return createLink(key);
};
function getTypeCacheKeys$D(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$C,
        mergeable: false
    });
}

function select$1x(luvio, params) {
    return select$1y();
}
function keyBuilder$1E(luvio, params) {
    return keyPrefix + '::ActionOverrideRepresentation:(' + 'defaultTemplateOnly:' + params.queryParams.defaultTemplateOnly + ',' + 'type:' + params.queryParams.type + ',' + 'objectApiName:' + params.urlParams.objectApiName + ')';
}
function getResponseCacheKeys$V(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$D(storeKeyMap, luvio, response, () => keyBuilder$1E(luvio, resourceParams));
}
function ingestSuccess$K(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1E(luvio, resourceParams);
    luvio.storeIngest(key, ingest$w, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1x(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$D(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1E(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$Z(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/overrides/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$T = 'getActionOverrides';
const getActionOverrides_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('defaultTemplateOnly', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('type', false, 1 /* QueryParameter */, 0 /* String */),
];
const getActionOverrides_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$T, getActionOverrides_ConfigPropertyMetadata);
const createResourceParams$T = /*#__PURE__*/ createResourceParams$13(getActionOverrides_ConfigPropertyMetadata);
function keyBuilder$1D(luvio, config) {
    const resourceParams = createResourceParams$T(config);
    return keyBuilder$1E(luvio, resourceParams);
}
function typeCheckConfig$X(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getActionOverrides_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$Z(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getActionOverrides_ConfigPropertyMetadata);
    const config = typeCheckConfig$X(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$C(luvio, config) {
    createResourceParams$T(config);
    return select$1x();
}
function onFetchResponseSuccess$F(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$K(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$Y(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$G(luvio, config, resourceParams, response) {
    const snapshot = ingestError$D(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$Y(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$Y(luvio, config, options) {
    const resourceParams = createResourceParams$T(config);
    const request = createResourceRequest$Z(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$F(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$V(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$G(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$K(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$Y, undefined, false);
}
function buildCachedSnapshotCachePolicy$J(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1D(luvio, config),
        node: adapterFragment$C(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$Y(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getActionOverridesAdapterFactory = (luvio) => function UiApi__getActionOverrides(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$Z(untrustedConfig, getActionOverrides_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$J, buildNetworkSnapshotCachePolicy$K);
};

function validate$1r(obj, path = 'FormulaOverridesInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldNames = obj.fieldNames;
        const path_fieldNames = path + '.fieldNames';
        if (!ArrayIsArray(obj_fieldNames)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fieldNames + '" (at "' + path_fieldNames + '")');
        }
        for (let i = 0; i < obj_fieldNames.length; i++) {
            const obj_fieldNames_item = obj_fieldNames[i];
            const path_fieldNames_item = path_fieldNames + '[' + i + ']';
            if (typeof obj_fieldNames_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_fieldNames_item + '" (at "' + path_fieldNames_item + '")');
            }
        }
        const obj_flexipageName = obj.flexipageName;
        const path_flexipageName = path + '.flexipageName';
        if (typeof obj_flexipageName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_flexipageName + '" (at "' + path_flexipageName + '")');
        }
        const obj_jsFormula = obj.jsFormula;
        const path_jsFormula = path + '.jsFormula';
        if (typeof obj_jsFormula !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_jsFormula + '" (at "' + path_jsFormula + '")');
        }
        const obj_order = obj.order;
        const path_order = path + '.order';
        if (typeof obj_order !== 'number' || (typeof obj_order === 'number' && Math.floor(obj_order) !== obj_order)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_order + '" (at "' + path_order + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$q = 300000;
const VERSION$X = "c57b66c259b23683db7b763e132e8633";
function validate$1q(obj, path = 'FlexipageFormulaActivationRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_activations = obj.activations;
        const path_activations = path + '.activations';
        if (typeof obj_activations !== 'object' || ArrayIsArray(obj_activations) || obj_activations === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_activations + '" (at "' + path_activations + '")');
        }
        const obj_activations_keys = ObjectKeys(obj_activations);
        for (let i = 0; i < obj_activations_keys.length; i++) {
            const key = obj_activations_keys[i];
            const obj_activations_prop = obj_activations[key];
            const path_activations_prop = path_activations + '["' + key + '"]';
            if (!ArrayIsArray(obj_activations_prop)) {
                return new TypeError('Expected "array" but received "' + typeof obj_activations_prop + '" (at "' + path_activations_prop + '")');
            }
            for (let i = 0; i < obj_activations_prop.length; i++) {
                const obj_activations_prop_item = obj_activations_prop[i];
                const path_activations_prop_item = path_activations_prop + '[' + i + ']';
                const referencepath_activations_prop_itemValidationError = validate$1r(obj_activations_prop_item, path_activations_prop_item);
                if (referencepath_activations_prop_itemValidationError !== null) {
                    let message = 'Object doesn\'t match FormulaOverridesInfoRepresentation (at "' + path_activations_prop_item + '")\n';
                    message += referencepath_activations_prop_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                    return new TypeError(message);
                }
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$B = 'FlexipageFormulaActivationRepresentation';
function normalize$v(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1w = function FlexipageFormulaActivationRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$X,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'activations',
                kind: 'Object',
                opaque: true
            }
        ]
    };
};
function equals$N(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$v = function FlexipageFormulaActivationRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1q(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$q;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$v, "UiApi", VERSION$X, RepresentationType$B, equals$N);
    return createLink(key);
};
function getTypeCacheKeys$C(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$B,
        mergeable: false
    });
}

function select$1v(luvio, params) {
    return select$1w();
}
function keyBuilder$1C(luvio, params) {
    return keyPrefix + '::FlexipageFormulaActivationRepresentation:(' + 'application:' + params.queryParams.application + ',' + 'objectApiNames:' + params.queryParams.objectApiNames + ',' + 'actionFeature:' + params.urlParams.actionFeature + ')';
}
function getResponseCacheKeys$U(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$C(storeKeyMap, luvio, response, () => keyBuilder$1C(luvio, resourceParams));
}
function ingestSuccess$J(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1C(luvio, resourceParams);
    luvio.storeIngest(key, ingest$v, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1v(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$C(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1C(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$q,
        namespace: keyPrefix,
        version: VERSION$X,
        representationName: RepresentationType$B
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$Y(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/formula-activation/' + config.urlParams.actionFeature + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$S = 'getFlexipageFormulaOverrides';
const getFlexipageFormulaOverrides_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionFeature', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('application', false, 1 /* QueryParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('objectApiNames', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getFlexipageFormulaOverrides_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$S, getFlexipageFormulaOverrides_ConfigPropertyMetadata);
const createResourceParams$S = /*#__PURE__*/ createResourceParams$13(getFlexipageFormulaOverrides_ConfigPropertyMetadata);
function keyBuilder$1B(luvio, config) {
    const resourceParams = createResourceParams$S(config);
    return keyBuilder$1C(luvio, resourceParams);
}
function typeCheckConfig$W(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getFlexipageFormulaOverrides_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$Y(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getFlexipageFormulaOverrides_ConfigPropertyMetadata);
    const config = typeCheckConfig$W(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$B(luvio, config) {
    createResourceParams$S(config);
    return select$1v();
}
function onFetchResponseSuccess$E(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$J(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$X(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$F(luvio, config, resourceParams, response) {
    const snapshot = ingestError$C(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$X(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$X(luvio, config, options) {
    const resourceParams = createResourceParams$S(config);
    const request = createResourceRequest$Y(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$E(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$U(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$F(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$J(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$X, undefined, false);
}
function buildCachedSnapshotCachePolicy$I(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1B(luvio, config),
        node: adapterFragment$B(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$X(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getFlexipageFormulaOverridesAdapterFactory = (luvio) => function UiApi__getFlexipageFormulaOverrides(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$Y(untrustedConfig, getFlexipageFormulaOverrides_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$I, buildNetworkSnapshotCachePolicy$J);
};

const VERSION$W = "7a5e66e0b88fe9d2233bb3158931bfa6";
function validate$1p(obj, path = 'QuickActionColorRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_color = obj.color;
        const path_color = path + '.color';
        if (typeof obj_color !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_color + '" (at "' + path_color + '")');
        }
        const obj_colorContext = obj.colorContext;
        const path_colorContext = path + '.colorContext';
        if (typeof obj_colorContext !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_colorContext + '" (at "' + path_colorContext + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_theme = obj.theme;
        const path_theme = path + '.theme';
        if (typeof obj_theme !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_theme + '" (at "' + path_theme + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1u = function QuickActionColorRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$W,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'color',
                kind: 'Scalar'
            },
            {
                name: 'colorContext',
                kind: 'Scalar'
            },
            {
                name: 'theme',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$M(existing, incoming) {
    const existing_color = existing.color;
    const incoming_color = incoming.color;
    if (!(existing_color === incoming_color)) {
        return false;
    }
    const existing_colorContext = existing.colorContext;
    const incoming_colorContext = incoming.colorContext;
    if (!(existing_colorContext === incoming_colorContext)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_theme = existing.theme;
    const incoming_theme = incoming.theme;
    if (!(existing_theme === incoming_theme)) {
        return false;
    }
    return true;
}

const VERSION$V = "5e970aa7dacfdd8e0c6d5daca575ec58";
function validate$1o(obj, path = 'CopilotQuickActionInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_inputName = obj.inputName;
        const path_inputName = path + '.inputName';
        if (typeof obj_inputName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_inputName + '" (at "' + path_inputName + '")');
        }
        const obj_inputValue = obj.inputValue;
        const path_inputValue = path + '.inputValue';
        if (typeof obj_inputValue !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_inputValue + '" (at "' + path_inputValue + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1t = function CopilotQuickActionInputRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$V,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'inputName',
                kind: 'Scalar'
            },
            {
                name: 'inputValue',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$L(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_inputName = existing.inputName;
    const incoming_inputName = incoming.inputName;
    if (!(existing_inputName === incoming_inputName)) {
        return false;
    }
    const existing_inputValue = existing.inputValue;
    const incoming_inputValue = incoming.inputValue;
    if (!(existing_inputValue === incoming_inputValue)) {
        return false;
    }
    return true;
}

const VERSION$U = "53b489083ef57944d2a9d4a2aaf72ec3";
function validate$1n(obj, path = 'QuickActionIconRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_contentType = obj.contentType;
        const path_contentType = path + '.contentType';
        if (typeof obj_contentType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_contentType + '" (at "' + path_contentType + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_height = obj.height;
        const path_height = path + '.height';
        if (typeof obj_height !== 'number' || (typeof obj_height === 'number' && Math.floor(obj_height) !== obj_height)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_height + '" (at "' + path_height + '")');
        }
        const obj_theme = obj.theme;
        const path_theme = path + '.theme';
        if (typeof obj_theme !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_theme + '" (at "' + path_theme + '")');
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
        const obj_width = obj.width;
        const path_width = path + '.width';
        if (typeof obj_width !== 'number' || (typeof obj_width === 'number' && Math.floor(obj_width) !== obj_width)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_width + '" (at "' + path_width + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1s = function QuickActionIconRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$U,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'contentType',
                kind: 'Scalar'
            },
            {
                name: 'height',
                kind: 'Scalar'
            },
            {
                name: 'theme',
                kind: 'Scalar'
            },
            {
                name: 'url',
                kind: 'Scalar'
            },
            {
                name: 'width',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$K(existing, incoming) {
    const existing_height = existing.height;
    const incoming_height = incoming.height;
    if (!(existing_height === incoming_height)) {
        return false;
    }
    const existing_width = existing.width;
    const incoming_width = incoming.width;
    if (!(existing_width === incoming_width)) {
        return false;
    }
    const existing_contentType = existing.contentType;
    const incoming_contentType = incoming.contentType;
    if (!(existing_contentType === incoming_contentType)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_theme = existing.theme;
    const incoming_theme = incoming.theme;
    if (!(existing_theme === incoming_theme)) {
        return false;
    }
    const existing_url = existing.url;
    const incoming_url = incoming.url;
    if (!(existing_url === incoming_url)) {
        return false;
    }
    return true;
}

const VERSION$T = "bab371abd4de5aea22d80f5c9843eb8a";
function validate$1m(obj, path = 'CopilotQuickActionParameterRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_parameterName = obj.parameterName;
        const path_parameterName = path + '.parameterName';
        if (typeof obj_parameterName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_parameterName + '" (at "' + path_parameterName + '")');
        }
        const obj_parameterValue = obj.parameterValue;
        const path_parameterValue = path + '.parameterValue';
        if (typeof obj_parameterValue !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_parameterValue + '" (at "' + path_parameterValue + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1r = function CopilotQuickActionParameterRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$T,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'parameterName',
                kind: 'Scalar'
            },
            {
                name: 'parameterValue',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$J(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_parameterName = existing.parameterName;
    const incoming_parameterName = incoming.parameterName;
    if (!(existing_parameterName === incoming_parameterName)) {
        return false;
    }
    const existing_parameterValue = existing.parameterValue;
    const incoming_parameterValue = incoming.parameterValue;
    if (!(existing_parameterValue === incoming_parameterValue)) {
        return false;
    }
    return true;
}

const TTL$p = 900000;
const VERSION$S = "463cd270460d626d438908f8348e6dc8";
function validate$1l(obj, path = 'QuickActionInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_accessLevelRequired = obj.accessLevelRequired;
        const path_accessLevelRequired = path + '.accessLevelRequired';
        let obj_accessLevelRequired_union0 = null;
        const obj_accessLevelRequired_union0_error = (() => {
            if (typeof obj_accessLevelRequired !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_accessLevelRequired + '" (at "' + path_accessLevelRequired + '")');
            }
        })();
        if (obj_accessLevelRequired_union0_error != null) {
            obj_accessLevelRequired_union0 = obj_accessLevelRequired_union0_error.message;
        }
        let obj_accessLevelRequired_union1 = null;
        const obj_accessLevelRequired_union1_error = (() => {
            if (obj_accessLevelRequired !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_accessLevelRequired + '" (at "' + path_accessLevelRequired + '")');
            }
        })();
        if (obj_accessLevelRequired_union1_error != null) {
            obj_accessLevelRequired_union1 = obj_accessLevelRequired_union1_error.message;
        }
        if (obj_accessLevelRequired_union0 && obj_accessLevelRequired_union1) {
            let message = 'Object doesn\'t match union (at "' + path_accessLevelRequired + '")';
            message += '\n' + obj_accessLevelRequired_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_accessLevelRequired_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_actionApiName = obj.actionApiName;
        const path_actionApiName = path + '.actionApiName';
        if (typeof obj_actionApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionApiName + '" (at "' + path_actionApiName + '")');
        }
        const obj_colors = obj.colors;
        const path_colors = path + '.colors';
        if (!ArrayIsArray(obj_colors)) {
            return new TypeError('Expected "array" but received "' + typeof obj_colors + '" (at "' + path_colors + '")');
        }
        for (let i = 0; i < obj_colors.length; i++) {
            const obj_colors_item = obj_colors[i];
            const path_colors_item = path_colors + '[' + i + ']';
            const referencepath_colors_itemValidationError = validate$1p(obj_colors_item, path_colors_item);
            if (referencepath_colors_itemValidationError !== null) {
                let message = 'Object doesn\'t match QuickActionColorRepresentation (at "' + path_colors_item + '")\n';
                message += referencepath_colors_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_copilotActionDescription = obj.copilotActionDescription;
        const path_copilotActionDescription = path + '.copilotActionDescription';
        let obj_copilotActionDescription_union0 = null;
        const obj_copilotActionDescription_union0_error = (() => {
            if (typeof obj_copilotActionDescription !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_copilotActionDescription + '" (at "' + path_copilotActionDescription + '")');
            }
        })();
        if (obj_copilotActionDescription_union0_error != null) {
            obj_copilotActionDescription_union0 = obj_copilotActionDescription_union0_error.message;
        }
        let obj_copilotActionDescription_union1 = null;
        const obj_copilotActionDescription_union1_error = (() => {
            if (obj_copilotActionDescription !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_copilotActionDescription + '" (at "' + path_copilotActionDescription + '")');
            }
        })();
        if (obj_copilotActionDescription_union1_error != null) {
            obj_copilotActionDescription_union1 = obj_copilotActionDescription_union1_error.message;
        }
        if (obj_copilotActionDescription_union0 && obj_copilotActionDescription_union1) {
            let message = 'Object doesn\'t match union (at "' + path_copilotActionDescription + '")';
            message += '\n' + obj_copilotActionDescription_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_copilotActionDescription_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_copilotInputs = obj.copilotInputs;
        const path_copilotInputs = path + '.copilotInputs';
        if (!ArrayIsArray(obj_copilotInputs)) {
            return new TypeError('Expected "array" but received "' + typeof obj_copilotInputs + '" (at "' + path_copilotInputs + '")');
        }
        for (let i = 0; i < obj_copilotInputs.length; i++) {
            const obj_copilotInputs_item = obj_copilotInputs[i];
            const path_copilotInputs_item = path_copilotInputs + '[' + i + ']';
            const referencepath_copilotInputs_itemValidationError = validate$1o(obj_copilotInputs_item, path_copilotInputs_item);
            if (referencepath_copilotInputs_itemValidationError !== null) {
                let message = 'Object doesn\'t match CopilotQuickActionInputRepresentation (at "' + path_copilotInputs_item + '")\n';
                message += referencepath_copilotInputs_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_copilotIntent = obj.copilotIntent;
        const path_copilotIntent = path + '.copilotIntent';
        let obj_copilotIntent_union0 = null;
        const obj_copilotIntent_union0_error = (() => {
            if (typeof obj_copilotIntent !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_copilotIntent + '" (at "' + path_copilotIntent + '")');
            }
        })();
        if (obj_copilotIntent_union0_error != null) {
            obj_copilotIntent_union0 = obj_copilotIntent_union0_error.message;
        }
        let obj_copilotIntent_union1 = null;
        const obj_copilotIntent_union1_error = (() => {
            if (obj_copilotIntent !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_copilotIntent + '" (at "' + path_copilotIntent + '")');
            }
        })();
        if (obj_copilotIntent_union1_error != null) {
            obj_copilotIntent_union1 = obj_copilotIntent_union1_error.message;
        }
        if (obj_copilotIntent_union0 && obj_copilotIntent_union1) {
            let message = 'Object doesn\'t match union (at "' + path_copilotIntent + '")';
            message += '\n' + obj_copilotIntent_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_copilotIntent_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_copilotPlanTemplateId = obj.copilotPlanTemplateId;
        const path_copilotPlanTemplateId = path + '.copilotPlanTemplateId';
        let obj_copilotPlanTemplateId_union0 = null;
        const obj_copilotPlanTemplateId_union0_error = (() => {
            if (typeof obj_copilotPlanTemplateId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_copilotPlanTemplateId + '" (at "' + path_copilotPlanTemplateId + '")');
            }
        })();
        if (obj_copilotPlanTemplateId_union0_error != null) {
            obj_copilotPlanTemplateId_union0 = obj_copilotPlanTemplateId_union0_error.message;
        }
        let obj_copilotPlanTemplateId_union1 = null;
        const obj_copilotPlanTemplateId_union1_error = (() => {
            if (obj_copilotPlanTemplateId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_copilotPlanTemplateId + '" (at "' + path_copilotPlanTemplateId + '")');
            }
        })();
        if (obj_copilotPlanTemplateId_union1_error != null) {
            obj_copilotPlanTemplateId_union1 = obj_copilotPlanTemplateId_union1_error.message;
        }
        if (obj_copilotPlanTemplateId_union0 && obj_copilotPlanTemplateId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_copilotPlanTemplateId + '")';
            message += '\n' + obj_copilotPlanTemplateId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_copilotPlanTemplateId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_copilotUserUtterance = obj.copilotUserUtterance;
        const path_copilotUserUtterance = path + '.copilotUserUtterance';
        let obj_copilotUserUtterance_union0 = null;
        const obj_copilotUserUtterance_union0_error = (() => {
            if (typeof obj_copilotUserUtterance !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_copilotUserUtterance + '" (at "' + path_copilotUserUtterance + '")');
            }
        })();
        if (obj_copilotUserUtterance_union0_error != null) {
            obj_copilotUserUtterance_union0 = obj_copilotUserUtterance_union0_error.message;
        }
        let obj_copilotUserUtterance_union1 = null;
        const obj_copilotUserUtterance_union1_error = (() => {
            if (obj_copilotUserUtterance !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_copilotUserUtterance + '" (at "' + path_copilotUserUtterance + '")');
            }
        })();
        if (obj_copilotUserUtterance_union1_error != null) {
            obj_copilotUserUtterance_union1 = obj_copilotUserUtterance_union1_error.message;
        }
        if (obj_copilotUserUtterance_union0 && obj_copilotUserUtterance_union1) {
            let message = 'Object doesn\'t match union (at "' + path_copilotUserUtterance + '")';
            message += '\n' + obj_copilotUserUtterance_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_copilotUserUtterance_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_flowDevName = obj.flowDevName;
        const path_flowDevName = path + '.flowDevName';
        let obj_flowDevName_union0 = null;
        const obj_flowDevName_union0_error = (() => {
            if (typeof obj_flowDevName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_flowDevName + '" (at "' + path_flowDevName + '")');
            }
        })();
        if (obj_flowDevName_union0_error != null) {
            obj_flowDevName_union0 = obj_flowDevName_union0_error.message;
        }
        let obj_flowDevName_union1 = null;
        const obj_flowDevName_union1_error = (() => {
            if (obj_flowDevName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_flowDevName + '" (at "' + path_flowDevName + '")');
            }
        })();
        if (obj_flowDevName_union1_error != null) {
            obj_flowDevName_union1 = obj_flowDevName_union1_error.message;
        }
        if (obj_flowDevName_union0 && obj_flowDevName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_flowDevName + '")';
            message += '\n' + obj_flowDevName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_flowDevName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_flowRecordIdVar = obj.flowRecordIdVar;
        const path_flowRecordIdVar = path + '.flowRecordIdVar';
        let obj_flowRecordIdVar_union0 = null;
        const obj_flowRecordIdVar_union0_error = (() => {
            if (typeof obj_flowRecordIdVar !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_flowRecordIdVar + '" (at "' + path_flowRecordIdVar + '")');
            }
        })();
        if (obj_flowRecordIdVar_union0_error != null) {
            obj_flowRecordIdVar_union0 = obj_flowRecordIdVar_union0_error.message;
        }
        let obj_flowRecordIdVar_union1 = null;
        const obj_flowRecordIdVar_union1_error = (() => {
            if (obj_flowRecordIdVar !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_flowRecordIdVar + '" (at "' + path_flowRecordIdVar + '")');
            }
        })();
        if (obj_flowRecordIdVar_union1_error != null) {
            obj_flowRecordIdVar_union1 = obj_flowRecordIdVar_union1_error.message;
        }
        if (obj_flowRecordIdVar_union0 && obj_flowRecordIdVar_union1) {
            let message = 'Object doesn\'t match union (at "' + path_flowRecordIdVar + '")';
            message += '\n' + obj_flowRecordIdVar_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_flowRecordIdVar_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_iconName = obj.iconName;
        const path_iconName = path + '.iconName';
        let obj_iconName_union0 = null;
        const obj_iconName_union0_error = (() => {
            if (typeof obj_iconName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_iconName + '" (at "' + path_iconName + '")');
            }
        })();
        if (obj_iconName_union0_error != null) {
            obj_iconName_union0 = obj_iconName_union0_error.message;
        }
        let obj_iconName_union1 = null;
        const obj_iconName_union1_error = (() => {
            if (obj_iconName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_iconName + '" (at "' + path_iconName + '")');
            }
        })();
        if (obj_iconName_union1_error != null) {
            obj_iconName_union1 = obj_iconName_union1_error.message;
        }
        if (obj_iconName_union0 && obj_iconName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_iconName + '")';
            message += '\n' + obj_iconName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_iconName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_icons = obj.icons;
        const path_icons = path + '.icons';
        if (!ArrayIsArray(obj_icons)) {
            return new TypeError('Expected "array" but received "' + typeof obj_icons + '" (at "' + path_icons + '")');
        }
        for (let i = 0; i < obj_icons.length; i++) {
            const obj_icons_item = obj_icons[i];
            const path_icons_item = path_icons + '[' + i + ']';
            const referencepath_icons_itemValidationError = validate$1n(obj_icons_item, path_icons_item);
            if (referencepath_icons_itemValidationError !== null) {
                let message = 'Object doesn\'t match QuickActionIconRepresentation (at "' + path_icons_item + '")\n';
                message += referencepath_icons_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_lightningComponentBundleName = obj.lightningComponentBundleName;
        const path_lightningComponentBundleName = path + '.lightningComponentBundleName';
        let obj_lightningComponentBundleName_union0 = null;
        const obj_lightningComponentBundleName_union0_error = (() => {
            if (typeof obj_lightningComponentBundleName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lightningComponentBundleName + '" (at "' + path_lightningComponentBundleName + '")');
            }
        })();
        if (obj_lightningComponentBundleName_union0_error != null) {
            obj_lightningComponentBundleName_union0 = obj_lightningComponentBundleName_union0_error.message;
        }
        let obj_lightningComponentBundleName_union1 = null;
        const obj_lightningComponentBundleName_union1_error = (() => {
            if (obj_lightningComponentBundleName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lightningComponentBundleName + '" (at "' + path_lightningComponentBundleName + '")');
            }
        })();
        if (obj_lightningComponentBundleName_union1_error != null) {
            obj_lightningComponentBundleName_union1 = obj_lightningComponentBundleName_union1_error.message;
        }
        if (obj_lightningComponentBundleName_union0 && obj_lightningComponentBundleName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lightningComponentBundleName + '")';
            message += '\n' + obj_lightningComponentBundleName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lightningComponentBundleName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_lightningComponentQualifiedName = obj.lightningComponentQualifiedName;
        const path_lightningComponentQualifiedName = path + '.lightningComponentQualifiedName';
        let obj_lightningComponentQualifiedName_union0 = null;
        const obj_lightningComponentQualifiedName_union0_error = (() => {
            if (typeof obj_lightningComponentQualifiedName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lightningComponentQualifiedName + '" (at "' + path_lightningComponentQualifiedName + '")');
            }
        })();
        if (obj_lightningComponentQualifiedName_union0_error != null) {
            obj_lightningComponentQualifiedName_union0 = obj_lightningComponentQualifiedName_union0_error.message;
        }
        let obj_lightningComponentQualifiedName_union1 = null;
        const obj_lightningComponentQualifiedName_union1_error = (() => {
            if (obj_lightningComponentQualifiedName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lightningComponentQualifiedName + '" (at "' + path_lightningComponentQualifiedName + '")');
            }
        })();
        if (obj_lightningComponentQualifiedName_union1_error != null) {
            obj_lightningComponentQualifiedName_union1 = obj_lightningComponentQualifiedName_union1_error.message;
        }
        if (obj_lightningComponentQualifiedName_union0 && obj_lightningComponentQualifiedName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lightningComponentQualifiedName + '")';
            message += '\n' + obj_lightningComponentQualifiedName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lightningComponentQualifiedName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_lightningWebComponentBundleName = obj.lightningWebComponentBundleName;
        const path_lightningWebComponentBundleName = path + '.lightningWebComponentBundleName';
        let obj_lightningWebComponentBundleName_union0 = null;
        const obj_lightningWebComponentBundleName_union0_error = (() => {
            if (typeof obj_lightningWebComponentBundleName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lightningWebComponentBundleName + '" (at "' + path_lightningWebComponentBundleName + '")');
            }
        })();
        if (obj_lightningWebComponentBundleName_union0_error != null) {
            obj_lightningWebComponentBundleName_union0 = obj_lightningWebComponentBundleName_union0_error.message;
        }
        let obj_lightningWebComponentBundleName_union1 = null;
        const obj_lightningWebComponentBundleName_union1_error = (() => {
            if (obj_lightningWebComponentBundleName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lightningWebComponentBundleName + '" (at "' + path_lightningWebComponentBundleName + '")');
            }
        })();
        if (obj_lightningWebComponentBundleName_union1_error != null) {
            obj_lightningWebComponentBundleName_union1 = obj_lightningWebComponentBundleName_union1_error.message;
        }
        if (obj_lightningWebComponentBundleName_union0 && obj_lightningWebComponentBundleName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lightningWebComponentBundleName + '")';
            message += '\n' + obj_lightningWebComponentBundleName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lightningWebComponentBundleName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_lightningWebComponentQualifiedName = obj.lightningWebComponentQualifiedName;
        const path_lightningWebComponentQualifiedName = path + '.lightningWebComponentQualifiedName';
        let obj_lightningWebComponentQualifiedName_union0 = null;
        const obj_lightningWebComponentQualifiedName_union0_error = (() => {
            if (typeof obj_lightningWebComponentQualifiedName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lightningWebComponentQualifiedName + '" (at "' + path_lightningWebComponentQualifiedName + '")');
            }
        })();
        if (obj_lightningWebComponentQualifiedName_union0_error != null) {
            obj_lightningWebComponentQualifiedName_union0 = obj_lightningWebComponentQualifiedName_union0_error.message;
        }
        let obj_lightningWebComponentQualifiedName_union1 = null;
        const obj_lightningWebComponentQualifiedName_union1_error = (() => {
            if (obj_lightningWebComponentQualifiedName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lightningWebComponentQualifiedName + '" (at "' + path_lightningWebComponentQualifiedName + '")');
            }
        })();
        if (obj_lightningWebComponentQualifiedName_union1_error != null) {
            obj_lightningWebComponentQualifiedName_union1 = obj_lightningWebComponentQualifiedName_union1_error.message;
        }
        if (obj_lightningWebComponentQualifiedName_union0 && obj_lightningWebComponentQualifiedName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lightningWebComponentQualifiedName + '")';
            message += '\n' + obj_lightningWebComponentQualifiedName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lightningWebComponentQualifiedName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_parameters = obj.parameters;
        const path_parameters = path + '.parameters';
        if (!ArrayIsArray(obj_parameters)) {
            return new TypeError('Expected "array" but received "' + typeof obj_parameters + '" (at "' + path_parameters + '")');
        }
        for (let i = 0; i < obj_parameters.length; i++) {
            const obj_parameters_item = obj_parameters[i];
            const path_parameters_item = path_parameters + '[' + i + ']';
            const referencepath_parameters_itemValidationError = validate$1m(obj_parameters_item, path_parameters_item);
            if (referencepath_parameters_itemValidationError !== null) {
                let message = 'Object doesn\'t match CopilotQuickActionParameterRepresentation (at "' + path_parameters_item + '")\n';
                message += referencepath_parameters_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_targetParentField = obj.targetParentField;
        const path_targetParentField = path + '.targetParentField';
        let obj_targetParentField_union0 = null;
        const obj_targetParentField_union0_error = (() => {
            if (typeof obj_targetParentField !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_targetParentField + '" (at "' + path_targetParentField + '")');
            }
        })();
        if (obj_targetParentField_union0_error != null) {
            obj_targetParentField_union0 = obj_targetParentField_union0_error.message;
        }
        let obj_targetParentField_union1 = null;
        const obj_targetParentField_union1_error = (() => {
            if (obj_targetParentField !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_targetParentField + '" (at "' + path_targetParentField + '")');
            }
        })();
        if (obj_targetParentField_union1_error != null) {
            obj_targetParentField_union1 = obj_targetParentField_union1_error.message;
        }
        if (obj_targetParentField_union0 && obj_targetParentField_union1) {
            let message = 'Object doesn\'t match union (at "' + path_targetParentField + '")';
            message += '\n' + obj_targetParentField_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_targetParentField_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_targetRecordTypeId = obj.targetRecordTypeId;
        const path_targetRecordTypeId = path + '.targetRecordTypeId';
        let obj_targetRecordTypeId_union0 = null;
        const obj_targetRecordTypeId_union0_error = (() => {
            if (typeof obj_targetRecordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_targetRecordTypeId + '" (at "' + path_targetRecordTypeId + '")');
            }
        })();
        if (obj_targetRecordTypeId_union0_error != null) {
            obj_targetRecordTypeId_union0 = obj_targetRecordTypeId_union0_error.message;
        }
        let obj_targetRecordTypeId_union1 = null;
        const obj_targetRecordTypeId_union1_error = (() => {
            if (obj_targetRecordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_targetRecordTypeId + '" (at "' + path_targetRecordTypeId + '")');
            }
        })();
        if (obj_targetRecordTypeId_union1_error != null) {
            obj_targetRecordTypeId_union1 = obj_targetRecordTypeId_union1_error.message;
        }
        if (obj_targetRecordTypeId_union0 && obj_targetRecordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_targetRecordTypeId + '")';
            message += '\n' + obj_targetRecordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_targetRecordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_targetSobjectType = obj.targetSobjectType;
        const path_targetSobjectType = path + '.targetSobjectType';
        let obj_targetSobjectType_union0 = null;
        const obj_targetSobjectType_union0_error = (() => {
            if (typeof obj_targetSobjectType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_targetSobjectType + '" (at "' + path_targetSobjectType + '")');
            }
        })();
        if (obj_targetSobjectType_union0_error != null) {
            obj_targetSobjectType_union0 = obj_targetSobjectType_union0_error.message;
        }
        let obj_targetSobjectType_union1 = null;
        const obj_targetSobjectType_union1_error = (() => {
            if (obj_targetSobjectType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_targetSobjectType + '" (at "' + path_targetSobjectType + '")');
            }
        })();
        if (obj_targetSobjectType_union1_error != null) {
            obj_targetSobjectType_union1 = obj_targetSobjectType_union1_error.message;
        }
        if (obj_targetSobjectType_union0 && obj_targetSobjectType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_targetSobjectType + '")';
            message += '\n' + obj_targetSobjectType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_targetSobjectType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$A = 'QuickActionInfoRepresentation';
function keyBuilder$1A(luvio, config) {
    return keyPrefix + '::' + RepresentationType$A + ':' + config.actionApiName;
}
function keyBuilderFromType$n(luvio, object) {
    const keyParams = {
        actionApiName: object.actionApiName
    };
    return keyBuilder$1A(luvio, keyParams);
}
function normalize$u(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1q = function QuickActionInfoRepresentationSelect() {
    const { selections: QuickActionColorRepresentation__selections, opaque: QuickActionColorRepresentation__opaque, } = select$1u();
    const { selections: CopilotQuickActionInputRepresentation__selections, opaque: CopilotQuickActionInputRepresentation__opaque, } = select$1t();
    const { selections: QuickActionIconRepresentation__selections, opaque: QuickActionIconRepresentation__opaque, } = select$1s();
    const { selections: CopilotQuickActionParameterRepresentation__selections, opaque: CopilotQuickActionParameterRepresentation__opaque, } = select$1r();
    return {
        kind: 'Fragment',
        version: VERSION$S,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'accessLevelRequired',
                kind: 'Scalar'
            },
            {
                name: 'actionApiName',
                kind: 'Scalar'
            },
            {
                name: 'colors',
                kind: 'Object',
                plural: true,
                selections: QuickActionColorRepresentation__selections
            },
            {
                name: 'copilotActionDescription',
                kind: 'Scalar'
            },
            {
                name: 'copilotInputs',
                kind: 'Object',
                plural: true,
                selections: CopilotQuickActionInputRepresentation__selections
            },
            {
                name: 'copilotIntent',
                kind: 'Scalar'
            },
            {
                name: 'copilotPlanTemplateId',
                kind: 'Scalar'
            },
            {
                name: 'copilotUserUtterance',
                kind: 'Scalar'
            },
            {
                name: 'flowDevName',
                kind: 'Scalar'
            },
            {
                name: 'flowRecordIdVar',
                kind: 'Scalar'
            },
            {
                name: 'iconName',
                kind: 'Scalar'
            },
            {
                name: 'icons',
                kind: 'Object',
                plural: true,
                selections: QuickActionIconRepresentation__selections
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'lightningComponentBundleName',
                kind: 'Scalar'
            },
            {
                name: 'lightningComponentQualifiedName',
                kind: 'Scalar'
            },
            {
                name: 'lightningWebComponentBundleName',
                kind: 'Scalar'
            },
            {
                name: 'lightningWebComponentQualifiedName',
                kind: 'Scalar'
            },
            {
                name: 'parameters',
                kind: 'Object',
                plural: true,
                selections: CopilotQuickActionParameterRepresentation__selections
            },
            {
                name: 'targetParentField',
                kind: 'Scalar'
            },
            {
                name: 'targetRecordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'targetSobjectType',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$I(existing, incoming) {
    const existing_actionApiName = existing.actionApiName;
    const incoming_actionApiName = incoming.actionApiName;
    if (!(existing_actionApiName === incoming_actionApiName)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_accessLevelRequired = existing.accessLevelRequired;
    const incoming_accessLevelRequired = incoming.accessLevelRequired;
    if (!(existing_accessLevelRequired === incoming_accessLevelRequired)) {
        return false;
    }
    const existing_colors = existing.colors;
    const incoming_colors = incoming.colors;
    const equals_colors_items = equalsArray(existing_colors, incoming_colors, (existing_colors_item, incoming_colors_item) => {
        if (!(equals$M(existing_colors_item, incoming_colors_item))) {
            return false;
        }
    });
    if (equals_colors_items === false) {
        return false;
    }
    const existing_copilotActionDescription = existing.copilotActionDescription;
    const incoming_copilotActionDescription = incoming.copilotActionDescription;
    if (!(existing_copilotActionDescription === incoming_copilotActionDescription)) {
        return false;
    }
    const existing_copilotInputs = existing.copilotInputs;
    const incoming_copilotInputs = incoming.copilotInputs;
    const equals_copilotInputs_items = equalsArray(existing_copilotInputs, incoming_copilotInputs, (existing_copilotInputs_item, incoming_copilotInputs_item) => {
        if (!(equals$L(existing_copilotInputs_item, incoming_copilotInputs_item))) {
            return false;
        }
    });
    if (equals_copilotInputs_items === false) {
        return false;
    }
    const existing_copilotIntent = existing.copilotIntent;
    const incoming_copilotIntent = incoming.copilotIntent;
    if (!(existing_copilotIntent === incoming_copilotIntent)) {
        return false;
    }
    const existing_copilotPlanTemplateId = existing.copilotPlanTemplateId;
    const incoming_copilotPlanTemplateId = incoming.copilotPlanTemplateId;
    if (!(existing_copilotPlanTemplateId === incoming_copilotPlanTemplateId)) {
        return false;
    }
    const existing_copilotUserUtterance = existing.copilotUserUtterance;
    const incoming_copilotUserUtterance = incoming.copilotUserUtterance;
    if (!(existing_copilotUserUtterance === incoming_copilotUserUtterance)) {
        return false;
    }
    const existing_flowDevName = existing.flowDevName;
    const incoming_flowDevName = incoming.flowDevName;
    if (!(existing_flowDevName === incoming_flowDevName)) {
        return false;
    }
    const existing_flowRecordIdVar = existing.flowRecordIdVar;
    const incoming_flowRecordIdVar = incoming.flowRecordIdVar;
    if (!(existing_flowRecordIdVar === incoming_flowRecordIdVar)) {
        return false;
    }
    const existing_iconName = existing.iconName;
    const incoming_iconName = incoming.iconName;
    if (!(existing_iconName === incoming_iconName)) {
        return false;
    }
    const existing_icons = existing.icons;
    const incoming_icons = incoming.icons;
    const equals_icons_items = equalsArray(existing_icons, incoming_icons, (existing_icons_item, incoming_icons_item) => {
        if (!(equals$K(existing_icons_item, incoming_icons_item))) {
            return false;
        }
    });
    if (equals_icons_items === false) {
        return false;
    }
    const existing_lightningComponentBundleName = existing.lightningComponentBundleName;
    const incoming_lightningComponentBundleName = incoming.lightningComponentBundleName;
    if (!(existing_lightningComponentBundleName === incoming_lightningComponentBundleName)) {
        return false;
    }
    const existing_lightningComponentQualifiedName = existing.lightningComponentQualifiedName;
    const incoming_lightningComponentQualifiedName = incoming.lightningComponentQualifiedName;
    if (!(existing_lightningComponentQualifiedName === incoming_lightningComponentQualifiedName)) {
        return false;
    }
    const existing_lightningWebComponentBundleName = existing.lightningWebComponentBundleName;
    const incoming_lightningWebComponentBundleName = incoming.lightningWebComponentBundleName;
    if (!(existing_lightningWebComponentBundleName === incoming_lightningWebComponentBundleName)) {
        return false;
    }
    const existing_lightningWebComponentQualifiedName = existing.lightningWebComponentQualifiedName;
    const incoming_lightningWebComponentQualifiedName = incoming.lightningWebComponentQualifiedName;
    if (!(existing_lightningWebComponentQualifiedName === incoming_lightningWebComponentQualifiedName)) {
        return false;
    }
    const existing_parameters = existing.parameters;
    const incoming_parameters = incoming.parameters;
    const equals_parameters_items = equalsArray(existing_parameters, incoming_parameters, (existing_parameters_item, incoming_parameters_item) => {
        if (!(equals$J(existing_parameters_item, incoming_parameters_item))) {
            return false;
        }
    });
    if (equals_parameters_items === false) {
        return false;
    }
    const existing_targetParentField = existing.targetParentField;
    const incoming_targetParentField = incoming.targetParentField;
    if (!(existing_targetParentField === incoming_targetParentField)) {
        return false;
    }
    const existing_targetRecordTypeId = existing.targetRecordTypeId;
    const incoming_targetRecordTypeId = incoming.targetRecordTypeId;
    if (!(existing_targetRecordTypeId === incoming_targetRecordTypeId)) {
        return false;
    }
    const existing_targetSobjectType = existing.targetSobjectType;
    const incoming_targetSobjectType = incoming.targetSobjectType;
    if (!(existing_targetSobjectType === incoming_targetSobjectType)) {
        return false;
    }
    return true;
}
const ingest$u = function QuickActionInfoRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1l(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$n(luvio, input);
    const ttlToUse = TTL$p;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$u, "UiApi", VERSION$S, RepresentationType$A, equals$I);
    return createLink(key);
};
function getTypeCacheKeys$B(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$n(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$A,
        mergeable: false
    });
}

function select$1p(luvio, params) {
    return select$1q();
}
function keyBuilder$1z(luvio, params) {
    return keyBuilder$1A(luvio, {
        actionApiName: params.urlParams.actionApiName
    });
}
function getResponseCacheKeys$T(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$B(storeKeyMap, luvio, response);
}
function ingestSuccess$I(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1z(luvio, resourceParams);
    luvio.storeIngest(key, ingest$u, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1p(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$B(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1z(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$p,
        namespace: keyPrefix,
        version: VERSION$S,
        representationName: RepresentationType$A
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$X(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/quick-action-info/' + config.urlParams.actionApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$R = 'getQuickActionInfo';
const getQuickActionInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('parentRecordId', false, 1 /* QueryParameter */, 0 /* String */, false, getRecordId18),
];
const getQuickActionInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$R, getQuickActionInfo_ConfigPropertyMetadata);
const createResourceParams$R = /*#__PURE__*/ createResourceParams$13(getQuickActionInfo_ConfigPropertyMetadata);
function keyBuilder$1y(luvio, config) {
    const resourceParams = createResourceParams$R(config);
    return keyBuilder$1z(luvio, resourceParams);
}
function typeCheckConfig$V(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getQuickActionInfo_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$X(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getQuickActionInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$V(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$A(luvio, config) {
    createResourceParams$R(config);
    return select$1p();
}
function onFetchResponseSuccess$D(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$I(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$W(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$E(luvio, config, resourceParams, response) {
    const snapshot = ingestError$B(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$W(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$W(luvio, config, options) {
    const resourceParams = createResourceParams$R(config);
    const request = createResourceRequest$X(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$D(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$T(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$E(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$I(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$W, undefined, false);
}
function buildCachedSnapshotCachePolicy$H(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1y(luvio, config),
        node: adapterFragment$A(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$W(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getQuickActionInfoAdapterFactory = (luvio) => function UiApi__getQuickActionInfo(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$X(untrustedConfig, getQuickActionInfo_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$H, buildNetworkSnapshotCachePolicy$I);
};

const QUICK_ACTION_DEFAULTS_STORE_METADATA_PARAMS = {
    ttl: TTL$t,
    namespace: keyPrefix,
    representationName: RepresentationType$H,
    version: VERSION$11,
};
function merge$1(existing, incoming) {
    if (existing === undefined) {
        return incoming;
    }
    // Merge QuickActionDefaultsRepresentation field values together
    return {
        ...incoming,
        fields: {
            ...existing.fields,
            ...incoming.fields,
        },
    };
}
const dynamicIngest$4 = (ingestParams) => {
    return function QuickActionDefaultsRepresentationIngest(input, path, luvio, store, timestamp) {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$1x(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        const key = keyBuilderFromType$r(luvio, input);
        const existingRecord = store.readEntry(key);
        let incomingRecord = dynamicNormalize$4(ingestParams)(input, store.readEntry(key), {
            fullPath: key,
            parent: path.parent,
            propertyName: path.propertyName,
        }, luvio, store, timestamp);
        incomingRecord = merge$1(existingRecord, incomingRecord);
        if (existingRecord === undefined || equals$T(existingRecord, incomingRecord) === false) {
            luvio.storePublish(key, incomingRecord);
        }
        luvio.publishStoreMetadata(key, {
            ...QUICK_ACTION_DEFAULTS_STORE_METADATA_PARAMS,
            ingestionTimestamp: timestamp,
        });
        return createLink(key);
    };
};

function createFieldsIngest$4(params) {
    const { fields, optionalFields, trackedFields, recordConflictMap } = params;
    const ingest = dynamicIngest$4({
        fields: createFieldsIngestion(fields, optionalFields, recordConflictMap)
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$7(fields) {
    return dynamicSelect$5({
        fields: createPathSelection('fields', fields)
    });
}

function createFieldsIngestSuccess$2(params) {
    const { trackedFields } = params;
    const recordConflictMap = {
        conflicts: {},
        serverRequestCount: 1,
    };
    const ingest = createFieldsIngest$4({
        ...params,
        recordConflictMap,
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        resolveConflict(luvio, recordConflictMap);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$6(luvio, params) {
    const optionalFields = params.queryParams.optionalFields || [];
    const fields = [];
    const trie = convertRecordFieldsArrayToTrie(fields, optionalFields);
    return selectFields$7(trie);
}

function keyBuilder$1x(luvio, params) {
    return keyBuilder$1Q(luvio, {
        actionApiName: params.urlParams.actionApiName
    });
}
function getResponseCacheKeys$S(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$I(storeKeyMap, luvio, response);
}
function ingestError$A(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1x(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$t,
        namespace: keyPrefix,
        version: VERSION$11,
        representationName: RepresentationType$H
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$W(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/record-defaults/' + config.urlParams.actionApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function adapterFragment$z(luvio, config) {
    const resourceParams = createResourceParams$Q(config);
    return selectFields$6(luvio, resourceParams);
}
function buildNetworkSnapshot$V(luvio, config, options) {
    const resourceParams = createResourceParams$Q(config);
    const request = createResourceRequest$W(resourceParams);
    const key = keyBuilder$1w(luvio, config);
    const trackedFieldsConfig = {
        maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMiss(),
        onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly()
    };
    const optionalFieldsTrie = convertFieldsToTrie(getTrackedFields(key, luvio.getNode(key), trackedFieldsConfig, config.optionalFields));
    const fieldsTrie = BLANK_RECORD_FIELDS_TRIE;
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const ingest = createFieldsIngestSuccess$2({
                fields: fieldsTrie,
                optionalFields: optionalFieldsTrie,
                trackedFields: optionalFieldsTrie,
            });
            luvio.storeIngest(key, ingest, response.body);
            const snapshot = buildCachedSnapshot$6(luvio, config);
            if (process.env.NODE_ENV !== 'production') {
                if (snapshot.state !== 'Fulfilled') {
                    throw new Error('Invalid network response. Expected network response to result in Fulfilled snapshot');
                }
            }
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$S(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => {
            return onFetchResponseError$D(luvio, config, resourceParams, response);
        });
    });
}

const adapterName$Q = 'getQuickActionDefaults';
const getQuickActionDefaults_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('parentRecordId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getQuickActionDefaults_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$Q, getQuickActionDefaults_ConfigPropertyMetadata);
const createResourceParams$Q = /*#__PURE__*/ createResourceParams$13(getQuickActionDefaults_ConfigPropertyMetadata);
function keyBuilder$1w(luvio, config) {
    const resourceParams = createResourceParams$Q(config);
    return keyBuilder$1x(luvio, resourceParams);
}
function typeCheckConfig$U(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getQuickActionDefaults_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$W(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getQuickActionDefaults_ConfigPropertyMetadata);
    const config = typeCheckConfig$U(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildCachedSnapshot$6(luvio, config) {
    const selector = {
        recordId: keyBuilder$1w(luvio, config),
        node: adapterFragment$z(luvio, config),
        variables: {},
    };
    return luvio.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$V(luvio, config, snapshotRefreshOptions)
    });
}
function onFetchResponseError$D(luvio, config, resourceParams, response) {
    const snapshot = ingestError$A(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$V(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshotCachePolicy$H(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$V, undefined, false);
}
function buildCachedSnapshotCachePolicy$G(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1w(luvio, config),
        node: adapterFragment$z(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$V(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getQuickActionDefaultsAdapterFactory = (luvio) => function UiApi__getQuickActionDefaults(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$W(untrustedConfig, getQuickActionDefaults_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$G, buildNetworkSnapshotCachePolicy$H);
};

function select$1o(luvio, params) {
    return select$1E();
}
function keyBuilder$1v(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'actionTypes:' + params.queryParams.actionTypes + ',' + 'apiNames:' + params.queryParams.apiNames + ',' + 'formFactor:' + params.queryParams.formFactor + ',' + 'retrievalMode:' + params.queryParams.retrievalMode + ',' + 'sections:' + params.queryParams.sections + ',' + 'recordIds:' + params.urlParams.recordIds + ')';
}
function getResponseCacheKeys$R(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1v(luvio, resourceParams));
}
function ingestSuccess$H(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1v(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1o(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$z(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1v(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$V(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/record/' + config.urlParams.recordIds + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$P = 'getRecordActions';
const oneOfConfigPropertiesIdentifier = [
    'sections',
    'apiNames'
];
const getRecordActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('actionTypes', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('apiNames', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArrayAllowEmpty),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('retrievalMode', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sections', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getRecordActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$P, getRecordActions_ConfigPropertyMetadata);
const createResourceParams$P = /*#__PURE__*/ createResourceParams$13(getRecordActions_ConfigPropertyMetadata);
function keyBuilder$1u(luvio, config) {
    const resourceParams = createResourceParams$P(config);
    return keyBuilder$1v(luvio, resourceParams);
}
function typeCheckConfig$T(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$V(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames, oneOfConfigPropertiesIdentifier);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$T(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    if (config.sections === undefined &&
        config.apiNames === undefined) {
        return null;
    }
    return config;
}
function adapterFragment$y(luvio, config) {
    createResourceParams$P(config);
    return select$1o();
}
function onFetchResponseSuccess$C(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$H(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$U(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$C(luvio, config, resourceParams, response) {
    const snapshot = ingestError$z(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$U(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$U(luvio, config, options) {
    const resourceParams = createResourceParams$P(config);
    const request = createResourceRequest$V(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$C(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$R(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$C(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$G(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$U, undefined, false);
}
function buildCachedSnapshotCachePolicy$F(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1u(luvio, config),
        node: adapterFragment$y(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$U(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRecordActionsAdapterFactory = (luvio) => function UiApi__getRecordActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$V(untrustedConfig, getRecordActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$F, buildNetworkSnapshotCachePolicy$G);
};

function select$1n(luvio, params) {
    return select$1E();
}
function keyBuilder$1t(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'actionTypes:' + params.queryParams.actionTypes + ',' + 'formFactor:' + params.queryParams.formFactor + ',' + 'sections:' + params.queryParams.sections + ',' + 'recordIds:' + params.urlParams.recordIds + ')';
}
function getResponseCacheKeys$Q(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1t(luvio, resourceParams));
}
function ingestSuccess$G(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1t(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1n(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$y(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1t(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$U(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/record/' + config.urlParams.recordIds + '/record-edit',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$O = 'getRecordEditActions';
const getRecordEditActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('actionTypes', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('sections', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getRecordEditActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$O, getRecordEditActions_ConfigPropertyMetadata);
const createResourceParams$O = /*#__PURE__*/ createResourceParams$13(getRecordEditActions_ConfigPropertyMetadata);
function keyBuilder$1s(luvio, config) {
    const resourceParams = createResourceParams$O(config);
    return keyBuilder$1t(luvio, resourceParams);
}
function typeCheckConfig$S(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordEditActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$U(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordEditActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$S(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$x(luvio, config) {
    createResourceParams$O(config);
    return select$1n();
}
function onFetchResponseSuccess$B(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$G(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$T(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$B(luvio, config, resourceParams, response) {
    const snapshot = ingestError$y(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$T(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$T(luvio, config, options) {
    const resourceParams = createResourceParams$O(config);
    const request = createResourceRequest$U(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$B(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$Q(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$B(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$F(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$T, undefined, false);
}
function buildCachedSnapshotCachePolicy$E(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1s(luvio, config),
        node: adapterFragment$x(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$T(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRecordEditActionsAdapterFactory = (luvio) => function UiApi__getRecordEditActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$U(untrustedConfig, getRecordEditActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$E, buildNetworkSnapshotCachePolicy$F);
};

function validate$1k(obj, path = 'ActionRelatedListSingleBatchInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.actionTypes !== undefined) {
            const obj_actionTypes = obj.actionTypes;
            const path_actionTypes = path + '.actionTypes';
            if (!ArrayIsArray(obj_actionTypes)) {
                return new TypeError('Expected "array" but received "' + typeof obj_actionTypes + '" (at "' + path_actionTypes + '")');
            }
            for (let i = 0; i < obj_actionTypes.length; i++) {
                const obj_actionTypes_item = obj_actionTypes[i];
                const path_actionTypes_item = path_actionTypes + '[' + i + ']';
                if (typeof obj_actionTypes_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_actionTypes_item + '" (at "' + path_actionTypes_item + '")');
                }
            }
        }
        if (obj.apiNames !== undefined) {
            const obj_apiNames = obj.apiNames;
            const path_apiNames = path + '.apiNames';
            if (!ArrayIsArray(obj_apiNames)) {
                return new TypeError('Expected "array" but received "' + typeof obj_apiNames + '" (at "' + path_apiNames + '")');
            }
            for (let i = 0; i < obj_apiNames.length; i++) {
                const obj_apiNames_item = obj_apiNames[i];
                const path_apiNames_item = path_apiNames + '[' + i + ']';
                if (typeof obj_apiNames_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_apiNames_item + '" (at "' + path_apiNames_item + '")');
                }
            }
        }
        if (obj.formFactor !== undefined) {
            const obj_formFactor = obj.formFactor;
            const path_formFactor = path + '.formFactor';
            if (typeof obj_formFactor !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_formFactor + '" (at "' + path_formFactor + '")');
            }
        }
        const obj_relatedListId = obj.relatedListId;
        const path_relatedListId = path + '.relatedListId';
        if (typeof obj_relatedListId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_relatedListId + '" (at "' + path_relatedListId + '")');
        }
        if (obj.retrievalMode !== undefined) {
            const obj_retrievalMode = obj.retrievalMode;
            const path_retrievalMode = path + '.retrievalMode';
            if (typeof obj_retrievalMode !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_retrievalMode + '" (at "' + path_retrievalMode + '")');
            }
        }
        if (obj.sections !== undefined) {
            const obj_sections = obj.sections;
            const path_sections = path + '.sections';
            if (!ArrayIsArray(obj_sections)) {
                return new TypeError('Expected "array" but received "' + typeof obj_sections + '" (at "' + path_sections + '")');
            }
            for (let i = 0; i < obj_sections.length; i++) {
                const obj_sections_item = obj_sections[i];
                const path_sections_item = path_sections + '[' + i + ']';
                if (typeof obj_sections_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_sections_item + '" (at "' + path_sections_item + '")');
                }
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function select$1m(luvio, params) {
    return select$1E();
}
function keyBuilder$1r(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'recordIds:' + params.urlParams.recordIds + ',' + 'relatedListId:' + params.urlParams.relatedListId + ',' + (params.body.actionTypes === undefined ? 'actionTypes' : 'actionTypes:' + params.body.actionTypes) + '::' + (params.body.apiNames === undefined ? 'apiNames' : 'apiNames:' + params.body.apiNames) + '::' + (params.body.formFactor === undefined ? 'formFactor' : 'formFactor:' + params.body.formFactor) + '::' + (params.body.retrievalMode === undefined ? 'retrievalMode' : 'retrievalMode:' + params.body.retrievalMode) + '::' + (params.body.sections === undefined ? 'sections' : 'sections:' + params.body.sections) + ')';
}
function getResponseCacheKeys$P(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1r(luvio, resourceParams));
}
function ingestSuccess$F(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1r(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1m(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$x(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1r(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$T(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/record/' + config.urlParams.recordIds + '/related-list/' + config.urlParams.relatedListId + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

function createChildResourceParams$9(resourceParams) {
    const childConfigs = [];
    for (let index = 0, len = resourceParams.body.relatedListsActionParameters.length; index < len; index += 1) {
        let childConfig = {
            urlParams: {
                recordIds: resourceParams.urlParams.recordIds,
                relatedListId: resourceParams.body.relatedListsActionParameters[index].relatedListId,
            },
            body: {},
        };
        let relatedListConfig = resourceParams.body.relatedListsActionParameters[index];
        // manually populate childConfig body
        if ('apiNames' in relatedListConfig) {
            childConfig.body.apiNames = toSortedStringArrayAllowEmpty(relatedListConfig.apiNames);
        }
        if ('retrievalMode' in relatedListConfig) {
            childConfig.body.retrievalMode = relatedListConfig.retrievalMode;
        }
        if ('formFactor' in relatedListConfig) {
            childConfig.body.formFactor = coerceFormFactor(relatedListConfig.formFactor);
        }
        if ('actionTypes' in relatedListConfig) {
            childConfig.body.actionTypes = relatedListConfig.actionTypes;
        }
        if ('sections' in relatedListConfig) {
            childConfig.body.sections = toSortedStringArray(relatedListConfig.sections);
        }
        childConfigs.push(childConfig);
    }
    return childConfigs;
}

const nonCachedErrors$6 = ObjectCreate$1(null);
function createChildResourceParams$8(resourceParams) {
    return createChildResourceParams$9(resourceParams);
}
function selectChildResourceParams$6(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$1q(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$1r(luvio, childResource);
                const childFragment = select$1m();
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$6[childKey];
                            if (nonCachedError === undefined || nonCachedError.expiration < reader.getTimeStamp()) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$1l(luvio, resourceParams) {
    const childResources = createChildResourceParams$8(resourceParams);
    return selectChildResourceParams$6(luvio, childResources, resourceParams);
}
function keyBuilder$1q(luvio, params) {
    return keyPrefix + '::ActionRelatedListsCollectionBatchRepresentation:(' + 'recordIds:' + params.urlParams.recordIds + ',' + '[' + params.body.relatedListsActionParameters.map(element => (element.actionTypes === undefined ? 'relatedListsActionParameters.actionTypes' : 'relatedListsActionParameters.actionTypes:' + element.actionTypes) + '::' + (element.apiNames === undefined ? 'relatedListsActionParameters.apiNames' : 'relatedListsActionParameters.apiNames:' + element.apiNames) + '::' + (element.formFactor === undefined ? 'relatedListsActionParameters.formFactor' : 'relatedListsActionParameters.formFactor:' + element.formFactor) + '::' + 'relatedListsActionParameters.relatedListId:' + element.relatedListId + '::' + (element.retrievalMode === undefined ? 'relatedListsActionParameters.retrievalMode' : 'relatedListsActionParameters.retrievalMode:' + element.retrievalMode) + '::' + (element.sections === undefined ? 'relatedListsActionParameters.sections' : 'relatedListsActionParameters.sections:' + element.sections)).join(',') + ']' + ')';
}
function getResponseCacheKeys$O(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$8(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$P(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$1r(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$E,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$7(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$1r(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$F(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$x(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$6[childKey] = { expiration: now + TTL$s, response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors$6[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$E(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$8(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$1q(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$7(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$1l(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$w(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1q(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$S(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/record/' + config.urlParams.recordIds + '/related-list/batch',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$N = 'getRelatedListsActions';
const getRelatedListsActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('relatedListsActionParameters', true, 2 /* Body */, 4 /* Unsupported */, true),
];
const getRelatedListsActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$N, getRelatedListsActions_ConfigPropertyMetadata);
const createResourceParams$N = /*#__PURE__*/ createResourceParams$13(getRelatedListsActions_ConfigPropertyMetadata);
function keyBuilder$1p(luvio, config) {
    const resourceParams = createResourceParams$N(config);
    return keyBuilder$1q(luvio, resourceParams);
}
function typeCheckConfig$R(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListsActions_ConfigPropertyMetadata);
    const untrustedConfig_relatedListsActionParameters = untrustedConfig.relatedListsActionParameters;
    if (ArrayIsArray$1(untrustedConfig_relatedListsActionParameters)) {
        const untrustedConfig_relatedListsActionParameters_array = [];
        for (let i = 0, arrayLength = untrustedConfig_relatedListsActionParameters.length; i < arrayLength; i++) {
            const untrustedConfig_relatedListsActionParameters_item = untrustedConfig_relatedListsActionParameters[i];
            const referenceActionRelatedListSingleBatchInputRepresentationValidationError = validate$1k(untrustedConfig_relatedListsActionParameters_item);
            if (referenceActionRelatedListSingleBatchInputRepresentationValidationError === null) {
                untrustedConfig_relatedListsActionParameters_array.push(untrustedConfig_relatedListsActionParameters_item);
            }
        }
        config.relatedListsActionParameters = untrustedConfig_relatedListsActionParameters_array;
    }
    return config;
}
function validateAdapterConfig$T(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListsActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$R(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$w(luvio, config) {
    const resourceParams = createResourceParams$N(config);
    return select$1l(luvio, resourceParams);
}
function onFetchResponseSuccess$A(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$E(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$S(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$A(luvio, config, resourceParams, response) {
    const snapshot = ingestError$w(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$S(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$S(luvio, config, options) {
    const resourceParams = createResourceParams$N(config);
    const request = createResourceRequest$S(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$A(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$O(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$A(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$E(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$S, 'get', false);
}
function buildCachedSnapshotCachePolicy$D(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1p(luvio, config),
        node: adapterFragment$w(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$S(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListsActionsAdapterFactory = (luvio) => function UiApi__getRelatedListsActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$T(untrustedConfig, getRelatedListsActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$D, buildNetworkSnapshotCachePolicy$E);
};

const adapterName$M = 'getRelatedListActions';
const getRelatedListActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('relatedListId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('actionTypes', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('apiNames', false, 2 /* Body */, 0 /* String */, true, toSortedStringArrayAllowEmpty),
    generateParamConfigMetadata('formFactor', false, 2 /* Body */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('retrievalMode', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('sections', false, 2 /* Body */, 0 /* String */, true, toSortedStringArray),
];
const getRelatedListActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$M, getRelatedListActions_ConfigPropertyMetadata);
const createResourceParams$M = /*#__PURE__*/ createResourceParams$13(getRelatedListActions_ConfigPropertyMetadata);
function keyBuilder$1o(luvio, config) {
    const resourceParams = createResourceParams$M(config);
    return keyBuilder$1r(luvio, resourceParams);
}
function typeCheckConfig$Q(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$S(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$Q(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$v(luvio, config) {
    createResourceParams$M(config);
    return select$1m();
}
function onFetchResponseSuccess$z(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$F(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$R(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$z(luvio, config, resourceParams, response) {
    const snapshot = ingestError$x(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$R(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$R(luvio, config, options) {
    const resourceParams = createResourceParams$M(config);
    const request = createResourceRequest$T(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$z(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$P(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$z(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$D(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$R, 'get', false);
}
function buildCachedSnapshotCachePolicy$C(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1o(luvio, config),
        node: adapterFragment$v(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$R(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListActionsAdapterFactory = (luvio) => function UiApi__getRelatedListActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$S(untrustedConfig, getRelatedListActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$C, buildNetworkSnapshotCachePolicy$D);
};

function select$1k(luvio, params) {
    return select$1E();
}
function keyBuilder$1n(luvio, params) {
    return keyPrefix + '::ActionRepresentation:(' + 'actionTypes:' + params.queryParams.actionTypes + ',' + 'formFactor:' + params.queryParams.formFactor + ',' + 'sections:' + params.queryParams.sections + ',' + 'recordIds:' + params.urlParams.recordIds + ',' + 'relatedListRecordIds:' + params.urlParams.relatedListRecordIds + ')';
}
function getResponseCacheKeys$N(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$F(storeKeyMap, luvio, response, () => keyBuilder$1n(luvio, resourceParams));
}
function ingestSuccess$D(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1n(luvio, resourceParams);
    luvio.storeIngest(key, ingest$y, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1k(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$v(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1n(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$s,
        namespace: keyPrefix,
        version: VERSION$_,
        representationName: RepresentationType$E
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$R(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/record/' + config.urlParams.recordIds + '/related-list-record/' + config.urlParams.relatedListRecordIds + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$L = 'getRelatedListRecordActions';
const getRelatedListRecordActions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('relatedListRecordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('actionTypes', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('sections', false, 1 /* QueryParameter */, 0 /* String */, true, toSortedStringArray),
];
const getRelatedListRecordActions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$L, getRelatedListRecordActions_ConfigPropertyMetadata);
const createResourceParams$L = /*#__PURE__*/ createResourceParams$13(getRelatedListRecordActions_ConfigPropertyMetadata);
function keyBuilder$1m(luvio, config) {
    const resourceParams = createResourceParams$L(config);
    return keyBuilder$1n(luvio, resourceParams);
}
function typeCheckConfig$P(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListRecordActions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$R(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListRecordActions_ConfigPropertyMetadata);
    const config = typeCheckConfig$P(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$u(luvio, config) {
    createResourceParams$L(config);
    return select$1k();
}
function onFetchResponseSuccess$y(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$D(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$Q(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$y(luvio, config, resourceParams, response) {
    const snapshot = ingestError$v(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$Q(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$Q(luvio, config, options) {
    const resourceParams = createResourceParams$L(config);
    const request = createResourceRequest$R(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$y(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$N(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$y(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$C(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$Q, undefined, false);
}
function buildCachedSnapshotCachePolicy$B(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1m(luvio, config),
        node: adapterFragment$u(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$Q(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListRecordActionsAdapterFactory = (luvio) => function UiApi__getRelatedListRecordActions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$R(untrustedConfig, getRelatedListRecordActions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$B, buildNetworkSnapshotCachePolicy$C);
};

const VERSION$R = "a316b3bba367f54adc67d7552ed7d36d";
function validate$1j(obj, path = 'PageReferenceRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_attributes = obj.attributes;
        const path_attributes = path + '.attributes';
        if (typeof obj_attributes !== 'object' || ArrayIsArray(obj_attributes) || obj_attributes === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_attributes + '" (at "' + path_attributes + '")');
        }
        const obj_attributes_keys = ObjectKeys(obj_attributes);
        for (let i = 0; i < obj_attributes_keys.length; i++) {
            const key = obj_attributes_keys[i];
            const obj_attributes_prop = obj_attributes[key];
            const path_attributes_prop = path_attributes + '["' + key + '"]';
            if (obj_attributes_prop === undefined) {
                return new TypeError('Expected "defined" but received "' + typeof obj_attributes_prop + '" (at "' + path_attributes_prop + '")');
            }
        }
        const obj_state = obj.state;
        const path_state = path + '.state';
        if (typeof obj_state !== 'object' || ArrayIsArray(obj_state) || obj_state === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_state + '" (at "' + path_state + '")');
        }
        const obj_state_keys = ObjectKeys(obj_state);
        for (let i = 0; i < obj_state_keys.length; i++) {
            const key = obj_state_keys[i];
            const obj_state_prop = obj_state[key];
            const path_state_prop = path_state + '["' + key + '"]';
            if (typeof obj_state_prop !== 'object' || ArrayIsArray(obj_state_prop) || obj_state_prop === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_state_prop + '" (at "' + path_state_prop + '")');
            }
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$z = 'PageReferenceRepresentation';
function normalize$t(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1j = function PageReferenceRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$R,
        private: [],
        opaque: true
    };
};
function equals$H(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$t = function PageReferenceRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1j(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$t, "UiApi", VERSION$R, RepresentationType$z, equals$H);
    return createLink(key);
};
function getTypeCacheKeys$A(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$z,
        mergeable: false
    });
}

const TTL$o = 120000;
const VERSION$Q = "09884ca5bf90ea4662092a4e48817081";
function validate$1i(obj, path = 'NavItemRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_availableInClassic = obj.availableInClassic;
        const path_availableInClassic = path + '.availableInClassic';
        if (typeof obj_availableInClassic !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_availableInClassic + '" (at "' + path_availableInClassic + '")');
        }
        const obj_availableInLightning = obj.availableInLightning;
        const path_availableInLightning = path + '.availableInLightning';
        if (typeof obj_availableInLightning !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_availableInLightning + '" (at "' + path_availableInLightning + '")');
        }
        const obj_color = obj.color;
        const path_color = path + '.color';
        if (typeof obj_color !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_color + '" (at "' + path_color + '")');
        }
        const obj_content = obj.content;
        const path_content = path + '.content';
        let obj_content_union0 = null;
        const obj_content_union0_error = (() => {
            if (typeof obj_content !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_content + '" (at "' + path_content + '")');
            }
        })();
        if (obj_content_union0_error != null) {
            obj_content_union0 = obj_content_union0_error.message;
        }
        let obj_content_union1 = null;
        const obj_content_union1_error = (() => {
            if (obj_content !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_content + '" (at "' + path_content + '")');
            }
        })();
        if (obj_content_union1_error != null) {
            obj_content_union1 = obj_content_union1_error.message;
        }
        if (obj_content_union0 && obj_content_union1) {
            let message = 'Object doesn\'t match union (at "' + path_content + '")';
            message += '\n' + obj_content_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_content_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_custom = obj.custom;
        const path_custom = path + '.custom';
        if (typeof obj_custom !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_custom + '" (at "' + path_custom + '")');
        }
        const obj_developerName = obj.developerName;
        const path_developerName = path + '.developerName';
        if (typeof obj_developerName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_developerName + '" (at "' + path_developerName + '")');
        }
        const obj_iconUrl = obj.iconUrl;
        const path_iconUrl = path + '.iconUrl';
        if (typeof obj_iconUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_itemType = obj.itemType;
        const path_itemType = path + '.itemType';
        if (typeof obj_itemType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_itemType + '" (at "' + path_itemType + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_objectLabel = obj.objectLabel;
        const path_objectLabel = path + '.objectLabel';
        let obj_objectLabel_union0 = null;
        const obj_objectLabel_union0_error = (() => {
            if (typeof obj_objectLabel !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectLabel + '" (at "' + path_objectLabel + '")');
            }
        })();
        if (obj_objectLabel_union0_error != null) {
            obj_objectLabel_union0 = obj_objectLabel_union0_error.message;
        }
        let obj_objectLabel_union1 = null;
        const obj_objectLabel_union1_error = (() => {
            if (obj_objectLabel !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_objectLabel + '" (at "' + path_objectLabel + '")');
            }
        })();
        if (obj_objectLabel_union1_error != null) {
            obj_objectLabel_union1 = obj_objectLabel_union1_error.message;
        }
        if (obj_objectLabel_union0 && obj_objectLabel_union1) {
            let message = 'Object doesn\'t match union (at "' + path_objectLabel + '")';
            message += '\n' + obj_objectLabel_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_objectLabel_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectLabelPlural = obj.objectLabelPlural;
        const path_objectLabelPlural = path + '.objectLabelPlural';
        let obj_objectLabelPlural_union0 = null;
        const obj_objectLabelPlural_union0_error = (() => {
            if (typeof obj_objectLabelPlural !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectLabelPlural + '" (at "' + path_objectLabelPlural + '")');
            }
        })();
        if (obj_objectLabelPlural_union0_error != null) {
            obj_objectLabelPlural_union0 = obj_objectLabelPlural_union0_error.message;
        }
        let obj_objectLabelPlural_union1 = null;
        const obj_objectLabelPlural_union1_error = (() => {
            if (obj_objectLabelPlural !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_objectLabelPlural + '" (at "' + path_objectLabelPlural + '")');
            }
        })();
        if (obj_objectLabelPlural_union1_error != null) {
            obj_objectLabelPlural_union1 = obj_objectLabelPlural_union1_error.message;
        }
        if (obj_objectLabelPlural_union0 && obj_objectLabelPlural_union1) {
            let message = 'Object doesn\'t match union (at "' + path_objectLabelPlural + '")';
            message += '\n' + obj_objectLabelPlural_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_objectLabelPlural_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_pageReference = obj.pageReference;
        const path_pageReference = path + '.pageReference';
        let obj_pageReference_union0 = null;
        const obj_pageReference_union0_error = (() => {
            if (typeof obj_pageReference !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_pageReference + '" (at "' + path_pageReference + '")');
            }
        })();
        if (obj_pageReference_union0_error != null) {
            obj_pageReference_union0 = obj_pageReference_union0_error.message;
        }
        let obj_pageReference_union1 = null;
        const obj_pageReference_union1_error = (() => {
            if (obj_pageReference !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_pageReference + '" (at "' + path_pageReference + '")');
            }
        })();
        if (obj_pageReference_union1_error != null) {
            obj_pageReference_union1 = obj_pageReference_union1_error.message;
        }
        if (obj_pageReference_union0 && obj_pageReference_union1) {
            let message = 'Object doesn\'t match union (at "' + path_pageReference + '")';
            message += '\n' + obj_pageReference_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_pageReference_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_standardType = obj.standardType;
        const path_standardType = path + '.standardType';
        let obj_standardType_union0 = null;
        const obj_standardType_union0_error = (() => {
            if (typeof obj_standardType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_standardType + '" (at "' + path_standardType + '")');
            }
        })();
        if (obj_standardType_union0_error != null) {
            obj_standardType_union0 = obj_standardType_union0_error.message;
        }
        let obj_standardType_union1 = null;
        const obj_standardType_union1_error = (() => {
            if (obj_standardType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_standardType + '" (at "' + path_standardType + '")');
            }
        })();
        if (obj_standardType_union1_error != null) {
            obj_standardType_union1 = obj_standardType_union1_error.message;
        }
        if (obj_standardType_union0 && obj_standardType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_standardType + '")';
            message += '\n' + obj_standardType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_standardType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$y = 'NavItemRepresentation';
function keyBuilder$1l(luvio, config) {
    return keyPrefix + '::' + RepresentationType$y + ':' + config.developerName;
}
function keyBuilderFromType$m(luvio, object) {
    const keyParams = {
        developerName: object.developerName
    };
    return keyBuilder$1l(luvio, keyParams);
}
function normalize$s(input, existing, path, luvio, store, timestamp) {
    const input_pageReference = input.pageReference;
    const input_pageReference_id = path.fullPath + '__pageReference';
    if (input_pageReference !== null && typeof input_pageReference === 'object') {
        input.pageReference = ingest$t(input_pageReference, {
            fullPath: input_pageReference_id,
            propertyName: 'pageReference',
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1i = function NavItemRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$Q,
        private: [],
        selections: [
            {
                name: 'availableInClassic',
                kind: 'Scalar'
            },
            {
                name: 'availableInLightning',
                kind: 'Scalar'
            },
            {
                name: 'color',
                kind: 'Scalar'
            },
            {
                name: 'content',
                kind: 'Scalar'
            },
            {
                name: 'custom',
                kind: 'Scalar'
            },
            {
                name: 'developerName',
                kind: 'Scalar'
            },
            {
                name: 'iconUrl',
                kind: 'Scalar'
            },
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'itemType',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'objectApiName',
                kind: 'Scalar'
            },
            {
                name: 'objectLabel',
                kind: 'Scalar'
            },
            {
                name: 'objectLabelPlural',
                kind: 'Scalar'
            },
            {
                name: 'pageReference',
                kind: 'Link',
                nullable: true,
                fragment: select$1j()
            },
            {
                name: 'standardType',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$G(existing, incoming) {
    const existing_availableInClassic = existing.availableInClassic;
    const incoming_availableInClassic = incoming.availableInClassic;
    if (!(existing_availableInClassic === incoming_availableInClassic)) {
        return false;
    }
    const existing_availableInLightning = existing.availableInLightning;
    const incoming_availableInLightning = incoming.availableInLightning;
    if (!(existing_availableInLightning === incoming_availableInLightning)) {
        return false;
    }
    const existing_custom = existing.custom;
    const incoming_custom = incoming.custom;
    if (!(existing_custom === incoming_custom)) {
        return false;
    }
    const existing_color = existing.color;
    const incoming_color = incoming.color;
    if (!(existing_color === incoming_color)) {
        return false;
    }
    const existing_developerName = existing.developerName;
    const incoming_developerName = incoming.developerName;
    if (!(existing_developerName === incoming_developerName)) {
        return false;
    }
    const existing_iconUrl = existing.iconUrl;
    const incoming_iconUrl = incoming.iconUrl;
    if (!(existing_iconUrl === incoming_iconUrl)) {
        return false;
    }
    const existing_itemType = existing.itemType;
    const incoming_itemType = incoming.itemType;
    if (!(existing_itemType === incoming_itemType)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_content = existing.content;
    const incoming_content = incoming.content;
    if (!(existing_content === incoming_content)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_objectLabel = existing.objectLabel;
    const incoming_objectLabel = incoming.objectLabel;
    if (!(existing_objectLabel === incoming_objectLabel)) {
        return false;
    }
    const existing_objectLabelPlural = existing.objectLabelPlural;
    const incoming_objectLabelPlural = incoming.objectLabelPlural;
    if (!(existing_objectLabelPlural === incoming_objectLabelPlural)) {
        return false;
    }
    const existing_pageReference = existing.pageReference;
    const incoming_pageReference = incoming.pageReference;
    if (!(existing_pageReference === incoming_pageReference
        || (existing_pageReference != null &&
            incoming_pageReference != null &&
            existing_pageReference.__ref != null &&
            incoming_pageReference.__ref != null &&
            existing_pageReference.__ref === incoming_pageReference.__ref))) {
        return false;
    }
    const existing_standardType = existing.standardType;
    const incoming_standardType = incoming.standardType;
    if (!(existing_standardType === incoming_standardType)) {
        return false;
    }
    return true;
}
const ingest$s = function NavItemRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1i(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$m(luvio, input);
    const ttlToUse = TTL$o;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$s, "UiApi", VERSION$Q, RepresentationType$y, equals$G);
    return createLink(key);
};
function getTypeCacheKeys$z(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$m(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$y,
        mergeable: false
    });
    if (input.pageReference !== null && typeof input.pageReference === 'object') {
        getTypeCacheKeys$A(rootKeySet, luvio, input.pageReference, () => rootKey + "__" + "pageReference");
    }
}

const TTL$n = 300000;
const VERSION$P = "0cd492fdd6c713c206ef53dc02175f71";
function validate$1h(obj, path = 'AppRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_appId = obj.appId;
        const path_appId = path + '.appId';
        let obj_appId_union0 = null;
        const obj_appId_union0_error = (() => {
            if (typeof obj_appId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_appId + '" (at "' + path_appId + '")');
            }
        })();
        if (obj_appId_union0_error != null) {
            obj_appId_union0 = obj_appId_union0_error.message;
        }
        let obj_appId_union1 = null;
        const obj_appId_union1_error = (() => {
            if (obj_appId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_appId + '" (at "' + path_appId + '")');
            }
        })();
        if (obj_appId_union1_error != null) {
            obj_appId_union1 = obj_appId_union1_error.message;
        }
        if (obj_appId_union0 && obj_appId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_appId + '")';
            message += '\n' + obj_appId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_appId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_description = obj.description;
        const path_description = path + '.description';
        let obj_description_union0 = null;
        const obj_description_union0_error = (() => {
            if (typeof obj_description !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_description + '" (at "' + path_description + '")');
            }
        })();
        if (obj_description_union0_error != null) {
            obj_description_union0 = obj_description_union0_error.message;
        }
        let obj_description_union1 = null;
        const obj_description_union1_error = (() => {
            if (obj_description !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_description + '" (at "' + path_description + '")');
            }
        })();
        if (obj_description_union1_error != null) {
            obj_description_union1 = obj_description_union1_error.message;
        }
        if (obj_description_union0 && obj_description_union1) {
            let message = 'Object doesn\'t match union (at "' + path_description + '")';
            message += '\n' + obj_description_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_description_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_developerName = obj.developerName;
        const path_developerName = path + '.developerName';
        if (typeof obj_developerName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_developerName + '" (at "' + path_developerName + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_formFactors = obj.formFactors;
        const path_formFactors = path + '.formFactors';
        if (!ArrayIsArray(obj_formFactors)) {
            return new TypeError('Expected "array" but received "' + typeof obj_formFactors + '" (at "' + path_formFactors + '")');
        }
        for (let i = 0; i < obj_formFactors.length; i++) {
            const obj_formFactors_item = obj_formFactors[i];
            const path_formFactors_item = path_formFactors + '[' + i + ']';
            if (typeof obj_formFactors_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_formFactors_item + '" (at "' + path_formFactors_item + '")');
            }
        }
        const obj_headerColor = obj.headerColor;
        const path_headerColor = path + '.headerColor';
        let obj_headerColor_union0 = null;
        const obj_headerColor_union0_error = (() => {
            if (typeof obj_headerColor !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_headerColor + '" (at "' + path_headerColor + '")');
            }
        })();
        if (obj_headerColor_union0_error != null) {
            obj_headerColor_union0 = obj_headerColor_union0_error.message;
        }
        let obj_headerColor_union1 = null;
        const obj_headerColor_union1_error = (() => {
            if (obj_headerColor !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_headerColor + '" (at "' + path_headerColor + '")');
            }
        })();
        if (obj_headerColor_union1_error != null) {
            obj_headerColor_union1 = obj_headerColor_union1_error.message;
        }
        if (obj_headerColor_union0 && obj_headerColor_union1) {
            let message = 'Object doesn\'t match union (at "' + path_headerColor + '")';
            message += '\n' + obj_headerColor_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_headerColor_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_iconUrl = obj.iconUrl;
        const path_iconUrl = path + '.iconUrl';
        let obj_iconUrl_union0 = null;
        const obj_iconUrl_union0_error = (() => {
            if (typeof obj_iconUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union0_error != null) {
            obj_iconUrl_union0 = obj_iconUrl_union0_error.message;
        }
        let obj_iconUrl_union1 = null;
        const obj_iconUrl_union1_error = (() => {
            if (obj_iconUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union1_error != null) {
            obj_iconUrl_union1 = obj_iconUrl_union1_error.message;
        }
        if (obj_iconUrl_union0 && obj_iconUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_iconUrl + '")';
            message += '\n' + obj_iconUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_iconUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_isNavAutoTempTabsDisabled = obj.isNavAutoTempTabsDisabled;
        const path_isNavAutoTempTabsDisabled = path + '.isNavAutoTempTabsDisabled';
        if (typeof obj_isNavAutoTempTabsDisabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isNavAutoTempTabsDisabled + '" (at "' + path_isNavAutoTempTabsDisabled + '")');
        }
        const obj_isNavPersonalizationDisabled = obj.isNavPersonalizationDisabled;
        const path_isNavPersonalizationDisabled = path + '.isNavPersonalizationDisabled';
        if (typeof obj_isNavPersonalizationDisabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isNavPersonalizationDisabled + '" (at "' + path_isNavPersonalizationDisabled + '")');
        }
        const obj_isNavTabPersistenceDisabled = obj.isNavTabPersistenceDisabled;
        const path_isNavTabPersistenceDisabled = path + '.isNavTabPersistenceDisabled';
        if (typeof obj_isNavTabPersistenceDisabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isNavTabPersistenceDisabled + '" (at "' + path_isNavTabPersistenceDisabled + '")');
        }
        const obj_isOmniPinnedViewEnabled = obj.isOmniPinnedViewEnabled;
        const path_isOmniPinnedViewEnabled = path + '.isOmniPinnedViewEnabled';
        if (typeof obj_isOmniPinnedViewEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isOmniPinnedViewEnabled + '" (at "' + path_isOmniPinnedViewEnabled + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_logoUrl = obj.logoUrl;
        const path_logoUrl = path + '.logoUrl';
        if (typeof obj_logoUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_logoUrl + '" (at "' + path_logoUrl + '")');
        }
        const obj_mobileStartUrl = obj.mobileStartUrl;
        const path_mobileStartUrl = path + '.mobileStartUrl';
        let obj_mobileStartUrl_union0 = null;
        const obj_mobileStartUrl_union0_error = (() => {
            if (typeof obj_mobileStartUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_mobileStartUrl + '" (at "' + path_mobileStartUrl + '")');
            }
        })();
        if (obj_mobileStartUrl_union0_error != null) {
            obj_mobileStartUrl_union0 = obj_mobileStartUrl_union0_error.message;
        }
        let obj_mobileStartUrl_union1 = null;
        const obj_mobileStartUrl_union1_error = (() => {
            if (obj_mobileStartUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_mobileStartUrl + '" (at "' + path_mobileStartUrl + '")');
            }
        })();
        if (obj_mobileStartUrl_union1_error != null) {
            obj_mobileStartUrl_union1 = obj_mobileStartUrl_union1_error.message;
        }
        if (obj_mobileStartUrl_union0 && obj_mobileStartUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_mobileStartUrl + '")';
            message += '\n' + obj_mobileStartUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_mobileStartUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_navItems = obj.navItems;
        const path_navItems = path + '.navItems';
        if (!ArrayIsArray(obj_navItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_navItems + '" (at "' + path_navItems + '")');
        }
        for (let i = 0; i < obj_navItems.length; i++) {
            const obj_navItems_item = obj_navItems[i];
            const path_navItems_item = path_navItems + '[' + i + ']';
            if (typeof obj_navItems_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_navItems_item + '" (at "' + path_navItems_item + '")');
            }
        }
        const obj_selected = obj.selected;
        const path_selected = path + '.selected';
        if (typeof obj_selected !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_selected + '" (at "' + path_selected + '")');
        }
        const obj_startUrl = obj.startUrl;
        const path_startUrl = path + '.startUrl';
        if (typeof obj_startUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_startUrl + '" (at "' + path_startUrl + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
        const obj_userNavItems = obj.userNavItems;
        const path_userNavItems = path + '.userNavItems';
        if (!ArrayIsArray(obj_userNavItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_userNavItems + '" (at "' + path_userNavItems + '")');
        }
        for (let i = 0; i < obj_userNavItems.length; i++) {
            const obj_userNavItems_item = obj_userNavItems[i];
            const path_userNavItems_item = path_userNavItems + '[' + i + ']';
            if (typeof obj_userNavItems_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_userNavItems_item + '" (at "' + path_userNavItems_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$x = 'AppRepresentation';
function keyBuilder$1k(luvio, config) {
    return keyPrefix + '::' + RepresentationType$x + ':' + (config.appId === null ? '' : config.appId);
}
function keyBuilderFromType$l(luvio, object) {
    const keyParams = {
        appId: object.appId
    };
    return keyBuilder$1k(luvio, keyParams);
}
function normalize$r(input, existing, path, luvio, store, timestamp) {
    const input_navItems = input.navItems;
    const input_navItems_id = path.fullPath + '__navItems';
    for (let i = 0; i < input_navItems.length; i++) {
        const input_navItems_item = input_navItems[i];
        let input_navItems_item_id = input_navItems_id + '__' + i;
        input_navItems[i] = ingest$s(input_navItems_item, {
            fullPath: input_navItems_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_userNavItems = input.userNavItems;
    const input_userNavItems_id = path.fullPath + '__userNavItems';
    for (let i = 0; i < input_userNavItems.length; i++) {
        const input_userNavItems_item = input_userNavItems[i];
        let input_userNavItems_item_id = input_userNavItems_id + '__' + i;
        input_userNavItems[i] = ingest$s(input_userNavItems_item, {
            fullPath: input_userNavItems_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1h = function AppRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$P,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'appId',
                kind: 'Scalar'
            },
            {
                name: 'description',
                kind: 'Scalar'
            },
            {
                name: 'developerName',
                kind: 'Scalar'
            },
            {
                name: 'formFactors',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'headerColor',
                kind: 'Scalar'
            },
            {
                name: 'iconUrl',
                kind: 'Scalar'
            },
            {
                name: 'isNavAutoTempTabsDisabled',
                kind: 'Scalar'
            },
            {
                name: 'isNavPersonalizationDisabled',
                kind: 'Scalar'
            },
            {
                name: 'isNavTabPersistenceDisabled',
                kind: 'Scalar'
            },
            {
                name: 'isOmniPinnedViewEnabled',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'logoUrl',
                kind: 'Scalar'
            },
            {
                name: 'mobileStartUrl',
                kind: 'Scalar'
            },
            {
                name: 'navItems',
                kind: 'Link',
                plural: true,
                fragment: select$1i()
            },
            {
                name: 'selected',
                kind: 'Scalar'
            },
            {
                name: 'startUrl',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            },
            {
                name: 'userNavItems',
                kind: 'Link',
                plural: true,
                fragment: select$1i()
            }
        ]
    };
};
function equals$F(existing, incoming) {
    const existing_isNavAutoTempTabsDisabled = existing.isNavAutoTempTabsDisabled;
    const incoming_isNavAutoTempTabsDisabled = incoming.isNavAutoTempTabsDisabled;
    if (!(existing_isNavAutoTempTabsDisabled === incoming_isNavAutoTempTabsDisabled)) {
        return false;
    }
    const existing_isNavPersonalizationDisabled = existing.isNavPersonalizationDisabled;
    const incoming_isNavPersonalizationDisabled = incoming.isNavPersonalizationDisabled;
    if (!(existing_isNavPersonalizationDisabled === incoming_isNavPersonalizationDisabled)) {
        return false;
    }
    const existing_isNavTabPersistenceDisabled = existing.isNavTabPersistenceDisabled;
    const incoming_isNavTabPersistenceDisabled = incoming.isNavTabPersistenceDisabled;
    if (!(existing_isNavTabPersistenceDisabled === incoming_isNavTabPersistenceDisabled)) {
        return false;
    }
    const existing_isOmniPinnedViewEnabled = existing.isOmniPinnedViewEnabled;
    const incoming_isOmniPinnedViewEnabled = incoming.isOmniPinnedViewEnabled;
    if (!(existing_isOmniPinnedViewEnabled === incoming_isOmniPinnedViewEnabled)) {
        return false;
    }
    const existing_selected = existing.selected;
    const incoming_selected = incoming.selected;
    if (!(existing_selected === incoming_selected)) {
        return false;
    }
    const existing_developerName = existing.developerName;
    const incoming_developerName = incoming.developerName;
    if (!(existing_developerName === incoming_developerName)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_logoUrl = existing.logoUrl;
    const incoming_logoUrl = incoming.logoUrl;
    if (!(existing_logoUrl === incoming_logoUrl)) {
        return false;
    }
    const existing_startUrl = existing.startUrl;
    const incoming_startUrl = incoming.startUrl;
    if (!(existing_startUrl === incoming_startUrl)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_appId = existing.appId;
    const incoming_appId = incoming.appId;
    if (!(existing_appId === incoming_appId)) {
        return false;
    }
    const existing_description = existing.description;
    const incoming_description = incoming.description;
    if (!(existing_description === incoming_description)) {
        return false;
    }
    const existing_formFactors = existing.formFactors;
    const incoming_formFactors = incoming.formFactors;
    const equals_formFactors_items = equalsArray(existing_formFactors, incoming_formFactors, (existing_formFactors_item, incoming_formFactors_item) => {
        if (!(existing_formFactors_item === incoming_formFactors_item)) {
            return false;
        }
    });
    if (equals_formFactors_items === false) {
        return false;
    }
    const existing_headerColor = existing.headerColor;
    const incoming_headerColor = incoming.headerColor;
    if (!(existing_headerColor === incoming_headerColor)) {
        return false;
    }
    const existing_iconUrl = existing.iconUrl;
    const incoming_iconUrl = incoming.iconUrl;
    if (!(existing_iconUrl === incoming_iconUrl)) {
        return false;
    }
    const existing_mobileStartUrl = existing.mobileStartUrl;
    const incoming_mobileStartUrl = incoming.mobileStartUrl;
    if (!(existing_mobileStartUrl === incoming_mobileStartUrl)) {
        return false;
    }
    const existing_navItems = existing.navItems;
    const incoming_navItems = incoming.navItems;
    const equals_navItems_items = equalsArray(existing_navItems, incoming_navItems, (existing_navItems_item, incoming_navItems_item) => {
        if (!(existing_navItems_item.__ref === incoming_navItems_item.__ref)) {
            return false;
        }
    });
    if (equals_navItems_items === false) {
        return false;
    }
    const existing_userNavItems = existing.userNavItems;
    const incoming_userNavItems = incoming.userNavItems;
    const equals_userNavItems_items = equalsArray(existing_userNavItems, incoming_userNavItems, (existing_userNavItems_item, incoming_userNavItems_item) => {
        if (!(existing_userNavItems_item.__ref === incoming_userNavItems_item.__ref)) {
            return false;
        }
    });
    if (equals_userNavItems_items === false) {
        return false;
    }
    return true;
}
const ingest$r = function AppRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1h(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$l(luvio, input);
    const ttlToUse = TTL$n;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$r, "UiApi", VERSION$P, RepresentationType$x, equals$F);
    return createLink(key);
};
function getTypeCacheKeys$y(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$l(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$x,
        mergeable: false
    });
    const input_navItems_length = input.navItems.length;
    for (let i = 0; i < input_navItems_length; i++) {
        getTypeCacheKeys$z(rootKeySet, luvio, input.navItems[i]);
    }
    const input_userNavItems_length = input.userNavItems.length;
    for (let i = 0; i < input_userNavItems_length; i++) {
        getTypeCacheKeys$z(rootKeySet, luvio, input.userNavItems[i]);
    }
}

const TTL$m = 300000;
const VERSION$O = "a254babf0b6414315db7808a157fd9fc";
function validate$1g(obj, path = 'AppsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apps = obj.apps;
        const path_apps = path + '.apps';
        if (!ArrayIsArray(obj_apps)) {
            return new TypeError('Expected "array" but received "' + typeof obj_apps + '" (at "' + path_apps + '")');
        }
        for (let i = 0; i < obj_apps.length; i++) {
            const obj_apps_item = obj_apps[i];
            const path_apps_item = path_apps + '[' + i + ']';
            if (typeof obj_apps_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_apps_item + '" (at "' + path_apps_item + '")');
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$w = 'AppsRepresentation';
function normalize$q(input, existing, path, luvio, store, timestamp) {
    const input_apps = input.apps;
    const input_apps_id = path.fullPath + '__apps';
    for (let i = 0; i < input_apps.length; i++) {
        const input_apps_item = input_apps[i];
        let input_apps_item_id = input_apps_id + '__' + i;
        input_apps[i] = ingest$r(input_apps_item, {
            fullPath: input_apps_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$1g = function AppsRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$O,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'apps',
                kind: 'Link',
                plural: true,
                fragment: select$1h()
            }
        ]
    };
};
function equals$E(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_apps = existing.apps;
    const incoming_apps = incoming.apps;
    const equals_apps_items = equalsArray(existing_apps, incoming_apps, (existing_apps_item, incoming_apps_item) => {
        if (!(existing_apps_item.__ref === incoming_apps_item.__ref)) {
            return false;
        }
    });
    if (equals_apps_items === false) {
        return false;
    }
    return true;
}
const ingest$q = function AppsRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1g(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$m;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$q, "UiApi", VERSION$O, RepresentationType$w, equals$E);
    return createLink(key);
};
function getTypeCacheKeys$x(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$w,
        mergeable: false
    });
    const input_apps_length = input.apps.length;
    for (let i = 0; i < input_apps_length; i++) {
        getTypeCacheKeys$y(rootKeySet, luvio, input.apps[i]);
    }
}

function select$1f(luvio, params) {
    return select$1g();
}
function keyBuilder$1j(luvio, params) {
    return keyPrefix + '::AppsRepresentation:(' + 'formFactor:' + params.queryParams.formFactor + ',' + 'userCustomizations:' + params.queryParams.userCustomizations + ')';
}
function getResponseCacheKeys$M(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$x(storeKeyMap, luvio, response, () => keyBuilder$1j(luvio, resourceParams));
}
function ingestSuccess$C(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1j(luvio, resourceParams);
    luvio.storeIngest(key, ingest$q, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1f(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$u(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1j(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$m,
        namespace: keyPrefix,
        version: VERSION$O,
        representationName: RepresentationType$w
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$Q(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/apps',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$K = 'getAllApps';
const getAllApps_ConfigPropertyMetadata = [
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('userCustomizations', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
const getAllApps_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$K, getAllApps_ConfigPropertyMetadata);
const createResourceParams$K = /*#__PURE__*/ createResourceParams$13(getAllApps_ConfigPropertyMetadata);
function keyBuilder$1i(luvio, config) {
    const resourceParams = createResourceParams$K(config);
    return keyBuilder$1j(luvio, resourceParams);
}
function typeCheckConfig$O(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getAllApps_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$Q(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getAllApps_ConfigPropertyMetadata);
    const config = typeCheckConfig$O(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$t(luvio, config) {
    createResourceParams$K(config);
    return select$1f();
}
function onFetchResponseSuccess$x(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$C(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$P(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$x(luvio, config, resourceParams, response) {
    const snapshot = ingestError$u(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$P(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$P(luvio, config, options) {
    const resourceParams = createResourceParams$K(config);
    const request = createResourceRequest$Q(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$x(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$M(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$x(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$B(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$P, undefined, false);
}
function buildCachedSnapshotCachePolicy$A(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1i(luvio, config),
        node: adapterFragment$t(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$P(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getAllAppsAdapterFactory = (luvio) => function UiApi__getAllApps(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$Q(untrustedConfig, getAllApps_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$A, buildNetworkSnapshotCachePolicy$B);
};

function select$1e(luvio, params) {
    return select$1h();
}
function keyBuilder$1h(luvio, params) {
    return keyBuilder$1k(luvio, {
        appId: params.urlParams.appId
    });
}
function getResponseCacheKeys$L(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$y(storeKeyMap, luvio, response);
}
function ingestSuccess$B(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1h(luvio, resourceParams);
    luvio.storeIngest(key, ingest$r, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1e(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$t(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1h(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$n,
        namespace: keyPrefix,
        version: VERSION$P,
        representationName: RepresentationType$x
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$P(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/apps/' + config.urlParams.appId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$J = 'getAppDetails';
const getAppDetails_ConfigPropertyMetadata = [
    generateParamConfigMetadata('appId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('userCustomizations', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
const getAppDetails_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$J, getAppDetails_ConfigPropertyMetadata);
const createResourceParams$J = /*#__PURE__*/ createResourceParams$13(getAppDetails_ConfigPropertyMetadata);
function keyBuilder$1g(luvio, config) {
    const resourceParams = createResourceParams$J(config);
    return keyBuilder$1h(luvio, resourceParams);
}
function typeCheckConfig$N(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getAppDetails_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$P(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getAppDetails_ConfigPropertyMetadata);
    const config = typeCheckConfig$N(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$s(luvio, config) {
    createResourceParams$J(config);
    return select$1e();
}
function onFetchResponseSuccess$w(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$B(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$O(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$w(luvio, config, resourceParams, response) {
    const snapshot = ingestError$t(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$O(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$O(luvio, config, options) {
    const resourceParams = createResourceParams$J(config);
    const request = createResourceRequest$P(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$w(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$L(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$w(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$A(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$O, undefined, false);
}
function buildCachedSnapshotCachePolicy$z(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1g(luvio, config),
        node: adapterFragment$s(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$O(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getAppDetailsAdapterFactory = (luvio) => function UiApi__getAppDetails(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$P(untrustedConfig, getAppDetails_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$z, buildNetworkSnapshotCachePolicy$A);
};

const VERSION$N = "f43ef90ffde4d488414d6868e3aaefcb";
function validate$1f(obj, path = 'DuplicateRuleFilterItemRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_field = obj.field;
        const path_field = path + '.field';
        if (typeof obj_field !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_field + '" (at "' + path_field + '")');
        }
        const obj_operation = obj.operation;
        const path_operation = path + '.operation';
        if (typeof obj_operation !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operation + '" (at "' + path_operation + '")');
        }
        const obj_sortOrder = obj.sortOrder;
        const path_sortOrder = path + '.sortOrder';
        if (typeof obj_sortOrder !== 'number' || (typeof obj_sortOrder === 'number' && Math.floor(obj_sortOrder) !== obj_sortOrder)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_sortOrder + '" (at "' + path_sortOrder + '")');
        }
        const obj_value = obj.value;
        const path_value = path + '.value';
        if (typeof obj_value !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_value + '" (at "' + path_value + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1d = function DuplicateRuleFilterItemRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$N,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'field',
                kind: 'Scalar'
            },
            {
                name: 'operation',
                kind: 'Scalar'
            },
            {
                name: 'sortOrder',
                kind: 'Scalar'
            },
            {
                name: 'value',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$M = "320d7f254687278f2763d4b490dab3fb";
function validate$1e(obj, path = 'DuplicateRuleFilterRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_booleanFilter = obj.booleanFilter;
        const path_booleanFilter = path + '.booleanFilter';
        if (typeof obj_booleanFilter !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_booleanFilter + '" (at "' + path_booleanFilter + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_filterItems = obj.filterItems;
        const path_filterItems = path + '.filterItems';
        if (!ArrayIsArray(obj_filterItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_filterItems + '" (at "' + path_filterItems + '")');
        }
        for (let i = 0; i < obj_filterItems.length; i++) {
            const obj_filterItems_item = obj_filterItems[i];
            const path_filterItems_item = path_filterItems + '[' + i + ']';
            const referencepath_filterItems_itemValidationError = validate$1f(obj_filterItems_item, path_filterItems_item);
            if (referencepath_filterItems_itemValidationError !== null) {
                let message = 'Object doesn\'t match DuplicateRuleFilterItemRepresentation (at "' + path_filterItems_item + '")\n';
                message += referencepath_filterItems_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_ruleCritera = obj.ruleCritera;
        const path_ruleCritera = path + '.ruleCritera';
        if (typeof obj_ruleCritera !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_ruleCritera + '" (at "' + path_ruleCritera + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1c = function DuplicateRuleFilterRepresentationSelect() {
    const { selections: DuplicateRuleFilterItemRepresentation__selections, opaque: DuplicateRuleFilterItemRepresentation__opaque, } = select$1d();
    return {
        kind: 'Fragment',
        version: VERSION$M,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'booleanFilter',
                kind: 'Scalar'
            },
            {
                name: 'filterItems',
                kind: 'Object',
                plural: true,
                selections: DuplicateRuleFilterItemRepresentation__selections
            },
            {
                name: 'ruleCritera',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$L = "b47b44e260e5ce777beaf3da9088997c";
function validate$1d(obj, path = 'MatchRuleRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_matchEngine = obj.matchEngine;
        const path_matchEngine = path + '.matchEngine';
        if (typeof obj_matchEngine !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_matchEngine + '" (at "' + path_matchEngine + '")');
        }
        const obj_matchFields = obj.matchFields;
        const path_matchFields = path + '.matchFields';
        if (!ArrayIsArray(obj_matchFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_matchFields + '" (at "' + path_matchFields + '")');
        }
        for (let i = 0; i < obj_matchFields.length; i++) {
            const obj_matchFields_item = obj_matchFields[i];
            const path_matchFields_item = path_matchFields + '[' + i + ']';
            if (typeof obj_matchFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_matchFields_item + '" (at "' + path_matchFields_item + '")');
            }
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1b = function MatchRuleRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$L,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'matchEngine',
                kind: 'Scalar'
            },
            {
                name: 'matchFields',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'name',
                kind: 'Scalar'
            },
            {
                name: 'objectApiName',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$K = "bb83d7210bb1d7861b6188bc5f552617";
function validate$1c(obj, path = 'DuplicateRuleRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_actionOnInsert = obj.actionOnInsert;
        const path_actionOnInsert = path + '.actionOnInsert';
        if (typeof obj_actionOnInsert !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionOnInsert + '" (at "' + path_actionOnInsert + '")');
        }
        const obj_actionOnUpdate = obj.actionOnUpdate;
        const path_actionOnUpdate = path + '.actionOnUpdate';
        if (typeof obj_actionOnUpdate !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_actionOnUpdate + '" (at "' + path_actionOnUpdate + '")');
        }
        const obj_active = obj.active;
        const path_active = path + '.active';
        if (typeof obj_active !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_active + '" (at "' + path_active + '")');
        }
        const obj_duplicateRuleFilters = obj.duplicateRuleFilters;
        const path_duplicateRuleFilters = path + '.duplicateRuleFilters';
        if (!ArrayIsArray(obj_duplicateRuleFilters)) {
            return new TypeError('Expected "array" but received "' + typeof obj_duplicateRuleFilters + '" (at "' + path_duplicateRuleFilters + '")');
        }
        for (let i = 0; i < obj_duplicateRuleFilters.length; i++) {
            const obj_duplicateRuleFilters_item = obj_duplicateRuleFilters[i];
            const path_duplicateRuleFilters_item = path_duplicateRuleFilters + '[' + i + ']';
            const referencepath_duplicateRuleFilters_itemValidationError = validate$1e(obj_duplicateRuleFilters_item, path_duplicateRuleFilters_item);
            if (referencepath_duplicateRuleFilters_itemValidationError !== null) {
                let message = 'Object doesn\'t match DuplicateRuleFilterRepresentation (at "' + path_duplicateRuleFilters_item + '")\n';
                message += referencepath_duplicateRuleFilters_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_matchRules = obj.matchRules;
        const path_matchRules = path + '.matchRules';
        if (!ArrayIsArray(obj_matchRules)) {
            return new TypeError('Expected "array" but received "' + typeof obj_matchRules + '" (at "' + path_matchRules + '")');
        }
        for (let i = 0; i < obj_matchRules.length; i++) {
            const obj_matchRules_item = obj_matchRules[i];
            const path_matchRules_item = path_matchRules + '[' + i + ']';
            const referencepath_matchRules_itemValidationError = validate$1d(obj_matchRules_item, path_matchRules_item);
            if (referencepath_matchRules_itemValidationError !== null) {
                let message = 'Object doesn\'t match MatchRuleRepresentation (at "' + path_matchRules_item + '")\n';
                message += referencepath_matchRules_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_operationsOnInsert = obj.operationsOnInsert;
        const path_operationsOnInsert = path + '.operationsOnInsert';
        if (!ArrayIsArray(obj_operationsOnInsert)) {
            return new TypeError('Expected "array" but received "' + typeof obj_operationsOnInsert + '" (at "' + path_operationsOnInsert + '")');
        }
        for (let i = 0; i < obj_operationsOnInsert.length; i++) {
            const obj_operationsOnInsert_item = obj_operationsOnInsert[i];
            const path_operationsOnInsert_item = path_operationsOnInsert + '[' + i + ']';
            if (typeof obj_operationsOnInsert_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_operationsOnInsert_item + '" (at "' + path_operationsOnInsert_item + '")');
            }
        }
        const obj_operationsOnUpdate = obj.operationsOnUpdate;
        const path_operationsOnUpdate = path + '.operationsOnUpdate';
        if (!ArrayIsArray(obj_operationsOnUpdate)) {
            return new TypeError('Expected "array" but received "' + typeof obj_operationsOnUpdate + '" (at "' + path_operationsOnUpdate + '")');
        }
        for (let i = 0; i < obj_operationsOnUpdate.length; i++) {
            const obj_operationsOnUpdate_item = obj_operationsOnUpdate[i];
            const path_operationsOnUpdate_item = path_operationsOnUpdate + '[' + i + ']';
            if (typeof obj_operationsOnUpdate_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_operationsOnUpdate_item + '" (at "' + path_operationsOnUpdate_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$1a = function DuplicateRuleRepresentationSelect() {
    const { selections: DuplicateRuleFilterRepresentation__selections, opaque: DuplicateRuleFilterRepresentation__opaque, } = select$1c();
    const { selections: MatchRuleRepresentation__selections, opaque: MatchRuleRepresentation__opaque, } = select$1b();
    return {
        kind: 'Fragment',
        version: VERSION$K,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'actionOnInsert',
                kind: 'Scalar'
            },
            {
                name: 'actionOnUpdate',
                kind: 'Scalar'
            },
            {
                name: 'active',
                kind: 'Scalar'
            },
            {
                name: 'duplicateRuleFilters',
                kind: 'Object',
                plural: true,
                selections: DuplicateRuleFilterRepresentation__selections
            },
            {
                name: 'matchRules',
                kind: 'Object',
                plural: true,
                selections: MatchRuleRepresentation__selections
            },
            {
                name: 'name',
                kind: 'Scalar'
            },
            {
                name: 'operationsOnInsert',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'operationsOnUpdate',
                kind: 'Scalar',
                plural: true
            }
        ]
    };
};

const TTL$l = 900000;
const VERSION$J = "be27ee99dc0dc43a1f66b8fe98dc532c";
function validate$1b(obj, path = 'DuplicatesConfigurationRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_dedupeEnabled = obj.dedupeEnabled;
        const path_dedupeEnabled = path + '.dedupeEnabled';
        if (typeof obj_dedupeEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_dedupeEnabled + '" (at "' + path_dedupeEnabled + '")');
        }
        const obj_dedupeFields = obj.dedupeFields;
        const path_dedupeFields = path + '.dedupeFields';
        if (!ArrayIsArray(obj_dedupeFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_dedupeFields + '" (at "' + path_dedupeFields + '")');
        }
        for (let i = 0; i < obj_dedupeFields.length; i++) {
            const obj_dedupeFields_item = obj_dedupeFields[i];
            const path_dedupeFields_item = path_dedupeFields + '[' + i + ']';
            if (typeof obj_dedupeFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_dedupeFields_item + '" (at "' + path_dedupeFields_item + '")');
            }
        }
        const obj_duplicateRules = obj.duplicateRules;
        const path_duplicateRules = path + '.duplicateRules';
        if (!ArrayIsArray(obj_duplicateRules)) {
            return new TypeError('Expected "array" but received "' + typeof obj_duplicateRules + '" (at "' + path_duplicateRules + '")');
        }
        for (let i = 0; i < obj_duplicateRules.length; i++) {
            const obj_duplicateRules_item = obj_duplicateRules[i];
            const path_duplicateRules_item = path_duplicateRules + '[' + i + ']';
            const referencepath_duplicateRules_itemValidationError = validate$1c(obj_duplicateRules_item, path_duplicateRules_item);
            if (referencepath_duplicateRules_itemValidationError !== null) {
                let message = 'Object doesn\'t match DuplicateRuleRepresentation (at "' + path_duplicateRules_item + '")\n';
                message += referencepath_duplicateRules_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_predupeEnabled = obj.predupeEnabled;
        const path_predupeEnabled = path + '.predupeEnabled';
        if (typeof obj_predupeEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_predupeEnabled + '" (at "' + path_predupeEnabled + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$v = 'DuplicatesConfigurationRepresentation';
function normalize$p(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$19 = function DuplicatesConfigurationRepresentationSelect() {
    const { selections: DuplicateRuleRepresentation__selections, opaque: DuplicateRuleRepresentation__opaque, } = select$1a();
    return {
        kind: 'Fragment',
        version: VERSION$J,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'dedupeEnabled',
                kind: 'Scalar'
            },
            {
                name: 'dedupeFields',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'duplicateRules',
                kind: 'Object',
                plural: true,
                selections: DuplicateRuleRepresentation__selections
            },
            {
                name: 'predupeEnabled',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$D(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$p = function DuplicatesConfigurationRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$1b(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$l;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$p, "UiApi", VERSION$J, RepresentationType$v, equals$D);
    return createLink(key);
};
function getTypeCacheKeys$w(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$v,
        mergeable: false
    });
}

function select$18(luvio, params) {
    return select$19();
}
function keyBuilder$1f(luvio, params) {
    return keyPrefix + '::DuplicatesConfigurationRepresentation:(' + 'recordTypeId:' + params.queryParams.recordTypeId + ',' + 'objectApiName:' + params.urlParams.objectApiName + ')';
}
function getResponseCacheKeys$K(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$w(storeKeyMap, luvio, response, () => keyBuilder$1f(luvio, resourceParams));
}
function ingestSuccess$A(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1f(luvio, resourceParams);
    luvio.storeIngest(key, ingest$p, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$18(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$s(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1f(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$l,
        namespace: keyPrefix,
        version: VERSION$J,
        representationName: RepresentationType$v
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$O(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/duplicates/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$I = 'getDuplicateConfiguration';
const getDuplicateConfiguration_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getDuplicateConfiguration_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$I, getDuplicateConfiguration_ConfigPropertyMetadata);
const createResourceParams$I = /*#__PURE__*/ createResourceParams$13(getDuplicateConfiguration_ConfigPropertyMetadata);
function keyBuilder$1e(luvio, config) {
    const resourceParams = createResourceParams$I(config);
    return keyBuilder$1f(luvio, resourceParams);
}
function typeCheckConfig$M(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getDuplicateConfiguration_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$O(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$M(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$r(luvio, config) {
    createResourceParams$I(config);
    return select$18();
}
function onFetchResponseSuccess$v(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$A(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$N(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$v(luvio, config, resourceParams, response) {
    const snapshot = ingestError$s(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$N(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$N(luvio, config, options) {
    const resourceParams = createResourceParams$I(config);
    const request = createResourceRequest$O(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$v(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$K(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$v(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$z(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$N, undefined, false);
}
function buildCachedSnapshotCachePolicy$y(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1e(luvio, config),
        node: adapterFragment$r(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$N(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getDuplicateConfigurationAdapterFactory = (luvio) => function UiApi__getDuplicateConfiguration(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$O(untrustedConfig, getDuplicateConfiguration_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$y, buildNetworkSnapshotCachePolicy$z);
};

var LayoutType;
(function (LayoutType) {
    LayoutType["Full"] = "Full";
    LayoutType["Compact"] = "Compact";
})(LayoutType || (LayoutType = {}));

function coerceLayoutType(value) {
    if (value === LayoutType.Full || value === LayoutType.Compact) {
        return value;
    }
    return undefined;
}

function coerceLayoutMode(value) {
    if (value === LayoutMode.Create || value === LayoutMode.Edit || value === LayoutMode.View) {
        return value;
    }
    return undefined;
}

function keyBuilder$1d(luvio, params) {
    return keyPrefix + '::RecordLayoutRepresentation:(' + 'formFactor:' + params.queryParams.formFactor + ',' + 'layoutType:' + params.queryParams.layoutType + ',' + 'mode:' + params.queryParams.mode + ',' + 'recordTypeId:' + params.queryParams.recordTypeId + ',' + 'objectApiName:' + params.urlParams.objectApiName + ')';
}
function getResponseCacheKeys$J(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$N(storeKeyMap, luvio, response);
}
function ingestError$r(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1d(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$w,
        namespace: keyPrefix,
        version: VERSION$17,
        representationName: RepresentationType$N
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$N(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/layout/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function onFetchResponseSuccess$u(luvio, config, resourceParams, response) {
    const { body } = response;
    const key = keyBuilder$1V(luvio, config);
    luvio.storeIngest(key, ingest$G, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$1L(),
        variables: {},
    }, {
        config,
        resolve: () => buildNetworkSnapshot$M(luvio, config, snapshotRefreshOptions),
    });
    return luvio.storeBroadcast().then(() => snapshot);
}

// FYI stricter required set than RAML, matches lds222 behavior
const getLayout_ConfigPropertyNames = {
    displayName: 'getLayout',
    parameters: {
        required: ['objectApiName', 'layoutType', 'mode'],
        optional: ['recordTypeId'],
    },
};

function validateAdapterConfig$N(untrustedConfig, _configPropertyNames) {
    const config = validateAdapterConfig$M(untrustedConfig, getLayout_ConfigPropertyNames);
    if (config === null) {
        return null;
    }
    let recordTypeId = config.recordTypeId;
    if (recordTypeId === undefined) {
        // must check untrusted bc config has been coerced
        if (untrustedConfig.recordTypeId !== null &&
            untrustedConfig.recordTypeId !== undefined) {
            return null;
        }
        recordTypeId = MAIN_RECORD_TYPE_ID;
    }
    // layoutType and mode are required during validation.
    // They will always be valid at this point.
    return {
        ...config,
        recordTypeId,
        layoutType: config.layoutType,
        mode: config.mode,
    };
}

function buildCachedSnapshotCachePolicy$x(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1V(luvio, config),
        node: select$1L(),
        variables: {},
    };
    return storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$M(luvio, config, snapshotRefreshOptions),
    });
}

const adapterName$H = 'getLayout';
const getLayout_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('layoutType', false, 1 /* QueryParameter */, 0 /* String */, false, coerceLayoutType),
    generateParamConfigMetadata('mode', false, 1 /* QueryParameter */, 0 /* String */, false, coerceLayoutMode),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */, false, getRecordId18),
];
const createResourceParams$H = /*#__PURE__*/ createResourceParams$13(getLayout_ConfigPropertyMetadata);
function typeCheckConfig$L(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getLayout_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$M(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getLayout_ConfigPropertyMetadata);
    const config = typeCheckConfig$L(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function onFetchResponseError$u(luvio, config, resourceParams, response) {
    const snapshot = ingestError$r(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$M(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$M(luvio, config, options) {
    const resourceParams = createResourceParams$H(config);
    const request = createResourceRequest$N(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$u(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$J(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$u(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$y(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$M, undefined, false);
}
const getLayoutAdapterFactory = (luvio) => function UiApi__getLayout(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$N(untrustedConfig);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$x, buildNetworkSnapshotCachePolicy$y);
};

function getResponseCacheKeys$I(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$M(storeKeyMap, luvio, response);
}
function createResourceRequest$M(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/layout/' + config.urlParams.objectApiName + '/user-state',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function buildCachedSnapshot$5(luvio, config) {
    const { objectApiName, recordTypeId, layoutType, mode } = config;
    const key = keyBuilder$1U(luvio, {
        apiName: objectApiName,
        recordTypeId,
        layoutType,
        mode,
    });
    const selector = {
        recordId: key,
        node: select$1K(),
        variables: {},
    };
    return luvio.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$L(luvio, config),
    });
}

function buildNetworkSnapshot$L(luvio, config, context) {
    const { resourceParams, request, key } = prepareRequest$4(luvio, config);
    return luvio
        .dispatchResourceRequest(request, context)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            return onFetchResponseSuccess$t(luvio, config, key, response);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$I(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (error) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$t(luvio, config, key, error));
    });
}
function onFetchResponseSuccess$t(luvio, config, key, response) {
    const { body } = response;
    const { recordTypeId, layoutType, mode } = config;
    // Hack- adding in this params so record-ui will be able to use normed values.
    body.apiName = config.objectApiName;
    body.recordTypeId = recordTypeId;
    body.layoutType = layoutType;
    body.mode = mode;
    luvio.storeIngest(key, ingest$F, body);
    const snapshot = buildCachedSnapshot$5(luvio, config);
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$t(luvio, config, key, error) {
    const errorSnapshot = luvio.errorSnapshot(error, {
        config,
        resolve: () => buildNetworkSnapshot$L(luvio, config),
    });
    luvio.storeIngestError(key, errorSnapshot);
    return luvio.storeBroadcast().then(() => errorSnapshot);
}
function prepareRequest$4(luvio, config) {
    const { recordTypeId, layoutType, mode, objectApiName } = config;
    const key = keyBuilder$1U(luvio, {
        apiName: objectApiName,
        recordTypeId,
        layoutType,
        mode,
    });
    const resourceParams = {
        urlParams: { objectApiName: config.objectApiName },
        queryParams: {
            layoutType: config.layoutType,
            mode: config.mode,
            recordTypeId: config.recordTypeId,
        },
    };
    const request = createResourceRequest$M(resourceParams);
    return { resourceParams, request, key };
}

function validateAdapterConfig$L(untrustedConfig, configPropertyNames) {
    const config = validateAdapterConfig$K(untrustedConfig, configPropertyNames);
    if (config === null) {
        return null;
    }
    // recordTypeId is overridden to be required
    const recordTypeId = config.recordTypeId;
    const untrusted = untrustedConfig;
    let layoutType = config.layoutType;
    if (layoutType === undefined) {
        if (untrusted.layoutType === undefined) {
            layoutType = LayoutType.Full;
        }
        else {
            return null;
        }
    }
    let mode = config.mode;
    if (mode === undefined) {
        if (untrusted.mode === undefined) {
            mode = LayoutMode.View;
        }
        else {
            return null;
        }
    }
    return {
        ...config,
        recordTypeId,
        layoutType,
        mode,
    };
}

// FYI stricter required set than RAML defines, matches lds222 behavior
const getLayoutUserState_ConfigPropertyNames = {
    displayName: 'getLayoutUserState',
    parameters: {
        required: ['objectApiName', 'recordTypeId'],
        optional: ['formFactor', 'layoutType', 'mode'],
    },
};

function buildCachedSnapshotCachePolicy$w(context, storeLookup) {
    const { config, luvio } = context;
    const { objectApiName, recordTypeId, layoutType, mode } = config;
    const selector = {
        recordId: keyBuilder$1U(luvio, {
            apiName: objectApiName,
            recordTypeId,
            layoutType,
            mode,
        }),
        node: select$1K(),
        variables: {},
    };
    return storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$L(luvio, config),
    });
}

const adapterName$G = 'getLayoutUserState';
const getLayoutUserState_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('layoutType', false, 1 /* QueryParameter */, 0 /* String */, false, coerceLayoutType),
    generateParamConfigMetadata('mode', false, 1 /* QueryParameter */, 0 /* String */, false, coerceLayoutMode),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */, false, getRecordId18),
];
function typeCheckConfig$K(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getLayoutUserState_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$K(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getLayoutUserState_ConfigPropertyMetadata);
    const config = typeCheckConfig$K(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshotCachePolicy$x(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$L, undefined, false);
}
const getLayoutUserStateAdapterFactory = (luvio) => function UiApi__getLayoutUserState(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$L(untrustedConfig, getLayoutUserState_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$w, buildNetworkSnapshotCachePolicy$x);
};

function keyBuilder$1c(luvio, params) {
    return keyBuilder$2a(luvio, {
        objectApiName: params.urlParams.objectApiName.toLowerCase(),
        listViewApiName: params.urlParams.listViewApiName.toLowerCase(),
        type: params.urlParams.listViewApiName.toLowerCase() === '__recent' ? 'mru' : 'listView',
    });
}

function select$17(luvio, params) {
    return select$1Z();
}
function getResponseCacheKeys$H(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$Z(storeKeyMap, luvio, response);
}
function ingestSuccess$z(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1c(luvio, resourceParams);
    luvio.storeIngest(key, ingest$R, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$17(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$q(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1c(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$B,
        namespace: keyPrefix,
        version: VERSION$1k,
        representationName: RepresentationType$Y
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$L(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-info/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

function createChildResourceParams$7(resourceParams) {
    const childConfigs = [];
    const { queryParams } = resourceParams;
    const { names = [] } = queryParams;
    for (const name of names) {
        const [objectApiName, listViewApiName] = name.split('.');
        childConfigs.push({
            urlParams: {
                objectApiName,
                listViewApiName,
            },
        });
    }
    return childConfigs;
}

const nonCachedErrors$5 = ObjectCreate$1(null);
function createChildResourceParams$6(resourceParams) {
    return createChildResourceParams$7(resourceParams);
}
function selectChildResourceParams$5(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$1b(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$1c(luvio, childResource);
                const childFragment = select$17();
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$5[childKey];
                            if (nonCachedError === undefined || nonCachedError.expiration < reader.getTimeStamp()) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$16(luvio, resourceParams) {
    const childResources = createChildResourceParams$6(resourceParams);
    return selectChildResourceParams$5(luvio, childResources, resourceParams);
}
function keyBuilder$1b(luvio, params) {
    return keyPrefix + '::ListInfoBatchRepresentation:(' + 'ids:' + params.queryParams.ids + ',' + 'names:' + params.queryParams.names + ')';
}
function getResponseCacheKeys$G(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$6(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$H(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$1c(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$Y,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$6(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$1c(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$z(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$q(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$5[childKey] = { expiration: now + TTL$B, response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors$5[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$y(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$6(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$1b(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$6(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$16(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$p(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1b(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$K(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-info/batch',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$F = 'getListInfosByName';
const getListInfosByName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('ids', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('names', false, 1 /* QueryParameter */, 0 /* String */, true),
];
const getListInfosByName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$F, getListInfosByName_ConfigPropertyMetadata);
const createResourceParams$G = /*#__PURE__*/ createResourceParams$13(getListInfosByName_ConfigPropertyMetadata);
function keyBuilder$1a(luvio, config) {
    const resourceParams = createResourceParams$G(config);
    return keyBuilder$1b(luvio, resourceParams);
}
function typeCheckConfig$J(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListInfosByName_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$J(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$J(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$q(luvio, config) {
    const resourceParams = createResourceParams$G(config);
    return select$16(luvio, resourceParams);
}
function onFetchResponseSuccess$s(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$y(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$K(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$s(luvio, config, resourceParams, response) {
    const snapshot = ingestError$p(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$K(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$K(luvio, config, options) {
    const resourceParams = createResourceParams$G(config);
    const request = createResourceRequest$K(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$s(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$G(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$s(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$w(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$K, undefined, false);
}
function buildCachedSnapshotCachePolicy$v(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$1a(luvio, config),
        node: adapterFragment$q(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$K(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getListInfosByNameAdapterFactory = (luvio) => function UiApi__getListInfosByName(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$J(untrustedConfig, getListInfosByName_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$v, buildNetworkSnapshotCachePolicy$w);
};

function createPaginationParams$1(params) {
    const { queryParams } = params;
    return {
        token: queryParams.pageToken,
        pageSize: queryParams.pageSize === undefined ? 20 : queryParams.pageSize
    };
}
function select$15(luvio, params) {
    const paginationParams = createPaginationParams$1(params);
    return select$1S(paginationParams);
}
function keyBuilder$19(luvio, params) {
    return keyBuilder$23(luvio, {
        objectApiName: params.urlParams.objectApiName,
        queryString: params.queryParams.q || null,
        recentListsOnly: params.queryParams.recentListsOnly || false
    });
}
function getResponseCacheKeys$F(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$R(storeKeyMap, luvio, response);
}
function ingestSuccess$x(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$19(luvio, resourceParams);
    luvio.storeIngest(key, ingest$K, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$15(luvio, resourceParams),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$o(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$19(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$J(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-info/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$E = 'getListInfosByObjectName';
const getListInfosByObjectName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('q', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('recentListsOnly', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
const getListInfosByObjectName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$E, getListInfosByObjectName_ConfigPropertyMetadata);
const createResourceParams$F = /*#__PURE__*/ createResourceParams$13(getListInfosByObjectName_ConfigPropertyMetadata);
function keyBuilder$18(luvio, config) {
    const resourceParams = createResourceParams$F(config);
    return keyBuilder$19(luvio, resourceParams);
}
function typeCheckConfig$I(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListInfosByObjectName_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$I(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$I(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$p(luvio, config) {
    const resourceParams = createResourceParams$F(config);
    return select$15(luvio, resourceParams);
}
function onFetchResponseSuccess$r(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$x(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$J(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$r(luvio, config, resourceParams, response) {
    const snapshot = ingestError$o(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$J(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function prepareRequest$3(luvio, config, resourceParams, cacheSnapshot) {
    if (cacheSnapshot === undefined) {
        return createResourceRequest$J(resourceParams);
    }
    const [newToken, newPageSize] = minimizePaginationParams$1(luvio, resourceParams, cacheSnapshot);
    if (newToken === undefined) {
        return createResourceRequest$J(resourceParams);
    }
    return createResourceRequest$J(createResourceParams$F({
        ...config,
        pageSize: newPageSize,
        pageToken: newToken
    }));
}
function minimizePaginationParams$1(luvio, resourceParams, cacheSnapshot) {
    const num = getCachedItemsNumber$2(cacheSnapshot);
    if (num > 0) {
        const paginationMetadata = getPaginationMetadata$2(luvio, resourceParams);
        if (paginationMetadata !== undefined) {
            const { token: configToken, pageSize: configPageSize } = createPaginationParams$1(resourceParams);
            const configTokenOffset = offsetFromToken(paginationMetadata, configToken);
            if (configTokenOffset < 0) {
                return [undefined, -1];
            }
            const maxOffset = configTokenOffset + num;
            const [token, offset] = tokenForAtMost(paginationMetadata, maxOffset);
            if (token !== undefined) {
                return [token, configPageSize - (offset - configTokenOffset)];
            }
        }
    }
    return [undefined, -1];
}
function getCachedItemsNumber$2(cacheSnapshot) {
    const { data } = cacheSnapshot;
    if (data === undefined || !data.lists) {
        return 0;
    }
    const items = data.lists;
    for (let i = 0; i < items.length; i++) {
        if (items[i] === undefined) {
            return i;
        }
    }
    return items.length;
}
function getPaginationMetadata$2(luvio, resourceParams) {
    const key = keyBuilder$19(luvio, resourceParams);
    const selector = {
        recordId: key,
        node: {
            kind: 'Fragment',
            version: VERSION$1b,
            private: [],
            selections: [
                {
                    kind: 'Link',
                    name: '__metadata',
                    fragment: {
                        kind: 'Fragment',
                        version: PAGINATION_VERSION$1,
                        opaque: true,
                        private: [],
                    },
                },
            ],
        },
        variables: {}
    };
    const node = luvio.storeLookup(selector);
    if (node.state !== 'Fulfilled') {
        return;
    }
    return node.data.__metadata;
}
function buildNetworkSnapshot$J(luvio, config, options, cacheSnapshot) {
    const resourceParams = createResourceParams$F(config);
    const request = prepareRequest$3(luvio, config, resourceParams, cacheSnapshot);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$r(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$F(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$r(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$v(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$J, undefined, true);
}
function buildCachedSnapshotCachePolicy$u(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$18(luvio, config),
        node: adapterFragment$p(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$J(luvio, config, snapshotRefreshOptions)
    });
    if (isUnfulfilledSnapshot$1(cacheSnapshot) && cacheSnapshot.data !== undefined) {
        context.cacheSnapshot = cacheSnapshot;
    }
    return cacheSnapshot;
}
const getListInfosByObjectNameAdapterFactory = (luvio) => function UiApi__getListInfosByObjectName(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$I(untrustedConfig, getListInfosByObjectName_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$u, buildNetworkSnapshotCachePolicy$v);
};

function validate$1a(obj, path = 'ListFilterByInfoInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_operandLabels = obj.operandLabels;
        const path_operandLabels = path + '.operandLabels';
        if (!ArrayIsArray(obj_operandLabels)) {
            return new TypeError('Expected "array" but received "' + typeof obj_operandLabels + '" (at "' + path_operandLabels + '")');
        }
        for (let i = 0; i < obj_operandLabels.length; i++) {
            const obj_operandLabels_item = obj_operandLabels[i];
            const path_operandLabels_item = path_operandLabels + '[' + i + ']';
            if (typeof obj_operandLabels_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_operandLabels_item + '" (at "' + path_operandLabels_item + '")');
            }
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$19(obj, path = 'ListScopeInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        if (obj.entityId !== undefined) {
            const obj_entityId = obj.entityId;
            const path_entityId = path + '.entityId';
            let obj_entityId_union0 = null;
            const obj_entityId_union0_error = (() => {
                if (typeof obj_entityId !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_entityId + '" (at "' + path_entityId + '")');
                }
            })();
            if (obj_entityId_union0_error != null) {
                obj_entityId_union0 = obj_entityId_union0_error.message;
            }
            let obj_entityId_union1 = null;
            const obj_entityId_union1_error = (() => {
                if (obj_entityId !== null) {
                    return new TypeError('Expected "null" but received "' + typeof obj_entityId + '" (at "' + path_entityId + '")');
                }
            })();
            if (obj_entityId_union1_error != null) {
                obj_entityId_union1 = obj_entityId_union1_error.message;
            }
            if (obj_entityId_union0 && obj_entityId_union1) {
                let message = 'Object doesn\'t match union (at "' + path_entityId + '")';
                message += '\n' + obj_entityId_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_entityId_union1.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.relatedEntityId !== undefined) {
            const obj_relatedEntityId = obj.relatedEntityId;
            const path_relatedEntityId = path + '.relatedEntityId';
            let obj_relatedEntityId_union0 = null;
            const obj_relatedEntityId_union0_error = (() => {
                if (typeof obj_relatedEntityId !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_relatedEntityId + '" (at "' + path_relatedEntityId + '")');
                }
            })();
            if (obj_relatedEntityId_union0_error != null) {
                obj_relatedEntityId_union0 = obj_relatedEntityId_union0_error.message;
            }
            let obj_relatedEntityId_union1 = null;
            const obj_relatedEntityId_union1_error = (() => {
                if (obj_relatedEntityId !== null) {
                    return new TypeError('Expected "null" but received "' + typeof obj_relatedEntityId + '" (at "' + path_relatedEntityId + '")');
                }
            })();
            if (obj_relatedEntityId_union1_error != null) {
                obj_relatedEntityId_union1 = obj_relatedEntityId_union1_error.message;
            }
            if (obj_relatedEntityId_union0 && obj_relatedEntityId_union1) {
                let message = 'Object doesn\'t match union (at "' + path_relatedEntityId + '")';
                message += '\n' + obj_relatedEntityId_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_relatedEntityId_union1.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function select$14(luvio, params) {
    return select$1Z();
}
function getResponseCacheKeys$E(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$Z(storeKeyMap, luvio, response);
}
function ingestSuccess$w(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$F(luvio, body);
    luvio.storeIngest(key, ingest$R, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$14(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$I(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-info/' + config.urlParams.objectApiName + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$D = 'createListInfo';
const createListInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('displayColumns', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('filterLogicString', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('filteredByInfo', false, 2 /* Body */, 4 /* Unsupported */, true),
    generateParamConfigMetadata('includeDefaultAttributes', false, 2 /* Body */, 1 /* Boolean */),
    generateParamConfigMetadata('label', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('listShares', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('listViewApiName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('scope', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('visibility', false, 2 /* Body */, 0 /* String */),
];
const createListInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$D, createListInfo_ConfigPropertyMetadata);
const createResourceParams$E = /*#__PURE__*/ createResourceParams$13(createListInfo_ConfigPropertyMetadata);
function typeCheckConfig$H(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, createListInfo_ConfigPropertyMetadata);
    const untrustedConfig_filteredByInfo = untrustedConfig.filteredByInfo;
    if (ArrayIsArray$1(untrustedConfig_filteredByInfo)) {
        const untrustedConfig_filteredByInfo_array = [];
        for (let i = 0, arrayLength = untrustedConfig_filteredByInfo.length; i < arrayLength; i++) {
            const untrustedConfig_filteredByInfo_item = untrustedConfig_filteredByInfo[i];
            const referenceListFilterByInfoInputRepresentationValidationError = validate$1a(untrustedConfig_filteredByInfo_item);
            if (referenceListFilterByInfoInputRepresentationValidationError === null) {
                untrustedConfig_filteredByInfo_array.push(untrustedConfig_filteredByInfo_item);
            }
        }
        config.filteredByInfo = untrustedConfig_filteredByInfo_array;
    }
    const untrustedConfig_scope = untrustedConfig.scope;
    const referenceListScopeInputRepresentationValidationError = validate$19(untrustedConfig_scope);
    if (referenceListScopeInputRepresentationValidationError === null) {
        config.scope = untrustedConfig_scope;
    }
    return config;
}
function validateAdapterConfig$H(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, createListInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$H(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$I(luvio, config, options) {
    const resourceParams = createResourceParams$E(config);
    const request = createResourceRequest$I(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$w(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$E(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const createListInfoAdapterFactory = (luvio) => {
    return function createListInfo(untrustedConfig) {
        const config = validateAdapterConfig$H(untrustedConfig, createListInfo_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error('Invalid config for "createListInfo"');
        }
        return buildNetworkSnapshot$I(luvio, config);
    };
};

function keyBuilder$17(luvio, params) {
    return keyBuilder$2a(luvio, {
        objectApiName: params.urlParams.objectApiName,
        listViewApiName: params.urlParams.listViewApiName,
        type: "listView"
    });
}
function getResponseCacheKeys$D(cacheKeyMap, luvio, resourceParams) {
    const key = keyBuilder$17(luvio, resourceParams);
    cacheKeyMap.set(key, {
        namespace: keyPrefix,
        representationName: RepresentationType$Y,
        mergeable: false
    });
}
function evictSuccess$1(luvio, resourceParams) {
    const key = keyBuilder$17(luvio, resourceParams);
    luvio.storeEvict(key);
}
function createResourceRequest$H(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-info/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'delete',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$C = 'deleteListInfo';
const deleteListInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
];
const deleteListInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$C, deleteListInfo_ConfigPropertyMetadata);
const createResourceParams$D = /*#__PURE__*/ createResourceParams$13(deleteListInfo_ConfigPropertyMetadata);
function typeCheckConfig$G(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, deleteListInfo_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$G(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$G(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$H(luvio, config, options) {
    const resourceParams = createResourceParams$D(config);
    const request = createResourceRequest$H(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then(() => {
        return luvio.handleSuccessResponse(() => {
            evictSuccess$1(luvio, resourceParams);
            return luvio.storeBroadcast();
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$D(cache, luvio, resourceParams);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const deleteListInfoAdapterFactory = (luvio) => {
    return function UiApideleteListInfo(untrustedConfig) {
        const config = validateAdapterConfig$G(untrustedConfig, deleteListInfo_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error(`Invalid config for "${adapterName$C}"`);
        }
        return buildNetworkSnapshot$H(luvio, config);
    };
};

const adapterName$B = 'getListInfoByName';
const getListInfoByName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
];
const getListInfoByName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$B, getListInfoByName_ConfigPropertyMetadata);
const createResourceParams$C = /*#__PURE__*/ createResourceParams$13(getListInfoByName_ConfigPropertyMetadata);
function keyBuilder$16(luvio, config) {
    const resourceParams = createResourceParams$C(config);
    return keyBuilder$1c(luvio, resourceParams);
}
function typeCheckConfig$F(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListInfoByName_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$F(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$F(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$o(luvio, config) {
    createResourceParams$C(config);
    return select$17();
}
function onFetchResponseSuccess$q(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$z(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$G(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$q(luvio, config, resourceParams, response) {
    const snapshot = ingestError$q(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$G(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$G(luvio, config, options) {
    const resourceParams = createResourceParams$C(config);
    const request = createResourceRequest$L(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$q(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$H(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$q(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$u(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$G, undefined, false);
}
function buildCachedSnapshotCachePolicy$t(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$16(luvio, config),
        node: adapterFragment$o(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$G(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getListInfoByNameAdapterFactory = (luvio) => function UiApi__getListInfoByName(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$F(untrustedConfig, getListInfoByName_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$t, buildNetworkSnapshotCachePolicy$u);
};

function select$13(luvio, params) {
    return select$1Z();
}
function getResponseCacheKeys$C(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$Z(storeKeyMap, luvio, response);
}
function ingestSuccess$v(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$F(luvio, body);
    luvio.storeIngest(key, ingest$R, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$13(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$G(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-info/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$A = 'updateListInfoByName';
const updateListInfoByName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('displayColumns', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('filterLogicString', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('filteredByInfo', false, 2 /* Body */, 4 /* Unsupported */, true),
    generateParamConfigMetadata('label', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('listShares', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('scope', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('visibility', false, 2 /* Body */, 0 /* String */),
];
const updateListInfoByName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$A, updateListInfoByName_ConfigPropertyMetadata);
const createResourceParams$B = /*#__PURE__*/ createResourceParams$13(updateListInfoByName_ConfigPropertyMetadata);
function typeCheckConfig$E(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, updateListInfoByName_ConfigPropertyMetadata);
    const untrustedConfig_filteredByInfo = untrustedConfig.filteredByInfo;
    if (ArrayIsArray$1(untrustedConfig_filteredByInfo)) {
        const untrustedConfig_filteredByInfo_array = [];
        for (let i = 0, arrayLength = untrustedConfig_filteredByInfo.length; i < arrayLength; i++) {
            const untrustedConfig_filteredByInfo_item = untrustedConfig_filteredByInfo[i];
            const referenceListFilterByInfoInputRepresentationValidationError = validate$1a(untrustedConfig_filteredByInfo_item);
            if (referenceListFilterByInfoInputRepresentationValidationError === null) {
                untrustedConfig_filteredByInfo_array.push(untrustedConfig_filteredByInfo_item);
            }
        }
        config.filteredByInfo = untrustedConfig_filteredByInfo_array;
    }
    const untrustedConfig_scope = untrustedConfig.scope;
    const referenceListScopeInputRepresentationValidationError = validate$19(untrustedConfig_scope);
    if (referenceListScopeInputRepresentationValidationError === null) {
        config.scope = untrustedConfig_scope;
    }
    return config;
}
function validateAdapterConfig$E(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, updateListInfoByName_ConfigPropertyMetadata);
    const config = typeCheckConfig$E(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$F(luvio, config, options) {
    const resourceParams = createResourceParams$B(config);
    const request = createResourceRequest$G(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$v(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$C(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const updateListInfoByNameAdapterFactory = (luvio) => {
    return function updateListInfoByName(untrustedConfig) {
        const config = validateAdapterConfig$E(untrustedConfig, updateListInfoByName_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error('Invalid config for "updateListInfoByName"');
        }
        return buildNetworkSnapshot$F(luvio, config);
    };
};

const VERSION$I = "d77026c4d63ef00cdd7e3d600687a40d";
function validate$18(obj, path = 'ListObjectScopeAvailableEntityRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$12 = function ListObjectScopeAvailableEntityRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$I,
        private: [],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$C(existing, incoming) {
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    return true;
}

const VERSION$H = "355933ff2970aa91a2848a94565e956a";
function validate$17(obj, path = 'ListObjectScopeRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_availableEntities = obj.availableEntities;
        const path_availableEntities = path + '.availableEntities';
        if (!ArrayIsArray(obj_availableEntities)) {
            return new TypeError('Expected "array" but received "' + typeof obj_availableEntities + '" (at "' + path_availableEntities + '")');
        }
        for (let i = 0; i < obj_availableEntities.length; i++) {
            const obj_availableEntities_item = obj_availableEntities[i];
            const path_availableEntities_item = path_availableEntities + '[' + i + ']';
            const referencepath_availableEntities_itemValidationError = validate$18(obj_availableEntities_item, path_availableEntities_item);
            if (referencepath_availableEntities_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListObjectScopeAvailableEntityRepresentation (at "' + path_availableEntities_item + '")\n';
                message += referencepath_availableEntities_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$11 = function ListObjectScopeRepresentationSelect() {
    const { selections: ListObjectScopeAvailableEntityRepresentation__selections, opaque: ListObjectScopeAvailableEntityRepresentation__opaque, } = select$12();
    return {
        kind: 'Fragment',
        version: VERSION$H,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'availableEntities',
                kind: 'Object',
                plural: true,
                selections: ListObjectScopeAvailableEntityRepresentation__selections
            },
            {
                name: 'label',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$B(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_availableEntities = existing.availableEntities;
    const incoming_availableEntities = incoming.availableEntities;
    const equals_availableEntities_items = equalsArray(existing_availableEntities, incoming_availableEntities, (existing_availableEntities_item, incoming_availableEntities_item) => {
        if (!(equals$C(existing_availableEntities_item, incoming_availableEntities_item))) {
            return false;
        }
    });
    if (equals_availableEntities_items === false) {
        return false;
    }
    return true;
}

const VERSION$G = "c5c08ea834378670c9d6f235ff71c9f0";
function validate$16(obj, path = 'ListObjectPicklistValueRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$10 = function ListObjectPicklistValueRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$G,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$A(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    return true;
}

const VERSION$F = "98f8e97eae828e3f165bd05c518ae8df";
function validate$15(obj, path = 'ListObjectQuickFilterOverridesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_dataType = obj.dataType;
        const path_dataType = path + '.dataType';
        let obj_dataType_union0 = null;
        const obj_dataType_union0_error = (() => {
            if (typeof obj_dataType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
            }
        })();
        if (obj_dataType_union0_error != null) {
            obj_dataType_union0 = obj_dataType_union0_error.message;
        }
        let obj_dataType_union1 = null;
        const obj_dataType_union1_error = (() => {
            if (obj_dataType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
            }
        })();
        if (obj_dataType_union1_error != null) {
            obj_dataType_union1 = obj_dataType_union1_error.message;
        }
        if (obj_dataType_union0 && obj_dataType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_dataType + '")';
            message += '\n' + obj_dataType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_dataType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_picklistValues = obj.picklistValues;
        const path_picklistValues = path + '.picklistValues';
        if (!ArrayIsArray(obj_picklistValues)) {
            return new TypeError('Expected "array" but received "' + typeof obj_picklistValues + '" (at "' + path_picklistValues + '")');
        }
        for (let i = 0; i < obj_picklistValues.length; i++) {
            const obj_picklistValues_item = obj_picklistValues[i];
            const path_picklistValues_item = path_picklistValues + '[' + i + ']';
            if (typeof obj_picklistValues_item !== 'object' || ArrayIsArray(obj_picklistValues_item) || obj_picklistValues_item === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_picklistValues_item + '" (at "' + path_picklistValues_item + '")');
            }
            const obj_picklistValues_item_keys = ObjectKeys(obj_picklistValues_item);
            for (let i = 0; i < obj_picklistValues_item_keys.length; i++) {
                const key = obj_picklistValues_item_keys[i];
                const obj_picklistValues_item_prop = obj_picklistValues_item[key];
                const path_picklistValues_item_prop = path_picklistValues_item + '["' + key + '"]';
                if (typeof obj_picklistValues_item_prop !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_picklistValues_item_prop + '" (at "' + path_picklistValues_item_prop + '")');
                }
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$$ = function ListObjectQuickFilterOverridesRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$F,
        private: [],
        selections: [
            {
                name: 'dataType',
                kind: 'Scalar'
            },
            {
                name: 'picklistValues',
                kind: 'Scalar',
                map: true
            }
        ]
    };
};
function equals$z(existing, incoming) {
    const existing_dataType = existing.dataType;
    const incoming_dataType = incoming.dataType;
    if (!(existing_dataType === incoming_dataType)) {
        return false;
    }
    const existing_picklistValues = existing.picklistValues;
    const incoming_picklistValues = incoming.picklistValues;
    const equals_picklistValues_items = equalsArray(existing_picklistValues, incoming_picklistValues, (existing_picklistValues_item, incoming_picklistValues_item) => {
        const equals_picklistValues_items_props = equalsObject(existing_picklistValues_item, incoming_picklistValues_item, (existing_picklistValues_item_prop, incoming_picklistValues_item_prop) => {
            if (!(existing_picklistValues_item_prop === incoming_picklistValues_item_prop)) {
                return false;
            }
        });
        if (equals_picklistValues_items_props === false) {
            return false;
        }
    });
    if (equals_picklistValues_items === false) {
        return false;
    }
    return true;
}

const VERSION$E = "394e8d71b515892fe366021cc2872dae";
function validate$14(obj, path = 'ListObjectColumnRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_alias = obj.alias;
        const path_alias = path + '.alias';
        if (typeof obj_alias !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_alias + '" (at "' + path_alias + '")');
        }
        const obj_dataType = obj.dataType;
        const path_dataType = path + '.dataType';
        let obj_dataType_union0 = null;
        const obj_dataType_union0_error = (() => {
            if (typeof obj_dataType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
            }
        })();
        if (obj_dataType_union0_error != null) {
            obj_dataType_union0 = obj_dataType_union0_error.message;
        }
        let obj_dataType_union1 = null;
        const obj_dataType_union1_error = (() => {
            if (obj_dataType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
            }
        })();
        if (obj_dataType_union1_error != null) {
            obj_dataType_union1 = obj_dataType_union1_error.message;
        }
        if (obj_dataType_union0 && obj_dataType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_dataType + '")';
            message += '\n' + obj_dataType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_dataType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_defaultFilterOperator = obj.defaultFilterOperator;
        const path_defaultFilterOperator = path + '.defaultFilterOperator';
        if (typeof obj_defaultFilterOperator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_defaultFilterOperator + '" (at "' + path_defaultFilterOperator + '")');
        }
        const obj_displayable = obj.displayable;
        const path_displayable = path + '.displayable';
        if (typeof obj_displayable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_displayable + '" (at "' + path_displayable + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_filterable = obj.filterable;
        const path_filterable = path + '.filterable';
        if (typeof obj_filterable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_filterable + '" (at "' + path_filterable + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_picklistValues = obj.picklistValues;
        const path_picklistValues = path + '.picklistValues';
        if (!ArrayIsArray(obj_picklistValues)) {
            return new TypeError('Expected "array" but received "' + typeof obj_picklistValues + '" (at "' + path_picklistValues + '")');
        }
        for (let i = 0; i < obj_picklistValues.length; i++) {
            const obj_picklistValues_item = obj_picklistValues[i];
            const path_picklistValues_item = path_picklistValues + '[' + i + ']';
            const referencepath_picklistValues_itemValidationError = validate$16(obj_picklistValues_item, path_picklistValues_item);
            if (referencepath_picklistValues_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListObjectPicklistValueRepresentation (at "' + path_picklistValues_item + '")\n';
                message += referencepath_picklistValues_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_quickFilterOperator = obj.quickFilterOperator;
        const path_quickFilterOperator = path + '.quickFilterOperator';
        let obj_quickFilterOperator_union0 = null;
        const obj_quickFilterOperator_union0_error = (() => {
            if (typeof obj_quickFilterOperator !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_quickFilterOperator + '" (at "' + path_quickFilterOperator + '")');
            }
        })();
        if (obj_quickFilterOperator_union0_error != null) {
            obj_quickFilterOperator_union0 = obj_quickFilterOperator_union0_error.message;
        }
        let obj_quickFilterOperator_union1 = null;
        const obj_quickFilterOperator_union1_error = (() => {
            if (obj_quickFilterOperator !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_quickFilterOperator + '" (at "' + path_quickFilterOperator + '")');
            }
        })();
        if (obj_quickFilterOperator_union1_error != null) {
            obj_quickFilterOperator_union1 = obj_quickFilterOperator_union1_error.message;
        }
        if (obj_quickFilterOperator_union0 && obj_quickFilterOperator_union1) {
            let message = 'Object doesn\'t match union (at "' + path_quickFilterOperator + '")';
            message += '\n' + obj_quickFilterOperator_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_quickFilterOperator_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_quickFilterOverrides = obj.quickFilterOverrides;
        const path_quickFilterOverrides = path + '.quickFilterOverrides';
        let obj_quickFilterOverrides_union0 = null;
        const obj_quickFilterOverrides_union0_error = (() => {
            const referencepath_quickFilterOverridesValidationError = validate$15(obj_quickFilterOverrides, path_quickFilterOverrides);
            if (referencepath_quickFilterOverridesValidationError !== null) {
                let message = 'Object doesn\'t match ListObjectQuickFilterOverridesRepresentation (at "' + path_quickFilterOverrides + '")\n';
                message += referencepath_quickFilterOverridesValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_quickFilterOverrides_union0_error != null) {
            obj_quickFilterOverrides_union0 = obj_quickFilterOverrides_union0_error.message;
        }
        let obj_quickFilterOverrides_union1 = null;
        const obj_quickFilterOverrides_union1_error = (() => {
            if (obj_quickFilterOverrides !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_quickFilterOverrides + '" (at "' + path_quickFilterOverrides + '")');
            }
        })();
        if (obj_quickFilterOverrides_union1_error != null) {
            obj_quickFilterOverrides_union1 = obj_quickFilterOverrides_union1_error.message;
        }
        if (obj_quickFilterOverrides_union0 && obj_quickFilterOverrides_union1) {
            let message = 'Object doesn\'t match union (at "' + path_quickFilterOverrides + '")';
            message += '\n' + obj_quickFilterOverrides_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_quickFilterOverrides_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_quickFilterable = obj.quickFilterable;
        const path_quickFilterable = path + '.quickFilterable';
        if (typeof obj_quickFilterable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_quickFilterable + '" (at "' + path_quickFilterable + '")');
        }
        const obj_sortable = obj.sortable;
        const path_sortable = path + '.sortable';
        if (typeof obj_sortable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_sortable + '" (at "' + path_sortable + '")');
        }
        const obj_supportedFilterOperators = obj.supportedFilterOperators;
        const path_supportedFilterOperators = path + '.supportedFilterOperators';
        if (!ArrayIsArray(obj_supportedFilterOperators)) {
            return new TypeError('Expected "array" but received "' + typeof obj_supportedFilterOperators + '" (at "' + path_supportedFilterOperators + '")');
        }
        for (let i = 0; i < obj_supportedFilterOperators.length; i++) {
            const obj_supportedFilterOperators_item = obj_supportedFilterOperators[i];
            const path_supportedFilterOperators_item = path_supportedFilterOperators + '[' + i + ']';
            if (typeof obj_supportedFilterOperators_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_supportedFilterOperators_item + '" (at "' + path_supportedFilterOperators_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$_ = function ListObjectColumnRepresentationSelect() {
    const { selections: ListObjectPicklistValueRepresentation__selections, opaque: ListObjectPicklistValueRepresentation__opaque, } = select$10();
    const { selections: ListObjectQuickFilterOverridesRepresentation__selections, opaque: ListObjectQuickFilterOverridesRepresentation__opaque, } = select$$();
    return {
        kind: 'Fragment',
        version: VERSION$E,
        private: [],
        selections: [
            {
                name: 'alias',
                kind: 'Scalar'
            },
            {
                name: 'dataType',
                kind: 'Scalar'
            },
            {
                name: 'defaultFilterOperator',
                kind: 'Scalar'
            },
            {
                name: 'displayable',
                kind: 'Scalar'
            },
            {
                name: 'fieldApiName',
                kind: 'Scalar'
            },
            {
                name: 'filterable',
                kind: 'Scalar'
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'picklistValues',
                kind: 'Object',
                plural: true,
                selections: ListObjectPicklistValueRepresentation__selections
            },
            {
                name: 'quickFilterOperator',
                kind: 'Scalar'
            },
            {
                name: 'quickFilterOverrides',
                kind: 'Object',
                nullable: true,
                selections: ListObjectQuickFilterOverridesRepresentation__selections
            },
            {
                name: 'quickFilterable',
                kind: 'Scalar'
            },
            {
                name: 'sortable',
                kind: 'Scalar'
            },
            {
                name: 'supportedFilterOperators',
                kind: 'Scalar',
                plural: true
            }
        ]
    };
};
function equals$y(existing, incoming) {
    const existing_displayable = existing.displayable;
    const incoming_displayable = incoming.displayable;
    if (!(existing_displayable === incoming_displayable)) {
        return false;
    }
    const existing_filterable = existing.filterable;
    const incoming_filterable = incoming.filterable;
    if (!(existing_filterable === incoming_filterable)) {
        return false;
    }
    const existing_quickFilterable = existing.quickFilterable;
    const incoming_quickFilterable = incoming.quickFilterable;
    if (!(existing_quickFilterable === incoming_quickFilterable)) {
        return false;
    }
    const existing_sortable = existing.sortable;
    const incoming_sortable = incoming.sortable;
    if (!(existing_sortable === incoming_sortable)) {
        return false;
    }
    const existing_alias = existing.alias;
    const incoming_alias = incoming.alias;
    if (!(existing_alias === incoming_alias)) {
        return false;
    }
    const existing_defaultFilterOperator = existing.defaultFilterOperator;
    const incoming_defaultFilterOperator = incoming.defaultFilterOperator;
    if (!(existing_defaultFilterOperator === incoming_defaultFilterOperator)) {
        return false;
    }
    const existing_fieldApiName = existing.fieldApiName;
    const incoming_fieldApiName = incoming.fieldApiName;
    if (!(existing_fieldApiName === incoming_fieldApiName)) {
        return false;
    }
    const existing_label = existing.label;
    const incoming_label = incoming.label;
    if (!(existing_label === incoming_label)) {
        return false;
    }
    const existing_dataType = existing.dataType;
    const incoming_dataType = incoming.dataType;
    if (!(existing_dataType === incoming_dataType)) {
        return false;
    }
    const existing_picklistValues = existing.picklistValues;
    const incoming_picklistValues = incoming.picklistValues;
    const equals_picklistValues_items = equalsArray(existing_picklistValues, incoming_picklistValues, (existing_picklistValues_item, incoming_picklistValues_item) => {
        if (!(equals$A(existing_picklistValues_item, incoming_picklistValues_item))) {
            return false;
        }
    });
    if (equals_picklistValues_items === false) {
        return false;
    }
    const existing_quickFilterOperator = existing.quickFilterOperator;
    const incoming_quickFilterOperator = incoming.quickFilterOperator;
    if (!(existing_quickFilterOperator === incoming_quickFilterOperator)) {
        return false;
    }
    const existing_quickFilterOverrides = existing.quickFilterOverrides;
    const incoming_quickFilterOverrides = incoming.quickFilterOverrides;
    if (!(existing_quickFilterOverrides === incoming_quickFilterOverrides
        || (existing_quickFilterOverrides != null &&
            incoming_quickFilterOverrides != null &&
            equals$z(existing_quickFilterOverrides, incoming_quickFilterOverrides)))) {
        return false;
    }
    const existing_supportedFilterOperators = existing.supportedFilterOperators;
    const incoming_supportedFilterOperators = incoming.supportedFilterOperators;
    const equals_supportedFilterOperators_items = equalsArray(existing_supportedFilterOperators, incoming_supportedFilterOperators, (existing_supportedFilterOperators_item, incoming_supportedFilterOperators_item) => {
        if (!(existing_supportedFilterOperators_item === incoming_supportedFilterOperators_item)) {
            return false;
        }
    });
    if (equals_supportedFilterOperators_items === false) {
        return false;
    }
    return true;
}

const TTL$k = 900000;
const VERSION$D = "2405a0b25c2c00f82e88b600edc16387";
function validate$13(obj, path = 'ListObjectInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_availableScopes = obj.availableScopes;
        const path_availableScopes = path + '.availableScopes';
        if (!ArrayIsArray(obj_availableScopes)) {
            return new TypeError('Expected "array" but received "' + typeof obj_availableScopes + '" (at "' + path_availableScopes + '")');
        }
        for (let i = 0; i < obj_availableScopes.length; i++) {
            const obj_availableScopes_item = obj_availableScopes[i];
            const path_availableScopes_item = path_availableScopes + '[' + i + ']';
            const referencepath_availableScopes_itemValidationError = validate$17(obj_availableScopes_item, path_availableScopes_item);
            if (referencepath_availableScopes_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListObjectScopeRepresentation (at "' + path_availableScopes_item + '")\n';
                message += referencepath_availableScopes_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_columns = obj.columns;
        const path_columns = path + '.columns';
        if (!ArrayIsArray(obj_columns)) {
            return new TypeError('Expected "array" but received "' + typeof obj_columns + '" (at "' + path_columns + '")');
        }
        for (let i = 0; i < obj_columns.length; i++) {
            const obj_columns_item = obj_columns[i];
            const path_columns_item = path_columns + '[' + i + ']';
            const referencepath_columns_itemValidationError = validate$14(obj_columns_item, path_columns_item);
            if (referencepath_columns_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListObjectColumnRepresentation (at "' + path_columns_item + '")\n';
                message += referencepath_columns_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_createable = obj.createable;
        const path_createable = path + '.createable';
        if (typeof obj_createable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_createable + '" (at "' + path_createable + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_publicOrSharedCreateable = obj.publicOrSharedCreateable;
        const path_publicOrSharedCreateable = path + '.publicOrSharedCreateable';
        if (typeof obj_publicOrSharedCreateable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_publicOrSharedCreateable + '" (at "' + path_publicOrSharedCreateable + '")');
        }
        const obj_relatedEntityApiName = obj.relatedEntityApiName;
        const path_relatedEntityApiName = path + '.relatedEntityApiName';
        let obj_relatedEntityApiName_union0 = null;
        const obj_relatedEntityApiName_union0_error = (() => {
            if (typeof obj_relatedEntityApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_relatedEntityApiName + '" (at "' + path_relatedEntityApiName + '")');
            }
        })();
        if (obj_relatedEntityApiName_union0_error != null) {
            obj_relatedEntityApiName_union0 = obj_relatedEntityApiName_union0_error.message;
        }
        let obj_relatedEntityApiName_union1 = null;
        const obj_relatedEntityApiName_union1_error = (() => {
            if (obj_relatedEntityApiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_relatedEntityApiName + '" (at "' + path_relatedEntityApiName + '")');
            }
        })();
        if (obj_relatedEntityApiName_union1_error != null) {
            obj_relatedEntityApiName_union1 = obj_relatedEntityApiName_union1_error.message;
        }
        if (obj_relatedEntityApiName_union0 && obj_relatedEntityApiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_relatedEntityApiName + '")';
            message += '\n' + obj_relatedEntityApiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_relatedEntityApiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$u = 'ListObjectInfoRepresentation';
function keyBuilder$15(luvio, config) {
    return keyPrefix + '::' + RepresentationType$u + ':' + config.objectApiName;
}
function keyBuilderFromType$k(luvio, object) {
    const keyParams = {
        objectApiName: object.objectApiName
    };
    return keyBuilder$15(luvio, keyParams);
}
function normalize$o(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$Z = function ListObjectInfoRepresentationSelect() {
    const { selections: ListObjectScopeRepresentation__selections, opaque: ListObjectScopeRepresentation__opaque, } = select$11();
    const { selections: ListObjectColumnRepresentation__selections, opaque: ListObjectColumnRepresentation__opaque, } = select$_();
    return {
        kind: 'Fragment',
        version: VERSION$D,
        private: [],
        selections: [
            {
                name: 'availableScopes',
                kind: 'Object',
                plural: true,
                selections: ListObjectScopeRepresentation__selections
            },
            {
                name: 'columns',
                kind: 'Object',
                plural: true,
                selections: ListObjectColumnRepresentation__selections
            },
            {
                name: 'createable',
                kind: 'Scalar'
            },
            {
                name: 'objectApiName',
                kind: 'Scalar'
            },
            {
                name: 'publicOrSharedCreateable',
                kind: 'Scalar'
            },
            {
                name: 'relatedEntityApiName',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$x(existing, incoming) {
    const existing_createable = existing.createable;
    const incoming_createable = incoming.createable;
    if (!(existing_createable === incoming_createable)) {
        return false;
    }
    const existing_publicOrSharedCreateable = existing.publicOrSharedCreateable;
    const incoming_publicOrSharedCreateable = incoming.publicOrSharedCreateable;
    if (!(existing_publicOrSharedCreateable === incoming_publicOrSharedCreateable)) {
        return false;
    }
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_availableScopes = existing.availableScopes;
    const incoming_availableScopes = incoming.availableScopes;
    const equals_availableScopes_items = equalsArray(existing_availableScopes, incoming_availableScopes, (existing_availableScopes_item, incoming_availableScopes_item) => {
        if (!(equals$B(existing_availableScopes_item, incoming_availableScopes_item))) {
            return false;
        }
    });
    if (equals_availableScopes_items === false) {
        return false;
    }
    const existing_columns = existing.columns;
    const incoming_columns = incoming.columns;
    const equals_columns_items = equalsArray(existing_columns, incoming_columns, (existing_columns_item, incoming_columns_item) => {
        if (!(equals$y(existing_columns_item, incoming_columns_item))) {
            return false;
        }
    });
    if (equals_columns_items === false) {
        return false;
    }
    const existing_relatedEntityApiName = existing.relatedEntityApiName;
    const incoming_relatedEntityApiName = incoming.relatedEntityApiName;
    if (!(existing_relatedEntityApiName === incoming_relatedEntityApiName)) {
        return false;
    }
    return true;
}
const ingest$o = function ListObjectInfoRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$13(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$k(luvio, input);
    const ttlToUse = TTL$k;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$o, "UiApi", VERSION$D, RepresentationType$u, equals$x);
    return createLink(key);
};
function getTypeCacheKeys$v(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$k(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$u,
        mergeable: false
    });
}

function select$Y(luvio, params) {
    return select$Z();
}
function keyBuilder$14(luvio, params) {
    return keyBuilder$15(luvio, {
        objectApiName: params.urlParams.objectApiName
    });
}
function getResponseCacheKeys$B(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$v(storeKeyMap, luvio, response);
}
function ingestSuccess$u(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$14(luvio, resourceParams);
    luvio.storeIngest(key, ingest$o, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$Y(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$n(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$14(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$k,
        namespace: keyPrefix,
        version: VERSION$D,
        representationName: RepresentationType$u
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$F(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-object-info/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$z = 'getListObjectInfo';
const getListObjectInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
];
const getListObjectInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$z, getListObjectInfo_ConfigPropertyMetadata);
const createResourceParams$A = /*#__PURE__*/ createResourceParams$13(getListObjectInfo_ConfigPropertyMetadata);
function keyBuilder$13(luvio, config) {
    const resourceParams = createResourceParams$A(config);
    return keyBuilder$14(luvio, resourceParams);
}
function typeCheckConfig$D(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListObjectInfo_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$D(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getListObjectInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$D(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$n(luvio, config) {
    createResourceParams$A(config);
    return select$Y();
}
function onFetchResponseSuccess$p(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$u(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$E(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$p(luvio, config, resourceParams, response) {
    const snapshot = ingestError$n(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$E(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$E(luvio, config, options) {
    const resourceParams = createResourceParams$A(config);
    const request = createResourceRequest$F(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$p(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$B(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$p(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$t(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$E, undefined, false);
}
function buildCachedSnapshotCachePolicy$s(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$13(luvio, config),
        node: adapterFragment$n(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$E(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getListObjectInfoAdapterFactory = (luvio) => function UiApi__getListObjectInfo(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$D(untrustedConfig, getListObjectInfo_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$s, buildNetworkSnapshotCachePolicy$t);
};

const TTL$j = 900000;
const VERSION$C = "458d4a6a30201e422e8daec5fcb03845";
function validate$12(obj, path = 'ListPreferencesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_columnWidths = obj.columnWidths;
        const path_columnWidths = path + '.columnWidths';
        if (typeof obj_columnWidths !== 'object' || ArrayIsArray(obj_columnWidths) || obj_columnWidths === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWidths + '" (at "' + path_columnWidths + '")');
        }
        const obj_columnWidths_keys = ObjectKeys(obj_columnWidths);
        for (let i = 0; i < obj_columnWidths_keys.length; i++) {
            const key = obj_columnWidths_keys[i];
            const obj_columnWidths_prop = obj_columnWidths[key];
            const path_columnWidths_prop = path_columnWidths + '["' + key + '"]';
            if (typeof obj_columnWidths_prop !== 'number' || (typeof obj_columnWidths_prop === 'number' && Math.floor(obj_columnWidths_prop) !== obj_columnWidths_prop)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_columnWidths_prop + '" (at "' + path_columnWidths_prop + '")');
            }
        }
        const obj_columnWrap = obj.columnWrap;
        const path_columnWrap = path + '.columnWrap';
        if (typeof obj_columnWrap !== 'object' || ArrayIsArray(obj_columnWrap) || obj_columnWrap === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWrap + '" (at "' + path_columnWrap + '")');
        }
        const obj_columnWrap_keys = ObjectKeys(obj_columnWrap);
        for (let i = 0; i < obj_columnWrap_keys.length; i++) {
            const key = obj_columnWrap_keys[i];
            const obj_columnWrap_prop = obj_columnWrap[key];
            const path_columnWrap_prop = path_columnWrap + '["' + key + '"]';
            if (typeof obj_columnWrap_prop !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_columnWrap_prop + '" (at "' + path_columnWrap_prop + '")');
            }
        }
        const obj_listReference = obj.listReference;
        const path_listReference = path + '.listReference';
        const referencepath_listReferenceValidationError = validate$29(obj_listReference, path_listReference);
        if (referencepath_listReferenceValidationError !== null) {
            let message = 'Object doesn\'t match ListReferenceRepresentation (at "' + path_listReference + '")\n';
            message += referencepath_listReferenceValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_orderedBy = obj.orderedBy;
        const path_orderedBy = path + '.orderedBy';
        if (!ArrayIsArray(obj_orderedBy)) {
            return new TypeError('Expected "array" but received "' + typeof obj_orderedBy + '" (at "' + path_orderedBy + '")');
        }
        for (let i = 0; i < obj_orderedBy.length; i++) {
            const obj_orderedBy_item = obj_orderedBy[i];
            const path_orderedBy_item = path_orderedBy + '[' + i + ']';
            const referencepath_orderedBy_itemValidationError = validate$26(obj_orderedBy_item, path_orderedBy_item);
            if (referencepath_orderedBy_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListOrderByInfoRepresentation (at "' + path_orderedBy_item + '")\n';
                message += referencepath_orderedBy_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$t = 'ListPreferencesRepresentation';
function keyBuilder$12(luvio, config) {
    return keyPrefix + '::' + RepresentationType$t + ':' + config.objectApiName + ':' + (config.listViewApiName === null ? '' : config.listViewApiName);
}
function keyBuilderFromType$j(luvio, object) {
    const keyParams = {
        objectApiName: object.listReference.objectApiName,
        listViewApiName: object.listReference.listViewApiName
    };
    return keyBuilder$12(luvio, keyParams);
}
function normalize$n(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$X = function ListPreferencesRepresentationSelect() {
    const { selections: ListReferenceRepresentation__selections, opaque: ListReferenceRepresentation__opaque, } = select$26();
    const { selections: ListOrderByInfoRepresentation__selections, opaque: ListOrderByInfoRepresentation__opaque, } = select$23();
    return {
        kind: 'Fragment',
        version: VERSION$C,
        private: [],
        selections: [
            {
                name: 'columnWidths',
                kind: 'Scalar',
                map: true
            },
            {
                name: 'columnWrap',
                kind: 'Scalar',
                map: true
            },
            {
                name: 'listReference',
                kind: 'Object',
                selections: ListReferenceRepresentation__selections
            },
            {
                name: 'orderedBy',
                kind: 'Object',
                plural: true,
                selections: ListOrderByInfoRepresentation__selections
            }
        ]
    };
};
function equals$w(existing, incoming) {
    const existing_columnWidths = existing.columnWidths;
    const incoming_columnWidths = incoming.columnWidths;
    const equals_columnWidths_props = equalsObject(existing_columnWidths, incoming_columnWidths, (existing_columnWidths_prop, incoming_columnWidths_prop) => {
        if (!(existing_columnWidths_prop === incoming_columnWidths_prop)) {
            return false;
        }
    });
    if (equals_columnWidths_props === false) {
        return false;
    }
    const existing_columnWrap = existing.columnWrap;
    const incoming_columnWrap = incoming.columnWrap;
    const equals_columnWrap_props = equalsObject(existing_columnWrap, incoming_columnWrap, (existing_columnWrap_prop, incoming_columnWrap_prop) => {
        if (!(existing_columnWrap_prop === incoming_columnWrap_prop)) {
            return false;
        }
    });
    if (equals_columnWrap_props === false) {
        return false;
    }
    const existing_listReference = existing.listReference;
    const incoming_listReference = incoming.listReference;
    if (!(equals$1c(existing_listReference, incoming_listReference))) {
        return false;
    }
    const existing_orderedBy = existing.orderedBy;
    const incoming_orderedBy = incoming.orderedBy;
    const equals_orderedBy_items = equalsArray(existing_orderedBy, incoming_orderedBy, (existing_orderedBy_item, incoming_orderedBy_item) => {
        if (!(equals$1b(existing_orderedBy_item, incoming_orderedBy_item))) {
            return false;
        }
    });
    if (equals_orderedBy_items === false) {
        return false;
    }
    return true;
}
const ingest$n = function ListPreferencesRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$12(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$j(luvio, input);
    const ttlToUse = TTL$j;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$n, "UiApi", VERSION$C, RepresentationType$t, equals$w);
    return createLink(key);
};
function getTypeCacheKeys$u(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$j(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$t,
        mergeable: false
    });
}

function select$W(luvio, params) {
    return select$X();
}
function keyBuilder$11(luvio, params) {
    return keyBuilder$12(luvio, {
        objectApiName: params.urlParams.objectApiName,
        listViewApiName: params.urlParams.listViewApiName
    });
}
function getResponseCacheKeys$A(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$u(storeKeyMap, luvio, response);
}
function ingestSuccess$t(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$11(luvio, resourceParams);
    luvio.storeIngest(key, ingest$n, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$W(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$m(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$11(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$j,
        namespace: keyPrefix,
        version: VERSION$C,
        representationName: RepresentationType$t
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$E(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-preferences/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$y = 'getListPreferences';
const getListPreferences_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
];
const getListPreferences_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$y, getListPreferences_ConfigPropertyMetadata);
const createResourceParams$z = /*#__PURE__*/ createResourceParams$13(getListPreferences_ConfigPropertyMetadata);
function keyBuilder$10(luvio, config) {
    const resourceParams = createResourceParams$z(config);
    return keyBuilder$11(luvio, resourceParams);
}
function typeCheckConfig$C(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListPreferences_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$C(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getListPreferences_ConfigPropertyMetadata);
    const config = typeCheckConfig$C(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$m(luvio, config) {
    createResourceParams$z(config);
    return select$W();
}
function onFetchResponseSuccess$o(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$t(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$D(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$o(luvio, config, resourceParams, response) {
    const snapshot = ingestError$m(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$D(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$D(luvio, config, options) {
    const resourceParams = createResourceParams$z(config);
    const request = createResourceRequest$E(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$o(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$A(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$o(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$s(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$D, undefined, false);
}
function buildCachedSnapshotCachePolicy$r(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$10(luvio, config),
        node: adapterFragment$m(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$D(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getListPreferencesAdapterFactory = (luvio) => function UiApi__getListPreferences(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$C(untrustedConfig, getListPreferences_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$r, buildNetworkSnapshotCachePolicy$s);
};

function validate$11(obj, path = 'ListOrderedByInfoInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_isAscending = obj.isAscending;
        const path_isAscending = path + '.isAscending';
        if (typeof obj_isAscending !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isAscending + '" (at "' + path_isAscending + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function select$V(luvio, params) {
    return select$X();
}
function getResponseCacheKeys$z(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$u(storeKeyMap, luvio, response);
}
function ingestSuccess$s(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$j(luvio, body);
    luvio.storeIngest(key, ingest$n, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$V(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$D(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/list-preferences/' + config.urlParams.objectApiName + '/' + config.urlParams.listViewApiName + '',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$x = 'updateListPreferences';
const updateListPreferences_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('columnWidths', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('columnWrap', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('orderedBy', false, 2 /* Body */, 4 /* Unsupported */, true),
];
const updateListPreferences_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$x, updateListPreferences_ConfigPropertyMetadata);
const createResourceParams$y = /*#__PURE__*/ createResourceParams$13(updateListPreferences_ConfigPropertyMetadata);
function typeCheckConfig$B(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, updateListPreferences_ConfigPropertyMetadata);
    const untrustedConfig_columnWidths = untrustedConfig.columnWidths;
    if (untrustedIsObject(untrustedConfig_columnWidths)) {
        const untrustedConfig_columnWidths_object = {};
        const untrustedConfig_columnWidths_keys = Object.keys(untrustedConfig_columnWidths);
        for (let i = 0, arrayLength = untrustedConfig_columnWidths_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_columnWidths_keys[i];
            const untrustedConfig_columnWidths_prop = untrustedConfig_columnWidths[key];
            if (typeof untrustedConfig_columnWidths_prop === 'number' && Math.floor(untrustedConfig_columnWidths_prop) === untrustedConfig_columnWidths_prop) {
                if (untrustedConfig_columnWidths_object !== undefined) {
                    untrustedConfig_columnWidths_object[key] = untrustedConfig_columnWidths_prop;
                }
            }
        }
        if (untrustedConfig_columnWidths_object !== undefined && Object.keys(untrustedConfig_columnWidths_object).length >= 0) {
            config.columnWidths = untrustedConfig_columnWidths_object;
        }
    }
    const untrustedConfig_columnWrap = untrustedConfig.columnWrap;
    if (untrustedIsObject(untrustedConfig_columnWrap)) {
        const untrustedConfig_columnWrap_object = {};
        const untrustedConfig_columnWrap_keys = Object.keys(untrustedConfig_columnWrap);
        for (let i = 0, arrayLength = untrustedConfig_columnWrap_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_columnWrap_keys[i];
            const untrustedConfig_columnWrap_prop = untrustedConfig_columnWrap[key];
            if (typeof untrustedConfig_columnWrap_prop === 'boolean') {
                if (untrustedConfig_columnWrap_object !== undefined) {
                    untrustedConfig_columnWrap_object[key] = untrustedConfig_columnWrap_prop;
                }
            }
        }
        if (untrustedConfig_columnWrap_object !== undefined && Object.keys(untrustedConfig_columnWrap_object).length >= 0) {
            config.columnWrap = untrustedConfig_columnWrap_object;
        }
    }
    const untrustedConfig_orderedBy = untrustedConfig.orderedBy;
    if (ArrayIsArray$1(untrustedConfig_orderedBy)) {
        const untrustedConfig_orderedBy_array = [];
        for (let i = 0, arrayLength = untrustedConfig_orderedBy.length; i < arrayLength; i++) {
            const untrustedConfig_orderedBy_item = untrustedConfig_orderedBy[i];
            const referenceListOrderedByInfoInputRepresentationValidationError = validate$11(untrustedConfig_orderedBy_item);
            if (referenceListOrderedByInfoInputRepresentationValidationError === null) {
                untrustedConfig_orderedBy_array.push(untrustedConfig_orderedBy_item);
            }
        }
        config.orderedBy = untrustedConfig_orderedBy_array;
    }
    return config;
}
function validateAdapterConfig$B(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, updateListPreferences_ConfigPropertyMetadata);
    const config = typeCheckConfig$B(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$C(luvio, config, options) {
    const resourceParams = createResourceParams$y(config);
    const request = createResourceRequest$D(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$s(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$z(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const updateListPreferencesAdapterFactory = (luvio) => {
    return function updateListPreferences(untrustedConfig) {
        const config = validateAdapterConfig$B(untrustedConfig, updateListPreferences_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error('Invalid config for "updateListPreferences"');
        }
        return buildNetworkSnapshot$C(luvio, config);
    };
};

const TTL$i = 120000;
const VERSION$B = "756779d0d7e137dd72c743544afbad82";
function validate$10(obj, path = 'NavItemsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        if (typeof obj_currentPageUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_navItems = obj.navItems;
        const path_navItems = path + '.navItems';
        if (!ArrayIsArray(obj_navItems)) {
            return new TypeError('Expected "array" but received "' + typeof obj_navItems + '" (at "' + path_navItems + '")');
        }
        for (let i = 0; i < obj_navItems.length; i++) {
            const obj_navItems_item = obj_navItems[i];
            const path_navItems_item = path_navItems + '[' + i + ']';
            if (typeof obj_navItems_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_navItems_item + '" (at "' + path_navItems_item + '")');
            }
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        let obj_nextPageUrl_union0 = null;
        const obj_nextPageUrl_union0_error = (() => {
            if (typeof obj_nextPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union0_error != null) {
            obj_nextPageUrl_union0 = obj_nextPageUrl_union0_error.message;
        }
        let obj_nextPageUrl_union1 = null;
        const obj_nextPageUrl_union1_error = (() => {
            if (obj_nextPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union1_error != null) {
            obj_nextPageUrl_union1 = obj_nextPageUrl_union1_error.message;
        }
        if (obj_nextPageUrl_union0 && obj_nextPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageUrl + '")';
            message += '\n' + obj_nextPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$s = 'NavItemsRepresentation';
function normalize$m(input, existing, path, luvio, store, timestamp) {
    const input_navItems = input.navItems;
    const input_navItems_id = path.fullPath + '__navItems';
    for (let i = 0; i < input_navItems.length; i++) {
        const input_navItems_item = input_navItems[i];
        let input_navItems_item_id = input_navItems_id + '__' + i;
        input_navItems[i] = ingest$s(input_navItems_item, {
            fullPath: input_navItems_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$U = function NavItemsRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$B,
        private: [
            'eTag',
            'currentPageUrl'
        ],
        selections: [
            {
                name: 'navItems',
                kind: 'Link',
                plural: true,
                fragment: select$1i()
            },
            {
                name: 'nextPageUrl',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$v(existing, incoming) {
    const existing_currentPageUrl = existing.currentPageUrl;
    const incoming_currentPageUrl = incoming.currentPageUrl;
    if (!(existing_currentPageUrl === incoming_currentPageUrl)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_navItems = existing.navItems;
    const incoming_navItems = incoming.navItems;
    const equals_navItems_items = equalsArray(existing_navItems, incoming_navItems, (existing_navItems_item, incoming_navItems_item) => {
        if (!(existing_navItems_item.__ref === incoming_navItems_item.__ref)) {
            return false;
        }
    });
    if (equals_navItems_items === false) {
        return false;
    }
    const existing_nextPageUrl = existing.nextPageUrl;
    const incoming_nextPageUrl = incoming.nextPageUrl;
    if (!(existing_nextPageUrl === incoming_nextPageUrl)) {
        return false;
    }
    return true;
}
const ingest$m = function NavItemsRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$10(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$i;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$m, "UiApi", VERSION$B, RepresentationType$s, equals$v);
    return createLink(key);
};
function getTypeCacheKeys$t(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$s,
        mergeable: false
    });
    const input_navItems_length = input.navItems.length;
    for (let i = 0; i < input_navItems_length; i++) {
        getTypeCacheKeys$z(rootKeySet, luvio, input.navItems[i]);
    }
}

function select$T(luvio, params) {
    return select$U();
}
function keyBuilder$$(luvio, params) {
    return keyPrefix + '::NavItemsRepresentation:(' + 'formFactor:' + params.queryParams.formFactor + ',' + 'navItemNames:' + params.queryParams.navItemNames + ',' + 'page:' + params.queryParams.page + ',' + 'pageSize:' + params.queryParams.pageSize + ')';
}
function getResponseCacheKeys$y(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$t(storeKeyMap, luvio, response, () => keyBuilder$$(luvio, resourceParams));
}
function ingestSuccess$r(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$$(luvio, resourceParams);
    luvio.storeIngest(key, ingest$m, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$T(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$l(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$$(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$i,
        namespace: keyPrefix,
        version: VERSION$B,
        representationName: RepresentationType$s
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$C(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/nav-items',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$w = 'getNavItems';
const getNavItems_ConfigPropertyMetadata = [
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('navItemNames', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('page', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
];
const getNavItems_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$w, getNavItems_ConfigPropertyMetadata);
const createResourceParams$x = /*#__PURE__*/ createResourceParams$13(getNavItems_ConfigPropertyMetadata);
function keyBuilder$_(luvio, config) {
    const resourceParams = createResourceParams$x(config);
    return keyBuilder$$(luvio, resourceParams);
}
function typeCheckConfig$A(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getNavItems_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$A(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getNavItems_ConfigPropertyMetadata);
    const config = typeCheckConfig$A(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$l(luvio, config) {
    createResourceParams$x(config);
    return select$T();
}
function onFetchResponseSuccess$n(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$r(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$B(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$n(luvio, config, resourceParams, response) {
    const snapshot = ingestError$l(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$B(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$B(luvio, config, options) {
    const resourceParams = createResourceParams$x(config);
    const request = createResourceRequest$C(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$n(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$y(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$n(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$r(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$B, undefined, false);
}
function buildCachedSnapshotCachePolicy$q(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$_(luvio, config),
        node: adapterFragment$l(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$B(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getNavItemsAdapterFactory = (luvio) => function UiApi__getNavItems(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$A(untrustedConfig, getNavItems_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$q, buildNetworkSnapshotCachePolicy$r);
};

function select$S(luvio, params) {
    return select$1I();
}
function keyBuilder$Z(luvio, params) {
    return keyPrefix + '::ObjectInfoDirectoryRepresentation:(' + ')';
}
function getResponseCacheKeys$x(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$K(storeKeyMap, luvio, response, () => keyBuilder$Z());
}
function ingestSuccess$q(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$Z();
    luvio.storeIngest(key, ingest$C, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$S(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$k(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$Z();
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$B(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/object-info',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$v = 'getObjectInfoDirectory';
const getObjectInfoDirectory_ConfigPropertyMetadata = [];
const getObjectInfoDirectory_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$v, getObjectInfoDirectory_ConfigPropertyMetadata);
const createResourceParams$w = /*#__PURE__*/ createResourceParams$13(getObjectInfoDirectory_ConfigPropertyMetadata);
function keyBuilder$Y(luvio, config) {
    createResourceParams$w(config);
    return keyBuilder$Z();
}
function typeCheckConfig$z(untrustedConfig) {
    const config = {};
    return config;
}
function validateAdapterConfig$z(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$z();
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$k(luvio, config) {
    createResourceParams$w(config);
    return select$S();
}
function onFetchResponseSuccess$m(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$q(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$A(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$m(luvio, config, resourceParams, response) {
    const snapshot = ingestError$k(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$A(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$A(luvio, config, options) {
    const resourceParams = createResourceParams$w(config);
    const request = createResourceRequest$B();
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$m(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$x(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$m(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$q(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$A, undefined, false);
}
function buildCachedSnapshotCachePolicy$p(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$Y(luvio, config),
        node: adapterFragment$k(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$A(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getObjectInfoDirectoryAdapterFactory = (luvio) => function UiApi__getObjectInfoDirectory(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$z(untrustedConfig, getObjectInfoDirectory_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$p, buildNetworkSnapshotCachePolicy$q);
};

const nonCachedErrors$4 = ObjectCreate$1(null);
function createChildResourceParams$5(resourceParams) {
    let childConfigs = [];
    for (let index = 0, len = resourceParams.urlParams.objectApiNames.length; index < len; index += 1) {
        const item = resourceParams.urlParams.objectApiNames[index];
        childConfigs.push({
            urlParams: {
                objectApiName: item
            }
        });
    }
    return childConfigs;
}
function selectChildResourceParams$4(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$X(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$1X(luvio, childResource);
                const childFragment = select$1M();
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$4[childKey];
                            if (nonCachedError === undefined || nonCachedError.expiration < reader.getTimeStamp()) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$R(luvio, resourceParams) {
    const childResources = createChildResourceParams$5(resourceParams);
    return selectChildResourceParams$4(luvio, childResources, resourceParams);
}
function keyBuilder$X(luvio, params) {
    return keyPrefix + '::SimplifiedBatchRepresentation:(' + 'objectApiNames:' + params.urlParams.objectApiNames + ')';
}
function getResponseCacheKeys$w(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$5(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$_(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$1X(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$O,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$5(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$1X(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$P(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$I(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$4[childKey] = { expiration: now + TTL$x, response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors$4[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$p(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$5(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$X(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$5(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$R(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$j(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$X(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$A(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/object-info/batch/' + config.urlParams.objectApiNames + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$u = 'getObjectInfos';
const getObjectInfos_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiNames', true, 0 /* UrlParameter */, 0 /* String */, true, getObjectApiNamesArray),
];
const getObjectInfos_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$u, getObjectInfos_ConfigPropertyMetadata);
const createResourceParams$v = /*#__PURE__*/ createResourceParams$13(getObjectInfos_ConfigPropertyMetadata);
function keyBuilder$W(luvio, config) {
    const resourceParams = createResourceParams$v(config);
    return keyBuilder$X(luvio, resourceParams);
}
function typeCheckConfig$y(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getObjectInfos_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$y(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getObjectInfos_ConfigPropertyMetadata);
    const config = typeCheckConfig$y(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$j(luvio, config) {
    const resourceParams = createResourceParams$v(config);
    return select$R(luvio, resourceParams);
}
function onFetchResponseSuccess$l(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$p(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$z(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$l(luvio, config, resourceParams, response) {
    const snapshot = ingestError$j(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$z(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$z(luvio, config, options) {
    const resourceParams = createResourceParams$v(config);
    const request = createResourceRequest$A(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$l(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$w(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$l(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$p(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$z, undefined, false);
}
function buildCachedSnapshotCachePolicy$o(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$W(luvio, config),
        node: adapterFragment$j(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$z(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getObjectInfosAdapterFactory = (luvio) => function UiApi__getObjectInfos(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$y(untrustedConfig, getObjectInfos_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$o, buildNetworkSnapshotCachePolicy$p);
};

const VERSION$A = "8d2032474fb4fabdf5cf4042be9042d9";
const select$Q = function WorkStepPicklistValueAttributeRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$M();
    return {
        kind: 'Fragment',
        version: VERSION$A,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'sortOrder',
                kind: 'Scalar'
            },
            {
                name: 'statusCode',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$z = "53893a219bc0888951863f2c44317cac";
const select$P = function LeadStatusPicklistValueAttributesRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$M();
    return {
        kind: 'Fragment',
        version: VERSION$z,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'converted',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$y = "4818ec07c499784571c1012ead048c88";
const select$O = function CaseStatusPicklistValueAttributesRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$M();
    return {
        kind: 'Fragment',
        version: VERSION$y,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'closed',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$x = "950a3a962acbd2b128f937d4c055a9d6";
const select$N = function OpportunityStagePicklistValueAttributesRepresentationSelect() {
    const { selections: AbstractPicklistValueAttributesRepresentationSelections } = select$M();
    return {
        kind: 'Fragment',
        version: VERSION$x,
        private: [],
        selections: [
            ...AbstractPicklistValueAttributesRepresentationSelections,
            {
                name: 'closed',
                kind: 'Scalar'
            },
            {
                name: 'defaultProbability',
                kind: 'Scalar'
            },
            {
                name: 'forecastCategoryName',
                kind: 'Scalar'
            },
            {
                name: 'won',
                kind: 'Scalar'
            }
        ]
    };
};

var DiscriminatorValues$4;
(function (DiscriminatorValues) {
    DiscriminatorValues["WorkStepStatus"] = "WorkStepStatus";
    DiscriminatorValues["LeadStatus"] = "LeadStatus";
    DiscriminatorValues["CaseStatus"] = "CaseStatus";
    DiscriminatorValues["OpportunityStage"] = "OpportunityStage";
})(DiscriminatorValues$4 || (DiscriminatorValues$4 = {}));
const VERSION$w = "bd523b2343366edfc25a2dbee2c4e986";
function validate$$(obj, path = 'AbstractPicklistValueAttributesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_picklistAtrributesValueType = obj.picklistAtrributesValueType;
        const path_picklistAtrributesValueType = path + '.picklistAtrributesValueType';
        if (typeof obj_picklistAtrributesValueType !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_picklistAtrributesValueType + '" (at "' + path_picklistAtrributesValueType + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const selectChildren$2 = function AbstractPicklistValueAttributesRepresentationSelectChildren() {
    const workStepPicklistValueAttributeRepresentationSelections = select$Q();
    const leadStatusPicklistValueAttributesRepresentationSelections = select$P();
    const caseStatusPicklistValueAttributesRepresentationSelections = select$O();
    const opportunityStagePicklistValueAttributesRepresentationSelections = select$N();
    return {
        kind: 'Fragment',
        union: true,
        discriminator: 'picklistAtrributesValueType',
        unionSelections: {
            [DiscriminatorValues$4.WorkStepStatus]: workStepPicklistValueAttributeRepresentationSelections,
            [DiscriminatorValues$4.LeadStatus]: leadStatusPicklistValueAttributesRepresentationSelections,
            [DiscriminatorValues$4.CaseStatus]: caseStatusPicklistValueAttributesRepresentationSelections,
            [DiscriminatorValues$4.OpportunityStage]: opportunityStagePicklistValueAttributesRepresentationSelections
        }
    };
};
const select$M = function AbstractPicklistValueAttributesRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$w,
        private: [],
        selections: [
            {
                name: 'picklistAtrributesValueType',
                kind: 'Scalar'
            }
        ]
    };
};

const VERSION$v = "9e2a16a80378487f557124c771201cf9";
function validate$_(obj, path = 'PicklistValueRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_attributes = obj.attributes;
        const path_attributes = path + '.attributes';
        let obj_attributes_union0 = null;
        const obj_attributes_union0_error = (() => {
            const referencepath_attributesValidationError = validate$$(obj_attributes, path_attributes);
            if (referencepath_attributesValidationError !== null) {
                let message = 'Object doesn\'t match AbstractPicklistValueAttributesRepresentation (at "' + path_attributes + '")\n';
                message += referencepath_attributesValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_attributes_union0_error != null) {
            obj_attributes_union0 = obj_attributes_union0_error.message;
        }
        let obj_attributes_union1 = null;
        const obj_attributes_union1_error = (() => {
            if (obj_attributes !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_attributes + '" (at "' + path_attributes + '")');
            }
        })();
        if (obj_attributes_union1_error != null) {
            obj_attributes_union1 = obj_attributes_union1_error.message;
        }
        if (obj_attributes_union0 && obj_attributes_union1) {
            let message = 'Object doesn\'t match union (at "' + path_attributes + '")';
            message += '\n' + obj_attributes_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_attributes_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_validFor = obj.validFor;
        const path_validFor = path + '.validFor';
        if (!ArrayIsArray(obj_validFor)) {
            return new TypeError('Expected "array" but received "' + typeof obj_validFor + '" (at "' + path_validFor + '")');
        }
        for (let i = 0; i < obj_validFor.length; i++) {
            const obj_validFor_item = obj_validFor[i];
            const path_validFor_item = path_validFor + '[' + i + ']';
            if (typeof obj_validFor_item !== 'number' || (typeof obj_validFor_item === 'number' && Math.floor(obj_validFor_item) !== obj_validFor_item)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_validFor_item + '" (at "' + path_validFor_item + '")');
            }
        }
        const obj_value = obj.value;
        const path_value = path + '.value';
        if (typeof obj_value !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_value + '" (at "' + path_value + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$L = function PicklistValueRepresentationSelect() {
    const AbstractPicklistValueAttributesRepresentation__unionSelections = selectChildren$2();
    return {
        kind: 'Fragment',
        version: VERSION$v,
        private: [],
        selections: [
            {
                kind: 'Object',
                name: 'attributes',
                discriminator: AbstractPicklistValueAttributesRepresentation__unionSelections.discriminator,
                union: true,
                nullable: true,
                unionSelections: AbstractPicklistValueAttributesRepresentation__unionSelections.unionSelections
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'validFor',
                kind: 'Scalar',
                plural: true
            },
            {
                name: 'value',
                kind: 'Scalar'
            }
        ]
    };
};

const keyBuilderFromType$i = 
/**
 * custom key builder from PicklistValuesRepresentation.
 * PicklistValuesRepresentation.url is like /services/data/v64.0/ui-api/object-info/Account/picklist-values/012000000000000AAA/AccountSource
 * the '/services/data/v64.0' in the key make trouble for new js release.  so chop it off make the key unique cross releases.
 */
function PicklistValuesRepresentationKeyBuilderFromType(luvio, object) {
    const id = object.url.substring(object.url.indexOf('/ui-api'));
    return keyBuilder$V(luvio, { id });
};

const TTL$h = 900000;
const VERSION$u = "0a361a49370acb4c6a31721a2057649a";
function validate$Z(obj, path = 'PicklistValuesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_controllerValues = obj.controllerValues;
        const path_controllerValues = path + '.controllerValues';
        if (typeof obj_controllerValues !== 'object' || ArrayIsArray(obj_controllerValues) || obj_controllerValues === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_controllerValues + '" (at "' + path_controllerValues + '")');
        }
        const obj_controllerValues_keys = ObjectKeys(obj_controllerValues);
        for (let i = 0; i < obj_controllerValues_keys.length; i++) {
            const key = obj_controllerValues_keys[i];
            const obj_controllerValues_prop = obj_controllerValues[key];
            const path_controllerValues_prop = path_controllerValues + '["' + key + '"]';
            if (typeof obj_controllerValues_prop !== 'number' || (typeof obj_controllerValues_prop === 'number' && Math.floor(obj_controllerValues_prop) !== obj_controllerValues_prop)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_controllerValues_prop + '" (at "' + path_controllerValues_prop + '")');
            }
        }
        const obj_defaultValue = obj.defaultValue;
        const path_defaultValue = path + '.defaultValue';
        let obj_defaultValue_union0 = null;
        const obj_defaultValue_union0_error = (() => {
            const referencepath_defaultValueValidationError = validate$_(obj_defaultValue, path_defaultValue);
            if (referencepath_defaultValueValidationError !== null) {
                let message = 'Object doesn\'t match PicklistValueRepresentation (at "' + path_defaultValue + '")\n';
                message += referencepath_defaultValueValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_defaultValue_union0_error != null) {
            obj_defaultValue_union0 = obj_defaultValue_union0_error.message;
        }
        let obj_defaultValue_union1 = null;
        const obj_defaultValue_union1_error = (() => {
            if (obj_defaultValue !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_defaultValue + '" (at "' + path_defaultValue + '")');
            }
        })();
        if (obj_defaultValue_union1_error != null) {
            obj_defaultValue_union1 = obj_defaultValue_union1_error.message;
        }
        if (obj_defaultValue_union0 && obj_defaultValue_union1) {
            let message = 'Object doesn\'t match union (at "' + path_defaultValue + '")';
            message += '\n' + obj_defaultValue_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_defaultValue_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_url = obj.url;
        const path_url = path + '.url';
        if (typeof obj_url !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
        }
        const obj_values = obj.values;
        const path_values = path + '.values';
        if (!ArrayIsArray(obj_values)) {
            return new TypeError('Expected "array" but received "' + typeof obj_values + '" (at "' + path_values + '")');
        }
        for (let i = 0; i < obj_values.length; i++) {
            const obj_values_item = obj_values[i];
            const path_values_item = path_values + '[' + i + ']';
            const referencepath_values_itemValidationError = validate$_(obj_values_item, path_values_item);
            if (referencepath_values_itemValidationError !== null) {
                let message = 'Object doesn\'t match PicklistValueRepresentation (at "' + path_values_item + '")\n';
                message += referencepath_values_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$r = 'PicklistValuesRepresentation';
function keyBuilder$V(luvio, config) {
    return keyPrefix + '::' + RepresentationType$r + ':' + config.id;
}
function normalize$l(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$K = function PicklistValuesRepresentationSelect() {
    const { selections: PicklistValueRepresentation__selections, opaque: PicklistValueRepresentation__opaque, } = select$L();
    return {
        kind: 'Fragment',
        version: VERSION$u,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'controllerValues',
                kind: 'Scalar',
                map: true
            },
            {
                name: 'defaultValue',
                kind: 'Object',
                nullable: true,
                selections: PicklistValueRepresentation__selections
            },
            {
                name: 'url',
                kind: 'Scalar'
            },
            {
                name: 'values',
                kind: 'Object',
                plural: true,
                selections: PicklistValueRepresentation__selections
            }
        ]
    };
};
function equals$u(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$l = function PicklistValuesRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$Z(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$i(luvio, input);
    const ttlToUse = TTL$h;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$l, "UiApi", VERSION$u, RepresentationType$r, equals$u);
    return createLink(key);
};
function getTypeCacheKeys$s(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$i(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$r,
        mergeable: false
    });
}

const TTL$g = 900000;
const VERSION$t = "ec03b0f6da287c949d1ccaa904ddbfd3";
function validate$Y(obj, path = 'PicklistValuesCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_picklistFieldValues = obj.picklistFieldValues;
        const path_picklistFieldValues = path + '.picklistFieldValues';
        if (typeof obj_picklistFieldValues !== 'object' || ArrayIsArray(obj_picklistFieldValues) || obj_picklistFieldValues === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_picklistFieldValues + '" (at "' + path_picklistFieldValues + '")');
        }
        const obj_picklistFieldValues_keys = ObjectKeys(obj_picklistFieldValues);
        for (let i = 0; i < obj_picklistFieldValues_keys.length; i++) {
            const key = obj_picklistFieldValues_keys[i];
            const obj_picklistFieldValues_prop = obj_picklistFieldValues[key];
            const path_picklistFieldValues_prop = path_picklistFieldValues + '["' + key + '"]';
            if (typeof obj_picklistFieldValues_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_picklistFieldValues_prop + '" (at "' + path_picklistFieldValues_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$q = 'PicklistValuesCollectionRepresentation';
function normalize$k(input, existing, path, luvio, store, timestamp) {
    const input_picklistFieldValues = input.picklistFieldValues;
    const input_picklistFieldValues_id = path.fullPath + '__picklistFieldValues';
    const input_picklistFieldValues_keys = Object.keys(input_picklistFieldValues);
    const input_picklistFieldValues_length = input_picklistFieldValues_keys.length;
    for (let i = 0; i < input_picklistFieldValues_length; i++) {
        const key = input_picklistFieldValues_keys[i];
        const input_picklistFieldValues_prop = input_picklistFieldValues[key];
        const input_picklistFieldValues_prop_id = input_picklistFieldValues_id + '__' + key;
        input_picklistFieldValues[key] = ingest$l(input_picklistFieldValues_prop, {
            fullPath: input_picklistFieldValues_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
const select$J = function PicklistValuesCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$t,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'picklistFieldValues',
                kind: 'Link',
                map: true,
                fragment: select$K()
            }
        ]
    };
};
function equals$t(existing, incoming) {
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_picklistFieldValues = existing.picklistFieldValues;
    const incoming_picklistFieldValues = incoming.picklistFieldValues;
    const equals_picklistFieldValues_props = equalsObject(existing_picklistFieldValues, incoming_picklistFieldValues, (existing_picklistFieldValues_prop, incoming_picklistFieldValues_prop) => {
        if (!(existing_picklistFieldValues_prop.__ref === incoming_picklistFieldValues_prop.__ref)) {
            return false;
        }
    });
    if (equals_picklistFieldValues_props === false) {
        return false;
    }
    return true;
}
const ingest$k = function PicklistValuesCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$Y(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$g;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$k, "UiApi", VERSION$t, RepresentationType$q, equals$t);
    return createLink(key);
};
function getTypeCacheKeys$r(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$q,
        mergeable: false
    });
    const input_picklistFieldValues = input.picklistFieldValues;
    const input_picklistFieldValues_keys = ObjectKeys(input_picklistFieldValues);
    const input_picklistFieldValues_length = input_picklistFieldValues_keys.length;
    for (let i = 0; i < input_picklistFieldValues_length; i++) {
        const key = input_picklistFieldValues_keys[i];
        getTypeCacheKeys$s(rootKeySet, luvio, input_picklistFieldValues[key]);
    }
}

function select$I(luvio, params) {
    return select$J();
}
function keyBuilder$U(luvio, params) {
    return keyPrefix + '::PicklistValuesCollectionRepresentation:(' + 'objectApiName:' + params.urlParams.objectApiName + ',' + 'recordTypeId:' + params.urlParams.recordTypeId + ')';
}
function getResponseCacheKeys$v(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$r(storeKeyMap, luvio, response, () => keyBuilder$U(luvio, resourceParams));
}
function ingestSuccess$o(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$U(luvio, resourceParams);
    luvio.storeIngest(key, ingest$k, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$I(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$i(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$U(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$g,
        namespace: keyPrefix,
        version: VERSION$t,
        representationName: RepresentationType$q
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$z(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/object-info/' + config.urlParams.objectApiName + '/picklist-values/' + config.urlParams.recordTypeId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$t = 'getPicklistValuesByRecordType';
const getPicklistValuesByRecordType_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('recordTypeId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
];
const getPicklistValuesByRecordType_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$t, getPicklistValuesByRecordType_ConfigPropertyMetadata);
const createResourceParams$u = /*#__PURE__*/ createResourceParams$13(getPicklistValuesByRecordType_ConfigPropertyMetadata);
function keyBuilder$T(luvio, config) {
    const resourceParams = createResourceParams$u(config);
    return keyBuilder$U(luvio, resourceParams);
}
function typeCheckConfig$x(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getPicklistValuesByRecordType_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$x(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getPicklistValuesByRecordType_ConfigPropertyMetadata);
    const config = typeCheckConfig$x(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$i(luvio, config) {
    createResourceParams$u(config);
    return select$I();
}
function onFetchResponseSuccess$k(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$o(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$y(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$k(luvio, config, resourceParams, response) {
    const snapshot = ingestError$i(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$y(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$y(luvio, config, options) {
    const resourceParams = createResourceParams$u(config);
    const request = createResourceRequest$z(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$k(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$v(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$k(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$o(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$y, undefined, false);
}
function buildCachedSnapshotCachePolicy$n(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$T(luvio, config),
        node: adapterFragment$i(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$y(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getPicklistValuesByRecordTypeAdapterFactory = (luvio) => function UiApi__getPicklistValuesByRecordType(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$x(untrustedConfig, getPicklistValuesByRecordType_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$n, buildNetworkSnapshotCachePolicy$o);
};

function getResponseCacheKeys$u(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$s(storeKeyMap, luvio, response);
}
function createResourceRequest$y(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/object-info/' + config.urlParams.objectApiName + '/picklist-values/' + config.urlParams.recordTypeId + '/' + config.urlParams.fieldApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const path = select$K().selections;
function buildSnapshotRefresh$2(luvio, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot$x(luvio, config),
    };
}
function buildRequestAndKey(luvio, config) {
    const { recordTypeId, fieldApiName } = config;
    const fieldNames = getFieldId(fieldApiName);
    const resourceParams = {
        urlParams: {
            objectApiName: fieldNames.objectApiName,
            fieldApiName: fieldNames.fieldApiName,
            recordTypeId,
        },
    };
    const request = createResourceRequest$y(resourceParams);
    const key = keyBuilder$V(luvio, { id: request.basePath });
    return { resourceParams, request, key };
}
function onResponseSuccess$1(luvio, config, key, response) {
    const { body } = response;
    luvio.storeIngest(key, ingest$l, body);
    const snapshot = buildCachedSnapshot$4(luvio, config);
    return luvio.storeBroadcast().then(() => snapshot);
}
function onResponseError(luvio, config, key, err) {
    const errorSnapshot = luvio.errorSnapshot(err, buildSnapshotRefresh$2(luvio, config));
    luvio.storeIngestError(key, errorSnapshot);
    return luvio.storeBroadcast().then(() => errorSnapshot);
}
function buildNetworkSnapshot$x(luvio, config, options) {
    const { resourceParams, request, key } = buildRequestAndKey(luvio, config);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        return luvio.handleSuccessResponse(() => {
            return onResponseSuccess$1(luvio, config, key, response);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$u(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return onResponseError(luvio, config, key, err);
        });
    });
}
function buildCachedSnapshot$4(luvio, config) {
    const fieldNames = getFieldId(config.fieldApiName);
    const request = createResourceRequest$y({
        urlParams: {
            objectApiName: fieldNames.objectApiName,
            fieldApiName: fieldNames.fieldApiName,
            recordTypeId: config.recordTypeId,
        },
    });
    const key = keyBuilder$V(luvio, { id: request.basePath });
    return luvio.storeLookup({
        recordId: key,
        node: {
            kind: 'Fragment',
            private: ['eTag'],
            selections: path,
            version: VERSION$u,
        },
        variables: {},
    }, buildSnapshotRefresh$2(luvio, config));
}
function buildNetworkSnapshotCachePolicy$n(context, coercedAdapterRequestContext) {
    const { config, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$x(luvio, config, dispatchOptions);
}
function buildCachedSnapshotCachePolicy$m(context, storeLookup) {
    const { config, luvio } = context;
    const fieldNames = getFieldId(config.fieldApiName);
    const { basePath } = createResourceRequest$y({
        urlParams: {
            objectApiName: fieldNames.objectApiName,
            fieldApiName: fieldNames.fieldApiName,
            recordTypeId: config.recordTypeId,
        },
    });
    const key = keyBuilder$V(luvio, { id: basePath });
    return storeLookup({
        recordId: key,
        node: {
            kind: 'Fragment',
            private: ['eTag'],
            selections: path,
            version: VERSION$u,
        },
        variables: {},
    }, buildSnapshotRefresh$2(luvio, config));
}
const picklistValuesConfigPropertyNames = {
    displayName: 'getPicklistValues',
    parameters: {
        required: ['recordTypeId', 'fieldApiName'],
        optional: [],
    },
};
function validateAdapterConfig$w(untrusted, _config) {
    return validateAdapterConfig$v(untrusted, picklistValuesConfigPropertyNames);
}

const adapterName$s = 'getPicklistValues';
const getPicklistValues_ConfigPropertyMetadata = [
    generateParamConfigMetadata('fieldApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getFieldApiName),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('recordTypeId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
];
function typeCheckConfig$w(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getPicklistValues_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$v(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getPicklistValues_ConfigPropertyMetadata);
    const config = typeCheckConfig$w(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
const getPicklistValuesAdapterFactory = (luvio) => function UiApi__getPicklistValues(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$w(untrustedConfig);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$m, buildNetworkSnapshotCachePolicy$n);
};

function select$H(luvio, params) {
    return select$1L();
}
function keyBuilder$S(luvio, params) {
    return keyBuilder$1V(luvio, {
        layoutType: "PathAssistant",
        objectApiName: params.urlParams.objectApiName,
        layoutOverride: params.queryParams.layoutOverride,
        recordTypeId: params.queryParams.recordTypeId || "",
        mode: params.queryParams.mode || "",
        formFactor: params.queryParams.formFactor || ""
    });
}
function getResponseCacheKeys$t(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$N(storeKeyMap, luvio, response);
}
function ingestSuccess$n(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$S(luvio, resourceParams);
    luvio.storeIngest(key, ingest$G, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$H(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$h(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$S(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$w,
        namespace: keyPrefix,
        version: VERSION$17,
        representationName: RepresentationType$N
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$x(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/path/layout/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$r = 'getPathLayout';
const getPathLayout_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('layoutOverride', true, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('mode', false, 1 /* QueryParameter */, 0 /* String */, false, coerceLayoutMode),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */, false, getRecordId18),
];
const getPathLayout_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$r, getPathLayout_ConfigPropertyMetadata);
const createResourceParams$t = /*#__PURE__*/ createResourceParams$13(getPathLayout_ConfigPropertyMetadata);
function keyBuilder$R(luvio, config) {
    const resourceParams = createResourceParams$t(config);
    return keyBuilder$S(luvio, resourceParams);
}
function typeCheckConfig$v(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getPathLayout_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$u(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getPathLayout_ConfigPropertyMetadata);
    const config = typeCheckConfig$v(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$h(luvio, config) {
    createResourceParams$t(config);
    return select$H();
}
function onFetchResponseSuccess$j(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$n(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$w(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$j(luvio, config, resourceParams, response) {
    const snapshot = ingestError$h(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$w(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$w(luvio, config, options) {
    const resourceParams = createResourceParams$t(config);
    const request = createResourceRequest$x(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$j(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$t(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$j(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$m(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$w, undefined, false);
}
function buildCachedSnapshotCachePolicy$l(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$R(luvio, config),
        node: adapterFragment$h(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$w(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getPathLayoutAdapterFactory = (luvio) => function UiApi__getPathLayout(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$u(untrustedConfig, getPathLayout_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$l, buildNetworkSnapshotCachePolicy$m);
};

function validate$X(obj, path = 'MatchResultInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_recordIds = obj.recordIds;
        const path_recordIds = path + '.recordIds';
        if (!ArrayIsArray(obj_recordIds)) {
            return new TypeError('Expected "array" but received "' + typeof obj_recordIds + '" (at "' + path_recordIds + '")');
        }
        for (let i = 0; i < obj_recordIds.length; i++) {
            const obj_recordIds_item = obj_recordIds[i];
            const path_recordIds_item = path_recordIds + '[' + i + ']';
            if (typeof obj_recordIds_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordIds_item + '" (at "' + path_recordIds_item + '")');
            }
        }
        const obj_rule = obj.rule;
        const path_rule = path + '.rule';
        if (typeof obj_rule !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_rule + '" (at "' + path_rule + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$W(obj, path = 'DuplicateResultInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_allowSave = obj.allowSave;
        const path_allowSave = path + '.allowSave';
        if (typeof obj_allowSave !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_allowSave + '" (at "' + path_allowSave + '")');
        }
        const obj_matchResultInfo = obj.matchResultInfo;
        const path_matchResultInfo = path + '.matchResultInfo';
        const referencepath_matchResultInfoValidationError = validate$X(obj_matchResultInfo, path_matchResultInfo);
        if (referencepath_matchResultInfoValidationError !== null) {
            let message = 'Object doesn\'t match MatchResultInfoRepresentation (at "' + path_matchResultInfo + '")\n';
            message += referencepath_matchResultInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_rule = obj.rule;
        const path_rule = path + '.rule';
        if (typeof obj_rule !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_rule + '" (at "' + path_rule + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$V(obj, path = 'MatchRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_duplicateResultInfos = obj.duplicateResultInfos;
        const path_duplicateResultInfos = path + '.duplicateResultInfos';
        if (typeof obj_duplicateResultInfos !== 'object' || ArrayIsArray(obj_duplicateResultInfos) || obj_duplicateResultInfos === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_duplicateResultInfos + '" (at "' + path_duplicateResultInfos + '")');
        }
        const obj_duplicateResultInfos_keys = ObjectKeys(obj_duplicateResultInfos);
        for (let i = 0; i < obj_duplicateResultInfos_keys.length; i++) {
            const key = obj_duplicateResultInfos_keys[i];
            const obj_duplicateResultInfos_prop = obj_duplicateResultInfos[key];
            const path_duplicateResultInfos_prop = path_duplicateResultInfos + '["' + key + '"]';
            const referencepath_duplicateResultInfos_propValidationError = validate$W(obj_duplicateResultInfos_prop, path_duplicateResultInfos_prop);
            if (referencepath_duplicateResultInfos_propValidationError !== null) {
                let message = 'Object doesn\'t match DuplicateResultInfoRepresentation (at "' + path_duplicateResultInfos_prop + '")\n';
                message += referencepath_duplicateResultInfos_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_recordIds = obj.recordIds;
        const path_recordIds = path + '.recordIds';
        if (!ArrayIsArray(obj_recordIds)) {
            return new TypeError('Expected "array" but received "' + typeof obj_recordIds + '" (at "' + path_recordIds + '")');
        }
        for (let i = 0; i < obj_recordIds.length; i++) {
            const obj_recordIds_item = obj_recordIds[i];
            const path_recordIds_item = path_recordIds + '[' + i + ']';
            if (typeof obj_recordIds_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordIds_item + '" (at "' + path_recordIds_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$f = 30000;
const VERSION$s = "583c38564fa15ce0fb3dd2807be1bdc6";
function validate$U(obj, path = 'DuplicatesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_allowSave = obj.allowSave;
        const path_allowSave = path + '.allowSave';
        if (typeof obj_allowSave !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_allowSave + '" (at "' + path_allowSave + '")');
        }
        const obj_duplicateError = obj.duplicateError;
        const path_duplicateError = path + '.duplicateError';
        if (typeof obj_duplicateError !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_duplicateError + '" (at "' + path_duplicateError + '")');
        }
        const obj_duplicateRules = obj.duplicateRules;
        const path_duplicateRules = path + '.duplicateRules';
        if (!ArrayIsArray(obj_duplicateRules)) {
            return new TypeError('Expected "array" but received "' + typeof obj_duplicateRules + '" (at "' + path_duplicateRules + '")');
        }
        for (let i = 0; i < obj_duplicateRules.length; i++) {
            const obj_duplicateRules_item = obj_duplicateRules[i];
            const path_duplicateRules_item = path_duplicateRules + '[' + i + ']';
            if (typeof obj_duplicateRules_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_duplicateRules_item + '" (at "' + path_duplicateRules_item + '")');
            }
        }
        const obj_matches = obj.matches;
        const path_matches = path + '.matches';
        if (!ArrayIsArray(obj_matches)) {
            return new TypeError('Expected "array" but received "' + typeof obj_matches + '" (at "' + path_matches + '")');
        }
        for (let i = 0; i < obj_matches.length; i++) {
            const obj_matches_item = obj_matches[i];
            const path_matches_item = path_matches + '[' + i + ']';
            const referencepath_matches_itemValidationError = validate$V(obj_matches_item, path_matches_item);
            if (referencepath_matches_itemValidationError !== null) {
                let message = 'Object doesn\'t match MatchRepresentation (at "' + path_matches_item + '")\n';
                message += referencepath_matches_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$p = 'DuplicatesRepresentation';
function normalize$j(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$G = function DuplicatesRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$s,
        private: [],
        opaque: true
    };
};
function equals$s(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$j = function DuplicatesRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$U(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$f;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$j, "UiApi", VERSION$s, RepresentationType$p, equals$s);
    return createLink(key);
};
function getTypeCacheKeys$q(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$p,
        mergeable: false
    });
}

function select$F(luvio, params) {
    return select$G();
}
function keyBuilder$Q(luvio, params) {
    return keyPrefix + '::DuplicatesRepresentation:(' + (params.body.allowSaveOnDuplicate === undefined ? 'allowSaveOnDuplicate' : 'allowSaveOnDuplicate:' + params.body.allowSaveOnDuplicate) + '::' + (params.body.apiName === undefined ? 'apiName' : 'apiName:' + params.body.apiName) + '::' + stableJSONStringify(params.body.fields) + ')';
}
function getResponseCacheKeys$s(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$q(storeKeyMap, luvio, response, () => keyBuilder$Q(luvio, resourceParams));
}
function ingestSuccess$m(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$Q(luvio, resourceParams);
    luvio.storeIngest(key, ingest$j, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$F(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$g(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$Q(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$f,
        namespace: keyPrefix,
        version: VERSION$s,
        representationName: RepresentationType$p
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$w(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/predupe',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$q = 'getDuplicates';
const getDuplicates_ConfigPropertyMetadata = [
    generateParamConfigMetadata('allowSaveOnDuplicate', false, 2 /* Body */, 1 /* Boolean */),
    generateParamConfigMetadata('apiName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('fields', true, 2 /* Body */, 4 /* Unsupported */),
];
const getDuplicates_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$q, getDuplicates_ConfigPropertyMetadata);
const createResourceParams$s = /*#__PURE__*/ createResourceParams$13(getDuplicates_ConfigPropertyMetadata);
function keyBuilder$P(luvio, config) {
    const resourceParams = createResourceParams$s(config);
    return keyBuilder$Q(luvio, resourceParams);
}
function typeCheckConfig$u(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getDuplicates_ConfigPropertyMetadata);
    const untrustedConfig_fields = untrustedConfig.fields;
    if (untrustedIsObject(untrustedConfig_fields)) {
        const untrustedConfig_fields_object = {};
        const untrustedConfig_fields_keys = Object.keys(untrustedConfig_fields);
        for (let i = 0, arrayLength = untrustedConfig_fields_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_fields_keys[i];
            const untrustedConfig_fields_prop = untrustedConfig_fields[key];
            if (typeof untrustedConfig_fields_prop === 'string') {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
            if (typeof untrustedConfig_fields_prop === 'number') {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
            if (untrustedConfig_fields_prop === null) {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
            if (typeof untrustedConfig_fields_prop === 'boolean') {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
        }
        if (untrustedConfig_fields_object !== undefined && Object.keys(untrustedConfig_fields_object).length >= 0) {
            config.fields = untrustedConfig_fields_object;
        }
    }
    return config;
}
function validateAdapterConfig$t(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$u(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$g(luvio, config) {
    createResourceParams$s(config);
    return select$F();
}
function onFetchResponseSuccess$i(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$m(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$v(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$i(luvio, config, resourceParams, response) {
    const snapshot = ingestError$g(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$v(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$v(luvio, config, options) {
    const resourceParams = createResourceParams$s(config);
    const request = createResourceRequest$w(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$i(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$s(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$i(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$l(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$v, 'get', false);
}
function buildCachedSnapshotCachePolicy$k(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$P(luvio, config),
        node: adapterFragment$g(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$v(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getDuplicatesAdapterFactory = (luvio) => function UiApi__getDuplicates(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$t(untrustedConfig, getDuplicates_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$k, buildNetworkSnapshotCachePolicy$l);
};

const VERSION$r = "e84b9ffdeff97c411bd111f2a55cf6b6";
function validate$T(obj, path = 'PhotoMetadataRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_companyBluemasterId = obj.companyBluemasterId;
        const path_companyBluemasterId = path + '.companyBluemasterId';
        let obj_companyBluemasterId_union0 = null;
        const obj_companyBluemasterId_union0_error = (() => {
            if (typeof obj_companyBluemasterId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_companyBluemasterId + '" (at "' + path_companyBluemasterId + '")');
            }
        })();
        if (obj_companyBluemasterId_union0_error != null) {
            obj_companyBluemasterId_union0 = obj_companyBluemasterId_union0_error.message;
        }
        let obj_companyBluemasterId_union1 = null;
        const obj_companyBluemasterId_union1_error = (() => {
            if (obj_companyBluemasterId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_companyBluemasterId + '" (at "' + path_companyBluemasterId + '")');
            }
        })();
        if (obj_companyBluemasterId_union1_error != null) {
            obj_companyBluemasterId_union1 = obj_companyBluemasterId_union1_error.message;
        }
        if (obj_companyBluemasterId_union0 && obj_companyBluemasterId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_companyBluemasterId + '")';
            message += '\n' + obj_companyBluemasterId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_companyBluemasterId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_responseId = obj.responseId;
        const path_responseId = path + '.responseId';
        let obj_responseId_union0 = null;
        const obj_responseId_union0_error = (() => {
            if (typeof obj_responseId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_responseId + '" (at "' + path_responseId + '")');
            }
        })();
        if (obj_responseId_union0_error != null) {
            obj_responseId_union0 = obj_responseId_union0_error.message;
        }
        let obj_responseId_union1 = null;
        const obj_responseId_union1_error = (() => {
            if (obj_responseId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_responseId + '" (at "' + path_responseId + '")');
            }
        })();
        if (obj_responseId_union1_error != null) {
            obj_responseId_union1 = obj_responseId_union1_error.message;
        }
        if (obj_responseId_union0 && obj_responseId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_responseId + '")';
            message += '\n' + obj_responseId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_responseId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$E = function PhotoMetadataRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$r,
        private: [],
        selections: [
            {
                name: 'companyBluemasterId',
                kind: 'Scalar'
            },
            {
                name: 'responseId',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$r(existing, incoming) {
    const existing_companyBluemasterId = existing.companyBluemasterId;
    const incoming_companyBluemasterId = incoming.companyBluemasterId;
    if (!(existing_companyBluemasterId === incoming_companyBluemasterId)) {
        return false;
    }
    const existing_responseId = existing.responseId;
    const incoming_responseId = incoming.responseId;
    if (!(existing_responseId === incoming_responseId)) {
        return false;
    }
    return true;
}

const VERSION$q = "34ffbf4219dfebb707bff609c2d5bf89";
function validate$S(obj, path = 'PhotoRecordAvatarRepresentation') {
    const validateAbstractRecordAvatarRepresentation_validateError = validate$Q(obj, path);
    if (validateAbstractRecordAvatarRepresentation_validateError !== null) {
        return validateAbstractRecordAvatarRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_backgroundColor = obj.backgroundColor;
        const path_backgroundColor = path + '.backgroundColor';
        let obj_backgroundColor_union0 = null;
        const obj_backgroundColor_union0_error = (() => {
            if (typeof obj_backgroundColor !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_backgroundColor + '" (at "' + path_backgroundColor + '")');
            }
        })();
        if (obj_backgroundColor_union0_error != null) {
            obj_backgroundColor_union0 = obj_backgroundColor_union0_error.message;
        }
        let obj_backgroundColor_union1 = null;
        const obj_backgroundColor_union1_error = (() => {
            if (obj_backgroundColor !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_backgroundColor + '" (at "' + path_backgroundColor + '")');
            }
        })();
        if (obj_backgroundColor_union1_error != null) {
            obj_backgroundColor_union1 = obj_backgroundColor_union1_error.message;
        }
        if (obj_backgroundColor_union0 && obj_backgroundColor_union1) {
            let message = 'Object doesn\'t match union (at "' + path_backgroundColor + '")';
            message += '\n' + obj_backgroundColor_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_backgroundColor_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_height = obj.height;
        const path_height = path + '.height';
        let obj_height_union0 = null;
        const obj_height_union0_error = (() => {
            if (typeof obj_height !== 'number' || (typeof obj_height === 'number' && Math.floor(obj_height) !== obj_height)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_height + '" (at "' + path_height + '")');
            }
        })();
        if (obj_height_union0_error != null) {
            obj_height_union0 = obj_height_union0_error.message;
        }
        let obj_height_union1 = null;
        const obj_height_union1_error = (() => {
            if (obj_height !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_height + '" (at "' + path_height + '")');
            }
        })();
        if (obj_height_union1_error != null) {
            obj_height_union1 = obj_height_union1_error.message;
        }
        if (obj_height_union0 && obj_height_union1) {
            let message = 'Object doesn\'t match union (at "' + path_height + '")';
            message += '\n' + obj_height_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_height_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_photoMetadata = obj.photoMetadata;
        const path_photoMetadata = path + '.photoMetadata';
        const referencepath_photoMetadataValidationError = validate$T(obj_photoMetadata, path_photoMetadata);
        if (referencepath_photoMetadataValidationError !== null) {
            let message = 'Object doesn\'t match PhotoMetadataRepresentation (at "' + path_photoMetadata + '")\n';
            message += referencepath_photoMetadataValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_photoUrl = obj.photoUrl;
        const path_photoUrl = path + '.photoUrl';
        if (typeof obj_photoUrl !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_photoUrl + '" (at "' + path_photoUrl + '")');
        }
        const obj_provider = obj.provider;
        const path_provider = path + '.provider';
        let obj_provider_union0 = null;
        const obj_provider_union0_error = (() => {
            if (typeof obj_provider !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_provider + '" (at "' + path_provider + '")');
            }
        })();
        if (obj_provider_union0_error != null) {
            obj_provider_union0 = obj_provider_union0_error.message;
        }
        let obj_provider_union1 = null;
        const obj_provider_union1_error = (() => {
            if (obj_provider !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_provider + '" (at "' + path_provider + '")');
            }
        })();
        if (obj_provider_union1_error != null) {
            obj_provider_union1 = obj_provider_union1_error.message;
        }
        if (obj_provider_union0 && obj_provider_union1) {
            let message = 'Object doesn\'t match union (at "' + path_provider + '")';
            message += '\n' + obj_provider_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_provider_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_width = obj.width;
        const path_width = path + '.width';
        let obj_width_union0 = null;
        const obj_width_union0_error = (() => {
            if (typeof obj_width !== 'number' || (typeof obj_width === 'number' && Math.floor(obj_width) !== obj_width)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_width + '" (at "' + path_width + '")');
            }
        })();
        if (obj_width_union0_error != null) {
            obj_width_union0 = obj_width_union0_error.message;
        }
        let obj_width_union1 = null;
        const obj_width_union1_error = (() => {
            if (obj_width !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_width + '" (at "' + path_width + '")');
            }
        })();
        if (obj_width_union1_error != null) {
            obj_width_union1 = obj_width_union1_error.message;
        }
        if (obj_width_union0 && obj_width_union1) {
            let message = 'Object doesn\'t match union (at "' + path_width + '")';
            message += '\n' + obj_width_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_width_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$o = 'PhotoRecordAvatarRepresentation';
function keyBuilderFromType$h(luvio, object) {
    return keyBuilderFromType$f(luvio, object);
}
function normalize$i(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$D = function PhotoRecordAvatarRepresentationSelect() {
    const { selections: AbstractRecordAvatarRepresentationSelections } = select$B();
    const { selections: PhotoMetadataRepresentation__selections, opaque: PhotoMetadataRepresentation__opaque, } = select$E();
    return {
        kind: 'Fragment',
        version: VERSION$q,
        private: [
            'eTag'
        ],
        selections: [
            ...AbstractRecordAvatarRepresentationSelections,
            {
                name: 'backgroundColor',
                kind: 'Scalar'
            },
            {
                name: 'height',
                kind: 'Scalar'
            },
            {
                name: 'photoMetadata',
                kind: 'Object',
                selections: PhotoMetadataRepresentation__selections
            },
            {
                name: 'photoUrl',
                kind: 'Scalar'
            },
            {
                name: 'provider',
                kind: 'Scalar'
            },
            {
                name: 'width',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$q(existing, incoming) {
    if (equals$o(existing, incoming) === false) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_photoUrl = existing.photoUrl;
    const incoming_photoUrl = incoming.photoUrl;
    if (!(existing_photoUrl === incoming_photoUrl)) {
        return false;
    }
    const existing_backgroundColor = existing.backgroundColor;
    const incoming_backgroundColor = incoming.backgroundColor;
    if (!(existing_backgroundColor === incoming_backgroundColor)) {
        return false;
    }
    const existing_height = existing.height;
    const incoming_height = incoming.height;
    if (!(existing_height === incoming_height)) {
        return false;
    }
    const existing_photoMetadata = existing.photoMetadata;
    const incoming_photoMetadata = incoming.photoMetadata;
    if (!(equals$r(existing_photoMetadata, incoming_photoMetadata))) {
        return false;
    }
    const existing_provider = existing.provider;
    const incoming_provider = incoming.provider;
    if (!(existing_provider === incoming_provider)) {
        return false;
    }
    const existing_width = existing.width;
    const incoming_width = incoming.width;
    if (!(existing_width === incoming_width)) {
        return false;
    }
    return true;
}
const ingest$i = function PhotoRecordAvatarRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$S(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$h(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$i, "UiApi", VERSION$q, RepresentationType$o, equals$q);
    return createLink(key);
};
function getTypeCacheKeys$p(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$h(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$m,
        mergeable: false
    });
}

const VERSION$p = "cbdcf69a6568d41ccf155b2b95ec70e7";
function validate$R(obj, path = 'ThemeRecordAvatarRepresentation') {
    const validateAbstractRecordAvatarRepresentation_validateError = validate$Q(obj, path);
    if (validateAbstractRecordAvatarRepresentation_validateError !== null) {
        return validateAbstractRecordAvatarRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_backgroundColor = obj.backgroundColor;
        const path_backgroundColor = path + '.backgroundColor';
        let obj_backgroundColor_union0 = null;
        const obj_backgroundColor_union0_error = (() => {
            if (typeof obj_backgroundColor !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_backgroundColor + '" (at "' + path_backgroundColor + '")');
            }
        })();
        if (obj_backgroundColor_union0_error != null) {
            obj_backgroundColor_union0 = obj_backgroundColor_union0_error.message;
        }
        let obj_backgroundColor_union1 = null;
        const obj_backgroundColor_union1_error = (() => {
            if (obj_backgroundColor !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_backgroundColor + '" (at "' + path_backgroundColor + '")');
            }
        })();
        if (obj_backgroundColor_union1_error != null) {
            obj_backgroundColor_union1 = obj_backgroundColor_union1_error.message;
        }
        if (obj_backgroundColor_union0 && obj_backgroundColor_union1) {
            let message = 'Object doesn\'t match union (at "' + path_backgroundColor + '")';
            message += '\n' + obj_backgroundColor_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_backgroundColor_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_iconUrl = obj.iconUrl;
        const path_iconUrl = path + '.iconUrl';
        let obj_iconUrl_union0 = null;
        const obj_iconUrl_union0_error = (() => {
            if (typeof obj_iconUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union0_error != null) {
            obj_iconUrl_union0 = obj_iconUrl_union0_error.message;
        }
        let obj_iconUrl_union1 = null;
        const obj_iconUrl_union1_error = (() => {
            if (obj_iconUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_iconUrl + '" (at "' + path_iconUrl + '")');
            }
        })();
        if (obj_iconUrl_union1_error != null) {
            obj_iconUrl_union1 = obj_iconUrl_union1_error.message;
        }
        if (obj_iconUrl_union0 && obj_iconUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_iconUrl + '")';
            message += '\n' + obj_iconUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_iconUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$n = 'ThemeRecordAvatarRepresentation';
function keyBuilderFromType$g(luvio, object) {
    return keyBuilderFromType$f(luvio, object);
}
function normalize$h(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$C = function ThemeRecordAvatarRepresentationSelect() {
    const { selections: AbstractRecordAvatarRepresentationSelections } = select$B();
    return {
        kind: 'Fragment',
        version: VERSION$p,
        private: [
            'eTag'
        ],
        selections: [
            ...AbstractRecordAvatarRepresentationSelections,
            {
                name: 'backgroundColor',
                kind: 'Scalar'
            },
            {
                name: 'iconUrl',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$p(existing, incoming) {
    if (equals$o(existing, incoming) === false) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_backgroundColor = existing.backgroundColor;
    const incoming_backgroundColor = incoming.backgroundColor;
    if (!(existing_backgroundColor === incoming_backgroundColor)) {
        return false;
    }
    const existing_iconUrl = existing.iconUrl;
    const incoming_iconUrl = incoming.iconUrl;
    if (!(existing_iconUrl === incoming_iconUrl)) {
        return false;
    }
    return true;
}
const ingest$h = function ThemeRecordAvatarRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$R(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$g(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$h, "UiApi", VERSION$p, RepresentationType$n, equals$p);
    return createLink(key);
};
function getTypeCacheKeys$o(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$g(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$m,
        mergeable: false
    });
}

var DiscriminatorValues$3;
(function (DiscriminatorValues) {
    DiscriminatorValues["Photo"] = "Photo";
    DiscriminatorValues["Theme"] = "Theme";
})(DiscriminatorValues$3 || (DiscriminatorValues$3 = {}));
const VERSION$o = "bc05f8d1c708b6c41c9bf2fe6001aff0";
function validate$Q(obj, path = 'AbstractRecordAvatarRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_recordId = obj.recordId;
        const path_recordId = path + '.recordId';
        if (typeof obj_recordId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_recordId + '" (at "' + path_recordId + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$m = 'AbstractRecordAvatarRepresentation';
function keyBuilder$O(luvio, config) {
    return keyPrefix + '::' + RepresentationType$m + ':' + config.recordId;
}
function keyBuilderFromType$f(luvio, object) {
    const keyParams = {
        recordId: object.recordId
    };
    return keyBuilder$O(luvio, keyParams);
}
const selectChildren$1 = function AbstractRecordAvatarRepresentationSelectChildren() {
    const photoRecordAvatarRepresentationSelections = select$D();
    const themeRecordAvatarRepresentationSelections = select$C();
    return {
        kind: 'Fragment',
        union: true,
        discriminator: 'type',
        unionSelections: {
            [DiscriminatorValues$3.Photo]: photoRecordAvatarRepresentationSelections,
            [DiscriminatorValues$3.Theme]: themeRecordAvatarRepresentationSelections
        }
    };
};
const select$B = function AbstractRecordAvatarRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$o,
        private: [],
        selections: [
            {
                name: 'recordId',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$o(existing, incoming) {
    const existing_recordId = existing.recordId;
    const incoming_recordId = incoming.recordId;
    if (!(existing_recordId === incoming_recordId)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    return true;
}
const discriminatorIngest$1 = function AbstractRecordAvatarRepresentationDiscriminatorIngest(input, path, luvio, store, timestamp) {
    const discriminatorValue = input.type;
    if (discriminatorValue === 'Photo') {
        return ingest$i(input, path, luvio, store, timestamp);
    }
    if (discriminatorValue === 'Theme') {
        return ingest$h(input, path, luvio, store, timestamp);
    }
    throw new Error(`Invalid discriminatorValue "${discriminatorValue}". Expected one of "Photo","Theme"`);
};
function getTypeCacheKeys$n(rootKeySet, luvio, input, fullPathFactory) {
    const discriminatorValue = input.type;
    if (discriminatorValue === 'Photo') {
        return getTypeCacheKeys$p(rootKeySet, luvio, input);
    }
    if (discriminatorValue === 'Theme') {
        return getTypeCacheKeys$o(rootKeySet, luvio, input);
    }
    throw new Error(`Invalid discriminatorValue "${discriminatorValue}". Expected one of "Photo","Theme"`);
}

const VERSION$n = "f531b44760afecfce89990fe5a5c5c29";
function validate$P(obj, path = 'RecordAvatarBatchRepresentation') {
    const validateAbstractRecordAvatarBatchRepresentation_validateError = validate$L(obj, path);
    if (validateAbstractRecordAvatarBatchRepresentation_validateError !== null) {
        return validateAbstractRecordAvatarBatchRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_result = obj.result;
        const path_result = path + '.result';
        if (typeof obj_result !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_result + '" (at "' + path_result + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$l = 'RecordAvatarBatchRepresentation';
function normalize$g(input, existing, path, luvio, store, timestamp) {
    const input_result = input.result;
    const input_result_id = path.fullPath + '__result';
    input.result = discriminatorIngest$1(input_result, {
        fullPath: input_result_id,
        propertyName: 'result',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    return input;
}
const select$A = function RecordAvatarBatchRepresentationSelect() {
    const { selections: AbstractRecordAvatarBatchRepresentationSelections } = select$w();
    return {
        kind: 'Fragment',
        version: VERSION$n,
        private: [],
        selections: [
            ...AbstractRecordAvatarBatchRepresentationSelections,
            {
                kind: 'Link',
                name: 'result',
                fragment: selectChildren$1()
            }
        ]
    };
};
function equals$n(existing, incoming) {
    if (equals$j(existing, incoming) === false) {
        return false;
    }
    const existing_result = existing.result;
    const incoming_result = incoming.result;
    if (!(existing_result.__ref === incoming_result.__ref)) {
        return false;
    }
    return true;
}
const ingest$g = function RecordAvatarBatchRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$P(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$e;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$g, "UiApi", VERSION$n, RepresentationType$l, equals$n);
    return createLink(key);
};
function getTypeCacheKeys$m(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$l,
        mergeable: false
    });
}

const VERSION$m = "17c20b01167dba9a81452e60bb28b2f2";
function validate$O(obj, path = 'ErrorSingleRecordAvatarRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_errorCode = obj.errorCode;
        const path_errorCode = path + '.errorCode';
        if (typeof obj_errorCode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_errorCode + '" (at "' + path_errorCode + '")');
        }
        const obj_message = obj.message;
        const path_message = path + '.message';
        if (typeof obj_message !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_message + '" (at "' + path_message + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$z = function ErrorSingleRecordAvatarRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$m,
        private: [],
        selections: [
            {
                name: 'errorCode',
                kind: 'Scalar'
            },
            {
                name: 'message',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$m(existing, incoming) {
    const existing_errorCode = existing.errorCode;
    const incoming_errorCode = incoming.errorCode;
    if (!(existing_errorCode === incoming_errorCode)) {
        return false;
    }
    const existing_message = existing.message;
    const incoming_message = incoming.message;
    if (!(existing_message === incoming_message)) {
        return false;
    }
    return true;
}

const VERSION$l = "e7fac2bfb5cdacc5e0f15c350f9ab8fe";
function validate$N(obj, path = 'ErrorBadRequestRecordAvatarBatchRepresentation') {
    const validateAbstractRecordAvatarBatchRepresentation_validateError = validate$L(obj, path);
    if (validateAbstractRecordAvatarBatchRepresentation_validateError !== null) {
        return validateAbstractRecordAvatarBatchRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_result = obj.result;
        const path_result = path + '.result';
        if (!ArrayIsArray(obj_result)) {
            return new TypeError('Expected "array" but received "' + typeof obj_result + '" (at "' + path_result + '")');
        }
        for (let i = 0; i < obj_result.length; i++) {
            const obj_result_item = obj_result[i];
            const path_result_item = path_result + '[' + i + ']';
            const referencepath_result_itemValidationError = validate$O(obj_result_item, path_result_item);
            if (referencepath_result_itemValidationError !== null) {
                let message = 'Object doesn\'t match ErrorSingleRecordAvatarRepresentation (at "' + path_result_item + '")\n';
                message += referencepath_result_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$k = 'ErrorBadRequestRecordAvatarBatchRepresentation';
function normalize$f(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$y = function ErrorBadRequestRecordAvatarBatchRepresentationSelect() {
    const { selections: AbstractRecordAvatarBatchRepresentationSelections } = select$w();
    const { selections: ErrorSingleRecordAvatarRepresentation__selections, opaque: ErrorSingleRecordAvatarRepresentation__opaque, } = select$z();
    return {
        kind: 'Fragment',
        version: VERSION$l,
        private: [],
        selections: [
            ...AbstractRecordAvatarBatchRepresentationSelections,
            {
                name: 'result',
                kind: 'Object',
                plural: true,
                selections: ErrorSingleRecordAvatarRepresentation__selections
            }
        ]
    };
};
function equals$l(existing, incoming) {
    if (equals$j(existing, incoming) === false) {
        return false;
    }
    const existing_result = existing.result;
    const incoming_result = incoming.result;
    const equals_result_items = equalsArray(existing_result, incoming_result, (existing_result_item, incoming_result_item) => {
        if (!(equals$m(existing_result_item, incoming_result_item))) {
            return false;
        }
    });
    if (equals_result_items === false) {
        return false;
    }
    return true;
}
const ingest$f = function ErrorBadRequestRecordAvatarBatchRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$N(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$e;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$f, "UiApi", VERSION$l, RepresentationType$k, equals$l);
    return createLink(key);
};
function getTypeCacheKeys$l(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$k,
        mergeable: false
    });
}

const VERSION$k = "cbd48fd50d0db463fdff7b1834c22bed";
function validate$M(obj, path = 'ErrorRecordAvatarBatchRepresentation') {
    const validateAbstractRecordAvatarBatchRepresentation_validateError = validate$L(obj, path);
    if (validateAbstractRecordAvatarBatchRepresentation_validateError !== null) {
        return validateAbstractRecordAvatarBatchRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_result = obj.result;
        const path_result = path + '.result';
        if (!ArrayIsArray(obj_result)) {
            return new TypeError('Expected "array" but received "' + typeof obj_result + '" (at "' + path_result + '")');
        }
        for (let i = 0; i < obj_result.length; i++) {
            const obj_result_item = obj_result[i];
            const path_result_item = path_result + '[' + i + ']';
            const referencepath_result_itemValidationError = validate$O(obj_result_item, path_result_item);
            if (referencepath_result_itemValidationError !== null) {
                let message = 'Object doesn\'t match ErrorSingleRecordAvatarRepresentation (at "' + path_result_item + '")\n';
                message += referencepath_result_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$j = 'ErrorRecordAvatarBatchRepresentation';
function normalize$e(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$x = function ErrorRecordAvatarBatchRepresentationSelect() {
    const { selections: AbstractRecordAvatarBatchRepresentationSelections } = select$w();
    const { selections: ErrorSingleRecordAvatarRepresentation__selections, opaque: ErrorSingleRecordAvatarRepresentation__opaque, } = select$z();
    return {
        kind: 'Fragment',
        version: VERSION$k,
        private: [],
        selections: [
            ...AbstractRecordAvatarBatchRepresentationSelections,
            {
                name: 'result',
                kind: 'Object',
                plural: true,
                selections: ErrorSingleRecordAvatarRepresentation__selections
            }
        ]
    };
};
function equals$k(existing, incoming) {
    if (equals$j(existing, incoming) === false) {
        return false;
    }
    const existing_result = existing.result;
    const incoming_result = incoming.result;
    const equals_result_items = equalsArray(existing_result, incoming_result, (existing_result_item, incoming_result_item) => {
        if (!(equals$m(existing_result_item, incoming_result_item))) {
            return false;
        }
    });
    if (equals_result_items === false) {
        return false;
    }
    return true;
}
const ingest$e = function ErrorRecordAvatarBatchRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$M(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$e;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$e, "UiApi", VERSION$k, RepresentationType$j, equals$k);
    return createLink(key);
};
function getTypeCacheKeys$k(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$j,
        mergeable: false
    });
}

const DiscriminatorValues$2 = {
    '200': 200,
    '400': 400,
    '404': 404
};
const TTL$e = 300000;
const VERSION$j = "8956293536e94d5ec63b274b61033d2c";
function validate$L(obj, path = 'AbstractRecordAvatarBatchRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_statusCode = obj.statusCode;
        const path_statusCode = path + '.statusCode';
        if (typeof obj_statusCode !== 'number') {
            return new TypeError('Expected "number" but received "' + typeof obj_statusCode + '" (at "' + path_statusCode + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const selectChildren = function AbstractRecordAvatarBatchRepresentationSelectChildren() {
    const recordAvatarBatchRepresentationSelections = select$A();
    const errorBadRequestRecordAvatarBatchRepresentationSelections = select$y();
    const errorRecordAvatarBatchRepresentationSelections = select$x();
    return {
        kind: 'Fragment',
        union: true,
        discriminator: 'statusCode',
        unionSelections: {
            [DiscriminatorValues$2['200']]: recordAvatarBatchRepresentationSelections,
            [DiscriminatorValues$2['400']]: errorBadRequestRecordAvatarBatchRepresentationSelections,
            [DiscriminatorValues$2['404']]: errorRecordAvatarBatchRepresentationSelections
        }
    };
};
const select$w = function AbstractRecordAvatarBatchRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$j,
        private: [],
        selections: [
            {
                name: 'statusCode',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$j(existing, incoming) {
    const existing_statusCode = existing.statusCode;
    const incoming_statusCode = incoming.statusCode;
    if (!(existing_statusCode === incoming_statusCode)) {
        return false;
    }
    return true;
}
const discriminatorIngest = function AbstractRecordAvatarBatchRepresentationDiscriminatorIngest(input, path, luvio, store, timestamp) {
    const discriminatorValue = input.statusCode;
    if (discriminatorValue === 200) {
        return ingest$g(input, path, luvio, store, timestamp);
    }
    if (discriminatorValue === 400) {
        return ingest$f(input, path, luvio, store, timestamp);
    }
    if (discriminatorValue === 404) {
        return ingest$e(input, path, luvio, store, timestamp);
    }
    throw new Error(`Invalid discriminatorValue "${discriminatorValue}". Expected one of "200","400","404"`);
};
function getTypeCacheKeys$j(rootKeySet, luvio, input, fullPathFactory) {
    const discriminatorValue = input.statusCode;
    if (discriminatorValue === 200) {
        return getTypeCacheKeys$m(rootKeySet, luvio, input, fullPathFactory);
    }
    if (discriminatorValue === 400) {
        return getTypeCacheKeys$l(rootKeySet, luvio, input, fullPathFactory);
    }
    if (discriminatorValue === 404) {
        return getTypeCacheKeys$k(rootKeySet, luvio, input, fullPathFactory);
    }
    throw new Error(`Invalid discriminatorValue "${discriminatorValue}". Expected one of "200","400","404"`);
}

const TTL$d = 3600000;
const VERSION$i = "c44c049fa6ad7cf7e932c0aab9107d86";
function validate$K(obj, path = 'RecordAvatarBulkMapRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_keys = ObjectKeys(obj);
        for (let i = 0; i < obj_keys.length; i++) {
            const key = obj_keys[i];
            const obj_prop = obj[key];
            const path_prop = path + '["' + key + '"]';
            if (typeof obj_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_prop + '" (at "' + path_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$i = 'RecordAvatarBulkMapRepresentation';
function normalize$d(input, existing, path, luvio, store, timestamp) {
    const input_keys = Object.keys(input);
    const input_length = input_keys.length;
    for (let i = 0; i < input_length; i++) {
        const key = input_keys[i];
        const input_prop = input[key];
        const input_prop_id = path.fullPath + '__' + key;
        input[key] = discriminatorIngest(input_prop, {
            fullPath: input_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
function equals$i(existing, incoming) {
    const equals_props = equalsObject(existing, incoming, (existing_prop, incoming_prop) => {
        if (!(existing_prop.__ref === incoming_prop.__ref)) {
            return false;
        }
    });
    if (equals_props === false) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$i(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$i,
        mergeable: false
    });
    const input__root = input;
    const input__root_keys = ObjectKeys(input__root);
    const input__root_length = input__root_keys.length;
    for (let i = 0; i < input__root_length; i++) {
        const key = input__root_keys[i];
        getTypeCacheKeys$j(rootKeySet, luvio, input__root[key], () => rootKey + "__" + key);
    }
}

function merge(existing, incoming, _luvio, _path) {
    if (existing === undefined) {
        return incoming;
    }
    // Merge RecordRepresentation field values together
    return {
        ...existing,
        ...incoming,
    };
}

const ingest$d = function RecordAvatarBulkMapRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$K(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const existingRecord = store.readEntry(key);
    let incomingRecord = normalize$d(input, store.readEntry(key), {
        fullPath: key,
        propertyName: path.propertyName,
        parent: path.parent,
    }, luvio, store, timestamp);
    incomingRecord = merge(existingRecord, incomingRecord);
    if (existingRecord === undefined || equals$i(existingRecord, incomingRecord) === false) {
        luvio.storePublish(key, incomingRecord);
    }
    return createLink(key);
};

function keyBuilder$N(luvio, params) {
    return keyPrefix + '::RecordAvatarBulkMapRepresentation:(' + 'formFactor:' + params.queryParams.formFactor + ',' + 'recordIds:' + params.urlParams.recordIds + ')';
}
function getResponseCacheKeys$r(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$i(storeKeyMap, luvio, response, () => keyBuilder$N(luvio, resourceParams));
}
function ingestError$f(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$N(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$d,
        namespace: keyPrefix,
        version: VERSION$i,
        representationName: RepresentationType$i
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$v(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/record-avatars/batch/' + config.urlParams.recordIds + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

// All of the avatars are ingested into
// the same top level object
const KEY = `${keyPrefix}RecordAvatarsBulk`;
function recordAvatarsFragment(recordIds) {
    return {
        kind: 'Fragment',
        private: [],
        version: VERSION$j,
        selections: recordIds.map((recordId) => {
            return {
                kind: 'Link',
                name: recordId,
                fragment: selectChildren(),
            };
        }),
    };
}
function recordAvatarsSelector(recordIds) {
    return {
        recordId: KEY,
        node: recordAvatarsFragment(recordIds),
        variables: {},
    };
}

function buildCachedSnapshot$3(luvio, config) {
    const { recordIds } = config;
    return luvio.storeLookup(recordAvatarsSelector(recordIds), {
        config,
        resolve: () => buildNetworkSnapshot$u(luvio, config, snapshotRefreshOptions),
    });
}

// Track in-flight xrequests so we known when to send out our fake response
const IN_FLIGHT_REQUESTS = new Set();
function getRecordIdsFlightStatus(recordIds, in_flight_requests) {
    const recordIdsNotInFlight = [], recordIdsInFlight = [];
    // Split up the given record ids into in flight ids and not in flight ids
    recordIds.forEach((id) => {
        if (in_flight_requests.has(id)) {
            recordIdsInFlight.push(id);
        }
        else {
            recordIdsNotInFlight.push(id);
        }
    });
    return {
        recordIdsInFlight: recordIdsInFlight,
        recordIdsNotInFlight: recordIdsNotInFlight,
    };
}
/**
 * TODO [W-8318817]: For 230/232 this is a workaround to not having inflight
 * deduping for record avatars.
 * The way it works is we ingest a fake response while the real response is pending.
 * So for example a component wires record avatars for ABC, while that request is in flight
 * another component wires record avatars AB. The wire for ABC will send off a request for data
 * Then AB comes in and will resolve the fake response instead of sending off a request.
 * Then once the real response comes back it will be ingested and it will notify both AB and ABC.
 * We will resolve this in 234 using real inflight deduping
 */
function ingestFakeResponse(luvio, recordIds) {
    const formatted = reduce.call(recordIds, (accum, recordId) => {
        accum[recordId] = {
            statusCode: 200,
            result: {
                backgroundColor: null,
                eTag: '',
                height: null,
                photoMetadata: { companyBluemasterId: null, responseId: null },
                photoUrl: '',
                provider: null,
                recordId: '',
                type: 'Photo',
                width: null,
            },
        };
        return accum;
    }, {});
    luvio.storeIngest(KEY, ingest$d, formatted);
}
function isRecordAvatarBulkMapRepresentation(response) {
    return response.body.hasErrors === undefined;
}
function buildNetworkSnapshot$u(luvio, config, options) {
    const { uncachedRecordIds, recordIds } = config;
    const { recordIdsInFlight, recordIdsNotInFlight } = getRecordIdsFlightStatus(uncachedRecordIds || recordIds, // If uncached records were specified, only get those, otherwise, get all of them
    IN_FLIGHT_REQUESTS);
    // For any remaining record ids send off the real request and add it to the in flight request list
    let luvioResponse;
    if (recordIdsNotInFlight.length > 0) {
        recordIdsNotInFlight.forEach((id) => IN_FLIGHT_REQUESTS.add(id));
        const resourceParams = createResourceParams$r({ ...config, recordIds: recordIdsNotInFlight });
        const request = createResourceRequest$v(resourceParams);
        luvioResponse = luvio
            .dispatchResourceRequest(request, options)
            .then((response) => {
            recordIdsNotInFlight.forEach((id) => IN_FLIGHT_REQUESTS.delete(id));
            // the selector passed to dispatchResourceRequest requests the data already formatted so the response
            // can either be a RecordAvatarBulkRepresentation or a RecordAvatarBulkMapRepresentation
            let formatted;
            if (isRecordAvatarBulkMapRepresentation(response)) {
                formatted = response.body;
            }
            else {
                formatted = response.body.results.reduce((seed, avatar, index) => {
                    const recordId = recordIdsNotInFlight[index];
                    seed[recordId] = avatar;
                    return seed;
                }, {});
            }
            response.body = formatted;
            return luvio.handleSuccessResponse(() => onFetchResponseSuccess$h(luvio, config, resourceParams, response), () => {
                const cache = new StoreKeyMap();
                getResponseCacheKeys$r(cache, luvio, resourceParams, formatted);
                return cache;
            });
        }, (err) => {
            recordIdsNotInFlight.forEach((id) => IN_FLIGHT_REQUESTS.delete(id));
            return luvio.handleErrorResponse(() => {
                return onFetchResponseError$h(luvio, config, resourceParams, err);
            });
        });
    }
    // For any currently in flight record ids lets emit a fake response
    if (recordIdsInFlight.length > 0) {
        ingestFakeResponse(luvio, recordIdsInFlight);
    }
    return luvioResponse ? luvioResponse : Promise.resolve(buildCachedSnapshot$3(luvio, config));
}

function ingestSuccess$l(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    luvio.storeIngest(KEY, ingest$d, body);
    let recordIds = [];
    if (snapshotRefresh) {
        recordIds = snapshotRefresh.config.recordIds;
    }
    const snapshot = luvio.storeLookup(recordAvatarsSelector(recordIds), snapshotRefresh);
    if (snapshot.state === 'Pending') {
        luvio.resolvePendingSnapshot(snapshot).then(() => {
            ingestSuccess$l(luvio, resourceParams, response, snapshotRefresh);
        });
        return Promise.resolve(snapshot);
    }
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    return Promise.resolve(snapshot);
}

function buildCachedSnapshotCachePolicy$j(context, storeLookup) {
    const { luvio, config } = context;
    const { recordIds } = config;
    const cachedSnapshot = storeLookup(recordAvatarsSelector(recordIds), {
        config,
        resolve: () => buildNetworkSnapshot$u(luvio, config, snapshotRefreshOptions),
    });
    // if the L1 lookup had some data but not all, then put the cache keys that were
    // missing onto the context, so buildNetworkSnapshotCachePolicy only requests
    // the missing records
    if (cachedSnapshot.data !== undefined && isUnfulfilledSnapshot(cachedSnapshot)) {
        context.uncachedRecordIds = cachedSnapshot.missingPaths.keysAsArray().sort();
    }
    return cachedSnapshot;
}

function buildNetworkSnapshotCachePolicy$k(context, coercedAdapterRequestContext) {
    const { luvio, config, uncachedRecordIds } = context;
    if (uncachedRecordIds !== undefined) {
        config.uncachedRecordIds = uncachedRecordIds;
    }
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$u(luvio, config, dispatchOptions);
}

const adapterName$p = 'getRecordAvatars';
const getRecordAvatars_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordIds', true, 0 /* UrlParameter */, 0 /* String */, true, getRecordId18Array),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
];
const getRecordAvatars_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$p, getRecordAvatars_ConfigPropertyMetadata);
const createResourceParams$r = /*#__PURE__*/ createResourceParams$13(getRecordAvatars_ConfigPropertyMetadata);
function typeCheckConfig$t(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordAvatars_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$s(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordAvatars_ConfigPropertyMetadata);
    const config = typeCheckConfig$t(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function onFetchResponseSuccess$h(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$l(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$u(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$h(luvio, config, resourceParams, response) {
    const snapshot = ingestError$f(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$u(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
const getRecordAvatarsAdapterFactory = (luvio) => function UiApi__getRecordAvatars(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$s(untrustedConfig, getRecordAvatars_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$j, buildNetworkSnapshotCachePolicy$k);
};

function coerceRecordId18Array(value) {
    const valueArray = ArrayIsArray$1(value) ? value : [value];
    const ret = [];
    for (let i = 0, len = valueArray.length; i < len; i += 1) {
        const item = valueArray[i];
        const coerced = getRecordId18(item);
        if (coerced === undefined) {
            return undefined;
        }
        ArrayPrototypePush.call(ret, coerced);
    }
    if (ret.length === 0) {
        return undefined;
    }
    return dedupe(ret);
}
function coerceConfig(config) {
    const coercedRecordsConfig = { records: [] };
    const { records: recordsFromConfig = [] } = config;
    for (let index = 0, len = recordsFromConfig.length; index < len; index += 1) {
        const coeredRecordConfig = {};
        const currentRecordBatch = recordsFromConfig[index];
        if (untrustedIsObject(currentRecordBatch)) {
            const recordIds = coerceRecordId18Array(currentRecordBatch.recordIds);
            if (recordIds !== undefined) {
                coeredRecordConfig.recordIds = recordIds;
            }
            const optionalFields = getFieldApiNamesArray(currentRecordBatch.optionalFields);
            if (optionalFields !== undefined) {
                coeredRecordConfig.optionalFields = optionalFields;
            }
            const fields = getFieldApiNamesArray(currentRecordBatch.fields);
            if (fields !== undefined) {
                coeredRecordConfig.fields = fields;
            }
            ArrayPrototypePush.call(coercedRecordsConfig.records, coeredRecordConfig);
        }
    }
    return coercedRecordsConfig;
}
function typeCheckConfig$s(untrustedConfig) {
    const coercedConfig = coerceConfig(untrustedConfig);
    const config = {};
    const untrustedConfigs_records = coercedConfig.records;
    if (ArrayIsArray$1(untrustedConfigs_records)) {
        const records = [];
        for (let index = 0, len = untrustedConfigs_records.length; index < len; index += 1) {
            const output_recordEntityConfig = {};
            const untrustedConfig_recordEntity = untrustedConfigs_records[index];
            if (untrustedIsObject(untrustedConfig_recordEntity)) {
                const { recordIds: untrustedConfig_recordIds, fields: untrustedConfig_fields, optionalFields: untrustedConfig_optionalFields, } = untrustedConfig_recordEntity;
                if (ArrayIsArray$1(untrustedConfig_recordIds)) {
                    const untrustedConfig_recordIds_array = [];
                    for (let i = 0, arrayLength = untrustedConfig_recordIds.length; i < arrayLength; i++) {
                        const untrustedConfig_recordIds_item = untrustedConfig_recordIds[i];
                        if (typeof untrustedConfig_recordIds_item === 'string') {
                            ArrayPrototypePush.call(untrustedConfig_recordIds_array, untrustedConfig_recordIds_item);
                        }
                    }
                    output_recordEntityConfig.recordIds = untrustedConfig_recordIds_array;
                }
                if (!output_recordEntityConfig.recordIds ||
                    output_recordEntityConfig.recordIds.length === 0) {
                    continue;
                }
                if (ArrayIsArray$1(untrustedConfig_fields)) {
                    const untrustedConfig_fields_array = [];
                    for (let i = 0, arrayLength = untrustedConfig_fields.length; i < arrayLength; i++) {
                        const untrustedConfig_fields_item = untrustedConfig_fields[i];
                        if (typeof untrustedConfig_fields_item === 'string') {
                            ArrayPrototypePush.call(untrustedConfig_fields_array, untrustedConfig_fields_item);
                        }
                    }
                    output_recordEntityConfig.fields = untrustedConfig_fields_array;
                }
                if (ArrayIsArray$1(untrustedConfig_optionalFields)) {
                    const untrustedConfig_optionalFields_array = [];
                    for (let i = 0, arrayLength = untrustedConfig_optionalFields.length; i < arrayLength; i++) {
                        const untrustedConfig_optionalFields_item = untrustedConfig_optionalFields[i];
                        if (typeof untrustedConfig_optionalFields_item === 'string') {
                            ArrayPrototypePush.call(untrustedConfig_optionalFields_array, untrustedConfig_optionalFields_item);
                        }
                    }
                    output_recordEntityConfig.optionalFields = untrustedConfig_optionalFields_array;
                }
                if (output_recordEntityConfig.fields === undefined &&
                    output_recordEntityConfig.optionalFields === undefined) {
                    continue;
                }
                ArrayPrototypePush.call(records, output_recordEntityConfig);
            }
        }
        if (records.length > 0) {
            assign(config, { records });
        }
    }
    return config;
}

function checkFieldsObjectApiName(fields, apiName) {
    return fields.every((field) => splitQualifiedFieldApiName(field)[0] === apiName);
}
function getObjectApiName(fields, optionalFields) {
    if (fields === undefined || fields.length === 0) {
        return splitQualifiedFieldApiName(optionalFields[0])[0];
    }
    return splitQualifiedFieldApiName(fields[0])[0];
}
function validateFieldsObjectApiName(config) {
    const configRecords = config.records;
    for (let index = 0, len = configRecords.length; index < len; index++) {
        const { fields: configRecordEntityFields, optionalFields: configRecordEntityOptionalFields, } = configRecords[index];
        const objectApiName = getObjectApiName(configRecordEntityFields, configRecordEntityOptionalFields);
        // check objectApiName of fields and optionalFields array
        if ((configRecordEntityFields !== undefined &&
            !checkFieldsObjectApiName(configRecordEntityFields, objectApiName)) ||
            (configRecordEntityOptionalFields !== undefined &&
                !checkFieldsObjectApiName(configRecordEntityOptionalFields, objectApiName))) {
            throw new TypeError(`all specified fields and optional fields must be of same ObjectApiName as ${objectApiName}`);
        }
    }
}
function validateAdapterConfig$r(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$s(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    // If we have made it this far, our config is validated and type checked
    if (process.env.NODE_ENV !== 'production') {
        validateFieldsObjectApiName(config);
    }
    return config;
}

const getRecords_ConfigPropertyNames = {
    displayName: 'getRecords',
    parameters: {
        required: ['records'],
        optional: [],
    },
};

const adapterName$o = 'getRecords';
function keyBuilder$M(luvio, config) {
    const resourceParams = createResourceParams$11(config);
    return keyBuilder$27(luvio, resourceParams);
}
function onFetchResponseError$g(luvio, config, resourceParams, response) {
    const snapshot = ingestError$L(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$t(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$t(luvio, config, options) {
    const resourceParams = createResourceParams$11(config);
    const request = createResourceRequest$1b(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$N(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$11(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$g(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$j(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$t, undefined, false);
}
function buildCachedSnapshotCachePolicy$i(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$M(luvio, config),
        node: adapterFragment$J(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$t(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRecordsAdapterFactory = (luvio) => function UiApi__getRecords(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$r(untrustedConfig, getRecords_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$i, buildNetworkSnapshotCachePolicy$j);
};

const VERSION$h = "4d4bdab5d0aa61e365e766409c9b3a31";
function validate$J(obj, path = 'RelatedListReferenceRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        let obj_id_union0 = null;
        const obj_id_union0_error = (() => {
            if (typeof obj_id !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union0_error != null) {
            obj_id_union0 = obj_id_union0_error.message;
        }
        let obj_id_union1 = null;
        const obj_id_union1_error = (() => {
            if (obj_id !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
            }
        })();
        if (obj_id_union1_error != null) {
            obj_id_union1 = obj_id_union1_error.message;
        }
        if (obj_id_union0 && obj_id_union1) {
            let message = 'Object doesn\'t match union (at "' + path_id + '")';
            message += '\n' + obj_id_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_id_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_inContextOfRecordId = obj.inContextOfRecordId;
        const path_inContextOfRecordId = path + '.inContextOfRecordId';
        let obj_inContextOfRecordId_union0 = null;
        const obj_inContextOfRecordId_union0_error = (() => {
            if (typeof obj_inContextOfRecordId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_inContextOfRecordId + '" (at "' + path_inContextOfRecordId + '")');
            }
        })();
        if (obj_inContextOfRecordId_union0_error != null) {
            obj_inContextOfRecordId_union0 = obj_inContextOfRecordId_union0_error.message;
        }
        let obj_inContextOfRecordId_union1 = null;
        const obj_inContextOfRecordId_union1_error = (() => {
            if (obj_inContextOfRecordId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_inContextOfRecordId + '" (at "' + path_inContextOfRecordId + '")');
            }
        })();
        if (obj_inContextOfRecordId_union1_error != null) {
            obj_inContextOfRecordId_union1 = obj_inContextOfRecordId_union1_error.message;
        }
        if (obj_inContextOfRecordId_union0 && obj_inContextOfRecordId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_inContextOfRecordId + '")';
            message += '\n' + obj_inContextOfRecordId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_inContextOfRecordId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_listViewApiName = obj.listViewApiName;
        const path_listViewApiName = path + '.listViewApiName';
        let obj_listViewApiName_union0 = null;
        const obj_listViewApiName_union0_error = (() => {
            if (typeof obj_listViewApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_listViewApiName + '" (at "' + path_listViewApiName + '")');
            }
        })();
        if (obj_listViewApiName_union0_error != null) {
            obj_listViewApiName_union0 = obj_listViewApiName_union0_error.message;
        }
        let obj_listViewApiName_union1 = null;
        const obj_listViewApiName_union1_error = (() => {
            if (obj_listViewApiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_listViewApiName + '" (at "' + path_listViewApiName + '")');
            }
        })();
        if (obj_listViewApiName_union1_error != null) {
            obj_listViewApiName_union1 = obj_listViewApiName_union1_error.message;
        }
        if (obj_listViewApiName_union0 && obj_listViewApiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_listViewApiName + '")';
            message += '\n' + obj_listViewApiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_listViewApiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        let obj_objectApiName_union0 = null;
        const obj_objectApiName_union0_error = (() => {
            if (typeof obj_objectApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
            }
        })();
        if (obj_objectApiName_union0_error != null) {
            obj_objectApiName_union0 = obj_objectApiName_union0_error.message;
        }
        let obj_objectApiName_union1 = null;
        const obj_objectApiName_union1_error = (() => {
            if (obj_objectApiName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
            }
        })();
        if (obj_objectApiName_union1_error != null) {
            obj_objectApiName_union1 = obj_objectApiName_union1_error.message;
        }
        if (obj_objectApiName_union0 && obj_objectApiName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_objectApiName + '")';
            message += '\n' + obj_objectApiName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_objectApiName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_parentObjectApiName = obj.parentObjectApiName;
        const path_parentObjectApiName = path + '.parentObjectApiName';
        if (typeof obj_parentObjectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_parentObjectApiName + '" (at "' + path_parentObjectApiName + '")');
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        let obj_recordTypeId_union0 = null;
        const obj_recordTypeId_union0_error = (() => {
            if (typeof obj_recordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union0_error != null) {
            obj_recordTypeId_union0 = obj_recordTypeId_union0_error.message;
        }
        let obj_recordTypeId_union1 = null;
        const obj_recordTypeId_union1_error = (() => {
            if (obj_recordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union1_error != null) {
            obj_recordTypeId_union1 = obj_recordTypeId_union1_error.message;
        }
        if (obj_recordTypeId_union0 && obj_recordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeId + '")';
            message += '\n' + obj_recordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_relatedListId = obj.relatedListId;
        const path_relatedListId = path + '.relatedListId';
        if (typeof obj_relatedListId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_relatedListId + '" (at "' + path_relatedListId + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const select$v = function RelatedListReferenceRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$h,
        private: [],
        selections: [
            {
                name: 'id',
                kind: 'Scalar'
            },
            {
                name: 'inContextOfRecordId',
                kind: 'Scalar'
            },
            {
                name: 'listViewApiName',
                kind: 'Scalar'
            },
            {
                name: 'objectApiName',
                kind: 'Scalar'
            },
            {
                name: 'parentObjectApiName',
                kind: 'Scalar'
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'relatedListId',
                kind: 'Scalar'
            },
            {
                name: 'type',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$h(existing, incoming) {
    const existing_parentObjectApiName = existing.parentObjectApiName;
    const incoming_parentObjectApiName = incoming.parentObjectApiName;
    if (!(existing_parentObjectApiName === incoming_parentObjectApiName)) {
        return false;
    }
    const existing_relatedListId = existing.relatedListId;
    const incoming_relatedListId = incoming.relatedListId;
    if (!(existing_relatedListId === incoming_relatedListId)) {
        return false;
    }
    const existing_type = existing.type;
    const incoming_type = incoming.type;
    if (!(existing_type === incoming_type)) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_inContextOfRecordId = existing.inContextOfRecordId;
    const incoming_inContextOfRecordId = incoming.inContextOfRecordId;
    if (!(existing_inContextOfRecordId === incoming_inContextOfRecordId)) {
        return false;
    }
    const existing_listViewApiName = existing.listViewApiName;
    const incoming_listViewApiName = incoming.listViewApiName;
    if (!(existing_listViewApiName === incoming_listViewApiName)) {
        return false;
    }
    const existing_objectApiName = existing.objectApiName;
    const incoming_objectApiName = incoming.objectApiName;
    if (!(existing_objectApiName === incoming_objectApiName)) {
        return false;
    }
    const existing_recordTypeId = existing.recordTypeId;
    const incoming_recordTypeId = incoming.recordTypeId;
    if (!(existing_recordTypeId === incoming_recordTypeId)) {
        return false;
    }
    return true;
}

const VERSION$g = "836b875b519813e7499efc62f0f1d04b";
function validate$I(obj, path = 'RelatedListRecordCountRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_count = obj.count;
        const path_count = path + '.count';
        let obj_count_union0 = null;
        const obj_count_union0_error = (() => {
            if (typeof obj_count !== 'number' || (typeof obj_count === 'number' && Math.floor(obj_count) !== obj_count)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_count + '" (at "' + path_count + '")');
            }
        })();
        if (obj_count_union0_error != null) {
            obj_count_union0 = obj_count_union0_error.message;
        }
        let obj_count_union1 = null;
        const obj_count_union1_error = (() => {
            if (obj_count !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_count + '" (at "' + path_count + '")');
            }
        })();
        if (obj_count_union1_error != null) {
            obj_count_union1 = obj_count_union1_error.message;
        }
        if (obj_count_union0 && obj_count_union1) {
            let message = 'Object doesn\'t match union (at "' + path_count + '")';
            message += '\n' + obj_count_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_count_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_hasMore = obj.hasMore;
        const path_hasMore = path + '.hasMore';
        if (typeof obj_hasMore !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_hasMore + '" (at "' + path_hasMore + '")');
        }
        const obj_listReference = obj.listReference;
        const path_listReference = path + '.listReference';
        const referencepath_listReferenceValidationError = validate$J(obj_listReference, path_listReference);
        if (referencepath_listReferenceValidationError !== null) {
            let message = 'Object doesn\'t match RelatedListReferenceRepresentation (at "' + path_listReference + '")\n';
            message += referencepath_listReferenceValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$h = 'RelatedListRecordCountRepresentation';
function keyBuilder$L(luvio, config) {
    return keyPrefix + '::' + RepresentationType$h + ':' + (config.parentRecordId === null ? '' : config.parentRecordId) + ':' + config.relatedListId;
}
function keyBuilderFromType$e(luvio, object) {
    const keyParams = {
        parentRecordId: object.listReference.inContextOfRecordId,
        relatedListId: object.listReference.relatedListId
    };
    return keyBuilder$L(luvio, keyParams);
}
function normalize$c(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$u = function RelatedListRecordCountRepresentationSelect() {
    const { selections: RelatedListReferenceRepresentation__selections, opaque: RelatedListReferenceRepresentation__opaque, } = select$v();
    return {
        kind: 'Fragment',
        version: VERSION$g,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'count',
                kind: 'Scalar'
            },
            {
                name: 'hasMore',
                kind: 'Scalar'
            },
            {
                name: 'listReference',
                kind: 'Object',
                selections: RelatedListReferenceRepresentation__selections
            }
        ]
    };
};
function equals$g(existing, incoming) {
    const existing_hasMore = existing.hasMore;
    const incoming_hasMore = incoming.hasMore;
    if (!(existing_hasMore === incoming_hasMore)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_count = existing.count;
    const incoming_count = incoming.count;
    if (!(existing_count === incoming_count)) {
        return false;
    }
    const existing_listReference = existing.listReference;
    const incoming_listReference = incoming.listReference;
    if (!(equals$h(existing_listReference, incoming_listReference))) {
        return false;
    }
    return true;
}
const ingest$c = function RelatedListRecordCountRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$I(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$e(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$c, "UiApi", VERSION$g, RepresentationType$h, equals$g);
    return createLink(key);
};
function getTypeCacheKeys$h(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$e(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$h,
        mergeable: false
    });
}

function select$t(luvio, params) {
    return select$u();
}
function keyBuilder$K(luvio, params) {
    return keyBuilder$L(luvio, {
        parentRecordId: params.urlParams.parentRecordId,
        relatedListId: params.urlParams.relatedListId
    });
}
function getResponseCacheKeys$q(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$h(storeKeyMap, luvio, response);
}
function ingestSuccess$k(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$K(luvio, resourceParams);
    luvio.storeIngest(key, ingest$c, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$t(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$e(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$K(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$u(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-count/' + config.urlParams.parentRecordId + '/' + config.urlParams.relatedListId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const nonCachedErrors$3 = ObjectCreate$1(null);
function createChildResourceParams$4(resourceParams) {
    let childConfigs = [];
    for (let index = 0, len = resourceParams.urlParams.relatedListNames.length; index < len; index += 1) {
        const item = resourceParams.urlParams.relatedListNames[index];
        childConfigs.push({
            urlParams: {
                parentRecordId: resourceParams.urlParams.parentRecordId,
                relatedListId: item
            },
            queryParams: {
                maxCount: resourceParams.queryParams.maxCount
            }
        });
    }
    return childConfigs;
}
function selectChildResourceParams$3(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$J(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$K(luvio, childResource);
                const childFragment = select$t();
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$3[childKey];
                            if (nonCachedError === undefined) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$s(luvio, resourceParams) {
    const childResources = createChildResourceParams$4(resourceParams);
    return selectChildResourceParams$3(luvio, childResources, resourceParams);
}
function keyBuilder$J(luvio, params) {
    return keyPrefix + '::BatchRelatedListCountRepresentation:(' + 'maxCount:' + params.queryParams.maxCount + ',' + 'parentRecordId:' + params.urlParams.parentRecordId + ',' + 'relatedListNames:' + params.urlParams.relatedListNames + ')';
}
function getResponseCacheKeys$p(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$4(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$q(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$K(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$h,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$4(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$K(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$k(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$e(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$3[childKey] = { response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors$3[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$j(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$4(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$J(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$4(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$s(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$d(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$J(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$t(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-count/batch/' + config.urlParams.parentRecordId + '/' + config.urlParams.relatedListNames + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$n = 'getRelatedListsCount';
const getRelatedListsCount_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentRecordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('relatedListNames', true, 0 /* UrlParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('maxCount', false, 1 /* QueryParameter */, 3 /* Integer */),
];
const getRelatedListsCount_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$n, getRelatedListsCount_ConfigPropertyMetadata);
const createResourceParams$q = /*#__PURE__*/ createResourceParams$13(getRelatedListsCount_ConfigPropertyMetadata);
function keyBuilder$I(luvio, config) {
    const resourceParams = createResourceParams$q(config);
    return keyBuilder$J(luvio, resourceParams);
}
function typeCheckConfig$r(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListsCount_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$q(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListsCount_ConfigPropertyMetadata);
    const config = typeCheckConfig$r(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$f(luvio, config) {
    const resourceParams = createResourceParams$q(config);
    return select$s(luvio, resourceParams);
}
function onFetchResponseSuccess$g(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$j(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$s(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$f(luvio, config, resourceParams, response) {
    const snapshot = ingestError$d(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$s(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$s(luvio, config, options) {
    const resourceParams = createResourceParams$q(config);
    const request = createResourceRequest$t(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$g(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$p(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$f(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$i(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$s, undefined, false);
}
function buildCachedSnapshotCachePolicy$h(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$I(luvio, config),
        node: adapterFragment$f(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$s(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListsCountAdapterFactory = (luvio) => function UiApi__getRelatedListsCount(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$q(untrustedConfig, getRelatedListsCount_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$h, buildNetworkSnapshotCachePolicy$i);
};

const adapterName$m = 'getRelatedListCount';
const getRelatedListCount_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentRecordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('relatedListId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('maxCount', false, 1 /* QueryParameter */, 3 /* Integer */),
];
const getRelatedListCount_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$m, getRelatedListCount_ConfigPropertyMetadata);
const createResourceParams$p = /*#__PURE__*/ createResourceParams$13(getRelatedListCount_ConfigPropertyMetadata);
function keyBuilder$H(luvio, config) {
    const resourceParams = createResourceParams$p(config);
    return keyBuilder$K(luvio, resourceParams);
}
function typeCheckConfig$q(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListCount_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$p(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListCount_ConfigPropertyMetadata);
    const config = typeCheckConfig$q(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$e(luvio, config) {
    createResourceParams$p(config);
    return select$t();
}
function onFetchResponseSuccess$f(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$k(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$r(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$e(luvio, config, resourceParams, response) {
    const snapshot = ingestError$e(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$r(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$r(luvio, config, options) {
    const resourceParams = createResourceParams$p(config);
    const request = createResourceRequest$u(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$f(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$q(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$e(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$h(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$r, undefined, false);
}
function buildCachedSnapshotCachePolicy$g(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$H(luvio, config),
        node: adapterFragment$e(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$r(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListCountAdapterFactory = (luvio) => function UiApi__getRelatedListCount(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$p(untrustedConfig, getRelatedListCount_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$g, buildNetworkSnapshotCachePolicy$h);
};

function validate$H(obj, path = 'RelatedListColumnRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_dataType = obj.dataType;
        const path_dataType = path + '.dataType';
        let obj_dataType_union0 = null;
        const obj_dataType_union0_error = (() => {
            if (typeof obj_dataType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
            }
        })();
        if (obj_dataType_union0_error != null) {
            obj_dataType_union0 = obj_dataType_union0_error.message;
        }
        let obj_dataType_union1 = null;
        const obj_dataType_union1_error = (() => {
            if (obj_dataType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_dataType + '" (at "' + path_dataType + '")');
            }
        })();
        if (obj_dataType_union1_error != null) {
            obj_dataType_union1 = obj_dataType_union1_error.message;
        }
        if (obj_dataType_union0 && obj_dataType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_dataType + '")';
            message += '\n' + obj_dataType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_dataType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_filterable = obj.filterable;
        const path_filterable = path + '.filterable';
        let obj_filterable_union0 = null;
        const obj_filterable_union0_error = (() => {
            if (typeof obj_filterable !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_filterable + '" (at "' + path_filterable + '")');
            }
        })();
        if (obj_filterable_union0_error != null) {
            obj_filterable_union0 = obj_filterable_union0_error.message;
        }
        let obj_filterable_union1 = null;
        const obj_filterable_union1_error = (() => {
            if (obj_filterable !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_filterable + '" (at "' + path_filterable + '")');
            }
        })();
        if (obj_filterable_union1_error != null) {
            obj_filterable_union1 = obj_filterable_union1_error.message;
        }
        if (obj_filterable_union0 && obj_filterable_union1) {
            let message = 'Object doesn\'t match union (at "' + path_filterable + '")';
            message += '\n' + obj_filterable_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_filterable_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_lookupId = obj.lookupId;
        const path_lookupId = path + '.lookupId';
        let obj_lookupId_union0 = null;
        const obj_lookupId_union0_error = (() => {
            if (typeof obj_lookupId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lookupId + '" (at "' + path_lookupId + '")');
            }
        })();
        if (obj_lookupId_union0_error != null) {
            obj_lookupId_union0 = obj_lookupId_union0_error.message;
        }
        let obj_lookupId_union1 = null;
        const obj_lookupId_union1_error = (() => {
            if (obj_lookupId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lookupId + '" (at "' + path_lookupId + '")');
            }
        })();
        if (obj_lookupId_union1_error != null) {
            obj_lookupId_union1 = obj_lookupId_union1_error.message;
        }
        if (obj_lookupId_union0 && obj_lookupId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lookupId + '")';
            message += '\n' + obj_lookupId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lookupId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_picklistValues = obj.picklistValues;
        const path_picklistValues = path + '.picklistValues';
        if (!ArrayIsArray(obj_picklistValues)) {
            return new TypeError('Expected "array" but received "' + typeof obj_picklistValues + '" (at "' + path_picklistValues + '")');
        }
        for (let i = 0; i < obj_picklistValues.length; i++) {
            const obj_picklistValues_item = obj_picklistValues[i];
            const path_picklistValues_item = path_picklistValues + '[' + i + ']';
            if (typeof obj_picklistValues_item !== 'object' || ArrayIsArray(obj_picklistValues_item) || obj_picklistValues_item === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_picklistValues_item + '" (at "' + path_picklistValues_item + '")');
            }
            const obj_picklistValues_item_keys = ObjectKeys(obj_picklistValues_item);
            for (let i = 0; i < obj_picklistValues_item_keys.length; i++) {
                const key = obj_picklistValues_item_keys[i];
                const obj_picklistValues_item_prop = obj_picklistValues_item[key];
                const path_picklistValues_item_prop = path_picklistValues_item + '["' + key + '"]';
                if (typeof obj_picklistValues_item_prop !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_picklistValues_item_prop + '" (at "' + path_picklistValues_item_prop + '")');
                }
            }
        }
        const obj_quickFilterOperator = obj.quickFilterOperator;
        const path_quickFilterOperator = path + '.quickFilterOperator';
        let obj_quickFilterOperator_union0 = null;
        const obj_quickFilterOperator_union0_error = (() => {
            if (typeof obj_quickFilterOperator !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_quickFilterOperator + '" (at "' + path_quickFilterOperator + '")');
            }
        })();
        if (obj_quickFilterOperator_union0_error != null) {
            obj_quickFilterOperator_union0 = obj_quickFilterOperator_union0_error.message;
        }
        let obj_quickFilterOperator_union1 = null;
        const obj_quickFilterOperator_union1_error = (() => {
            if (obj_quickFilterOperator !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_quickFilterOperator + '" (at "' + path_quickFilterOperator + '")');
            }
        })();
        if (obj_quickFilterOperator_union1_error != null) {
            obj_quickFilterOperator_union1 = obj_quickFilterOperator_union1_error.message;
        }
        if (obj_quickFilterOperator_union0 && obj_quickFilterOperator_union1) {
            let message = 'Object doesn\'t match union (at "' + path_quickFilterOperator + '")';
            message += '\n' + obj_quickFilterOperator_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_quickFilterOperator_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_sortable = obj.sortable;
        const path_sortable = path + '.sortable';
        if (typeof obj_sortable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_sortable + '" (at "' + path_sortable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$c = 900000;
const VERSION$f = "c977d65d153a2b4e888ddd45fb083248";
function validate$G(obj, path = 'RelatedListInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_cloneable = obj.cloneable;
        const path_cloneable = path + '.cloneable';
        if (typeof obj_cloneable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_cloneable + '" (at "' + path_cloneable + '")');
        }
        const obj_createable = obj.createable;
        const path_createable = path + '.createable';
        if (typeof obj_createable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_createable + '" (at "' + path_createable + '")');
        }
        const obj_deletable = obj.deletable;
        const path_deletable = path + '.deletable';
        if (typeof obj_deletable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_deletable + '" (at "' + path_deletable + '")');
        }
        const obj_displayColumns = obj.displayColumns;
        const path_displayColumns = path + '.displayColumns';
        if (!ArrayIsArray(obj_displayColumns)) {
            return new TypeError('Expected "array" but received "' + typeof obj_displayColumns + '" (at "' + path_displayColumns + '")');
        }
        for (let i = 0; i < obj_displayColumns.length; i++) {
            const obj_displayColumns_item = obj_displayColumns[i];
            const path_displayColumns_item = path_displayColumns + '[' + i + ']';
            const referencepath_displayColumns_itemValidationError = validate$H(obj_displayColumns_item, path_displayColumns_item);
            if (referencepath_displayColumns_itemValidationError !== null) {
                let message = 'Object doesn\'t match RelatedListColumnRepresentation (at "' + path_displayColumns_item + '")\n';
                message += referencepath_displayColumns_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (!ArrayIsArray(obj_fields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        for (let i = 0; i < obj_fields.length; i++) {
            const obj_fields_item = obj_fields[i];
            const path_fields_item = path_fields + '[' + i + ']';
            if (typeof obj_fields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_fields_item + '" (at "' + path_fields_item + '")');
            }
        }
        const obj_filterLogicString = obj.filterLogicString;
        const path_filterLogicString = path + '.filterLogicString';
        if (typeof obj_filterLogicString !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_filterLogicString + '" (at "' + path_filterLogicString + '")');
        }
        const obj_filterable = obj.filterable;
        const path_filterable = path + '.filterable';
        if (typeof obj_filterable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_filterable + '" (at "' + path_filterable + '")');
        }
        const obj_filteredByInfo = obj.filteredByInfo;
        const path_filteredByInfo = path + '.filteredByInfo';
        if (!ArrayIsArray(obj_filteredByInfo)) {
            return new TypeError('Expected "array" but received "' + typeof obj_filteredByInfo + '" (at "' + path_filteredByInfo + '")');
        }
        for (let i = 0; i < obj_filteredByInfo.length; i++) {
            const obj_filteredByInfo_item = obj_filteredByInfo[i];
            const path_filteredByInfo_item = path_filteredByInfo + '[' + i + ']';
            const referencepath_filteredByInfo_itemValidationError = validate$2b(obj_filteredByInfo_item, path_filteredByInfo_item);
            if (referencepath_filteredByInfo_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListFilterByInfoRepresentation (at "' + path_filteredByInfo_item + '")\n';
                message += referencepath_filteredByInfo_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_listReference = obj.listReference;
        const path_listReference = path + '.listReference';
        const referencepath_listReferenceValidationError = validate$J(obj_listReference, path_listReference);
        if (referencepath_listReferenceValidationError !== null) {
            let message = 'Object doesn\'t match RelatedListReferenceRepresentation (at "' + path_listReference + '")\n';
            message += referencepath_listReferenceValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiNames = obj.objectApiNames;
        const path_objectApiNames = path + '.objectApiNames';
        if (!ArrayIsArray(obj_objectApiNames)) {
            return new TypeError('Expected "array" but received "' + typeof obj_objectApiNames + '" (at "' + path_objectApiNames + '")');
        }
        for (let i = 0; i < obj_objectApiNames.length; i++) {
            const obj_objectApiNames_item = obj_objectApiNames[i];
            const path_objectApiNames_item = path_objectApiNames + '[' + i + ']';
            if (typeof obj_objectApiNames_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectApiNames_item + '" (at "' + path_objectApiNames_item + '")');
            }
        }
        const obj_optionalFields = obj.optionalFields;
        const path_optionalFields = path + '.optionalFields';
        if (!ArrayIsArray(obj_optionalFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_optionalFields + '" (at "' + path_optionalFields + '")');
        }
        for (let i = 0; i < obj_optionalFields.length; i++) {
            const obj_optionalFields_item = obj_optionalFields[i];
            const path_optionalFields_item = path_optionalFields + '[' + i + ']';
            if (typeof obj_optionalFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_optionalFields_item + '" (at "' + path_optionalFields_item + '")');
            }
        }
        const obj_orderedByInfo = obj.orderedByInfo;
        const path_orderedByInfo = path + '.orderedByInfo';
        if (!ArrayIsArray(obj_orderedByInfo)) {
            return new TypeError('Expected "array" but received "' + typeof obj_orderedByInfo + '" (at "' + path_orderedByInfo + '")');
        }
        for (let i = 0; i < obj_orderedByInfo.length; i++) {
            const obj_orderedByInfo_item = obj_orderedByInfo[i];
            const path_orderedByInfo_item = path_orderedByInfo + '[' + i + ']';
            const referencepath_orderedByInfo_itemValidationError = validate$26(obj_orderedByInfo_item, path_orderedByInfo_item);
            if (referencepath_orderedByInfo_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListOrderByInfoRepresentation (at "' + path_orderedByInfo_item + '")\n';
                message += referencepath_orderedByInfo_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_restrictColumnsToLayout = obj.restrictColumnsToLayout;
        const path_restrictColumnsToLayout = path + '.restrictColumnsToLayout';
        if (typeof obj_restrictColumnsToLayout !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_restrictColumnsToLayout + '" (at "' + path_restrictColumnsToLayout + '")');
        }
        const obj_updateable = obj.updateable;
        const path_updateable = path + '.updateable';
        if (typeof obj_updateable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_updateable + '" (at "' + path_updateable + '")');
        }
        const obj_userPreferences = obj.userPreferences;
        const path_userPreferences = path + '.userPreferences';
        const referencepath_userPreferencesValidationError = validate$22(obj_userPreferences, path_userPreferences);
        if (referencepath_userPreferencesValidationError !== null) {
            let message = 'Object doesn\'t match ListUserPreferenceRepresentation (at "' + path_userPreferences + '")\n';
            message += referencepath_userPreferencesValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_visibility = obj.visibility;
        const path_visibility = path + '.visibility';
        if (typeof obj_visibility !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_visibility + '" (at "' + path_visibility + '")');
        }
        const obj_visibilityEditable = obj.visibilityEditable;
        const path_visibilityEditable = path + '.visibilityEditable';
        if (typeof obj_visibilityEditable !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_visibilityEditable + '" (at "' + path_visibilityEditable + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$g = 'RelatedListInfoRepresentation';
function keyBuilder$G(luvio, config) {
    return keyPrefix + '::' + RepresentationType$g + ':' + config.relatedListId + ':' + config.parentObjectApiName + ':' + config.restrictColumnsToLayout + ':' + (config.recordTypeId === null ? '' : config.recordTypeId) + ':' + '[' + config.optionalFields.join(',') + ']' + ':' + '[' + config.fields.join(',') + ']';
}
function keyBuilderFromType$d(luvio, object) {
    const keyParams = {
        relatedListId: object.listReference.relatedListId,
        parentObjectApiName: object.listReference.parentObjectApiName,
        restrictColumnsToLayout: object.restrictColumnsToLayout,
        recordTypeId: object.listReference.recordTypeId,
        optionalFields: object.optionalFields,
        fields: object.fields
    };
    return keyBuilder$G(luvio, keyParams);
}
function normalize$b(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$r = function RelatedListInfoRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$f,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'cloneable',
                kind: 'Scalar'
            },
            {
                name: 'createable',
                kind: 'Scalar'
            },
            {
                name: 'deletable',
                kind: 'Scalar'
            },
            {
                name: 'displayColumns',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'fieldApiName',
                kind: 'Scalar'
            },
            {
                name: 'fields',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'filterLogicString',
                kind: 'Scalar'
            },
            {
                name: 'filterable',
                kind: 'Scalar'
            },
            {
                name: 'filteredByInfo',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'label',
                kind: 'Scalar'
            },
            {
                name: 'listReference',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'objectApiNames',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'optionalFields',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'orderedByInfo',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'restrictColumnsToLayout',
                kind: 'Scalar'
            },
            {
                name: 'updateable',
                kind: 'Scalar'
            },
            {
                name: 'userPreferences',
                kind: 'Object',
                opaque: true
            },
            {
                name: 'visibility',
                kind: 'Scalar'
            },
            {
                name: 'visibilityEditable',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$f(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$b = function RelatedListInfoRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$G(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$d(luvio, input);
    const ttlToUse = TTL$c;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$b, "UiApi", VERSION$f, RepresentationType$g, equals$f);
    return createLink(key);
};
function getTypeCacheKeys$g(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$d(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$g,
        mergeable: false
    });
}

function select$q(luvio, params) {
    return select$r();
}
function keyBuilder$F(luvio, params) {
    return keyBuilder$G(luvio, {
        relatedListId: params.urlParams.relatedListId,
        parentObjectApiName: params.urlParams.parentObjectApiName,
        restrictColumnsToLayout: params.queryParams.restrictColumnsToLayout === false ? false : true,
        recordTypeId: params.queryParams.recordTypeId || null,
        optionalFields: params.queryParams.optionalFields || [],
        fields: params.queryParams.fields || []
    });
}
function getResponseCacheKeys$o(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$g(storeKeyMap, luvio, response);
}
function ingestSuccess$i(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$F(luvio, resourceParams);
    luvio.storeIngest(key, ingest$b, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$q(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$c(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$F(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$c,
        namespace: keyPrefix,
        version: VERSION$f,
        representationName: RepresentationType$g
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$s(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-info/' + config.urlParams.parentObjectApiName + '/' + config.urlParams.relatedListId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function createChildResourceParams$3(resourceParams) {
    const childConfigs = [];
    for (let index = 0, len = resourceParams.urlParams.relatedListNames.length; index < len; index += 1) {
        const item = resourceParams.urlParams.relatedListNames[index];
        childConfigs.push({
            urlParams: {
                parentObjectApiName: resourceParams.urlParams.parentObjectApiName,
                relatedListId: item,
            },
            queryParams: {
                recordTypeId: resourceParams.queryParams.recordTypeId,
                fields: [],
                optionalFields: [],
                restrictColumnsToLayout: true,
            },
        });
    }
    return childConfigs;
}

const nonCachedErrors$2 = ObjectCreate$1(null);
function selectChildResourceParams$2(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$E(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$F(luvio, childResource);
                const childFragment = select$q();
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$2[childKey];
                            if (nonCachedError === undefined || nonCachedError.expiration < reader.getTimeStamp()) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$p(luvio, resourceParams) {
    const childResources = createChildResourceParams$3(resourceParams);
    return selectChildResourceParams$2(luvio, childResources, resourceParams);
}
function keyBuilder$E(luvio, params) {
    return keyPrefix + '::RelatedListInfoBatchRepresentation:(' + 'recordTypeId:' + params.queryParams.recordTypeId + ',' + 'parentObjectApiName:' + params.urlParams.parentObjectApiName + ',' + 'relatedListNames:' + params.urlParams.relatedListNames + ')';
}
function getResponseCacheKeys$n(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$3(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$o(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$F(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$g,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$3(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$F(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$i(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$c(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$2[childKey] = { expiration: now + TTL$c, response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors$2[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$h(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$3(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$E(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$3(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$p(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$b(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$E(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$r(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-info/batch/' + config.urlParams.parentObjectApiName + '/' + config.urlParams.relatedListNames + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$l = 'getRelatedListInfoBatch';
const getRelatedListInfoBatch_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentObjectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('relatedListNames', true, 0 /* UrlParameter */, 0 /* String */, true),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getRelatedListInfoBatch_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$l, getRelatedListInfoBatch_ConfigPropertyMetadata);
const createResourceParams$o = /*#__PURE__*/ createResourceParams$13(getRelatedListInfoBatch_ConfigPropertyMetadata);
function keyBuilder$D(luvio, config) {
    const resourceParams = createResourceParams$o(config);
    return keyBuilder$E(luvio, resourceParams);
}
function typeCheckConfig$p(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListInfoBatch_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$o(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListInfoBatch_ConfigPropertyMetadata);
    const config = typeCheckConfig$p(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$d(luvio, config) {
    const resourceParams = createResourceParams$o(config);
    return select$p(luvio, resourceParams);
}
function onFetchResponseSuccess$e(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$h(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$q(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$d(luvio, config, resourceParams, response) {
    const snapshot = ingestError$b(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$q(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$q(luvio, config, options) {
    const resourceParams = createResourceParams$o(config);
    const request = createResourceRequest$r(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$e(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$n(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$d(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$g(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$q, undefined, false);
}
function buildCachedSnapshotCachePolicy$f(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$D(luvio, config),
        node: adapterFragment$d(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$q(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListInfoBatchAdapterFactory = (luvio) => function UiApi__getRelatedListInfoBatch(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$o(untrustedConfig, getRelatedListInfoBatch_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$f, buildNetworkSnapshotCachePolicy$g);
};

function validate$F(obj, path = 'RelatedListSummaryInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_entityLabel = obj.entityLabel;
        const path_entityLabel = path + '.entityLabel';
        if (typeof obj_entityLabel !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_entityLabel + '" (at "' + path_entityLabel + '")');
        }
        const obj_entityPluralLabel = obj.entityPluralLabel;
        const path_entityPluralLabel = path + '.entityPluralLabel';
        if (typeof obj_entityPluralLabel !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_entityPluralLabel + '" (at "' + path_entityPluralLabel + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_keyPrefix = obj.keyPrefix;
        const path_keyPrefix = path + '.keyPrefix';
        let obj_keyPrefix_union0 = null;
        const obj_keyPrefix_union0_error = (() => {
            if (typeof obj_keyPrefix !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_keyPrefix + '" (at "' + path_keyPrefix + '")');
            }
        })();
        if (obj_keyPrefix_union0_error != null) {
            obj_keyPrefix_union0 = obj_keyPrefix_union0_error.message;
        }
        let obj_keyPrefix_union1 = null;
        const obj_keyPrefix_union1_error = (() => {
            if (obj_keyPrefix !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_keyPrefix + '" (at "' + path_keyPrefix + '")');
            }
        })();
        if (obj_keyPrefix_union1_error != null) {
            obj_keyPrefix_union1 = obj_keyPrefix_union1_error.message;
        }
        if (obj_keyPrefix_union0 && obj_keyPrefix_union1) {
            let message = 'Object doesn\'t match union (at "' + path_keyPrefix + '")';
            message += '\n' + obj_keyPrefix_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_keyPrefix_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_parentFieldApiName = obj.parentFieldApiName;
        const path_parentFieldApiName = path + '.parentFieldApiName';
        if (typeof obj_parentFieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_parentFieldApiName + '" (at "' + path_parentFieldApiName + '")');
        }
        const obj_relatedListId = obj.relatedListId;
        const path_relatedListId = path + '.relatedListId';
        if (typeof obj_relatedListId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_relatedListId + '" (at "' + path_relatedListId + '")');
        }
        const obj_relatedListInfoUrl = obj.relatedListInfoUrl;
        const path_relatedListInfoUrl = path + '.relatedListInfoUrl';
        let obj_relatedListInfoUrl_union0 = null;
        const obj_relatedListInfoUrl_union0_error = (() => {
            if (typeof obj_relatedListInfoUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_relatedListInfoUrl + '" (at "' + path_relatedListInfoUrl + '")');
            }
        })();
        if (obj_relatedListInfoUrl_union0_error != null) {
            obj_relatedListInfoUrl_union0 = obj_relatedListInfoUrl_union0_error.message;
        }
        let obj_relatedListInfoUrl_union1 = null;
        const obj_relatedListInfoUrl_union1_error = (() => {
            if (obj_relatedListInfoUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_relatedListInfoUrl + '" (at "' + path_relatedListInfoUrl + '")');
            }
        })();
        if (obj_relatedListInfoUrl_union1_error != null) {
            obj_relatedListInfoUrl_union1 = obj_relatedListInfoUrl_union1_error.message;
        }
        if (obj_relatedListInfoUrl_union0 && obj_relatedListInfoUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_relatedListInfoUrl + '")';
            message += '\n' + obj_relatedListInfoUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_relatedListInfoUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_themeInfo = obj.themeInfo;
        const path_themeInfo = path + '.themeInfo';
        let obj_themeInfo_union0 = null;
        const obj_themeInfo_union0_error = (() => {
            const referencepath_themeInfoValidationError = validate$1L(obj_themeInfo, path_themeInfo);
            if (referencepath_themeInfoValidationError !== null) {
                let message = 'Object doesn\'t match ThemeInfoRepresentation (at "' + path_themeInfo + '")\n';
                message += referencepath_themeInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_themeInfo_union0_error != null) {
            obj_themeInfo_union0 = obj_themeInfo_union0_error.message;
        }
        let obj_themeInfo_union1 = null;
        const obj_themeInfo_union1_error = (() => {
            if (obj_themeInfo !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_themeInfo + '" (at "' + path_themeInfo + '")');
            }
        })();
        if (obj_themeInfo_union1_error != null) {
            obj_themeInfo_union1 = obj_themeInfo_union1_error.message;
        }
        if (obj_themeInfo_union0 && obj_themeInfo_union1) {
            let message = 'Object doesn\'t match union (at "' + path_themeInfo + '")';
            message += '\n' + obj_themeInfo_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_themeInfo_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_uiApiEnabledLayout = obj.uiApiEnabledLayout;
        const path_uiApiEnabledLayout = path + '.uiApiEnabledLayout';
        if (typeof obj_uiApiEnabledLayout !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_uiApiEnabledLayout + '" (at "' + path_uiApiEnabledLayout + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const VERSION$e = "2a1722afba0e1ee52d6b7b0a25ccd9f4";
function validate$E(obj, path = 'RelatedListSummaryInfoCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_parentObjectApiName = obj.parentObjectApiName;
        const path_parentObjectApiName = path + '.parentObjectApiName';
        if (typeof obj_parentObjectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_parentObjectApiName + '" (at "' + path_parentObjectApiName + '")');
        }
        const obj_parentRecordTypeId = obj.parentRecordTypeId;
        const path_parentRecordTypeId = path + '.parentRecordTypeId';
        let obj_parentRecordTypeId_union0 = null;
        const obj_parentRecordTypeId_union0_error = (() => {
            if (typeof obj_parentRecordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_parentRecordTypeId + '" (at "' + path_parentRecordTypeId + '")');
            }
        })();
        if (obj_parentRecordTypeId_union0_error != null) {
            obj_parentRecordTypeId_union0 = obj_parentRecordTypeId_union0_error.message;
        }
        let obj_parentRecordTypeId_union1 = null;
        const obj_parentRecordTypeId_union1_error = (() => {
            if (obj_parentRecordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_parentRecordTypeId + '" (at "' + path_parentRecordTypeId + '")');
            }
        })();
        if (obj_parentRecordTypeId_union1_error != null) {
            obj_parentRecordTypeId_union1 = obj_parentRecordTypeId_union1_error.message;
        }
        if (obj_parentRecordTypeId_union0 && obj_parentRecordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_parentRecordTypeId + '")';
            message += '\n' + obj_parentRecordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_parentRecordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_relatedLists = obj.relatedLists;
        const path_relatedLists = path + '.relatedLists';
        if (!ArrayIsArray(obj_relatedLists)) {
            return new TypeError('Expected "array" but received "' + typeof obj_relatedLists + '" (at "' + path_relatedLists + '")');
        }
        for (let i = 0; i < obj_relatedLists.length; i++) {
            const obj_relatedLists_item = obj_relatedLists[i];
            const path_relatedLists_item = path_relatedLists + '[' + i + ']';
            const referencepath_relatedLists_itemValidationError = validate$F(obj_relatedLists_item, path_relatedLists_item);
            if (referencepath_relatedLists_itemValidationError !== null) {
                let message = 'Object doesn\'t match RelatedListSummaryInfoRepresentation (at "' + path_relatedLists_item + '")\n';
                message += referencepath_relatedLists_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$f = 'RelatedListSummaryInfoCollectionRepresentation';
function keyBuilder$C(luvio, config) {
    return keyPrefix + '::' + RepresentationType$f + ':' + config.parentObjectApiName + ':' + (config.recordTypeId === null ? '' : config.recordTypeId);
}
function keyBuilderFromType$c(luvio, object) {
    const keyParams = {
        parentObjectApiName: object.parentObjectApiName,
        recordTypeId: object.parentRecordTypeId
    };
    return keyBuilder$C(luvio, keyParams);
}
function normalize$a(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$o = function RelatedListSummaryInfoCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$e,
        private: [
            'eTag'
        ],
        selections: [
            {
                name: 'parentObjectApiName',
                kind: 'Scalar'
            },
            {
                name: 'parentRecordTypeId',
                kind: 'Scalar'
            },
            {
                name: 'relatedLists',
                kind: 'Object',
                opaque: true
            }
        ]
    };
};
function equals$e(existing, incoming) {
    if (existing.eTag !== incoming.eTag) {
        return false;
    }
    return true;
}
const ingest$a = function RelatedListSummaryInfoCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$E(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$c(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$a, "UiApi", VERSION$e, RepresentationType$f, equals$e);
    return createLink(key);
};
function getTypeCacheKeys$f(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$c(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$f,
        mergeable: false
    });
}

function select$n(luvio, params) {
    return select$o();
}
function keyBuilder$B(luvio, params) {
    return keyBuilder$C(luvio, {
        parentObjectApiName: params.urlParams.parentObjectApiName,
        recordTypeId: params.queryParams.recordTypeId || null
    });
}
function getResponseCacheKeys$m(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$f(storeKeyMap, luvio, response);
}
function ingestSuccess$g(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$B(luvio, resourceParams);
    luvio.storeIngest(key, ingest$a, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$n(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$a(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$B(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$q(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-info/' + config.urlParams.parentObjectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$k = 'getRelatedListsInfo';
const getRelatedListsInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentObjectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getRelatedListsInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$k, getRelatedListsInfo_ConfigPropertyMetadata);
const createResourceParams$n = /*#__PURE__*/ createResourceParams$13(getRelatedListsInfo_ConfigPropertyMetadata);
function keyBuilder$A(luvio, config) {
    const resourceParams = createResourceParams$n(config);
    return keyBuilder$B(luvio, resourceParams);
}
function typeCheckConfig$o(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListsInfo_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$n(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListsInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$o(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$c(luvio, config) {
    createResourceParams$n(config);
    return select$n();
}
function onFetchResponseSuccess$d(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$g(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$p(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$c(luvio, config, resourceParams, response) {
    const snapshot = ingestError$a(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$p(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$p(luvio, config, options) {
    const resourceParams = createResourceParams$n(config);
    const request = createResourceRequest$q(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$d(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$m(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$c(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$f(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$p, undefined, false);
}
function buildCachedSnapshotCachePolicy$e(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$A(luvio, config),
        node: adapterFragment$c(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$p(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListsInfoAdapterFactory = (luvio) => function UiApi__getRelatedListsInfo(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$n(untrustedConfig, getRelatedListsInfo_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$e, buildNetworkSnapshotCachePolicy$f);
};

const adapterName$j = 'getRelatedListInfo';
const getRelatedListInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentObjectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('relatedListId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('fields', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('restrictColumnsToLayout', false, 1 /* QueryParameter */, 1 /* Boolean */),
];
const getRelatedListInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$j, getRelatedListInfo_ConfigPropertyMetadata);
const createResourceParams$m = /*#__PURE__*/ createResourceParams$13(getRelatedListInfo_ConfigPropertyMetadata);
function keyBuilder$z(luvio, config) {
    const resourceParams = createResourceParams$m(config);
    return keyBuilder$F(luvio, resourceParams);
}
function typeCheckConfig$n(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListInfo_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$m(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$n(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$b(luvio, config) {
    createResourceParams$m(config);
    return select$q();
}
function onFetchResponseSuccess$c(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$i(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$o(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$b(luvio, config, resourceParams, response) {
    const snapshot = ingestError$c(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$o(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$o(luvio, config, options) {
    const resourceParams = createResourceParams$m(config);
    const request = createResourceRequest$s(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$c(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$o(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$b(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$e(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$o, undefined, false);
}
function buildCachedSnapshotCachePolicy$d(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$z(luvio, config),
        node: adapterFragment$b(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$o(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListInfoAdapterFactory = (luvio) => function UiApi__getRelatedListInfo(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$m(untrustedConfig, getRelatedListInfo_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$d, buildNetworkSnapshotCachePolicy$e);
};

function validate$D(obj, path = 'ListUserPreferenceInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_columnWidths = obj.columnWidths;
        const path_columnWidths = path + '.columnWidths';
        if (typeof obj_columnWidths !== 'object' || ArrayIsArray(obj_columnWidths) || obj_columnWidths === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWidths + '" (at "' + path_columnWidths + '")');
        }
        const obj_columnWidths_keys = ObjectKeys(obj_columnWidths);
        for (let i = 0; i < obj_columnWidths_keys.length; i++) {
            const key = obj_columnWidths_keys[i];
            const obj_columnWidths_prop = obj_columnWidths[key];
            const path_columnWidths_prop = path_columnWidths + '["' + key + '"]';
            if (typeof obj_columnWidths_prop !== 'number' || (typeof obj_columnWidths_prop === 'number' && Math.floor(obj_columnWidths_prop) !== obj_columnWidths_prop)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_columnWidths_prop + '" (at "' + path_columnWidths_prop + '")');
            }
        }
        const obj_columnWrap = obj.columnWrap;
        const path_columnWrap = path + '.columnWrap';
        if (typeof obj_columnWrap !== 'object' || ArrayIsArray(obj_columnWrap) || obj_columnWrap === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWrap + '" (at "' + path_columnWrap + '")');
        }
        const obj_columnWrap_keys = ObjectKeys(obj_columnWrap);
        for (let i = 0; i < obj_columnWrap_keys.length; i++) {
            const key = obj_columnWrap_keys[i];
            const obj_columnWrap_prop = obj_columnWrap[key];
            const path_columnWrap_prop = path_columnWrap + '["' + key + '"]';
            if (typeof obj_columnWrap_prop !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_columnWrap_prop + '" (at "' + path_columnWrap_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function select$m(luvio, params) {
    return select$r();
}
function getResponseCacheKeys$l(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$g(storeKeyMap, luvio, response);
}
function ingestSuccess$f(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$d(luvio, body);
    luvio.storeIngest(key, ingest$b, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$m(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$p(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-info/' + config.urlParams.parentObjectApiName + '/' + config.urlParams.relatedListId + '',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function typeCheckConfig$m(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, updateRelatedListInfo_ConfigPropertyMetadata);
    const untrustedConfig_orderedByInfo = untrustedConfig.orderedByInfo;
    if (ArrayIsArray$1(untrustedConfig_orderedByInfo)) {
        const untrustedConfig_orderedByInfo_array = [];
        for (let i = 0, arrayLength = untrustedConfig_orderedByInfo.length; i < arrayLength; i++) {
            const untrustedConfig_orderedByInfo_item = untrustedConfig_orderedByInfo[i];
            const referenceListOrderedByInfoInputRepresentationValidationError = validate$11(untrustedConfig_orderedByInfo_item);
            if (referenceListOrderedByInfoInputRepresentationValidationError === null) {
                untrustedConfig_orderedByInfo_array.push(untrustedConfig_orderedByInfo_item);
            }
        }
        config.orderedByInfo = untrustedConfig_orderedByInfo_array;
    }
    const untrustedConfig_userPreferences = untrustedConfig.userPreferences;
    const referenceListUserPreferenceInputRepresentationValidationError = validate$D(untrustedConfig_userPreferences);
    if (referenceListUserPreferenceInputRepresentationValidationError === null) {
        config.userPreferences = untrustedConfig_userPreferences;
    }
    else {
        throw referenceListUserPreferenceInputRepresentationValidationError;
    }
    return config;
}

const adapterName$i = 'updateRelatedListInfo';
const updateRelatedListInfo_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentObjectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('relatedListId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('orderedByInfo', true, 2 /* Body */, 4 /* Unsupported */, true),
    generateParamConfigMetadata('userPreferences', true, 2 /* Body */, 4 /* Unsupported */),
];
const updateRelatedListInfo_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$i, updateRelatedListInfo_ConfigPropertyMetadata);
const createResourceParams$l = /*#__PURE__*/ createResourceParams$13(updateRelatedListInfo_ConfigPropertyMetadata);
function validateAdapterConfig$l(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, updateRelatedListInfo_ConfigPropertyMetadata);
    const config = typeCheckConfig$m(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$n(luvio, config, options) {
    const resourceParams = createResourceParams$l(config);
    const request = createResourceRequest$p(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$f(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$l(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const updateRelatedListInfoAdapterFactory = (luvio) => {
    return function updateRelatedListInfo(untrustedConfig) {
        const config = validateAdapterConfig$l(untrustedConfig, updateRelatedListInfo_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error('Invalid config for "updateRelatedListInfo"');
        }
        return buildNetworkSnapshot$n(luvio, config);
    };
};

const TTL$b = 900000;
const VERSION$d = "094cdf8e3e1f07fca02c4e51e14c528e";
function validate$C(obj, path = 'RelatedListUserPreferencesRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_columnWidths = obj.columnWidths;
        const path_columnWidths = path + '.columnWidths';
        if (typeof obj_columnWidths !== 'object' || ArrayIsArray(obj_columnWidths) || obj_columnWidths === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWidths + '" (at "' + path_columnWidths + '")');
        }
        const obj_columnWidths_keys = ObjectKeys(obj_columnWidths);
        for (let i = 0; i < obj_columnWidths_keys.length; i++) {
            const key = obj_columnWidths_keys[i];
            const obj_columnWidths_prop = obj_columnWidths[key];
            const path_columnWidths_prop = path_columnWidths + '["' + key + '"]';
            if (typeof obj_columnWidths_prop !== 'number' || (typeof obj_columnWidths_prop === 'number' && Math.floor(obj_columnWidths_prop) !== obj_columnWidths_prop)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_columnWidths_prop + '" (at "' + path_columnWidths_prop + '")');
            }
        }
        const obj_columnWrap = obj.columnWrap;
        const path_columnWrap = path + '.columnWrap';
        if (typeof obj_columnWrap !== 'object' || ArrayIsArray(obj_columnWrap) || obj_columnWrap === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_columnWrap + '" (at "' + path_columnWrap + '")');
        }
        const obj_columnWrap_keys = ObjectKeys(obj_columnWrap);
        for (let i = 0; i < obj_columnWrap_keys.length; i++) {
            const key = obj_columnWrap_keys[i];
            const obj_columnWrap_prop = obj_columnWrap[key];
            const path_columnWrap_prop = path_columnWrap + '["' + key + '"]';
            if (typeof obj_columnWrap_prop !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_columnWrap_prop + '" (at "' + path_columnWrap_prop + '")');
            }
        }
        const obj_orderedBy = obj.orderedBy;
        const path_orderedBy = path + '.orderedBy';
        if (!ArrayIsArray(obj_orderedBy)) {
            return new TypeError('Expected "array" but received "' + typeof obj_orderedBy + '" (at "' + path_orderedBy + '")');
        }
        for (let i = 0; i < obj_orderedBy.length; i++) {
            const obj_orderedBy_item = obj_orderedBy[i];
            const path_orderedBy_item = path_orderedBy + '[' + i + ']';
            const referencepath_orderedBy_itemValidationError = validate$26(obj_orderedBy_item, path_orderedBy_item);
            if (referencepath_orderedBy_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListOrderByInfoRepresentation (at "' + path_orderedBy_item + '")\n';
                message += referencepath_orderedBy_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_preferencesId = obj.preferencesId;
        const path_preferencesId = path + '.preferencesId';
        if (typeof obj_preferencesId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_preferencesId + '" (at "' + path_preferencesId + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$e = 'RelatedListUserPreferencesRepresentation';
function keyBuilder$y(luvio, config) {
    return keyPrefix + '::' + RepresentationType$e + ':' + config.preferencesId;
}
function keyBuilderFromType$b(luvio, object) {
    const keyParams = {
        preferencesId: object.preferencesId
    };
    return keyBuilder$y(luvio, keyParams);
}
function normalize$9(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$l = function RelatedListUserPreferencesRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$d,
        private: [],
        opaque: true
    };
};
function equals$d(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$9 = function RelatedListUserPreferencesRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$C(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$b(luvio, input);
    const ttlToUse = TTL$b;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$9, "UiApi", VERSION$d, RepresentationType$e, equals$d);
    return createLink(key);
};
function getTypeCacheKeys$e(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$b(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$e,
        mergeable: false
    });
}

function select$k(luvio, params) {
    return select$l();
}
function keyBuilder$x(luvio, params) {
    return keyBuilder$y(luvio, {
        preferencesId: params.urlParams.preferencesId
    });
}
function getResponseCacheKeys$k(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$e(storeKeyMap, luvio, response);
}
function ingestSuccess$e(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$x(luvio, resourceParams);
    luvio.storeIngest(key, ingest$9, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$k(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$9(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$x(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$b,
        namespace: keyPrefix,
        version: VERSION$d,
        representationName: RepresentationType$e
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$o(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-preferences/' + config.urlParams.preferencesId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const nonCachedErrors$1 = ObjectCreate$1(null);
function createChildResourceParams$2(resourceParams) {
    let childConfigs = [];
    for (let index = 0, len = resourceParams.urlParams.preferencesIds.length; index < len; index += 1) {
        const item = resourceParams.urlParams.preferencesIds[index];
        childConfigs.push({
            urlParams: {
                preferencesId: item
            }
        });
    }
    return childConfigs;
}
function selectChildResourceParams$1(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$w(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$x(luvio, childResource);
                const childFragment = select$k();
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors$1[childKey];
                            if (nonCachedError === undefined || nonCachedError.expiration < reader.getTimeStamp()) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$j(luvio, resourceParams) {
    const childResources = createChildResourceParams$2(resourceParams);
    return selectChildResourceParams$1(luvio, childResources, resourceParams);
}
function keyBuilder$w(luvio, params) {
    return keyPrefix + '::RelatedListPreferencesBatchRepresentation:(' + 'preferencesIds:' + params.urlParams.preferencesIds + ')';
}
function getResponseCacheKeys$j(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams$2(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$k(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$x(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$e,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$2(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$x(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$e(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$9(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors$1[childKey] = { expiration: now + TTL$b, response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors$1[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$d(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams$2(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$w(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$2(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$j(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$8(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$w(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$n(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-preferences/batch/' + config.urlParams.preferencesIds + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$h = 'getRelatedListPreferencesBatch';
const getRelatedListPreferencesBatch_ConfigPropertyMetadata = [
    generateParamConfigMetadata('preferencesIds', true, 0 /* UrlParameter */, 0 /* String */, true),
];
const getRelatedListPreferencesBatch_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$h, getRelatedListPreferencesBatch_ConfigPropertyMetadata);
const createResourceParams$k = /*#__PURE__*/ createResourceParams$13(getRelatedListPreferencesBatch_ConfigPropertyMetadata);
function keyBuilder$v(luvio, config) {
    const resourceParams = createResourceParams$k(config);
    return keyBuilder$w(luvio, resourceParams);
}
function typeCheckConfig$l(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListPreferencesBatch_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$k(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$l(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$a(luvio, config) {
    const resourceParams = createResourceParams$k(config);
    return select$j(luvio, resourceParams);
}
function onFetchResponseSuccess$b(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$d(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$m(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$a(luvio, config, resourceParams, response) {
    const snapshot = ingestError$8(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$m(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$m(luvio, config, options) {
    const resourceParams = createResourceParams$k(config);
    const request = createResourceRequest$n(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$b(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$j(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$a(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$d(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$m, undefined, false);
}
function buildCachedSnapshotCachePolicy$c(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$v(luvio, config),
        node: adapterFragment$a(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$m(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListPreferencesBatchAdapterFactory = (luvio) => function UiApi__getRelatedListPreferencesBatch(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$k(untrustedConfig, getRelatedListPreferencesBatch_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$c, buildNetworkSnapshotCachePolicy$d);
};

const adapterName$g = 'getRelatedListPreferences';
const getRelatedListPreferences_ConfigPropertyMetadata = [
    generateParamConfigMetadata('preferencesId', true, 0 /* UrlParameter */, 0 /* String */),
];
const getRelatedListPreferences_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$g, getRelatedListPreferences_ConfigPropertyMetadata);
const createResourceParams$j = /*#__PURE__*/ createResourceParams$13(getRelatedListPreferences_ConfigPropertyMetadata);
function keyBuilder$u(luvio, config) {
    const resourceParams = createResourceParams$j(config);
    return keyBuilder$x(luvio, resourceParams);
}
function typeCheckConfig$k(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListPreferences_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$j(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$k(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$9(luvio, config) {
    createResourceParams$j(config);
    return select$k();
}
function onFetchResponseSuccess$a(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$e(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$l(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$9(luvio, config, resourceParams, response) {
    const snapshot = ingestError$9(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$l(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$l(luvio, config, options) {
    const resourceParams = createResourceParams$j(config);
    const request = createResourceRequest$o(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$a(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$k(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$9(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$c(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$l, undefined, false);
}
function buildCachedSnapshotCachePolicy$b(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$u(luvio, config),
        node: adapterFragment$9(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$l(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListPreferencesAdapterFactory = (luvio) => function UiApi__getRelatedListPreferences(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$j(untrustedConfig, getRelatedListPreferences_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$b, buildNetworkSnapshotCachePolicy$c);
};

function select$i(luvio, params) {
    return select$l();
}
function getResponseCacheKeys$i(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$e(storeKeyMap, luvio, response);
}
function ingestSuccess$c(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$b(luvio, body);
    luvio.storeIngest(key, ingest$9, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$i(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$m(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-preferences/' + config.urlParams.preferencesId + '',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$f = 'updateRelatedListPreferences';
const updateRelatedListPreferences_ConfigPropertyMetadata = [
    generateParamConfigMetadata('preferencesId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('columnWidths', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('columnWrap', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('orderedBy', false, 2 /* Body */, 4 /* Unsupported */, true),
];
const updateRelatedListPreferences_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$f, updateRelatedListPreferences_ConfigPropertyMetadata);
const createResourceParams$i = /*#__PURE__*/ createResourceParams$13(updateRelatedListPreferences_ConfigPropertyMetadata);
function typeCheckConfig$j(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, updateRelatedListPreferences_ConfigPropertyMetadata);
    const untrustedConfig_columnWidths = untrustedConfig.columnWidths;
    if (untrustedIsObject(untrustedConfig_columnWidths)) {
        const untrustedConfig_columnWidths_object = {};
        const untrustedConfig_columnWidths_keys = Object.keys(untrustedConfig_columnWidths);
        for (let i = 0, arrayLength = untrustedConfig_columnWidths_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_columnWidths_keys[i];
            const untrustedConfig_columnWidths_prop = untrustedConfig_columnWidths[key];
            if (typeof untrustedConfig_columnWidths_prop === 'number' && Math.floor(untrustedConfig_columnWidths_prop) === untrustedConfig_columnWidths_prop) {
                if (untrustedConfig_columnWidths_object !== undefined) {
                    untrustedConfig_columnWidths_object[key] = untrustedConfig_columnWidths_prop;
                }
            }
        }
        if (untrustedConfig_columnWidths_object !== undefined && Object.keys(untrustedConfig_columnWidths_object).length >= 0) {
            config.columnWidths = untrustedConfig_columnWidths_object;
        }
    }
    const untrustedConfig_columnWrap = untrustedConfig.columnWrap;
    if (untrustedIsObject(untrustedConfig_columnWrap)) {
        const untrustedConfig_columnWrap_object = {};
        const untrustedConfig_columnWrap_keys = Object.keys(untrustedConfig_columnWrap);
        for (let i = 0, arrayLength = untrustedConfig_columnWrap_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_columnWrap_keys[i];
            const untrustedConfig_columnWrap_prop = untrustedConfig_columnWrap[key];
            if (typeof untrustedConfig_columnWrap_prop === 'boolean') {
                if (untrustedConfig_columnWrap_object !== undefined) {
                    untrustedConfig_columnWrap_object[key] = untrustedConfig_columnWrap_prop;
                }
            }
        }
        if (untrustedConfig_columnWrap_object !== undefined && Object.keys(untrustedConfig_columnWrap_object).length >= 0) {
            config.columnWrap = untrustedConfig_columnWrap_object;
        }
    }
    const untrustedConfig_orderedBy = untrustedConfig.orderedBy;
    if (ArrayIsArray$1(untrustedConfig_orderedBy)) {
        const untrustedConfig_orderedBy_array = [];
        for (let i = 0, arrayLength = untrustedConfig_orderedBy.length; i < arrayLength; i++) {
            const untrustedConfig_orderedBy_item = untrustedConfig_orderedBy[i];
            const referenceListOrderedByInfoInputRepresentationValidationError = validate$11(untrustedConfig_orderedBy_item);
            if (referenceListOrderedByInfoInputRepresentationValidationError === null) {
                untrustedConfig_orderedBy_array.push(untrustedConfig_orderedBy_item);
            }
        }
        config.orderedBy = untrustedConfig_orderedBy_array;
    }
    return config;
}
function validateAdapterConfig$i(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$j(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$k(luvio, config, options) {
    const resourceParams = createResourceParams$i(config);
    const request = createResourceRequest$m(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$c(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$i(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const updateRelatedListPreferencesAdapterFactory = (luvio) => {
    return function updateRelatedListPreferences(untrustedConfig) {
        const config = validateAdapterConfig$i(untrustedConfig, updateRelatedListPreferences_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error('Invalid config for "updateRelatedListPreferences"');
        }
        return buildNetworkSnapshot$k(luvio, config);
    };
};

function validate$B(obj, path = 'RelatedListRecordsSingleBatchInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.fields !== undefined) {
            const obj_fields = obj.fields;
            const path_fields = path + '.fields';
            if (!ArrayIsArray(obj_fields)) {
                return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
            }
            for (let i = 0; i < obj_fields.length; i++) {
                const obj_fields_item = obj_fields[i];
                const path_fields_item = path_fields + '[' + i + ']';
                if (typeof obj_fields_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_fields_item + '" (at "' + path_fields_item + '")');
                }
            }
        }
        if (obj.optionalFields !== undefined) {
            const obj_optionalFields = obj.optionalFields;
            const path_optionalFields = path + '.optionalFields';
            if (!ArrayIsArray(obj_optionalFields)) {
                return new TypeError('Expected "array" but received "' + typeof obj_optionalFields + '" (at "' + path_optionalFields + '")');
            }
            for (let i = 0; i < obj_optionalFields.length; i++) {
                const obj_optionalFields_item = obj_optionalFields[i];
                const path_optionalFields_item = path_optionalFields + '[' + i + ']';
                if (typeof obj_optionalFields_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_optionalFields_item + '" (at "' + path_optionalFields_item + '")');
                }
            }
        }
        if (obj.pageSize !== undefined) {
            const obj_pageSize = obj.pageSize;
            const path_pageSize = path + '.pageSize';
            if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
                return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
            }
        }
        const obj_relatedListId = obj.relatedListId;
        const path_relatedListId = path + '.relatedListId';
        if (typeof obj_relatedListId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_relatedListId + '" (at "' + path_relatedListId + '")');
        }
        if (obj.sortBy !== undefined) {
            const obj_sortBy = obj.sortBy;
            const path_sortBy = path + '.sortBy';
            if (!ArrayIsArray(obj_sortBy)) {
                return new TypeError('Expected "array" but received "' + typeof obj_sortBy + '" (at "' + path_sortBy + '")');
            }
            for (let i = 0; i < obj_sortBy.length; i++) {
                const obj_sortBy_item = obj_sortBy[i];
                const path_sortBy_item = path_sortBy + '[' + i + ']';
                if (typeof obj_sortBy_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_sortBy_item + '" (at "' + path_sortBy_item + '")');
                }
            }
        }
        if (obj.where !== undefined) {
            const obj_where = obj.where;
            const path_where = path + '.where';
            if (typeof obj_where !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_where + '" (at "' + path_where + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

const PAGINATION_VERSION = "0.111.0";
const paginationStoreMetadata = {
    ttl: Number.MAX_SAFE_INTEGER,
    namespace: '',
    representationName: '',
    version: PAGINATION_VERSION
};
function clientTokenFromOffset(paginationMetadata, offset) {
    const { clientTokens } = paginationMetadata;
    const tokens = Object.keys(clientTokens);
    for (let i = 0, len = tokens.length; i < len; i++) {
        const token = tokens[i];
        if (clientTokens[token] === offset) {
            return token;
        }
    }
}
function offsetFromClientToken(paginationMetadata, token) {
    if (token === undefined) {
        return 0;
    }
    const offset = paginationMetadata.clientTokens[token];
    return offset === undefined ? -1 : offset;
}
function offsetFromServerToken(paginationMetadata, token) {
    return paginationMetadata.serverTokens.indexOf(token);
}
function getNextPageTokens(paginationMetadata, pageEndOffset) {
    const listEndOffset = paginationMetadata.__END__;
    if (listEndOffset === undefined || pageEndOffset < listEndOffset) {
        const clientToken = clientTokenFromOffset(paginationMetadata, pageEndOffset);
        if (clientToken === undefined) {
            return {
                clientToken: undefined,
                serverToken: undefined,
            };
        }
        return {
            clientToken,
            serverToken: paginationMetadata.serverTokens[pageEndOffset] || undefined
        };
    }
    return {
        clientToken: null,
        serverToken: null,
    };
}
function getPreviousClientToken(paginationMetadata, startOffset, pageSize) {
    const previousPageOffset = startOffset - pageSize;
    if (previousPageOffset < 0) {
        return null;
    }
    const listEndOffset = paginationMetadata.__END__;
    if (listEndOffset !== undefined && previousPageOffset >= listEndOffset) {
        return;
    }
    return clientTokenFromOffset(paginationMetadata, previousPageOffset);
}
function pageEndOffset(paginationMetadata, startOffset, pageSize) {
    const listEndOffset = paginationMetadata.__END__;
    const nextPageOffset = startOffset + pageSize;
    if (listEndOffset === undefined) {
        return nextPageOffset;
    }
    return Math.min(nextPageOffset, listEndOffset);
}
function getPageTokenAndOffset(paginationMetadata, token) {
    if (token === undefined) {
        const startToken = clientTokenFromOffset(paginationMetadata, 0);
        if (startToken === undefined) {
            return;
        }
        return [startToken, 0];
    }
    const startOffset = offsetFromClientToken(paginationMetadata, token);
    if (startOffset < 0) {
        return;
    }
    return [token, startOffset];
}
function serverTokenForAtMost(paginationMetadata, maxOffset) {
    const { serverTokens } = paginationMetadata;
    for (let i = maxOffset; i >= 0; i--) {
        const token = serverTokens[i];
        if (token !== undefined) {
            return [token, i];
        }
    }
    return [undefined, -1];
}
function generateClientToken(offset) {
    return base64Encode('client:' + offset);
}
// Code lifted from https://github.com/MaxArt2501/base64-js/blob/master/base64.js
// base64 character set, plus padding character (=)
const b64 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
function base64Encode(input) {
    let bitmap, a, b, c;
    let result = "", i = 0;
    const rest = input.length % 3; // To determine the final padding
    for (; i < input.length;) {
        if ((a = input.charCodeAt(i++)) > 255
            || (b = input.charCodeAt(i++)) > 255
            || (c = input.charCodeAt(i++)) > 255) {
            throw new TypeError("Failed base64ToAscii encoding: The string to be encoded contains characters outside of the Latin1 range. " + input);
        }
        bitmap = (a << 16) | (b << 8) | c;
        result += b64.charAt(bitmap >> 18 & 63) + b64.charAt(bitmap >> 12 & 63)
            + b64.charAt(bitmap >> 6 & 63) + b64.charAt(bitmap & 63);
    }
    // If there's need of padding, replace the last 'A's with equal signs
    return rest ? result.slice(0, rest - 3) + "===".substring(rest) : result;
}
function addTokens(paginationMetadata, offset, clientToken, serverToken) {
    paginationMetadata.clientTokens[clientToken] = offset;
    if (serverToken !== undefined) {
        paginationMetadata.serverTokens[offset] = serverToken;
    }
}
function mergeMetadata(existingMetadata, incomingMetadata) {
    if (existingMetadata === undefined) {
        return incomingMetadata;
    }
    const clientTokens = {
        ...existingMetadata.clientTokens,
        ...incomingMetadata.clientTokens
    };
    const serverTokens = mergeArrays(existingMetadata.serverTokens, incomingMetadata.serverTokens);
    const __END__ = incomingMetadata.hasOwnProperty('__END__') ? incomingMetadata.__END__ : existingMetadata.__END__;
    return {
        clientTokens,
        serverTokens,
        __END__
    };
}
function mergeArrays(existing, incoming) {
    const merged = [];
    const len = Math.max(existing.length, incoming.length);
    for (let i = 0; i < len; i++) {
        const value = incoming[i] || existing[i];
        merged.push(value);
    }
    return merged;
}
function equalsMetadata(existingMetadata, incomingMetadata) {
    const { clientTokens: existingClientTokens, serverTokens: existingServerTokens, __END__: existingListEnd } = existingMetadata;
    const { clientTokens: incomingClientTokens, serverTokens: incomingServerTokens, __END__: incomingListEnd } = incomingMetadata;
    const existingKeys = Object.keys(existingClientTokens);
    const incomingKeys = Object.keys(incomingClientTokens);
    const clientTokensLength = existingKeys.length;
    if (clientTokensLength !== incomingKeys.length) {
        return false;
    }
    for (let i = 0; i < clientTokensLength; i++) {
        const key = existingKeys[i];
        if (existingClientTokens[key] !== incomingClientTokens[key]) {
            return false;
        }
    }
    const serverTokensLength = existingServerTokens.length;
    if (serverTokensLength !== incomingServerTokens.length) {
        return false;
    }
    for (let i = 0; i < serverTokensLength; i++) {
        if (existingServerTokens[i] !== incomingServerTokens[i]) {
            return false;
        }
    }
    return existingListEnd === incomingListEnd;
}

const TTL$a = 30000;
const VERSION$c = "62467c27c19349b70c9db2a8d9d591d9";
function validate$A(obj, path = 'RelatedListRecordCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_count = obj.count;
        const path_count = path + '.count';
        if (typeof obj_count !== 'number' || (typeof obj_count === 'number' && Math.floor(obj_count) !== obj_count)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_count + '" (at "' + path_count + '")');
        }
        const obj_currentPageToken = obj.currentPageToken;
        const path_currentPageToken = path + '.currentPageToken';
        if (typeof obj_currentPageToken !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
        }
        const obj_currentPageUrl = obj.currentPageUrl;
        const path_currentPageUrl = path + '.currentPageUrl';
        let obj_currentPageUrl_union0 = null;
        const obj_currentPageUrl_union0_error = (() => {
            if (typeof obj_currentPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
            }
        })();
        if (obj_currentPageUrl_union0_error != null) {
            obj_currentPageUrl_union0 = obj_currentPageUrl_union0_error.message;
        }
        let obj_currentPageUrl_union1 = null;
        const obj_currentPageUrl_union1_error = (() => {
            if (obj_currentPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_currentPageUrl + '" (at "' + path_currentPageUrl + '")');
            }
        })();
        if (obj_currentPageUrl_union1_error != null) {
            obj_currentPageUrl_union1 = obj_currentPageUrl_union1_error.message;
        }
        if (obj_currentPageUrl_union0 && obj_currentPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_currentPageUrl + '")';
            message += '\n' + obj_currentPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_currentPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (!ArrayIsArray(obj_fields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        for (let i = 0; i < obj_fields.length; i++) {
            const obj_fields_item = obj_fields[i];
            const path_fields_item = path_fields + '[' + i + ']';
            if (typeof obj_fields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_fields_item + '" (at "' + path_fields_item + '")');
            }
        }
        const obj_listInfoETag = obj.listInfoETag;
        const path_listInfoETag = path + '.listInfoETag';
        let obj_listInfoETag_union0 = null;
        const obj_listInfoETag_union0_error = (() => {
            if (typeof obj_listInfoETag !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_listInfoETag + '" (at "' + path_listInfoETag + '")');
            }
        })();
        if (obj_listInfoETag_union0_error != null) {
            obj_listInfoETag_union0 = obj_listInfoETag_union0_error.message;
        }
        let obj_listInfoETag_union1 = null;
        const obj_listInfoETag_union1_error = (() => {
            if (obj_listInfoETag !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_listInfoETag + '" (at "' + path_listInfoETag + '")');
            }
        })();
        if (obj_listInfoETag_union1_error != null) {
            obj_listInfoETag_union1 = obj_listInfoETag_union1_error.message;
        }
        if (obj_listInfoETag_union0 && obj_listInfoETag_union1) {
            let message = 'Object doesn\'t match union (at "' + path_listInfoETag + '")';
            message += '\n' + obj_listInfoETag_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_listInfoETag_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_listReference = obj.listReference;
        const path_listReference = path + '.listReference';
        const referencepath_listReferenceValidationError = validate$J(obj_listReference, path_listReference);
        if (referencepath_listReferenceValidationError !== null) {
            let message = 'Object doesn\'t match RelatedListReferenceRepresentation (at "' + path_listReference + '")\n';
            message += referencepath_listReferenceValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageToken = obj.nextPageToken;
        const path_nextPageToken = path + '.nextPageToken';
        let obj_nextPageToken_union0 = null;
        const obj_nextPageToken_union0_error = (() => {
            if (typeof obj_nextPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union0_error != null) {
            obj_nextPageToken_union0 = obj_nextPageToken_union0_error.message;
        }
        let obj_nextPageToken_union1 = null;
        const obj_nextPageToken_union1_error = (() => {
            if (obj_nextPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union1_error != null) {
            obj_nextPageToken_union1 = obj_nextPageToken_union1_error.message;
        }
        if (obj_nextPageToken_union0 && obj_nextPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageToken + '")';
            message += '\n' + obj_nextPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageUrl = obj.nextPageUrl;
        const path_nextPageUrl = path + '.nextPageUrl';
        let obj_nextPageUrl_union0 = null;
        const obj_nextPageUrl_union0_error = (() => {
            if (typeof obj_nextPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union0_error != null) {
            obj_nextPageUrl_union0 = obj_nextPageUrl_union0_error.message;
        }
        let obj_nextPageUrl_union1 = null;
        const obj_nextPageUrl_union1_error = (() => {
            if (obj_nextPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageUrl + '" (at "' + path_nextPageUrl + '")');
            }
        })();
        if (obj_nextPageUrl_union1_error != null) {
            obj_nextPageUrl_union1 = obj_nextPageUrl_union1_error.message;
        }
        if (obj_nextPageUrl_union0 && obj_nextPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageUrl + '")';
            message += '\n' + obj_nextPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_optionalFields = obj.optionalFields;
        const path_optionalFields = path + '.optionalFields';
        if (!ArrayIsArray(obj_optionalFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_optionalFields + '" (at "' + path_optionalFields + '")');
        }
        for (let i = 0; i < obj_optionalFields.length; i++) {
            const obj_optionalFields_item = obj_optionalFields[i];
            const path_optionalFields_item = path_optionalFields + '[' + i + ']';
            if (typeof obj_optionalFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_optionalFields_item + '" (at "' + path_optionalFields_item + '")');
            }
        }
        const obj_pageSize = obj.pageSize;
        const path_pageSize = path + '.pageSize';
        if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
        }
        const obj_previousPageToken = obj.previousPageToken;
        const path_previousPageToken = path + '.previousPageToken';
        let obj_previousPageToken_union0 = null;
        const obj_previousPageToken_union0_error = (() => {
            if (typeof obj_previousPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union0_error != null) {
            obj_previousPageToken_union0 = obj_previousPageToken_union0_error.message;
        }
        let obj_previousPageToken_union1 = null;
        const obj_previousPageToken_union1_error = (() => {
            if (obj_previousPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union1_error != null) {
            obj_previousPageToken_union1 = obj_previousPageToken_union1_error.message;
        }
        if (obj_previousPageToken_union0 && obj_previousPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageToken + '")';
            message += '\n' + obj_previousPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_previousPageUrl = obj.previousPageUrl;
        const path_previousPageUrl = path + '.previousPageUrl';
        let obj_previousPageUrl_union0 = null;
        const obj_previousPageUrl_union0_error = (() => {
            if (typeof obj_previousPageUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union0_error != null) {
            obj_previousPageUrl_union0 = obj_previousPageUrl_union0_error.message;
        }
        let obj_previousPageUrl_union1 = null;
        const obj_previousPageUrl_union1_error = (() => {
            if (obj_previousPageUrl !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageUrl + '" (at "' + path_previousPageUrl + '")');
            }
        })();
        if (obj_previousPageUrl_union1_error != null) {
            obj_previousPageUrl_union1 = obj_previousPageUrl_union1_error.message;
        }
        if (obj_previousPageUrl_union0 && obj_previousPageUrl_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageUrl + '")';
            message += '\n' + obj_previousPageUrl_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageUrl_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (!ArrayIsArray(obj_records)) {
            return new TypeError('Expected "array" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
        for (let i = 0; i < obj_records.length; i++) {
            const obj_records_item = obj_records[i];
            const path_records_item = path_records + '[' + i + ']';
            if (typeof obj_records_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_records_item + '" (at "' + path_records_item + '")');
            }
        }
        const obj_sortBy = obj.sortBy;
        const path_sortBy = path + '.sortBy';
        if (!ArrayIsArray(obj_sortBy)) {
            return new TypeError('Expected "array" but received "' + typeof obj_sortBy + '" (at "' + path_sortBy + '")');
        }
        for (let i = 0; i < obj_sortBy.length; i++) {
            const obj_sortBy_item = obj_sortBy[i];
            const path_sortBy_item = path_sortBy + '[' + i + ']';
            if (typeof obj_sortBy_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_sortBy_item + '" (at "' + path_sortBy_item + '")');
            }
        }
        const obj_where = obj.where;
        const path_where = path + '.where';
        let obj_where_union0 = null;
        const obj_where_union0_error = (() => {
            if (typeof obj_where !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_where + '" (at "' + path_where + '")');
            }
        })();
        if (obj_where_union0_error != null) {
            obj_where_union0 = obj_where_union0_error.message;
        }
        let obj_where_union1 = null;
        const obj_where_union1_error = (() => {
            if (obj_where !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_where + '" (at "' + path_where + '")');
            }
        })();
        if (obj_where_union1_error != null) {
            obj_where_union1 = obj_where_union1_error.message;
        }
        if (obj_where_union0 && obj_where_union1) {
            let message = 'Object doesn\'t match union (at "' + path_where + '")';
            message += '\n' + obj_where_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_where_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$d = 'RelatedListRecordCollectionRepresentation';
function keyBuilder$t(luvio, config) {
    return keyPrefix + '::' + RepresentationType$d + ':' + '[' + config.sortBy.join(',') + ']' + ':' + (config.parentRecordId === null ? '' : config.parentRecordId) + ':' + config.relatedListId + ':' + (config.where === null ? '' : config.where);
}
function keyBuilderFromType$a(luvio, object) {
    const keyParams = {
        sortBy: object.sortBy,
        parentRecordId: object.listReference.inContextOfRecordId,
        relatedListId: object.listReference.relatedListId,
        where: object.where
    };
    return keyBuilder$t(luvio, keyParams);
}
function normalize$8(input, existing, path, luvio, store, timestamp) {
    const input_records = input.records;
    const input_records_id = path.fullPath + '__records';
    for (let i = 0; i < input_records.length; i++) {
        const input_records_item = input_records[i];
        let input_records_item_id = input_records_id + '__' + i;
        input_records[i] = ingest$O(input_records_item, {
            fullPath: input_records_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
function getPageMetadata(paginationMetadata, paginationParams) {
    const metadataProperties = {};
    const sink = {
        metadataProperties
    };
    if (paginationMetadata === undefined) {
        return sink;
    }
    const { token, pageSize } = paginationParams;
    const pageTokenAndOffset = getPageTokenAndOffset(paginationMetadata, token);
    if (pageTokenAndOffset === undefined) {
        return sink;
    }
    const [pageToken, startOffset] = pageTokenAndOffset;
    const endOffset = pageEndOffset(paginationMetadata, startOffset, pageSize);
    sink.startOffset = startOffset;
    sink.endOffset = endOffset;
    metadataProperties.currentPageToken = pageToken;
    const { clientToken: nextClientToken, serverToken: nextServerToken } = getNextPageTokens(paginationMetadata, endOffset);
    if (nextClientToken !== undefined) {
        metadataProperties.nextPageToken = nextClientToken;
        sink.nextServerToken = nextServerToken;
    }
    const previousClientToken = getPreviousClientToken(paginationMetadata, startOffset, pageSize);
    if (previousClientToken !== undefined) {
        metadataProperties.previousPageToken = previousClientToken;
    }
    metadataProperties.pageSize = pageSize;
    metadataProperties.count = endOffset - startOffset;
    return sink;
}
const dynamicSelect$4 = function dynamicRelatedListRecordCollectionRepresentationSelect(params, paginationParams) {
    const recordsPathSelection = params.records === undefined ? {
        name: 'records',
        kind: 'Link',
        fragment: select$1V()
    } : params.records;
    const { selections: RelatedListReferenceRepresentation__selections, opaque: RelatedListReferenceRepresentation__opaque, } = select$v();
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: false,
        version: VERSION$c,
        read: (source, reader) => {
            const sink = {};
            if (paginationParams === undefined) {
                return sink;
            }
            const metadata = reader.resolveMetadata(source, PAGINATION_VERSION);
            const currentPageMetadata = getPageMetadata(metadata, paginationParams);
            const { startOffset, endOffset, metadataProperties } = currentPageMetadata;
            if (metadata !== undefined && startOffset !== undefined && endOffset !== undefined) {
                const itemsProperty = 'records';
                reader.enterPath(itemsProperty);
                const itemsSource = source[itemsProperty];
                const itemsSink = [];
                const allSink = [];
                for (let i = startOffset; i < endOffset; i++) {
                    reader.enterPath(i);
                    reader.readSingleLink(i, recordsPathSelection, itemsSource, allSink, i - startOffset);
                    if (reader.getIsDataMissing() === false) {
                        itemsSink[i - startOffset] = allSink[i - startOffset];
                    }
                    reader.exitPath();
                }
                reader.exitPath();
                reader.assignNonScalar(sink, itemsProperty, itemsSink);
            }
            reader.enterPath('currentPageToken');
            reader.readScalar('currentPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('nextPageToken');
            reader.readScalar('nextPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('previousPageToken');
            reader.readScalar('previousPageToken', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('pageSize');
            reader.readScalar('pageSize', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('count');
            reader.readScalar('count', metadataProperties, sink);
            reader.exitPath();
            reader.enterPath('fields');
            reader.readScalarPlural('fields', source, sink, true);
            reader.exitPath();
            reader.enterPath('listInfoETag');
            reader.readScalar('listInfoETag', source, sink);
            reader.exitPath();
            reader.enterPath('listReference');
            reader.readObject('listReference', {
                name: 'listReference',
                kind: 'Object',
                selections: RelatedListReferenceRepresentation__selections
            }, source, sink);
            reader.exitPath();
            reader.enterPath('optionalFields');
            reader.readScalarPlural('optionalFields', source, sink, true);
            reader.exitPath();
            reader.enterPath('sortBy');
            reader.readScalarPlural('sortBy', source, sink, true);
            reader.exitPath();
            reader.enterPath('where');
            reader.readScalar('where', source, sink);
            reader.exitPath();
            return sink;
        },
    };
};
function equals$c(existing, incoming) {
    const existing_count = existing.count;
    const incoming_count = incoming.count;
    if (!(existing_count === incoming_count)) {
        return false;
    }
    const existing_pageSize = existing.pageSize;
    const incoming_pageSize = incoming.pageSize;
    if (!(existing_pageSize === incoming_pageSize)) {
        return false;
    }
    const existing_currentPageToken = existing.currentPageToken;
    const incoming_currentPageToken = incoming.currentPageToken;
    if (!(existing_currentPageToken === incoming_currentPageToken)) {
        return false;
    }
    const existing_currentPageUrl = existing.currentPageUrl;
    const incoming_currentPageUrl = incoming.currentPageUrl;
    if (!(existing_currentPageUrl === incoming_currentPageUrl)) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_items = equalsArray(existing_fields, incoming_fields, (existing_fields_item, incoming_fields_item) => {
        if (!(existing_fields_item === incoming_fields_item)) {
            return false;
        }
    });
    if (equals_fields_items === false) {
        return false;
    }
    const existing_listInfoETag = existing.listInfoETag;
    const incoming_listInfoETag = incoming.listInfoETag;
    if (!(existing_listInfoETag === incoming_listInfoETag)) {
        return false;
    }
    const existing_listReference = existing.listReference;
    const incoming_listReference = incoming.listReference;
    if (!(equals$h(existing_listReference, incoming_listReference))) {
        return false;
    }
    const existing_nextPageToken = existing.nextPageToken;
    const incoming_nextPageToken = incoming.nextPageToken;
    if (!(existing_nextPageToken === incoming_nextPageToken)) {
        return false;
    }
    const existing_nextPageUrl = existing.nextPageUrl;
    const incoming_nextPageUrl = incoming.nextPageUrl;
    if (!(existing_nextPageUrl === incoming_nextPageUrl)) {
        return false;
    }
    const existing_optionalFields = existing.optionalFields;
    const incoming_optionalFields = incoming.optionalFields;
    const equals_optionalFields_items = equalsArray(existing_optionalFields, incoming_optionalFields, (existing_optionalFields_item, incoming_optionalFields_item) => {
        if (!(existing_optionalFields_item === incoming_optionalFields_item)) {
            return false;
        }
    });
    if (equals_optionalFields_items === false) {
        return false;
    }
    const existing_previousPageToken = existing.previousPageToken;
    const incoming_previousPageToken = incoming.previousPageToken;
    if (!(existing_previousPageToken === incoming_previousPageToken)) {
        return false;
    }
    const existing_previousPageUrl = existing.previousPageUrl;
    const incoming_previousPageUrl = incoming.previousPageUrl;
    if (!(existing_previousPageUrl === incoming_previousPageUrl)) {
        return false;
    }
    const existing_records = existing.records;
    const incoming_records = incoming.records;
    const equals_records_items = equalsArray(existing_records, incoming_records, (existing_records_item, incoming_records_item) => {
        if (!(existing_records_item.__ref === incoming_records_item.__ref)) {
            return false;
        }
    });
    if (equals_records_items === false) {
        return false;
    }
    const existing_sortBy = existing.sortBy;
    const incoming_sortBy = incoming.sortBy;
    const equals_sortBy_items = equalsArray(existing_sortBy, incoming_sortBy, (existing_sortBy_item, incoming_sortBy_item) => {
        if (!(existing_sortBy_item === incoming_sortBy_item)) {
            return false;
        }
    });
    if (equals_sortBy_items === false) {
        return false;
    }
    const existing_where = existing.where;
    const incoming_where = incoming.where;
    if (!(existing_where === incoming_where)) {
        return false;
    }
    return true;
}
const ingest$8 = function RelatedListRecordCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$A(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$a(luvio, input);
    const existingRecord = store.readEntry(key);
    const ttlToUse = TTL$a;
    let incomingRecord = normalize$8(input, store.readEntry(key), {
        fullPath: key,
        parent: path.parent,
        propertyName: path.propertyName,
        ttl: ttlToUse
    }, luvio, store, timestamp);
    const paginationKey = key + '__pagination';
    const existingPaginationMetadata = store.readEntry(paginationKey);
    const { count: count, currentPageToken: token, nextPageToken: nextToken, pageSize: pageSize, previousPageToken: previousToken, records: items } = input;
    const startOffset = existingPaginationMetadata === undefined ? 0 : offsetFromServerToken(existingPaginationMetadata, token);
    if (process.env.NODE_ENV !== 'production') {
        if (startOffset < 0 ||
            (existingRecord && existingRecord.records && existingRecord.records.length < startOffset)) {
            throw new RangeError('currentPageToken value ' + token + ' is not recognized');
        }
    }
    const incomingPaginationMetadata = {
        clientTokens: {},
        serverTokens: []
    };
    const pageClientToken = generateClientToken(startOffset);
    addTokens(incomingPaginationMetadata, startOffset, pageClientToken, token);
    const nextOffset = startOffset + items.length;
    if (nextToken === null) {
        incomingPaginationMetadata.__END__ = nextOffset;
    }
    else {
        const nextClientToken = generateClientToken(nextOffset);
        addTokens(incomingPaginationMetadata, nextOffset, nextClientToken, nextToken);
        if (existingPaginationMetadata !== undefined) {
            const listEndOffset = existingPaginationMetadata.__END__;
            if (listEndOffset !== undefined && nextOffset >= listEndOffset) {
                incomingPaginationMetadata.__END__ = undefined;
            }
        }
    }
    if (previousToken !== null) {
        const previousOffset = Math.max(startOffset - pageSize, 0);
        const previousClientToken = generateClientToken(previousOffset);
        addTokens(incomingPaginationMetadata, previousOffset, previousClientToken, previousToken);
    }
    for (let i = startOffset + 1; i < nextOffset; i++) {
        const itemClientToken = generateClientToken(i);
        addTokens(incomingPaginationMetadata, i, itemClientToken);
    }
    const mergedPaginationMetadata = mergeMetadata(existingPaginationMetadata, incomingPaginationMetadata);
    if (existingPaginationMetadata === undefined ||
        equalsMetadata(existingPaginationMetadata, mergedPaginationMetadata) === false) {
        luvio.storePublish(paginationKey, mergedPaginationMetadata);
        luvio.publishStoreMetadata(paginationKey, paginationStoreMetadata);
    }
    assignMetadataLink(incomingRecord, paginationKey);
    if (existingRecord !== undefined && existingRecord.records !== undefined) {
        incomingRecord.records = [
            ...existingRecord.records.slice(0, startOffset),
            ...incomingRecord.records,
            ...existingRecord.records.slice(nextOffset),
        ];
    }
    if (existingRecord === undefined || equals$c(existingRecord, incomingRecord) === false) {
        luvio.storePublish(key, incomingRecord);
    }
    {
        const storeMetadataParams = {
            ttl: ttlToUse,
            namespace: "UiApi",
            version: VERSION$c,
            representationName: RepresentationType$d,
            ingestionTimestamp: timestamp,
        };
        luvio.publishStoreMetadata(key, storeMetadataParams);
    }
    return createLink(key);
};
function getTypeCacheKeys$d(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$a(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$d,
        mergeable: true
    });
    rootKeySet.set(rootKey + '__pagination', {
        namespace: keyPrefix,
        representationName: RepresentationType$d,
        mergeable: true
    });
    const input_records_length = input.records.length;
    for (let i = 0; i < input_records_length; i++) {
        getTypeCacheKeys$X(rootKeySet, luvio, input.records[i]);
    }
}

function select$h(luvio, params) {
    const { fields = [], optionalFields = [] } = params.body;
    return dynamicSelect$4({
        records: {
            name: 'records',
            kind: 'Link',
            fragment: {
                kind: 'Fragment',
                private: ['eTag', 'weakEtag'],
                selections: buildSelectionFromFields(fields, optionalFields),
                version: VERSION$1g
            },
        },
    }, createPaginationParams(params));
}
function ingestSuccess$b(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$s(luvio, resourceParams);
    luvio.storeIngest(key, ingest$8, body);
    const optionalFields = resourceParams.body.optionalFields;
    if (optionalFields && optionalFields.length > 0) {
        const normalized = body;
        markMissingOptionalFieldsOnRecords(luvio, normalized, optionalFields);
    }
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$h(luvio, resourceParams),
        variables: {},
    }, snapshotRefresh);
    return snapshot;
}
function markMissingOptionalFieldsOnRecords(luvio, nomalized, optionalFields) {
    const records = nomalized.records;
    for (let i = 0; i < records.length; i++) {
        const record = records[i];
        const recordKey = record.__ref;
        if (recordKey !== undefined) {
            const node = luvio.getNode(recordKey);
            markMissingOptionalFields(node, optionalFields);
        }
    }
}

function createPaginationParams(params) {
    const { body } = params;
    return {
        token: body.pageToken,
        pageSize: body.pageSize === undefined ? 50 : body.pageSize
    };
}
function keyBuilder$s(luvio, params) {
    return keyBuilder$t(luvio, {
        sortBy: params.body.sortBy || [],
        where: params.body.where || null,
        parentRecordId: params.urlParams.parentRecordId,
        relatedListId: params.urlParams.relatedListId
    });
}
function getResponseCacheKeys$h(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$d(storeKeyMap, luvio, response);
}
function ingestError$7(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$s(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$a,
        namespace: keyPrefix,
        version: VERSION$c,
        representationName: RepresentationType$d
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$l(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-records/' + config.urlParams.parentRecordId + '/' + config.urlParams.relatedListId + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

function createChildResourceParams$1(resourceParams) {
    const childConfigs = [];
    for (let index = 0, len = resourceParams.body.relatedListParameters.length; index < len; index += 1) {
        let childConfig = {
            urlParams: {
                parentRecordId: resourceParams.urlParams.parentRecordId,
                relatedListId: resourceParams.body.relatedListParameters[index].relatedListId,
            },
            body: {},
        };
        let relatedListConfig = resourceParams.body.relatedListParameters[index];
        // manually populate childConfig body
        if ('fields' in relatedListConfig) {
            childConfig.body.fields = relatedListConfig.fields;
        }
        if ('optionalFields' in relatedListConfig) {
            childConfig.body.optionalFields = relatedListConfig.optionalFields;
        }
        if ('pageSize' in relatedListConfig) {
            childConfig.body.pageSize = relatedListConfig.pageSize;
        }
        if ('sortBy' in relatedListConfig) {
            childConfig.body.sortBy = relatedListConfig.sortBy;
        }
        if ('where' in relatedListConfig) {
            childConfig.body.where = relatedListConfig.where;
        }
        childConfigs.push(childConfig);
    }
    return childConfigs;
}

const nonCachedErrors = ObjectCreate$1(null);
function createChildResourceParams(resourceParams) {
    return createChildResourceParams$1(resourceParams);
}
function selectChildResourceParams(luvio, childResources, resourceParams) {
    const envelopeBodyPath = 'result';
    const envelopeStatusCodePath = 'statusCode';
    const envelopePath = 'results';
    return {
        kind: 'Fragment',
        reader: true,
        synthetic: true,
        read: (reader) => {
            // Top-level 404 lookup
            const result = reader.storeLookup(keyBuilder$r(luvio, resourceParams));
            if (result.state === reader.StoreResolveResultState.Error && result.value.status === 404) {
                return {
                    state: 'Error',
                    value: result.value,
                };
            }
            const sink = {};
            reader.enterPath(envelopePath);
            const results = [];
            for (let i = 0, len = childResources.length; i < len; i += 1) {
                reader.enterPath(i);
                reader.enterPath(envelopeBodyPath);
                const childResource = childResources[i];
                const childKey = keyBuilder$s(luvio, childResource);
                const childFragment = select$h(luvio, childResource);
                const isMissingDataBeforeChildRead = reader.getIsDataMissing();
                const childSnapshot = reader.read({
                    recordId: childKey,
                    node: childFragment,
                    variables: {},
                });
                reader.exitPath();
                const childSink = {};
                reader.markSeenId(childKey);
                switch (childSnapshot.state) {
                    case 'Stale':
                        reader.markStale();
                    // Stale needs envelope bodies filled in so don't break
                    case 'Fulfilled':
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, 200);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshot.data);
                        reader.exitPath();
                        break;
                    case 'Error':
                        const childSnapshotError = childSnapshot.error;
                        reader.enterPath(envelopeStatusCodePath);
                        reader.assignScalar(envelopeStatusCodePath, childSink, childSnapshotError.status);
                        reader.exitPath();
                        reader.enterPath(envelopeBodyPath);
                        reader.assignNonScalar(childSink, envelopeBodyPath, childSnapshotError.body);
                        reader.exitPath();
                        break;
                    case 'Unfulfilled':
                        // if child snapshot doesn't have any data then
                        // that means the child record key is missing
                        if (childSnapshot.data === undefined) {
                            if (reader.isRebuilding() === false) {
                                // not a rebuild, mark as missing and move on
                                reader.markMissingLink(childKey);
                                break;
                            }
                            // On rebuilds we have to check if there is a non-cached
                            // error that we know about.  If we don't do this then
                            // rebuilds will go into endless refresh loop if a child
                            // has non-cached errors (since the top-level composite
                            // snapshot will look like an Unfulfilled snapshot
                            // instead of an error snapshot).
                            const nonCachedError = nonCachedErrors[childKey];
                            if (nonCachedError === undefined || nonCachedError.expiration < reader.getTimeStamp()) {
                                reader.markMissingLink(childKey);
                            }
                            else {
                                // if this child error was the only reason the reader
                                // is marked as missing then we want to undo that
                                if (isMissingDataBeforeChildRead === false) {
                                    reader.unMarkMissing();
                                }
                                // put status code and body into reader path
                                const { response: nonCachedBody, status: nonCachedStatus } = nonCachedError;
                                reader.enterPath(envelopeStatusCodePath);
                                reader.assignScalar(envelopeStatusCodePath, childSink, nonCachedStatus);
                                reader.exitPath();
                                reader.enterPath(envelopeBodyPath);
                                reader.assignNonScalar(childSink, envelopeBodyPath, nonCachedBody);
                                reader.exitPath();
                            }
                        }
                        break;
                    case 'Pending':
                        reader.markPending();
                        break;
                }
                ArrayPrototypePush.call(results, childSink);
                reader.exitPath();
            }
            reader.assignNonScalar(sink, envelopePath, results);
            reader.exitPath();
            return sink;
        }
    };
}
function select$g(luvio, resourceParams) {
    const childResources = createChildResourceParams(resourceParams);
    return selectChildResourceParams(luvio, childResources, resourceParams);
}
function keyBuilder$r(luvio, params) {
    return keyPrefix + '::RelatedListRecordCollectionBatchRepresentation:(' + 'parentRecordId:' + params.urlParams.parentRecordId + ',' + '[' + params.body.relatedListParameters.map(element => (element.fields === undefined ? 'relatedListParameters.fields' : 'relatedListParameters.fields:' + element.fields) + '::' + (element.optionalFields === undefined ? 'relatedListParameters.optionalFields' : 'relatedListParameters.optionalFields:' + element.optionalFields) + '::' + (element.pageSize === undefined ? 'relatedListParameters.pageSize' : 'relatedListParameters.pageSize:' + element.pageSize) + '::' + 'relatedListParameters.relatedListId:' + element.relatedListId + '::' + (element.sortBy === undefined ? 'relatedListParameters.sortBy' : 'relatedListParameters.sortBy:' + element.sortBy) + '::' + (element.where === undefined ? 'relatedListParameters.where' : 'relatedListParameters.where:' + element.where)).join(',') + ']' + ')';
}
function getResponseCacheKeys$g(keys, luvio, resourceParams, response) {
    const childEnvelopes = response.results;
    const childResourceParamsArray = createChildResourceParams(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    // get children keys
    for (let index = 0, len = childResourceParamsArray.length; index < len; index++) {
        const childResourceParams = childResourceParamsArray[index];
        const childResult = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = childResult;
        if (childStatusCode === 200) {
            getResponseCacheKeys$h(keys, luvio, childResourceParams, childBody);
        }
        else if (childStatusCode === 404) {
            const childKey = keyBuilder$s(luvio, childResourceParams);
            keys.set(childKey, {
                namespace: keyPrefix,
                representationName: RepresentationType$d,
                mergeable: false
            });
        }
    }
}
function ingestSuccessChildResourceParams$1(luvio, childResourceParamsArray, childEnvelopes) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let snapshotState = 'Fulfilled';
    const now = Date.now();
    for (let index = 0, len = childResourceParamsArray.length; index < len; index += 1) {
        const childResourceParams = childResourceParamsArray[index];
        const childKey = keyBuilder$s(luvio, childResourceParams);
        const result = childEnvelopes[index];
        const { statusCode: childStatusCode, result: childBody } = result;
        if (childStatusCode === 200) {
            const childResponse = {
                status: 200,
                body: childBody,
                ok: true,
                statusText: 'OK',
                headers: {},
            };
            const childSnapshot = ingestSuccess$b(luvio, childResourceParams, childResponse);
            if (childSnapshot.state === "Stale") {
                snapshotState = "Stale";
            }
            seenRecords.merge(childSnapshot.seenRecords);
            seenRecords.add(childSnapshot.recordId);
            const childValue = {
                statusCode: 200,
                result: childSnapshot.data,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        else {
            const childStatusCodeText = getFetchResponseStatusText(result.statusCode);
            const childResponse = {
                status: childStatusCode,
                body: childBody,
                ok: false,
                statusText: childStatusCodeText,
                headers: {},
                errorType: 'fetchResponse'
            };
            ingestError$7(luvio, childResourceParams, childResponse);
            seenRecords.add(childKey);
            const childValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            deepFreeze(childValue);
            ArrayPrototypePush.call(childSnapshotDataResponses, childValue);
        }
        // track non-cached responses so rebuilds work properly
        if (childStatusCode !== 404 && childStatusCode !== 200) {
            nonCachedErrors[childKey] = { expiration: now + TTL$a, response: childBody, status: childStatusCode };
        }
        else {
            delete nonCachedErrors[childKey];
        }
    }
    const childSnapshotData = {
        results: childSnapshotDataResponses
    };
    deepFreeze(childSnapshotData);
    return { childSnapshotData: childSnapshotData, seenRecords, snapshotState };
}
function ingestSuccess$a(luvio, resourceParams, response, snapshotRefresh) {
    const childEnvelopes = response.body.results;
    const childResourceParamsArray = createChildResourceParams(resourceParams);
    if (process.env.NODE_ENV !== 'production') {
        if (childResourceParamsArray.length !== childEnvelopes.length) {
            throw new Error('Invalid composite resource response. Expected ' + childResourceParamsArray.length + ' items, received ' + childEnvelopes.length);
        }
    }
    const key = keyBuilder$r(luvio, resourceParams);
    const { childSnapshotData, seenRecords, snapshotState } = ingestSuccessChildResourceParams$1(luvio, childResourceParamsArray, childEnvelopes);
    const syntheticSnapshot = {
        recordId: key,
        data: childSnapshotData,
        state: snapshotState,
        seenRecords: seenRecords,
        select: {
            recordId: key,
            node: select$g(luvio, resourceParams),
            variables: {},
        },
        refresh: snapshotRefresh,
        variables: {}
    };
    // evict top level composite record from the store. This covers the case where a previous resource request returned a 404.
    luvio.storeEvict(key);
    return syntheticSnapshot;
}
function ingestError$6(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$r(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest$k(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/related-list-records/batch/' + config.urlParams.parentRecordId + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$e = 'getRelatedListRecordsBatch';
const getRelatedListRecordsBatch_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentRecordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('relatedListParameters', true, 2 /* Body */, 4 /* Unsupported */, true),
];
const getRelatedListRecordsBatch_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$e, getRelatedListRecordsBatch_ConfigPropertyMetadata);
const createResourceParams$h = /*#__PURE__*/ createResourceParams$13(getRelatedListRecordsBatch_ConfigPropertyMetadata);
function keyBuilder$q(luvio, config) {
    const resourceParams = createResourceParams$h(config);
    return keyBuilder$r(luvio, resourceParams);
}
function typeCheckConfig$i(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListRecordsBatch_ConfigPropertyMetadata);
    const untrustedConfig_relatedListParameters = untrustedConfig.relatedListParameters;
    if (ArrayIsArray$1(untrustedConfig_relatedListParameters)) {
        const untrustedConfig_relatedListParameters_array = [];
        for (let i = 0, arrayLength = untrustedConfig_relatedListParameters.length; i < arrayLength; i++) {
            const untrustedConfig_relatedListParameters_item = untrustedConfig_relatedListParameters[i];
            const referenceRelatedListRecordsSingleBatchInputRepresentationValidationError = validate$B(untrustedConfig_relatedListParameters_item);
            if (referenceRelatedListRecordsSingleBatchInputRepresentationValidationError === null) {
                untrustedConfig_relatedListParameters_array.push(untrustedConfig_relatedListParameters_item);
            }
        }
        config.relatedListParameters = untrustedConfig_relatedListParameters_array;
    }
    return config;
}
function validateAdapterConfig$h(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListRecordsBatch_ConfigPropertyMetadata);
    const config = typeCheckConfig$i(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$8(luvio, config) {
    const resourceParams = createResourceParams$h(config);
    return select$g(luvio, resourceParams);
}
function onFetchResponseSuccess$9(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$a(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$j(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$8(luvio, config, resourceParams, response) {
    const snapshot = ingestError$6(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$j(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$j(luvio, config, options) {
    const resourceParams = createResourceParams$h(config);
    const request = createResourceRequest$k(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$9(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$g(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$8(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$b(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$j, 'get', false);
}
function buildCachedSnapshotCachePolicy$a(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$q(luvio, config),
        node: adapterFragment$8(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$j(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getRelatedListRecordsBatchAdapterFactory = (luvio) => function UiApi__getRelatedListRecordsBatch(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$h(untrustedConfig, getRelatedListRecordsBatch_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$a, buildNetworkSnapshotCachePolicy$b);
};

const adapterName$d = 'getRelatedListRecords';
const getRelatedListRecords_ConfigPropertyMetadata = [
    generateParamConfigMetadata('parentRecordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('relatedListId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('fields', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('optionalFields', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('pageSize', false, 2 /* Body */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('where', false, 2 /* Body */, 0 /* String */),
];
const getRelatedListRecords_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$d, getRelatedListRecords_ConfigPropertyMetadata);
const createResourceParams$g = /*#__PURE__*/ createResourceParams$13(getRelatedListRecords_ConfigPropertyMetadata);
function keyBuilder$p(luvio, config) {
    const resourceParams = createResourceParams$g(config);
    return keyBuilder$s(luvio, resourceParams);
}
function typeCheckConfig$h(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRelatedListRecords_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$g(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRelatedListRecords_ConfigPropertyMetadata);
    const config = typeCheckConfig$h(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$7(luvio, config) {
    const resourceParams = createResourceParams$g(config);
    return select$h(luvio, resourceParams);
}
function onFetchResponseSuccess$8(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$b(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$i(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$7(luvio, config, resourceParams, response) {
    const snapshot = ingestError$7(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$i(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function prepareRequest$2(luvio, config, resourceParams, cacheSnapshot) {
    const paginationMetadata = getPaginationMetadata$1(luvio, resourceParams);
    if (paginationMetadata === undefined) {
        return createResourceRequest$l(resourceParams);
    }
    const { token: configToken, pageSize: configPageSize } = createPaginationParams(resourceParams);
    const configTokenOffset = offsetFromClientToken(paginationMetadata, configToken);
    const maxOffset = getRequestMaxOffset(configTokenOffset, cacheSnapshot);
    const [serverToken, serverTokenOffset] = serverTokenForAtMost(paginationMetadata, maxOffset);
    return createResourceRequest$l(createResourceParams$g({
        ...config,
        pageSize: configPageSize - (serverTokenOffset - configTokenOffset),
        pageToken: serverToken
    }));
}
function getRequestMaxOffset(configTokenOffset, cacheSnapshot) {
    if (cacheSnapshot === undefined) {
        return configTokenOffset;
    }
    const num = getCachedItemsNumber$1(cacheSnapshot);
    if (num <= 0) {
        return configTokenOffset;
    }
    return Math.max(configTokenOffset + num, configTokenOffset);
}
function getCachedItemsNumber$1(cacheSnapshot) {
    const { data } = cacheSnapshot;
    if (data === undefined || !data.records) {
        return 0;
    }
    const items = data.records;
    for (let i = 0; i < items.length; i++) {
        if (items[i] === undefined) {
            return i;
        }
    }
    return items.length;
}
function getPaginationMetadata$1(luvio, resourceParams) {
    const key = keyBuilder$s(luvio, resourceParams);
    const selector = {
        recordId: key,
        node: {
            kind: 'Fragment',
            version: VERSION$c,
            private: [],
            selections: [
                {
                    kind: 'Link',
                    name: '__metadata',
                    fragment: {
                        kind: 'Fragment',
                        version: PAGINATION_VERSION,
                        opaque: true,
                        private: [],
                    },
                },
            ],
        },
        variables: {}
    };
    const node = luvio.storeLookup(selector);
    if (node.state !== 'Fulfilled') {
        return;
    }
    return node.data.__metadata;
}
function buildNetworkSnapshot$i(luvio, config, options, cacheSnapshot) {
    const resourceParams = createResourceParams$g(config);
    const request = prepareRequest$2(luvio, config, resourceParams, cacheSnapshot);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$8(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$h(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$7(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$a(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$i, 'get', true);
}
function buildCachedSnapshotCachePolicy$9(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$p(luvio, config),
        node: adapterFragment$7(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$i(luvio, config, snapshotRefreshOptions)
    });
    if (isUnfulfilledSnapshot$1(cacheSnapshot) && cacheSnapshot.data !== undefined) {
        context.cacheSnapshot = cacheSnapshot;
    }
    return cacheSnapshot;
}
const getRelatedListRecordsAdapterFactory = (luvio) => function UiApi__getRelatedListRecords(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$g(untrustedConfig, getRelatedListRecords_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$9, buildNetworkSnapshotCachePolicy$a);
};

function validate$z(obj, path = 'SearchFilterOptionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_value = obj.value;
        const path_value = path + '.value';
        if (typeof obj_value !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_value + '" (at "' + path_value + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

var DiscriminatorValues$1;
(function (DiscriminatorValues) {
    DiscriminatorValues["Text"] = "Text";
    DiscriminatorValues["Select"] = "Select";
})(DiscriminatorValues$1 || (DiscriminatorValues$1 = {}));

var DiscriminatorValues;
(function (DiscriminatorValues) {
    DiscriminatorValues["Field"] = "Field";
    DiscriminatorValues["DataCategory"] = "DataCategory";
})(DiscriminatorValues || (DiscriminatorValues = {}));
function validate$y(obj, path = 'SearchFilterDefinitionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_defaultValues = obj.defaultValues;
        const path_defaultValues = path + '.defaultValues';
        if (!ArrayIsArray(obj_defaultValues)) {
            return new TypeError('Expected "array" but received "' + typeof obj_defaultValues + '" (at "' + path_defaultValues + '")');
        }
        for (let i = 0; i < obj_defaultValues.length; i++) {
            const obj_defaultValues_item = obj_defaultValues[i];
            const path_defaultValues_item = path_defaultValues + '[' + i + ']';
            if (typeof obj_defaultValues_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_defaultValues_item + '" (at "' + path_defaultValues_item + '")');
            }
        }
        if (obj.helpMessage !== undefined) {
            const obj_helpMessage = obj.helpMessage;
            const path_helpMessage = path + '.helpMessage';
            let obj_helpMessage_union0 = null;
            const obj_helpMessage_union0_error = (() => {
                if (typeof obj_helpMessage !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_helpMessage + '" (at "' + path_helpMessage + '")');
                }
            })();
            if (obj_helpMessage_union0_error != null) {
                obj_helpMessage_union0 = obj_helpMessage_union0_error.message;
            }
            let obj_helpMessage_union1 = null;
            const obj_helpMessage_union1_error = (() => {
                if (obj_helpMessage !== null) {
                    return new TypeError('Expected "null" but received "' + typeof obj_helpMessage + '" (at "' + path_helpMessage + '")');
                }
            })();
            if (obj_helpMessage_union1_error != null) {
                obj_helpMessage_union1 = obj_helpMessage_union1_error.message;
            }
            if (obj_helpMessage_union0 && obj_helpMessage_union1) {
                let message = 'Object doesn\'t match union (at "' + path_helpMessage + '")';
                message += '\n' + obj_helpMessage_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_helpMessage_union1.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$9 = 30000;
const VERSION$b = "46ebae6041d5914e45bd2ccc6cb89271";
function validate$x(obj, path = 'SearchFilterMetadataCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_channel = obj.channel;
        const path_channel = path + '.channel';
        let obj_channel_union0 = null;
        const obj_channel_union0_error = (() => {
            if (typeof obj_channel !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_channel + '" (at "' + path_channel + '")');
            }
        })();
        if (obj_channel_union0_error != null) {
            obj_channel_union0 = obj_channel_union0_error.message;
        }
        let obj_channel_union1 = null;
        const obj_channel_union1_error = (() => {
            if (obj_channel !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_channel + '" (at "' + path_channel + '")');
            }
        })();
        if (obj_channel_union1_error != null) {
            obj_channel_union1 = obj_channel_union1_error.message;
        }
        if (obj_channel_union0 && obj_channel_union1) {
            let message = 'Object doesn\'t match union (at "' + path_channel + '")';
            message += '\n' + obj_channel_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_channel_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_configurationName = obj.configurationName;
        const path_configurationName = path + '.configurationName';
        let obj_configurationName_union0 = null;
        const obj_configurationName_union0_error = (() => {
            if (typeof obj_configurationName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_configurationName + '" (at "' + path_configurationName + '")');
            }
        })();
        if (obj_configurationName_union0_error != null) {
            obj_configurationName_union0 = obj_configurationName_union0_error.message;
        }
        let obj_configurationName_union1 = null;
        const obj_configurationName_union1_error = (() => {
            if (obj_configurationName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_configurationName + '" (at "' + path_configurationName + '")');
            }
        })();
        if (obj_configurationName_union1_error != null) {
            obj_configurationName_union1 = obj_configurationName_union1_error.message;
        }
        if (obj_configurationName_union0 && obj_configurationName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_configurationName + '")';
            message += '\n' + obj_configurationName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_configurationName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_filters = obj.filters;
        const path_filters = path + '.filters';
        if (!ArrayIsArray(obj_filters)) {
            return new TypeError('Expected "array" but received "' + typeof obj_filters + '" (at "' + path_filters + '")');
        }
        for (let i = 0; i < obj_filters.length; i++) {
            const obj_filters_item = obj_filters[i];
            const path_filters_item = path_filters + '[' + i + ']';
            const referencepath_filters_itemValidationError = validate$y(obj_filters_item, path_filters_item);
            if (referencepath_filters_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchFilterDefinitionRepresentation (at "' + path_filters_item + '")\n';
                message += referencepath_filters_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$c = 'SearchFilterMetadataCollectionRepresentation';
function keyBuilder$o(luvio, config) {
    return keyPrefix + '::' + RepresentationType$c + ':' + config.objectApiName + ':' + (config.channel === null ? '' : config.channel) + ':' + (config.configurationName === null ? '' : config.configurationName);
}
function keyBuilderFromType$9(luvio, object) {
    const keyParams = {
        objectApiName: object.objectApiName,
        channel: object.channel,
        configurationName: object.configurationName
    };
    return keyBuilder$o(luvio, keyParams);
}
function normalize$7(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$f = function SearchFilterMetadataCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$b,
        private: [],
        opaque: true
    };
};
function equals$b(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$7 = function SearchFilterMetadataCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$x(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$9(luvio, input);
    const ttlToUse = TTL$9;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$7, "UiApi", VERSION$b, RepresentationType$c, equals$b);
    return createLink(key);
};
function getTypeCacheKeys$c(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$9(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$c,
        mergeable: false
    });
}

function select$e(luvio, params) {
    return select$f();
}
function keyBuilder$n(luvio, params) {
    return keyBuilder$o(luvio, {
        objectApiName: params.urlParams.objectApiName,
        channel: params.queryParams.channel || null,
        configurationName: params.queryParams.configurationName || null
    });
}
function getResponseCacheKeys$f(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$c(storeKeyMap, luvio, response);
}
function ingestSuccess$9(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$n(luvio, resourceParams);
    luvio.storeIngest(key, ingest$7, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$e(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$5(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$n(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$9,
        namespace: keyPrefix,
        version: VERSION$b,
        representationName: RepresentationType$c
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$j(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/search-info/' + config.urlParams.objectApiName + '/filters',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$c = 'getSearchFilterMetadata';
const getSearchFilterMetadata_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('channel', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('configurationName', false, 1 /* QueryParameter */, 0 /* String */),
];
const getSearchFilterMetadata_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$c, getSearchFilterMetadata_ConfigPropertyMetadata);
const createResourceParams$f = /*#__PURE__*/ createResourceParams$13(getSearchFilterMetadata_ConfigPropertyMetadata);
function keyBuilder$m(luvio, config) {
    const resourceParams = createResourceParams$f(config);
    return keyBuilder$n(luvio, resourceParams);
}
function typeCheckConfig$g(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getSearchFilterMetadata_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$f(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$g(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$6(luvio, config) {
    createResourceParams$f(config);
    return select$e();
}
function onFetchResponseSuccess$7(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$9(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$h(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$6(luvio, config, resourceParams, response) {
    const snapshot = ingestError$5(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$h(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$h(luvio, config, options) {
    const resourceParams = createResourceParams$f(config);
    const request = createResourceRequest$j(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$7(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$f(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$6(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$9(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$h, undefined, false);
}
function buildCachedSnapshotCachePolicy$8(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$m(luvio, config),
        node: adapterFragment$6(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$h(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getSearchFilterMetadataAdapterFactory = (luvio) => function UiApi__getSearchFilterMetadata(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$f(untrustedConfig, getSearchFilterMetadata_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$8, buildNetworkSnapshotCachePolicy$9);
};

const TTL$8 = 30000;
const VERSION$a = "8d851a8d9abf0a061a8ad81d4cbb83bc";
function validate$w(obj, path = 'SearchFilterOptionCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_filterApiName = obj.filterApiName;
        const path_filterApiName = path + '.filterApiName';
        if (typeof obj_filterApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_filterApiName + '" (at "' + path_filterApiName + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_options = obj.options;
        const path_options = path + '.options';
        if (!ArrayIsArray(obj_options)) {
            return new TypeError('Expected "array" but received "' + typeof obj_options + '" (at "' + path_options + '")');
        }
        for (let i = 0; i < obj_options.length; i++) {
            const obj_options_item = obj_options[i];
            const path_options_item = path_options + '[' + i + ']';
            const referencepath_options_itemValidationError = validate$z(obj_options_item, path_options_item);
            if (referencepath_options_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchFilterOptionRepresentation (at "' + path_options_item + '")\n';
                message += referencepath_options_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_query = obj.query;
        const path_query = path + '.query';
        let obj_query_union0 = null;
        const obj_query_union0_error = (() => {
            if (typeof obj_query !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_query + '" (at "' + path_query + '")');
            }
        })();
        if (obj_query_union0_error != null) {
            obj_query_union0 = obj_query_union0_error.message;
        }
        let obj_query_union1 = null;
        const obj_query_union1_error = (() => {
            if (obj_query !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_query + '" (at "' + path_query + '")');
            }
        })();
        if (obj_query_union1_error != null) {
            obj_query_union1 = obj_query_union1_error.message;
        }
        if (obj_query_union0 && obj_query_union1) {
            let message = 'Object doesn\'t match union (at "' + path_query + '")';
            message += '\n' + obj_query_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_query_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$b = 'SearchFilterOptionCollectionRepresentation';
function keyBuilder$l(luvio, config) {
    return keyPrefix + '::' + RepresentationType$b + ':' + (config.query === null ? '' : config.query) + ':' + config.objectApiName + ':' + config.filterApiName;
}
function keyBuilderFromType$8(luvio, object) {
    const keyParams = {
        query: object.query,
        objectApiName: object.objectApiName,
        filterApiName: object.filterApiName
    };
    return keyBuilder$l(luvio, keyParams);
}
function normalize$6(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$d = function SearchFilterOptionCollectionRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$a,
        private: [],
        opaque: true
    };
};
function equals$a(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$6 = function SearchFilterOptionCollectionRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$w(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$8(luvio, input);
    const ttlToUse = TTL$8;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$6, "UiApi", VERSION$a, RepresentationType$b, equals$a);
    return createLink(key);
};
function getTypeCacheKeys$b(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$8(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$b,
        mergeable: false
    });
}

function select$c(luvio, params) {
    return select$d();
}
function keyBuilder$k(luvio, params) {
    return keyBuilder$l(luvio, {
        query: params.queryParams.q || null,
        objectApiName: params.urlParams.objectApiName,
        filterApiName: params.urlParams.filterApiName
    });
}
function getResponseCacheKeys$e(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$b(storeKeyMap, luvio, response);
}
function ingestSuccess$8(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$k(luvio, resourceParams);
    luvio.storeIngest(key, ingest$6, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$c(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$4(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$k(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$8,
        namespace: keyPrefix,
        version: VERSION$a,
        representationName: RepresentationType$b
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$i(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/search-info/' + config.urlParams.objectApiName + '/filters/' + config.urlParams.filterApiName + '/options',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$b = 'getSearchFilterOptions';
const getSearchFilterOptions_ConfigPropertyMetadata = [
    generateParamConfigMetadata('filterApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('q', false, 1 /* QueryParameter */, 0 /* String */),
];
const getSearchFilterOptions_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$b, getSearchFilterOptions_ConfigPropertyMetadata);
const createResourceParams$e = /*#__PURE__*/ createResourceParams$13(getSearchFilterOptions_ConfigPropertyMetadata);
function keyBuilder$j(luvio, config) {
    const resourceParams = createResourceParams$e(config);
    return keyBuilder$k(luvio, resourceParams);
}
function typeCheckConfig$f(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getSearchFilterOptions_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$e(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$f(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$5(luvio, config) {
    createResourceParams$e(config);
    return select$c();
}
function onFetchResponseSuccess$6(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$8(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$g(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$5(luvio, config, resourceParams, response) {
    const snapshot = ingestError$4(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$g(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$g(luvio, config, options) {
    const resourceParams = createResourceParams$e(config);
    const request = createResourceRequest$i(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$6(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$e(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$5(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$8(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$g, undefined, false);
}
function buildCachedSnapshotCachePolicy$7(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$j(luvio, config),
        node: adapterFragment$5(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$g(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getSearchFilterOptionsAdapterFactory = (luvio) => function UiApi__getSearchFilterOptions(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$e(untrustedConfig, getSearchFilterOptions_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$7, buildNetworkSnapshotCachePolicy$8);
};

function validate$v(obj, path = 'AdvancedLookupDisplayInfoFieldRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldPath = obj.fieldPath;
        const path_fieldPath = path + '.fieldPath';
        if (typeof obj_fieldPath !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldPath + '" (at "' + path_fieldPath + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$u(obj, path = 'AdvancedLookupDisplayInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (!ArrayIsArray(obj_fields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        for (let i = 0; i < obj_fields.length; i++) {
            const obj_fields_item = obj_fields[i];
            const path_fields_item = path_fields + '[' + i + ']';
            const referencepath_fields_itemValidationError = validate$v(obj_fields_item, path_fields_item);
            if (referencepath_fields_itemValidationError !== null) {
                let message = 'Object doesn\'t match AdvancedLookupDisplayInfoFieldRepresentation (at "' + path_fields_item + '")\n';
                message += referencepath_fields_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$t(obj, path = 'AdvancedLookupInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_displayInfo = obj.displayInfo;
        const path_displayInfo = path + '.displayInfo';
        const referencepath_displayInfoValidationError = validate$u(obj_displayInfo, path_displayInfo);
        if (referencepath_displayInfoValidationError !== null) {
            let message = 'Object doesn\'t match AdvancedLookupDisplayInfoRepresentation (at "' + path_displayInfo + '")\n';
            message += referencepath_displayInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$s(obj, path = 'DisplayLayoutRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_displayFields = obj.displayFields;
        const path_displayFields = path + '.displayFields';
        if (!ArrayIsArray(obj_displayFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_displayFields + '" (at "' + path_displayFields + '")');
        }
        for (let i = 0; i < obj_displayFields.length; i++) {
            const obj_displayFields_item = obj_displayFields[i];
            const path_displayFields_item = path_displayFields + '[' + i + ']';
            if (typeof obj_displayFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_displayFields_item + '" (at "' + path_displayFields_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$r(obj, path = 'MatchingInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_matchingFields = obj.matchingFields;
        const path_matchingFields = path + '.matchingFields';
        if (!ArrayIsArray(obj_matchingFields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_matchingFields + '" (at "' + path_matchingFields + '")');
        }
        for (let i = 0; i < obj_matchingFields.length; i++) {
            const obj_matchingFields_item = obj_matchingFields[i];
            const path_matchingFields_item = path_matchingFields + '[' + i + ']';
            if (typeof obj_matchingFields_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_matchingFields_item + '" (at "' + path_matchingFields_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$q(obj, path = 'DisplayLayoutAndMatchingInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_displayLayout = obj.displayLayout;
        const path_displayLayout = path + '.displayLayout';
        const referencepath_displayLayoutValidationError = validate$s(obj_displayLayout, path_displayLayout);
        if (referencepath_displayLayoutValidationError !== null) {
            let message = 'Object doesn\'t match DisplayLayoutRepresentation (at "' + path_displayLayout + '")\n';
            message += referencepath_displayLayoutValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_matchingInfo = obj.matchingInfo;
        const path_matchingInfo = path + '.matchingInfo';
        const referencepath_matchingInfoValidationError = validate$r(obj_matchingInfo, path_matchingInfo);
        if (referencepath_matchingInfoValidationError !== null) {
            let message = 'Object doesn\'t match MatchingInfoRepresentation (at "' + path_matchingInfo + '")\n';
            message += referencepath_matchingInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$p(obj, path = 'LookupMetadataTargetInfoRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_advancedLookupInfo = obj.advancedLookupInfo;
        const path_advancedLookupInfo = path + '.advancedLookupInfo';
        const referencepath_advancedLookupInfoValidationError = validate$t(obj_advancedLookupInfo, path_advancedLookupInfo);
        if (referencepath_advancedLookupInfoValidationError !== null) {
            let message = 'Object doesn\'t match AdvancedLookupInfoRepresentation (at "' + path_advancedLookupInfo + '")\n';
            message += referencepath_advancedLookupInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_suggestionsInfo = obj.suggestionsInfo;
        const path_suggestionsInfo = path + '.suggestionsInfo';
        const referencepath_suggestionsInfoValidationError = validate$q(obj_suggestionsInfo, path_suggestionsInfo);
        if (referencepath_suggestionsInfoValidationError !== null) {
            let message = 'Object doesn\'t match DisplayLayoutAndMatchingInfoRepresentation (at "' + path_suggestionsInfo + '")\n';
            message += referencepath_suggestionsInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$7 = 30000;
const VERSION$9 = "ab99b79a5e8a78e051ec92b39d76a6bd";
function validate$o(obj, path = 'LookupMetadataRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldApiName = obj.fieldApiName;
        const path_fieldApiName = path + '.fieldApiName';
        if (typeof obj_fieldApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldApiName + '" (at "' + path_fieldApiName + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_secondaryField = obj.secondaryField;
        const path_secondaryField = path + '.secondaryField';
        let obj_secondaryField_union0 = null;
        const obj_secondaryField_union0_error = (() => {
            if (typeof obj_secondaryField !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_secondaryField + '" (at "' + path_secondaryField + '")');
            }
        })();
        if (obj_secondaryField_union0_error != null) {
            obj_secondaryField_union0 = obj_secondaryField_union0_error.message;
        }
        let obj_secondaryField_union1 = null;
        const obj_secondaryField_union1_error = (() => {
            if (obj_secondaryField !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_secondaryField + '" (at "' + path_secondaryField + '")');
            }
        })();
        if (obj_secondaryField_union1_error != null) {
            obj_secondaryField_union1 = obj_secondaryField_union1_error.message;
        }
        if (obj_secondaryField_union0 && obj_secondaryField_union1) {
            let message = 'Object doesn\'t match union (at "' + path_secondaryField + '")';
            message += '\n' + obj_secondaryField_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_secondaryField_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_targetInfo = obj.targetInfo;
        const path_targetInfo = path + '.targetInfo';
        if (typeof obj_targetInfo !== 'object' || ArrayIsArray(obj_targetInfo) || obj_targetInfo === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_targetInfo + '" (at "' + path_targetInfo + '")');
        }
        const obj_targetInfo_keys = ObjectKeys(obj_targetInfo);
        for (let i = 0; i < obj_targetInfo_keys.length; i++) {
            const key = obj_targetInfo_keys[i];
            const obj_targetInfo_prop = obj_targetInfo[key];
            const path_targetInfo_prop = path_targetInfo + '["' + key + '"]';
            const referencepath_targetInfo_propValidationError = validate$p(obj_targetInfo_prop, path_targetInfo_prop);
            if (referencepath_targetInfo_propValidationError !== null) {
                let message = 'Object doesn\'t match LookupMetadataTargetInfoRepresentation (at "' + path_targetInfo_prop + '")\n';
                message += referencepath_targetInfo_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$a = 'LookupMetadataRepresentation';
function keyBuilder$i(luvio, config) {
    return keyPrefix + '::' + RepresentationType$a + ':' + config.objectApiName + ':' + config.fieldApiName;
}
function keyBuilderFromType$7(luvio, object) {
    const keyParams = {
        objectApiName: object.objectApiName,
        fieldApiName: object.fieldApiName
    };
    return keyBuilder$i(luvio, keyParams);
}
function normalize$5(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$b = function LookupMetadataRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$9,
        private: [],
        opaque: true
    };
};
function equals$9(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$5 = function LookupMetadataRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$o(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$7(luvio, input);
    const ttlToUse = TTL$7;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$5, "UiApi", VERSION$9, RepresentationType$a, equals$9);
    return createLink(key);
};
function getTypeCacheKeys$a(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$7(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$a,
        mergeable: false
    });
}

function select$a(luvio, params) {
    return select$b();
}
function keyBuilder$h(luvio, params) {
    return keyBuilder$i(luvio, {
        objectApiName: params.urlParams.objectApiName,
        fieldApiName: params.urlParams.fieldApiName
    });
}
function getResponseCacheKeys$d(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$a(storeKeyMap, luvio, response);
}
function ingestSuccess$7(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$h(luvio, resourceParams);
    luvio.storeIngest(key, ingest$5, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$a(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$3(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$h(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$7,
        namespace: keyPrefix,
        version: VERSION$9,
        representationName: RepresentationType$a
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$h(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/search-info/' + config.urlParams.objectApiName + '/lookup/' + config.urlParams.fieldApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$a = 'getLookupMetadata';
const getLookupMetadata_ConfigPropertyMetadata = [
    generateParamConfigMetadata('fieldApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
];
const getLookupMetadata_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$a, getLookupMetadata_ConfigPropertyMetadata);
const createResourceParams$d = /*#__PURE__*/ createResourceParams$13(getLookupMetadata_ConfigPropertyMetadata);
function keyBuilder$g(luvio, config) {
    const resourceParams = createResourceParams$d(config);
    return keyBuilder$h(luvio, resourceParams);
}
function typeCheckConfig$e(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getLookupMetadata_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$d(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$e(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$4(luvio, config) {
    createResourceParams$d(config);
    return select$a();
}
function onFetchResponseSuccess$5(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$7(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$f(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$4(luvio, config, resourceParams, response) {
    const snapshot = ingestError$3(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$f(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$f(luvio, config, options) {
    const resourceParams = createResourceParams$d(config);
    const request = createResourceRequest$h(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$5(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$d(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$4(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$7(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$f, undefined, false);
}
function buildCachedSnapshotCachePolicy$6(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$g(luvio, config),
        node: adapterFragment$4(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$f(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getLookupMetadataAdapterFactory = (luvio) => function UiApi__getLookupMetadata(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$d(untrustedConfig, getLookupMetadata_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$6, buildNetworkSnapshotCachePolicy$7);
};

function validate$n(obj, path = 'SearchDataCategoryInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_groupName = obj.groupName;
        const path_groupName = path + '.groupName';
        if (typeof obj_groupName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_groupName + '" (at "' + path_groupName + '")');
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
        const obj_values = obj.values;
        const path_values = path + '.values';
        if (!ArrayIsArray(obj_values)) {
            return new TypeError('Expected "array" but received "' + typeof obj_values + '" (at "' + path_values + '")');
        }
        for (let i = 0; i < obj_values.length; i++) {
            const obj_values_item = obj_values[i];
            const path_values_item = path_values + '[' + i + ']';
            if (typeof obj_values_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$m(obj, path = 'SearchFilterInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldPath = obj.fieldPath;
        const path_fieldPath = path + '.fieldPath';
        if (typeof obj_fieldPath !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldPath + '" (at "' + path_fieldPath + '")');
        }
        if (obj.objectApiName !== undefined) {
            const obj_objectApiName = obj.objectApiName;
            const path_objectApiName = path + '.objectApiName';
            if (typeof obj_objectApiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
            }
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
        const obj_values = obj.values;
        const path_values = path + '.values';
        if (!ArrayIsArray(obj_values)) {
            return new TypeError('Expected "array" but received "' + typeof obj_values + '" (at "' + path_values + '")');
        }
        for (let i = 0; i < obj_values.length; i++) {
            const obj_values_item = obj_values[i];
            const path_values_item = path_values + '[' + i + ']';
            let obj_values_item_union0 = null;
            const obj_values_item_union0_error = (() => {
                if (typeof obj_values_item !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
                }
            })();
            if (obj_values_item_union0_error != null) {
                obj_values_item_union0 = obj_values_item_union0_error.message;
            }
            let obj_values_item_union1 = null;
            const obj_values_item_union1_error = (() => {
                if (typeof obj_values_item !== 'number') {
                    return new TypeError('Expected "number" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
                }
            })();
            if (obj_values_item_union1_error != null) {
                obj_values_item_union1 = obj_values_item_union1_error.message;
            }
            let obj_values_item_union2 = null;
            const obj_values_item_union2_error = (() => {
                if (typeof obj_values_item !== 'boolean') {
                    return new TypeError('Expected "boolean" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
                }
            })();
            if (obj_values_item_union2_error != null) {
                obj_values_item_union2 = obj_values_item_union2_error.message;
            }
            if (obj_values_item_union0 && obj_values_item_union1 && obj_values_item_union2) {
                let message = 'Object doesn\'t match union (at "' + path_values_item + '")';
                message += '\n' + obj_values_item_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_values_item_union1.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_values_item_union2.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$l(obj, path = 'SearchObjectOptionsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_dataCategories = obj.dataCategories;
        const path_dataCategories = path + '.dataCategories';
        if (!ArrayIsArray(obj_dataCategories)) {
            return new TypeError('Expected "array" but received "' + typeof obj_dataCategories + '" (at "' + path_dataCategories + '")');
        }
        for (let i = 0; i < obj_dataCategories.length; i++) {
            const obj_dataCategories_item = obj_dataCategories[i];
            const path_dataCategories_item = path_dataCategories + '[' + i + ']';
            const referencepath_dataCategories_itemValidationError = validate$n(obj_dataCategories_item, path_dataCategories_item);
            if (referencepath_dataCategories_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchDataCategoryInputRepresentation (at "' + path_dataCategories_item + '")\n';
                message += referencepath_dataCategories_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_filters = obj.filters;
        const path_filters = path + '.filters';
        if (!ArrayIsArray(obj_filters)) {
            return new TypeError('Expected "array" but received "' + typeof obj_filters + '" (at "' + path_filters + '")');
        }
        for (let i = 0; i < obj_filters.length; i++) {
            const obj_filters_item = obj_filters[i];
            const path_filters_item = path_filters + '[' + i + ']';
            const referencepath_filters_itemValidationError = validate$m(obj_filters_item, path_filters_item);
            if (referencepath_filters_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchFilterInputRepresentation (at "' + path_filters_item + '")\n';
                message += referencepath_filters_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$k(obj, path = 'ErrorMessageRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_errorCode = obj.errorCode;
        const path_errorCode = path + '.errorCode';
        if (typeof obj_errorCode !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_errorCode + '" (at "' + path_errorCode + '")');
        }
        const obj_message = obj.message;
        const path_message = path + '.message';
        let obj_message_union0 = null;
        const obj_message_union0_error = (() => {
            if (typeof obj_message !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_message + '" (at "' + path_message + '")');
            }
        })();
        if (obj_message_union0_error != null) {
            obj_message_union0 = obj_message_union0_error.message;
        }
        let obj_message_union1 = null;
        const obj_message_union1_error = (() => {
            if (obj_message !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_message + '" (at "' + path_message + '")');
            }
        })();
        if (obj_message_union1_error != null) {
            obj_message_union1 = obj_message_union1_error.message;
        }
        if (obj_message_union0 && obj_message_union1) {
            let message = 'Object doesn\'t match union (at "' + path_message + '")';
            message += '\n' + obj_message_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_message_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$j(obj, path = 'SearchResultCollectionRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_currentPageToken = obj.currentPageToken;
        const path_currentPageToken = path + '.currentPageToken';
        if (typeof obj_currentPageToken !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_currentPageToken + '" (at "' + path_currentPageToken + '")');
        }
        const obj_error = obj.error;
        const path_error = path + '.error';
        let obj_error_union0 = null;
        const obj_error_union0_error = (() => {
            const referencepath_errorValidationError = validate$k(obj_error, path_error);
            if (referencepath_errorValidationError !== null) {
                let message = 'Object doesn\'t match ErrorMessageRepresentation (at "' + path_error + '")\n';
                message += referencepath_errorValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_error_union0_error != null) {
            obj_error_union0 = obj_error_union0_error.message;
        }
        let obj_error_union1 = null;
        const obj_error_union1_error = (() => {
            if (obj_error !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_error + '" (at "' + path_error + '")');
            }
        })();
        if (obj_error_union1_error != null) {
            obj_error_union1 = obj_error_union1_error.message;
        }
        if (obj_error_union0 && obj_error_union1) {
            let message = 'Object doesn\'t match union (at "' + path_error + '")';
            message += '\n' + obj_error_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_error_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nextPageToken = obj.nextPageToken;
        const path_nextPageToken = path + '.nextPageToken';
        let obj_nextPageToken_union0 = null;
        const obj_nextPageToken_union0_error = (() => {
            if (typeof obj_nextPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union0_error != null) {
            obj_nextPageToken_union0 = obj_nextPageToken_union0_error.message;
        }
        let obj_nextPageToken_union1 = null;
        const obj_nextPageToken_union1_error = (() => {
            if (obj_nextPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nextPageToken + '" (at "' + path_nextPageToken + '")');
            }
        })();
        if (obj_nextPageToken_union1_error != null) {
            obj_nextPageToken_union1 = obj_nextPageToken_union1_error.message;
        }
        if (obj_nextPageToken_union0 && obj_nextPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nextPageToken + '")';
            message += '\n' + obj_nextPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nextPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_orderBy = obj.orderBy;
        const path_orderBy = path + '.orderBy';
        if (!ArrayIsArray(obj_orderBy)) {
            return new TypeError('Expected "array" but received "' + typeof obj_orderBy + '" (at "' + path_orderBy + '")');
        }
        for (let i = 0; i < obj_orderBy.length; i++) {
            const obj_orderBy_item = obj_orderBy[i];
            const path_orderBy_item = path_orderBy + '[' + i + ']';
            const referencepath_orderBy_itemValidationError = validate$26(obj_orderBy_item, path_orderBy_item);
            if (referencepath_orderBy_itemValidationError !== null) {
                let message = 'Object doesn\'t match ListOrderByInfoRepresentation (at "' + path_orderBy_item + '")\n';
                message += referencepath_orderBy_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_pageSize = obj.pageSize;
        const path_pageSize = path + '.pageSize';
        if (typeof obj_pageSize !== 'number' || (typeof obj_pageSize === 'number' && Math.floor(obj_pageSize) !== obj_pageSize)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_pageSize + '" (at "' + path_pageSize + '")');
        }
        const obj_previousPageToken = obj.previousPageToken;
        const path_previousPageToken = path + '.previousPageToken';
        let obj_previousPageToken_union0 = null;
        const obj_previousPageToken_union0_error = (() => {
            if (typeof obj_previousPageToken !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union0_error != null) {
            obj_previousPageToken_union0 = obj_previousPageToken_union0_error.message;
        }
        let obj_previousPageToken_union1 = null;
        const obj_previousPageToken_union1_error = (() => {
            if (obj_previousPageToken !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_previousPageToken + '" (at "' + path_previousPageToken + '")');
            }
        })();
        if (obj_previousPageToken_union1_error != null) {
            obj_previousPageToken_union1 = obj_previousPageToken_union1_error.message;
        }
        if (obj_previousPageToken_union0 && obj_previousPageToken_union1) {
            let message = 'Object doesn\'t match union (at "' + path_previousPageToken + '")';
            message += '\n' + obj_previousPageToken_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_previousPageToken_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (!ArrayIsArray(obj_records)) {
            return new TypeError('Expected "array" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
        for (let i = 0; i < obj_records.length; i++) {
            const obj_records_item = obj_records[i];
            const path_records_item = path_records + '[' + i + ']';
            if (typeof obj_records_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_records_item + '" (at "' + path_records_item + '")');
            }
        }
        const obj_relatedObjectApiNames = obj.relatedObjectApiNames;
        const path_relatedObjectApiNames = path + '.relatedObjectApiNames';
        if (!ArrayIsArray(obj_relatedObjectApiNames)) {
            return new TypeError('Expected "array" but received "' + typeof obj_relatedObjectApiNames + '" (at "' + path_relatedObjectApiNames + '")');
        }
        for (let i = 0; i < obj_relatedObjectApiNames.length; i++) {
            const obj_relatedObjectApiNames_item = obj_relatedObjectApiNames[i];
            const path_relatedObjectApiNames_item = path_relatedObjectApiNames + '[' + i + ']';
            if (typeof obj_relatedObjectApiNames_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_relatedObjectApiNames_item + '" (at "' + path_relatedObjectApiNames_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$i(obj, path = 'KeywordSearchResultsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_results = obj.results;
        const path_results = path + '.results';
        if (!ArrayIsArray(obj_results)) {
            return new TypeError('Expected "array" but received "' + typeof obj_results + '" (at "' + path_results + '")');
        }
        for (let i = 0; i < obj_results.length; i++) {
            const obj_results_item = obj_results[i];
            const path_results_item = path_results + '[' + i + ']';
            if (typeof obj_results_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_results_item + '" (at "' + path_results_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$h(obj, path = 'NLSResultsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_hasNoResult = obj.hasNoResult;
        const path_hasNoResult = path + '.hasNoResult';
        let obj_hasNoResult_union0 = null;
        const obj_hasNoResult_union0_error = (() => {
            if (typeof obj_hasNoResult !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_hasNoResult + '" (at "' + path_hasNoResult + '")');
            }
        })();
        if (obj_hasNoResult_union0_error != null) {
            obj_hasNoResult_union0 = obj_hasNoResult_union0_error.message;
        }
        let obj_hasNoResult_union1 = null;
        const obj_hasNoResult_union1_error = (() => {
            if (obj_hasNoResult !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_hasNoResult + '" (at "' + path_hasNoResult + '")');
            }
        })();
        if (obj_hasNoResult_union1_error != null) {
            obj_hasNoResult_union1 = obj_hasNoResult_union1_error.message;
        }
        if (obj_hasNoResult_union0 && obj_hasNoResult_union1) {
            let message = 'Object doesn\'t match union (at "' + path_hasNoResult + '")';
            message += '\n' + obj_hasNoResult_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_hasNoResult_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_results = obj.results;
        const path_results = path + '.results';
        if (typeof obj_results !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_results + '" (at "' + path_results + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$g(obj, path = 'AppliedSearchFilterOutputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldPath = obj.fieldPath;
        const path_fieldPath = path + '.fieldPath';
        if (typeof obj_fieldPath !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldPath + '" (at "' + path_fieldPath + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
        const obj_values = obj.values;
        const path_values = path + '.values';
        if (!ArrayIsArray(obj_values)) {
            return new TypeError('Expected "array" but received "' + typeof obj_values + '" (at "' + path_values + '")');
        }
        for (let i = 0; i < obj_values.length; i++) {
            const obj_values_item = obj_values[i];
            const path_values_item = path_values + '[' + i + ']';
            if (typeof obj_values_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$f(obj, path = 'SearchAnswersRecordRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_objectApiLabel = obj.objectApiLabel;
        const path_objectApiLabel = path + '.objectApiLabel';
        if (typeof obj_objectApiLabel !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiLabel + '" (at "' + path_objectApiLabel + '")');
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_recordId = obj.recordId;
        const path_recordId = path + '.recordId';
        if (typeof obj_recordId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_recordId + '" (at "' + path_recordId + '")');
        }
        const obj_title = obj.title;
        const path_title = path + '.title';
        if (typeof obj_title !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_title + '" (at "' + path_title + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$e(obj, path = 'SearchAnswersResultRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_answerType = obj.answerType;
        const path_answerType = path + '.answerType';
        let obj_answerType_union0 = null;
        const obj_answerType_union0_error = (() => {
            if (typeof obj_answerType !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_answerType + '" (at "' + path_answerType + '")');
            }
        })();
        if (obj_answerType_union0_error != null) {
            obj_answerType_union0 = obj_answerType_union0_error.message;
        }
        let obj_answerType_union1 = null;
        const obj_answerType_union1_error = (() => {
            if (obj_answerType !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_answerType + '" (at "' + path_answerType + '")');
            }
        })();
        if (obj_answerType_union1_error != null) {
            obj_answerType_union1 = obj_answerType_union1_error.message;
        }
        if (obj_answerType_union0 && obj_answerType_union1) {
            let message = 'Object doesn\'t match union (at "' + path_answerType + '")';
            message += '\n' + obj_answerType_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_answerType_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_appliedFilters = obj.appliedFilters;
        const path_appliedFilters = path + '.appliedFilters';
        if (!ArrayIsArray(obj_appliedFilters)) {
            return new TypeError('Expected "array" but received "' + typeof obj_appliedFilters + '" (at "' + path_appliedFilters + '")');
        }
        for (let i = 0; i < obj_appliedFilters.length; i++) {
            const obj_appliedFilters_item = obj_appliedFilters[i];
            const path_appliedFilters_item = path_appliedFilters + '[' + i + ']';
            const referencepath_appliedFilters_itemValidationError = validate$g(obj_appliedFilters_item, path_appliedFilters_item);
            if (referencepath_appliedFilters_itemValidationError !== null) {
                let message = 'Object doesn\'t match AppliedSearchFilterOutputRepresentation (at "' + path_appliedFilters_item + '")\n';
                message += referencepath_appliedFilters_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_llmGenerationId = obj.llmGenerationId;
        const path_llmGenerationId = path + '.llmGenerationId';
        let obj_llmGenerationId_union0 = null;
        const obj_llmGenerationId_union0_error = (() => {
            if (typeof obj_llmGenerationId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_llmGenerationId + '" (at "' + path_llmGenerationId + '")');
            }
        })();
        if (obj_llmGenerationId_union0_error != null) {
            obj_llmGenerationId_union0 = obj_llmGenerationId_union0_error.message;
        }
        let obj_llmGenerationId_union1 = null;
        const obj_llmGenerationId_union1_error = (() => {
            if (obj_llmGenerationId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_llmGenerationId + '" (at "' + path_llmGenerationId + '")');
            }
        })();
        if (obj_llmGenerationId_union1_error != null) {
            obj_llmGenerationId_union1 = obj_llmGenerationId_union1_error.message;
        }
        if (obj_llmGenerationId_union0 && obj_llmGenerationId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_llmGenerationId + '")';
            message += '\n' + obj_llmGenerationId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_llmGenerationId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_passage = obj.passage;
        const path_passage = path + '.passage';
        let obj_passage_union0 = null;
        const obj_passage_union0_error = (() => {
            if (typeof obj_passage !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_passage + '" (at "' + path_passage + '")');
            }
        })();
        if (obj_passage_union0_error != null) {
            obj_passage_union0 = obj_passage_union0_error.message;
        }
        let obj_passage_union1 = null;
        const obj_passage_union1_error = (() => {
            if (obj_passage !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_passage + '" (at "' + path_passage + '")');
            }
        })();
        if (obj_passage_union1_error != null) {
            obj_passage_union1 = obj_passage_union1_error.message;
        }
        if (obj_passage_union0 && obj_passage_union1) {
            let message = 'Object doesn\'t match union (at "' + path_passage + '")';
            message += '\n' + obj_passage_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_passage_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_records = obj.records;
        const path_records = path + '.records';
        if (!ArrayIsArray(obj_records)) {
            return new TypeError('Expected "array" but received "' + typeof obj_records + '" (at "' + path_records + '")');
        }
        for (let i = 0; i < obj_records.length; i++) {
            const obj_records_item = obj_records[i];
            const path_records_item = path_records + '[' + i + ']';
            const referencepath_records_itemValidationError = validate$f(obj_records_item, path_records_item);
            if (referencepath_records_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchAnswersRecordRepresentation (at "' + path_records_item + '")\n';
                message += referencepath_records_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$d(obj, path = 'SearchDataCategoryOutputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_groupName = obj.groupName;
        const path_groupName = path + '.groupName';
        if (typeof obj_groupName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_groupName + '" (at "' + path_groupName + '")');
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
        const obj_values = obj.values;
        const path_values = path + '.values';
        if (!ArrayIsArray(obj_values)) {
            return new TypeError('Expected "array" but received "' + typeof obj_values + '" (at "' + path_values + '")');
        }
        for (let i = 0; i < obj_values.length; i++) {
            const obj_values_item = obj_values[i];
            const path_values_item = path_values + '[' + i + ']';
            if (typeof obj_values_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$c(obj, path = 'SearchFilterOutputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_fieldPath = obj.fieldPath;
        const path_fieldPath = path + '.fieldPath';
        if (typeof obj_fieldPath !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_fieldPath + '" (at "' + path_fieldPath + '")');
        }
        const obj_operator = obj.operator;
        const path_operator = path + '.operator';
        if (typeof obj_operator !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_operator + '" (at "' + path_operator + '")');
        }
        const obj_values = obj.values;
        const path_values = path + '.values';
        if (!ArrayIsArray(obj_values)) {
            return new TypeError('Expected "array" but received "' + typeof obj_values + '" (at "' + path_values + '")');
        }
        for (let i = 0; i < obj_values.length; i++) {
            const obj_values_item = obj_values[i];
            const path_values_item = path_values + '[' + i + ']';
            if (typeof obj_values_item !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_values_item + '" (at "' + path_values_item + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$b(obj, path = 'SearchObjectOptionsOutputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_dataCategories = obj.dataCategories;
        const path_dataCategories = path + '.dataCategories';
        if (!ArrayIsArray(obj_dataCategories)) {
            return new TypeError('Expected "array" but received "' + typeof obj_dataCategories + '" (at "' + path_dataCategories + '")');
        }
        for (let i = 0; i < obj_dataCategories.length; i++) {
            const obj_dataCategories_item = obj_dataCategories[i];
            const path_dataCategories_item = path_dataCategories + '[' + i + ']';
            const referencepath_dataCategories_itemValidationError = validate$d(obj_dataCategories_item, path_dataCategories_item);
            if (referencepath_dataCategories_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchDataCategoryOutputRepresentation (at "' + path_dataCategories_item + '")\n';
                message += referencepath_dataCategories_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        const obj_filters = obj.filters;
        const path_filters = path + '.filters';
        if (!ArrayIsArray(obj_filters)) {
            return new TypeError('Expected "array" but received "' + typeof obj_filters + '" (at "' + path_filters + '")');
        }
        for (let i = 0; i < obj_filters.length; i++) {
            const obj_filters_item = obj_filters[i];
            const path_filters_item = path_filters + '[' + i + ']';
            const referencepath_filters_itemValidationError = validate$c(obj_filters_item, path_filters_item);
            if (referencepath_filters_itemValidationError !== null) {
                let message = 'Object doesn\'t match SearchFilterOutputRepresentation (at "' + path_filters_item + '")\n';
                message += referencepath_filters_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

const TTL$6 = 200;
const VERSION$8 = "94ab97aedd252f899c90d52d898e547f";
function validate$a(obj, path = 'SearchResultsSummaryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_configurationName = obj.configurationName;
        const path_configurationName = path + '.configurationName';
        let obj_configurationName_union0 = null;
        const obj_configurationName_union0_error = (() => {
            if (typeof obj_configurationName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_configurationName + '" (at "' + path_configurationName + '")');
            }
        })();
        if (obj_configurationName_union0_error != null) {
            obj_configurationName_union0 = obj_configurationName_union0_error.message;
        }
        let obj_configurationName_union1 = null;
        const obj_configurationName_union1_error = (() => {
            if (obj_configurationName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_configurationName + '" (at "' + path_configurationName + '")');
            }
        })();
        if (obj_configurationName_union1_error != null) {
            obj_configurationName_union1 = obj_configurationName_union1_error.message;
        }
        if (obj_configurationName_union0 && obj_configurationName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_configurationName + '")';
            message += '\n' + obj_configurationName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_configurationName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_keywordSearchResults = obj.keywordSearchResults;
        const path_keywordSearchResults = path + '.keywordSearchResults';
        let obj_keywordSearchResults_union0 = null;
        const obj_keywordSearchResults_union0_error = (() => {
            const referencepath_keywordSearchResultsValidationError = validate$i(obj_keywordSearchResults, path_keywordSearchResults);
            if (referencepath_keywordSearchResultsValidationError !== null) {
                let message = 'Object doesn\'t match KeywordSearchResultsRepresentation (at "' + path_keywordSearchResults + '")\n';
                message += referencepath_keywordSearchResultsValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_keywordSearchResults_union0_error != null) {
            obj_keywordSearchResults_union0 = obj_keywordSearchResults_union0_error.message;
        }
        let obj_keywordSearchResults_union1 = null;
        const obj_keywordSearchResults_union1_error = (() => {
            if (obj_keywordSearchResults !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_keywordSearchResults + '" (at "' + path_keywordSearchResults + '")');
            }
        })();
        if (obj_keywordSearchResults_union1_error != null) {
            obj_keywordSearchResults_union1 = obj_keywordSearchResults_union1_error.message;
        }
        if (obj_keywordSearchResults_union0 && obj_keywordSearchResults_union1) {
            let message = 'Object doesn\'t match union (at "' + path_keywordSearchResults + '")';
            message += '\n' + obj_keywordSearchResults_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_keywordSearchResults_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_nlsResults = obj.nlsResults;
        const path_nlsResults = path + '.nlsResults';
        let obj_nlsResults_union0 = null;
        const obj_nlsResults_union0_error = (() => {
            const referencepath_nlsResultsValidationError = validate$h(obj_nlsResults, path_nlsResults);
            if (referencepath_nlsResultsValidationError !== null) {
                let message = 'Object doesn\'t match NLSResultsRepresentation (at "' + path_nlsResults + '")\n';
                message += referencepath_nlsResultsValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_nlsResults_union0_error != null) {
            obj_nlsResults_union0 = obj_nlsResults_union0_error.message;
        }
        let obj_nlsResults_union1 = null;
        const obj_nlsResults_union1_error = (() => {
            if (obj_nlsResults !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_nlsResults + '" (at "' + path_nlsResults + '")');
            }
        })();
        if (obj_nlsResults_union1_error != null) {
            obj_nlsResults_union1 = obj_nlsResults_union1_error.message;
        }
        if (obj_nlsResults_union0 && obj_nlsResults_union1) {
            let message = 'Object doesn\'t match union (at "' + path_nlsResults + '")';
            message += '\n' + obj_nlsResults_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_nlsResults_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_qnaResult = obj.qnaResult;
        const path_qnaResult = path + '.qnaResult';
        let obj_qnaResult_union0 = null;
        const obj_qnaResult_union0_error = (() => {
            const referencepath_qnaResultValidationError = validate$e(obj_qnaResult, path_qnaResult);
            if (referencepath_qnaResultValidationError !== null) {
                let message = 'Object doesn\'t match SearchAnswersResultRepresentation (at "' + path_qnaResult + '")\n';
                message += referencepath_qnaResultValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_qnaResult_union0_error != null) {
            obj_qnaResult_union0 = obj_qnaResult_union0_error.message;
        }
        let obj_qnaResult_union1 = null;
        const obj_qnaResult_union1_error = (() => {
            if (obj_qnaResult !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_qnaResult + '" (at "' + path_qnaResult + '")');
            }
        })();
        if (obj_qnaResult_union1_error != null) {
            obj_qnaResult_union1 = obj_qnaResult_union1_error.message;
        }
        if (obj_qnaResult_union0 && obj_qnaResult_union1) {
            let message = 'Object doesn\'t match union (at "' + path_qnaResult + '")';
            message += '\n' + obj_qnaResult_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_qnaResult_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_query = obj.query;
        const path_query = path + '.query';
        if (typeof obj_query !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_query + '" (at "' + path_query + '")');
        }
        const obj_queryId = obj.queryId;
        const path_queryId = path + '.queryId';
        if (typeof obj_queryId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_queryId + '" (at "' + path_queryId + '")');
        }
        const obj_searchObjectOptions = obj.searchObjectOptions;
        const path_searchObjectOptions = path + '.searchObjectOptions';
        if (typeof obj_searchObjectOptions !== 'object' || ArrayIsArray(obj_searchObjectOptions) || obj_searchObjectOptions === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_searchObjectOptions + '" (at "' + path_searchObjectOptions + '")');
        }
        const obj_searchObjectOptions_keys = ObjectKeys(obj_searchObjectOptions);
        for (let i = 0; i < obj_searchObjectOptions_keys.length; i++) {
            const key = obj_searchObjectOptions_keys[i];
            const obj_searchObjectOptions_prop = obj_searchObjectOptions[key];
            const path_searchObjectOptions_prop = path_searchObjectOptions + '["' + key + '"]';
            const referencepath_searchObjectOptions_propValidationError = validate$b(obj_searchObjectOptions_prop, path_searchObjectOptions_prop);
            if (referencepath_searchObjectOptions_propValidationError !== null) {
                let message = 'Object doesn\'t match SearchObjectOptionsOutputRepresentation (at "' + path_searchObjectOptions_prop + '")\n';
                message += referencepath_searchObjectOptions_propValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$9 = 'SearchResultsSummaryRepresentation';
function keyBuilder$f(luvio, config) {
    return keyPrefix + '::' + RepresentationType$9 + ':' + config.query + ':' + (config.configurationName === null ? '' : config.configurationName);
}
function keyBuilderFromType$6(luvio, object) {
    const keyParams = {
        query: object.query,
        configurationName: object.configurationName
    };
    return keyBuilder$f(luvio, keyParams);
}
function normalize$4(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$9 = function SearchResultsSummaryRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$8,
        private: [],
        opaque: true
    };
};
function equals$8(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$4 = function SearchResultsSummaryRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$a(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$6(luvio, input);
    const ttlToUse = TTL$6;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$4, "UiApi", VERSION$8, RepresentationType$9, equals$8);
    return createLink(key);
};
function getTypeCacheKeys$9(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$6(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$9,
        mergeable: false
    });
}

function select$8(luvio, params) {
    return select$9();
}
function keyBuilder$e(luvio, params) {
    return keyBuilder$f(luvio, {
        query: params.queryParams.q,
        configurationName: params.body.configurationName || null
    });
}
function getResponseCacheKeys$c(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$9(storeKeyMap, luvio, response);
}
function ingestSuccess$6(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$e(luvio, resourceParams);
    luvio.storeIngest(key, ingest$4, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$8(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$2(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$e(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$6,
        namespace: keyPrefix,
        version: VERSION$8,
        representationName: RepresentationType$9
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$g(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/search/results',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$9 = 'getSearchResults';
const getSearchResults_ConfigPropertyMetadata = [
    generateParamConfigMetadata('q', true, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('answerTypes', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('configurationName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('objectApiNames', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('searchObjectOptions', false, 2 /* Body */, 4 /* Unsupported */),
];
const getSearchResults_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$9, getSearchResults_ConfigPropertyMetadata);
const createResourceParams$c = /*#__PURE__*/ createResourceParams$13(getSearchResults_ConfigPropertyMetadata);
function keyBuilder$d(luvio, config) {
    const resourceParams = createResourceParams$c(config);
    return keyBuilder$e(luvio, resourceParams);
}
function typeCheckConfig$d(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getSearchResults_ConfigPropertyMetadata);
    const untrustedConfig_searchObjectOptions = untrustedConfig.searchObjectOptions;
    if (untrustedIsObject(untrustedConfig_searchObjectOptions)) {
        const untrustedConfig_searchObjectOptions_object = {};
        const untrustedConfig_searchObjectOptions_keys = Object.keys(untrustedConfig_searchObjectOptions);
        for (let i = 0, arrayLength = untrustedConfig_searchObjectOptions_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_searchObjectOptions_keys[i];
            const untrustedConfig_searchObjectOptions_prop = untrustedConfig_searchObjectOptions[key];
            const referenceSearchObjectOptionsRepresentationValidationError = validate$l(untrustedConfig_searchObjectOptions_prop);
            if (referenceSearchObjectOptionsRepresentationValidationError === null) {
                if (untrustedConfig_searchObjectOptions_object !== undefined) {
                    untrustedConfig_searchObjectOptions_object[key] = untrustedConfig_searchObjectOptions_prop;
                }
            }
        }
        if (untrustedConfig_searchObjectOptions_object !== undefined && Object.keys(untrustedConfig_searchObjectOptions_object).length >= 0) {
            config.searchObjectOptions = untrustedConfig_searchObjectOptions_object;
        }
    }
    return config;
}
function validateAdapterConfig$c(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$d(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$3(luvio, config) {
    createResourceParams$c(config);
    return select$8();
}
function onFetchResponseSuccess$4(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$6(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$e(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$3(luvio, config, resourceParams, response) {
    const snapshot = ingestError$2(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$e(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$e(luvio, config, options) {
    const resourceParams = createResourceParams$c(config);
    const request = createResourceRequest$g(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$4(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$c(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$3(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$6(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$e, 'get', false);
}
function buildCachedSnapshotCachePolicy$5(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$d(luvio, config),
        node: adapterFragment$3(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$e(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getSearchResultsAdapterFactory = (luvio) => function UiApi__getSearchResults(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$c(untrustedConfig, getSearchResults_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$5, buildNetworkSnapshotCachePolicy$6);
};

const TTL$5 = 200;
const VERSION$7 = "3102453bf10ea449d9665914d5f5febf";
function validate$9(obj, path = 'KeywordSearchResultsSummaryRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_configurationName = obj.configurationName;
        const path_configurationName = path + '.configurationName';
        let obj_configurationName_union0 = null;
        const obj_configurationName_union0_error = (() => {
            if (typeof obj_configurationName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_configurationName + '" (at "' + path_configurationName + '")');
            }
        })();
        if (obj_configurationName_union0_error != null) {
            obj_configurationName_union0 = obj_configurationName_union0_error.message;
        }
        let obj_configurationName_union1 = null;
        const obj_configurationName_union1_error = (() => {
            if (obj_configurationName !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_configurationName + '" (at "' + path_configurationName + '")');
            }
        })();
        if (obj_configurationName_union1_error != null) {
            obj_configurationName_union1 = obj_configurationName_union1_error.message;
        }
        if (obj_configurationName_union0 && obj_configurationName_union1) {
            let message = 'Object doesn\'t match union (at "' + path_configurationName + '")';
            message += '\n' + obj_configurationName_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_configurationName_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_keywordSearchResult = obj.keywordSearchResult;
        const path_keywordSearchResult = path + '.keywordSearchResult';
        const referencepath_keywordSearchResultValidationError = validate$j(obj_keywordSearchResult, path_keywordSearchResult);
        if (referencepath_keywordSearchResultValidationError !== null) {
            let message = 'Object doesn\'t match SearchResultCollectionRepresentation (at "' + path_keywordSearchResult + '")\n';
            message += referencepath_keywordSearchResultValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectApiName = obj.objectApiName;
        const path_objectApiName = path + '.objectApiName';
        if (typeof obj_objectApiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_objectApiName + '" (at "' + path_objectApiName + '")');
        }
        const obj_query = obj.query;
        const path_query = path + '.query';
        if (typeof obj_query !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_query + '" (at "' + path_query + '")');
        }
        const obj_queryId = obj.queryId;
        const path_queryId = path + '.queryId';
        if (typeof obj_queryId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_queryId + '" (at "' + path_queryId + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$8 = 'KeywordSearchResultsSummaryRepresentation';
function keyBuilder$c(luvio, config) {
    return keyPrefix + '::' + RepresentationType$8 + ':' + config.query + ':' + config.objectApiName + ':' + (config.configurationName === null ? '' : config.configurationName);
}
function keyBuilderFromType$5(luvio, object) {
    const keyParams = {
        query: object.query,
        objectApiName: object.objectApiName,
        configurationName: object.configurationName
    };
    return keyBuilder$c(luvio, keyParams);
}
function normalize$3(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$7 = function KeywordSearchResultsSummaryRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$7,
        private: [],
        opaque: true
    };
};
function equals$7(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest$3 = function KeywordSearchResultsSummaryRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$9(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType$5(luvio, input);
    const ttlToUse = TTL$5;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$3, "UiApi", VERSION$7, RepresentationType$8, equals$7);
    return createLink(key);
};
function getTypeCacheKeys$8(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$5(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$8,
        mergeable: false
    });
}

function select$6(luvio, params) {
    return select$7();
}
function keyBuilder$b(luvio, params) {
    return keyBuilder$c(luvio, {
        query: params.queryParams.q,
        objectApiName: params.queryParams.objectApiName,
        configurationName: params.body.configurationName || null
    });
}
function getResponseCacheKeys$b(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$8(storeKeyMap, luvio, response);
}
function ingestSuccess$5(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$b(luvio, resourceParams);
    luvio.storeIngest(key, ingest$3, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$6(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError$1(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$b(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL$5,
        namespace: keyPrefix,
        version: VERSION$7,
        representationName: RepresentationType$8
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$f(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/search/results/keyword',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$8 = 'getKeywordSearchResults';
const getKeywordSearchResults_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('q', true, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('configurationName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('dataCategories', false, 2 /* Body */, 4 /* Unsupported */, true),
    generateParamConfigMetadata('filters', false, 2 /* Body */, 4 /* Unsupported */, true),
    generateParamConfigMetadata('pageSize', false, 2 /* Body */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 2 /* Body */, 0 /* String */),
];
const getKeywordSearchResults_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$8, getKeywordSearchResults_ConfigPropertyMetadata);
const createResourceParams$b = /*#__PURE__*/ createResourceParams$13(getKeywordSearchResults_ConfigPropertyMetadata);
function keyBuilder$a(luvio, config) {
    const resourceParams = createResourceParams$b(config);
    return keyBuilder$b(luvio, resourceParams);
}
function typeCheckConfig$c(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getKeywordSearchResults_ConfigPropertyMetadata);
    const untrustedConfig_dataCategories = untrustedConfig.dataCategories;
    if (ArrayIsArray$1(untrustedConfig_dataCategories)) {
        const untrustedConfig_dataCategories_array = [];
        for (let i = 0, arrayLength = untrustedConfig_dataCategories.length; i < arrayLength; i++) {
            const untrustedConfig_dataCategories_item = untrustedConfig_dataCategories[i];
            const referenceSearchDataCategoryInputRepresentationValidationError = validate$n(untrustedConfig_dataCategories_item);
            if (referenceSearchDataCategoryInputRepresentationValidationError === null) {
                untrustedConfig_dataCategories_array.push(untrustedConfig_dataCategories_item);
            }
        }
        config.dataCategories = untrustedConfig_dataCategories_array;
    }
    const untrustedConfig_filters = untrustedConfig.filters;
    if (ArrayIsArray$1(untrustedConfig_filters)) {
        const untrustedConfig_filters_array = [];
        for (let i = 0, arrayLength = untrustedConfig_filters.length; i < arrayLength; i++) {
            const untrustedConfig_filters_item = untrustedConfig_filters[i];
            const referenceSearchFilterInputRepresentationValidationError = validate$m(untrustedConfig_filters_item);
            if (referenceSearchFilterInputRepresentationValidationError === null) {
                untrustedConfig_filters_array.push(untrustedConfig_filters_item);
            }
        }
        config.filters = untrustedConfig_filters_array;
    }
    return config;
}
function validateAdapterConfig$b(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$c(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$2(luvio, config) {
    createResourceParams$b(config);
    return select$6();
}
function onFetchResponseSuccess$3(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$5(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$d(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$2(luvio, config, resourceParams, response) {
    const snapshot = ingestError$1(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$d(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$d(luvio, config, options) {
    const resourceParams = createResourceParams$b(config);
    const request = createResourceRequest$f(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$3(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$b(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$2(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy$5(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$d, 'get', false);
}
function buildCachedSnapshotCachePolicy$4(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$a(luvio, config),
        node: adapterFragment$2(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$d(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getKeywordSearchResultsAdapterFactory = (luvio) => function UiApi__getKeywordSearchResults(untrustedConfig, requestContext) {
    const config = validateAdapterConfig$b(untrustedConfig, getKeywordSearchResults_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy$4, buildNetworkSnapshotCachePolicy$5);
};

const API_NAMESPACE = 'UiApi';
const RECORD_REPRESENTATION_NAME = 'RecordRepresentation';
const RECORD_VIEW_ENTITY_REPRESENTATION_NAME = 'RecordViewEntityRepresentation';
const RECORD_ID_PREFIX = `${API_NAMESPACE}::${RECORD_REPRESENTATION_NAME}:`;
const RECORD_VIEW_ENTITY_ID_PREFIX = `${API_NAMESPACE}::${RECORD_VIEW_ENTITY_REPRESENTATION_NAME}:Name:`;
const RECORD_FIELDS_KEY_JUNCTION = '__fields__';
function extractRecordIdFromStoreKey(key) {
    if (key === undefined ||
        (key.indexOf(RECORD_ID_PREFIX) === -1 && key.indexOf(RECORD_VIEW_ENTITY_ID_PREFIX) === -1)) {
        return undefined;
    }
    const parts = key.split(':');
    return parts[parts.length - 1].split('_')[0];
}
function isStoreKeyRecordViewEntity(key) {
    return (key.indexOf(RECORD_VIEW_ENTITY_ID_PREFIX) > -1 &&
        key.indexOf(RECORD_FIELDS_KEY_JUNCTION) === -1);
}
function buildRecordRepKeyFromId(recordId) {
    return `${API_NAMESPACE}::${RECORD_REPRESENTATION_NAME}:${recordId}`;
}

// The rest of this is copy-pasted. Sorry.
ObjectCreate$1(null);

function getResponseCacheKeys$a(cacheKeyMap, luvio, _resourceParams, // For consistency of interface with other adapters
response) {
    const results = response.results;
    for (let index = 0, len = results.length; index < len; index += 1) {
        const { statusCode: childStatusCode, result: childBody } = results[index];
        if (childStatusCode === 200 || childStatusCode === 201) {
            if (isDeleteResponse(childBody)) {
                const recordKey = keyBuilder$29(luvio, { recordId: childBody.id });
                cacheKeyMap.set(recordKey, {
                    namespace: keyPrefix,
                    representationName: RepresentationType$V,
                    mergeable: false,
                });
            }
            else {
                getTypeCacheKeys$X(cacheKeyMap, luvio, childBody);
            }
        }
    }
}
function ingestSuccessChildResourceParams(luvio, response) {
    const childSnapshotDataResponses = [];
    let seenRecords = new StoreKeySet();
    let batchSnapshotState = 'Fulfilled';
    const results = response.results;
    for (let index = 0, len = results.length; index < len; index += 1) {
        const individualResponse = results[index];
        const { statusCode: childStatusCode, result: childBody } = individualResponse;
        if (childStatusCode === 200 || childStatusCode === 201) {
            if (isDeleteResponse(childBody)) {
                const recordKey = keyBuilder$29(luvio, { recordId: childBody.id });
                luvio.storeEvict(recordKey);
                ArrayPrototypePush.call(childSnapshotDataResponses, {
                    ...individualResponse,
                });
            }
            else {
                const childSnapshot = ingestRecord(childBody, luvio);
                if (childSnapshot.state !== 'Error') {
                    // Not sure why it's possible to get Error here but it is
                    seenRecords.merge(childSnapshot.seenRecords);
                    seenRecords.add(childSnapshot.recordId);
                    if (childSnapshot.state === 'Stale') {
                        batchSnapshotState = 'Stale';
                    }
                }
                const childDataValue = {
                    ...individualResponse,
                    result: childSnapshot.data, // verify, is this safe w/ pending snapshots and stuff? Do we even need to return the snapshot really?
                };
                ArrayPrototypePush.call(childSnapshotDataResponses, childDataValue);
            }
        }
        else {
            // Got an error back
            const childErrorValue = {
                statusCode: childStatusCode,
                result: childBody,
            };
            ArrayPrototypePush.call(childSnapshotDataResponses, childErrorValue);
        }
    }
    const childSnapshotData = {
        hasErrors: response.hasErrors,
        results: childSnapshotDataResponses,
    };
    deepFreeze(childSnapshotData);
    return {
        result: childSnapshotData,
        seenRecords,
        snapshotState: batchSnapshotState,
    };
}
function ingestRecord(childBody, luvio) {
    const childResponse = {
        status: 200,
        body: childBody,
        ok: true,
        statusText: 'OK',
        headers: {},
    };
    const fieldTrie = BLANK_RECORD_FIELDS_TRIE;
    const optionalFieldTrie = BLANK_RECORD_FIELDS_TRIE;
    const conflictMap = {
        conflicts: {},
        serverRequestCount: 0,
    };
    const recordIngest = createRecordIngest(fieldTrie, optionalFieldTrie, conflictMap);
    const childSnapshot = ingestRecordResponse(luvio, childResponse, childBody.id, recordIngest, conflictMap);
    return childSnapshot;
}
function isDeleteResponse(childBody) {
    return childBody.fields === undefined && childBody.id !== undefined;
}
function ingestSuccess$4(luvio, response) {
    const { result, snapshotState, seenRecords } = ingestSuccessChildResourceParams(luvio, response.body);
    const syntheticSnapshot = {
        state: snapshotState,
        seenRecords,
        data: result,
    };
    return syntheticSnapshot;
}
function createResourceRequest$e(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/batch',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$7 = 'executeBatchRecordOperations';
const executeBatchRecordOperations_ConfigPropertyMetadata = [
    generateParamConfigMetadata('allOrNone', true, 2, 1, false),
    generateParamConfigMetadata('operations', true, 2, 4, true),
    generateParamConfigMetadata('useDefaultRule', false, 1, 1, false), // Not Requred, QueryParam, Boolean, single
];
const executeBatchRecordOperations_ConfigPropertyNames = 
/*#__PURE__*/ buildAdapterValidationConfig(adapterName$7, executeBatchRecordOperations_ConfigPropertyMetadata);
const acceptedOperations = ['CREATE', 'UPDATE', 'DELETE'];
const batchUpdateRecordsCreateResourceParams = /*#__PURE__*/ createResourceParams$13(executeBatchRecordOperations_ConfigPropertyMetadata);
function batchUpdateRecordsTypeCheckConfig(untrustedConfig) {
    const config = {};
    const untrustedConfigOperations = untrustedConfig.operations;
    if (untrustedConfigOperations !== undefined && ArrayIsArray$1(untrustedConfigOperations)) {
        const trustedOperations = [];
        let hasInvalidOperation = false;
        for (let i = 0, arrayLength = untrustedConfigOperations.length; i < arrayLength; i++) {
            const untrustedSingleOperation = untrustedConfigOperations[i];
            // Not much deep validation here - if it's got a CREATE/UPDATE/DELETE type and a 'records' property, we add it
            if (untrustedIsObject(untrustedSingleOperation)) {
                if (untrustedSingleOperation !== undefined &&
                    untrustedSingleOperation.type !== undefined &&
                    typeof untrustedSingleOperation.type === 'string' &&
                    acceptedOperations.includes(untrustedSingleOperation.type.toUpperCase()) &&
                    ObjectPrototypeHasOwnProperty.call(untrustedSingleOperation, 'records')) {
                    trustedOperations.push(untrustedSingleOperation);
                }
                else {
                    hasInvalidOperation = true;
                }
            }
        }
        if (!hasInvalidOperation && trustedOperations.length > 0) {
            config.operations = trustedOperations;
        }
    }
    const untrustedConfigAllOrNone = untrustedConfig.allOrNone;
    if (untrustedConfigAllOrNone !== undefined && typeof untrustedConfigAllOrNone === 'boolean') {
        config.allOrNone = untrustedConfigAllOrNone;
    }
    const untrustedConfiguseDefaultRule = untrustedConfig.useDefaultRule;
    if (untrustedConfiguseDefaultRule !== undefined &&
        typeof untrustedConfiguseDefaultRule === 'boolean') {
        config.useDefaultRule = untrustedConfiguseDefaultRule;
    }
    return config;
}
function validateAdapterConfig$a(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    // Do we need to coerce all the incoming recordIds to 18 character? We don't use the config for any ingestion so might be okay.
    const coercedConfig = coerceConfig$1(untrustedConfig, executeBatchRecordOperations_ConfigPropertyMetadata);
    const config = batchUpdateRecordsTypeCheckConfig(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$c(luvio, config, options) {
    const resourceParams = batchUpdateRecordsCreateResourceParams(config);
    const request = createResourceRequest$e(resourceParams);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$4(luvio, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$a(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const factory$e = (luvio) => {
    return function executeBatchRecordOperations(untrustedConfig) {
        const config = validateAdapterConfig$a(untrustedConfig, executeBatchRecordOperations_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            // eslint-disable-next-line @salesforce/lds/no-error-in-production
            throw new Error('Invalid config for "executeBatchRecordOperations"');
        }
        return buildNetworkSnapshot$c(luvio, config);
    };
};

function select$5(luvio, params) {
    return select$1H();
}
function getResponseCacheKeys$9(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$J(storeKeyMap, luvio, response);
}
function ingestSuccess$3(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$s(luvio, body);
    luvio.storeIngest(key, ingest$B, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$5(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$d(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/perform-quick-action/' + config.urlParams.actionApiName + '',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const performUpdateRecordQuickAction_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('allowSaveOnDuplicate', false, 2 /* Body */, 1 /* Boolean */),
    generateParamConfigMetadata('apiName', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('contextId', false, 2 /* Body */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('fields', true, 2 /* Body */, 4 /* Unsupported */),
];
const createResourceParams$a = /*#__PURE__*/ createResourceParams$13(performUpdateRecordQuickAction_ConfigPropertyMetadata);
function buildNetworkSnapshot$b(luvio, config, options) {
    const resourceParams = createResourceParams$a(config);
    const request = createResourceRequest$d(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$3(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$9(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}

function select$4(luvio, params) {
    return select$1H();
}
function getResponseCacheKeys$8(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$J(storeKeyMap, luvio, response);
}
function ingestSuccess$2(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType$s(luvio, body);
    luvio.storeIngest(key, ingest$B, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select$4(),
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function createResourceRequest$c(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/actions/perform-quick-action/' + config.urlParams.actionApiName + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const performQuickAction_ConfigPropertyMetadata = [
    generateParamConfigMetadata('actionApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('allowSaveOnDuplicate', false, 2 /* Body */, 1 /* Boolean */),
    generateParamConfigMetadata('apiName', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('contextId', false, 2 /* Body */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('fields', true, 2 /* Body */, 4 /* Unsupported */),
];
const createResourceParams$9 = /*#__PURE__*/ createResourceParams$13(performQuickAction_ConfigPropertyMetadata);
function buildNetworkSnapshot$a(luvio, config, options) {
    const resourceParams = createResourceParams$9(config);
    const request = createResourceRequest$c(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$2(luvio, resourceParams, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$8(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}

const factory$d = (luvio) => {
    return function (untrustedConfig) {
        const config = untrustedConfig;
        const draftAdapter = configurationForRestAdapters.getDraftAwarePerformUpdateRecordQuickActionAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, (config) => {
                const resourceParams = createResourceParams$9(config);
                return createResourceRequest$d(resourceParams);
            });
        }
        return buildNetworkSnapshot$b(luvio, config);
    };
};

const factory$c = (luvio) => {
    return function (untrustedConfig) {
        const config = untrustedConfig;
        const draftAdapter = configurationForRestAdapters.getDraftAwarePerformQuickActionAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, (config) => {
                const resourceParams = createResourceParams$9(config);
                return createResourceRequest$c(resourceParams);
            });
        }
        return buildNetworkSnapshot$a(luvio, config);
    };
};

function createResourceRequest$b(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/layout/' + config.urlParams.objectApiName + '/user-state',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function validate$8(obj, path = 'RecordLayoutUserStateInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_sectionUserStates = obj.sectionUserStates;
        const path_sectionUserStates = path + '.sectionUserStates';
        if (typeof obj_sectionUserStates !== 'object' || ArrayIsArray(obj_sectionUserStates) || obj_sectionUserStates === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_sectionUserStates + '" (at "' + path_sectionUserStates + '")');
        }
        const obj_sectionUserStates_keys = ObjectKeys(obj_sectionUserStates);
        for (let i = 0; i < obj_sectionUserStates_keys.length; i++) {
            const key = obj_sectionUserStates_keys[i];
            const obj_sectionUserStates_prop = obj_sectionUserStates[key];
            const path_sectionUserStates_prop = path_sectionUserStates + '["' + key + '"]';
            if (typeof obj_sectionUserStates_prop !== 'object' || ArrayIsArray(obj_sectionUserStates_prop) || obj_sectionUserStates_prop === null) {
                return new TypeError('Expected "object" but received "' + typeof obj_sectionUserStates_prop + '" (at "' + path_sectionUserStates_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

// Hack method- this should be removed eventually when layoutUserState raml is fixed.
function addAdditionalFieldsForNorming(layoutUserState, apiName, recordTypeId, layoutType, mode) {
    // Hack- adding in this params so record-ui will be able to use normed values.
    layoutUserState.apiName = apiName;
    layoutUserState.recordTypeId = recordTypeId;
    layoutUserState.layoutType = layoutType;
    layoutUserState.mode = mode;
}
function updateLayoutUserState$1(luvio, config, key, updateRequest) {
    return luvio.dispatchResourceRequest(updateRequest).then((response) => {
        const { body } = response;
        return luvio.handleSuccessResponse(() => ingestAndBroadcast(luvio, key, config, body), () => {
            const cache = new StoreKeyMap();
            getTypeCacheKeys$M(cache, luvio, body);
            return cache;
        });
    }, (err) => {
        deepFreeze(err);
        throw err;
    });
}
function ingestAndBroadcast(luvio, key, config, body) {
    addAdditionalFieldsForNorming(body, config.objectApiName, config.recordTypeId, config.layoutType, config.mode);
    luvio.storeIngest(key, ingest$F, body);
    return luvio.storeBroadcast().then(() => {
        return buildCachedSnapshot$5(luvio, config);
    });
}
function clone(userLayoutState) {
    return parse(stringify(userLayoutState));
}
// Applies optimisticUpdate to layoutUserState
// If the optimistic update can be applied, returns RecordLayoutUserStateRepresentation
// If the optimistic update cannot be applied, returns null
// The optimistic update can be applied only IF the cached layoutUserState has all the sections
// enumerated on the layout user state input
function optimisticUpdate(cachedLayoutUserState, layoutUserStateInput) {
    let clonedLayoutUserState;
    let clonedLayoutUserStateSections;
    const { sectionUserStates } = layoutUserStateInput;
    const { sectionUserStates: cachedSectionUserStates } = cachedLayoutUserState;
    const sectionUserStateKeys = keys(sectionUserStates);
    for (let i = 0, len = sectionUserStateKeys.length; i < len; i += 1) {
        const sectionId = sectionUserStateKeys[i];
        if (cachedSectionUserStates[sectionId] === undefined) {
            // Cannot update a section that isn't in the cache. Cancel the optimistic update.
            return null;
        }
        if (clonedLayoutUserState === undefined) {
            // We have to clone cachedLayoutUserState because this object is coming from
            // a snapshot, where it is frozen
            clonedLayoutUserState = clone(cachedLayoutUserState);
            // hold onto sectionUserStates from clonedLayoutUserState
            clonedLayoutUserStateSections = clonedLayoutUserState.sectionUserStates;
        }
        // DEV MODE sanity check
        if (process.env.NODE_ENV !== 'production') {
            if (clonedLayoutUserStateSections === undefined) {
                throw new Error('clonedLayoutUserStateSections is undefined in updateLayoutUserState optimisticUpdate');
            }
        }
        const userState = sectionUserStates[sectionId];
        clonedLayoutUserStateSections[sectionId].collapsed = userState.collapsed;
    }
    // DEV MODE sanity check
    if (process.env.NODE_ENV !== 'production') {
        if (clonedLayoutUserState === undefined) {
            throw new Error('clonedLayoutUserState is undefined in updateLayoutUserState optimisticUpdate');
        }
    }
    return clonedLayoutUserState;
}
function coerceConfigWithDefaults$2(untrusted, layoutUserStateInput) {
    const config = validateAdapterConfig$L(untrusted, getLayoutUserState_ConfigPropertyNames);
    if (config === null) {
        // eslint-disable-next-line @salesforce/lds/no-error-in-production
        throw new Error(`@wire(updateLayoutUserState) invalid configuration ${stringify(untrusted)}`);
    }
    // This will throw if layoutUserStateInput is not a valid input
    validate$8(layoutUserStateInput, 'layoutUserStateInput');
    return {
        ...config,
        layoutUserStateInput: layoutUserStateInput,
    };
}
const factory$b = (luvio) => {
    return (untrustedObjectApiName, untrustedRecordTypeId, untrustedLayoutType, untrustedMode, untrustedLayoutUserStateInput) => {
        const untrusted = {
            objectApiName: untrustedObjectApiName,
            recordTypeId: untrustedRecordTypeId,
            layoutType: untrustedLayoutType,
            mode: untrustedMode,
        };
        const config = coerceConfigWithDefaults$2(untrusted, untrustedLayoutUserStateInput);
        if (config === null) {
            if (process.env.NODE_ENV !== 'production') {
                throw new Error(`@wire(updateLayoutUserState) invalid configuration ${stringify(untrusted)}`);
            }
        }
        const { objectApiName, layoutType, mode, recordTypeId, layoutUserStateInput } = config;
        const updateRequest = createResourceRequest$b({
            urlParams: {
                objectApiName,
            },
            body: layoutUserStateInput,
            queryParams: {
                layoutType,
                mode,
                recordTypeId,
            },
        });
        const key = keyBuilder$1U(luvio, {
            apiName: objectApiName,
            recordTypeId,
            layoutType,
            mode,
        });
        const cacheSnapshot = buildCachedSnapshot$5(luvio, config);
        if (isFulfilledSnapshot(cacheSnapshot)) {
            // Create an optimistic update if we can
            const updatedLayoutUserState = optimisticUpdate(cacheSnapshot.data, layoutUserStateInput);
            if (updatedLayoutUserState !== null) {
                // Ingest optimistic update done client side
                ingestAndBroadcast(luvio, key, config, updatedLayoutUserState);
            }
        }
        return updateLayoutUserState$1(luvio, config, key, updateRequest);
    };
};

function buildNetworkSnapshot$9(luvio, config, options, cacheSnapshot) {
    const resourceParams = createResourceParams$8(config);
    const request = prepareRequest$1(luvio, config, resourceParams, cacheSnapshot);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        const { body } = response;
        // Hand-rolling: The server returns sortBy as a comma-delimited String, but LDS expects an array.
        // getListUi does the same in its index.ts.
        const sortBy = body.sortBy;
        if (sortBy && typeof sortBy === 'string') {
            response.body.sortBy = sortBy.split(',');
        }
        // Hand-rolling: The server returns sortBy as null for MRU when we don't pass it as a parameter.
        // Changing server response to avoid key mismatch
        const listViewApiName = body.listReference && body.listReference.listViewApiName
            ? body.listReference.listViewApiName
            : null;
        if (listViewApiName === '__Recent' && !sortBy) {
            response.body.sortBy = [];
        }
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess$1(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$10(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError$1(luvio, config, resourceParams, response));
    });
}

const adapterName$6 = 'getListRecordsByName';
const getListRecordsByName_ConfigPropertyMetadata = [
    generateParamConfigMetadata('listViewApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('fields', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('optionalFields', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('pageSize', false, 2 /* Body */, 3 /* Integer */),
    generateParamConfigMetadata('pageToken', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('searchTerm', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('sortBy', false, 2 /* Body */, 0 /* String */, true),
    generateParamConfigMetadata('where', false, 2 /* Body */, 0 /* String */),
];
const getListRecordsByName_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$6, getListRecordsByName_ConfigPropertyMetadata);
const createResourceParams$8 = /*#__PURE__*/ createResourceParams$13(getListRecordsByName_ConfigPropertyMetadata);
function keyBuilder$9(luvio, config) {
    const resourceParams = createResourceParams$8(config);
    return keyBuilder$22(luvio, resourceParams);
}
function typeCheckConfig$b(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getListRecordsByName_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$9(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$b(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment$1(luvio, config) {
    const resourceParams = createResourceParams$8(config);
    return select$1R(luvio, resourceParams);
}
function onFetchResponseSuccess$2(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess$R(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$9(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError$1(luvio, config, resourceParams, response) {
    const snapshot = ingestError$K(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot$9(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function prepareRequest$1(luvio, config, resourceParams, cacheSnapshot) {
    if (cacheSnapshot === undefined) {
        return createResourceRequest$17(resourceParams);
    }
    const [newToken, newPageSize] = minimizePaginationParams(luvio, resourceParams, cacheSnapshot);
    if (newToken === undefined) {
        return createResourceRequest$17(resourceParams);
    }
    return createResourceRequest$17(createResourceParams$8({
        ...config,
        pageSize: newPageSize,
        pageToken: newToken
    }));
}
function minimizePaginationParams(luvio, resourceParams, cacheSnapshot) {
    const num = getCachedItemsNumber(cacheSnapshot);
    if (num > 0) {
        const paginationMetadata = getPaginationMetadata(luvio, resourceParams);
        if (paginationMetadata !== undefined) {
            const { token: configToken, pageSize: configPageSize } = createPaginationParams$4(resourceParams);
            const configTokenOffset = offsetFromToken(paginationMetadata, configToken);
            if (configTokenOffset < 0) {
                return [undefined, -1];
            }
            const maxOffset = configTokenOffset + num;
            const [token, offset] = tokenForAtMost(paginationMetadata, maxOffset);
            if (token !== undefined) {
                return [token, configPageSize - (offset - configTokenOffset)];
            }
        }
    }
    return [undefined, -1];
}
function getCachedItemsNumber(cacheSnapshot) {
    const { data } = cacheSnapshot;
    if (data === undefined || !data.records) {
        return 0;
    }
    const items = data.records;
    for (let i = 0; i < items.length; i++) {
        if (items[i] === undefined) {
            return i;
        }
    }
    return items.length;
}
function getPaginationMetadata(luvio, resourceParams) {
    const key = keyBuilder$22(luvio, resourceParams);
    const selector = {
        recordId: key,
        node: {
            kind: 'Fragment',
            version: VERSION$1e,
            private: [],
            selections: [
                {
                    kind: 'Link',
                    name: '__metadata',
                    fragment: {
                        kind: 'Fragment',
                        version: PAGINATION_VERSION$1,
                        opaque: true,
                        private: [],
                    },
                },
            ],
        },
        variables: {}
    };
    const node = luvio.storeLookup(selector);
    if (node.state !== 'Fulfilled') {
        return;
    }
    return node.data.__metadata;
}
function buildNetworkSnapshotCachePolicy$4(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$S(context, coercedAdapterRequestContext, buildNetworkSnapshot$9, 'get', true);
}
function buildCachedSnapshotCachePolicy$3(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder$9(luvio, config),
        node: adapterFragment$1(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$9(luvio, config, snapshotRefreshOptions)
    });
    if (isUnfulfilledSnapshot$1(cacheSnapshot) && cacheSnapshot.data !== undefined) {
        context.cacheSnapshot = cacheSnapshot;
    }
    return cacheSnapshot;
}

let context;
function setContext(adapterContext) {
    context = adapterContext;
}
function onFetchResponseSuccess$1(luvio, config, resourceParams, response) {
    const { body } = response, originalListRef = body.listReference;
    // If the response contains a listReference, then we need to add it/update it in the internal store
    if (originalListRef !== undefined) {
        const mutatedListRef = { ...originalListRef };
        // Setting the id to the eTag in the stored AdapterContext entry only, because
        // keyBuilder needs the eTag to generate the correct key for a cache hit.
        // Ideally, this can be removed once we deprecate getListUi and remove the hardcoded eTag reference in ListRecordCollectionRepresentation
        // Note: The original listReference will remain unchanged in the response.
        mutatedListRef.id = body.listInfoETag;
        addListReferenceWithId(mutatedListRef, context, body.listReference.id);
        // storing sortBy ensuring a cache hit when requesting records with no sortBy provided
        addServerDefaults(config, body, originalListRef, context);
    }
    return onFetchResponseSuccess$2(luvio, config, resourceParams, response);
}

const contextId$3 = `${keyPrefix}__${adapterName$6}`;
const factory$a = (luvio) => {
    return luvio.withContext(function UiApi__getListRecordsByName(untrustedConfig, adapterContext, requestContext) {
        const config = validateAdapterConfig$9(untrustedConfig, getListRecordsByName_ConfigPropertyNames);
        if (config === null) {
            return null;
        }
        setContext$1(adapterContext);
        setContext(adapterContext);
        return luvio.applyCachePolicy(requestContext || {}, { adapterContext, config, luvio }, buildCachedSnapshotCachePolicy$3, buildNetworkSnapshotCachePolicy$4);
    }, { contextId: contextId$3 });
};

function validate$7(obj, path = 'RecordInputRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.allowSaveOnDuplicate !== undefined) {
            const obj_allowSaveOnDuplicate = obj.allowSaveOnDuplicate;
            const path_allowSaveOnDuplicate = path + '.allowSaveOnDuplicate';
            if (typeof obj_allowSaveOnDuplicate !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_allowSaveOnDuplicate + '" (at "' + path_allowSaveOnDuplicate + '")');
            }
        }
        if (obj.apiName !== undefined) {
            const obj_apiName = obj.apiName;
            const path_apiName = path + '.apiName';
            if (typeof obj_apiName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
            }
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            let obj_fields_prop_union0 = null;
            const obj_fields_prop_union0_error = (() => {
                if (typeof obj_fields_prop !== 'string') {
                    return new TypeError('Expected "string" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union0_error != null) {
                obj_fields_prop_union0 = obj_fields_prop_union0_error.message;
            }
            let obj_fields_prop_union1 = null;
            const obj_fields_prop_union1_error = (() => {
                if (typeof obj_fields_prop !== 'number') {
                    return new TypeError('Expected "number" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union1_error != null) {
                obj_fields_prop_union1 = obj_fields_prop_union1_error.message;
            }
            let obj_fields_prop_union2 = null;
            const obj_fields_prop_union2_error = (() => {
                if (obj_fields_prop !== null) {
                    return new TypeError('Expected "null" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union2_error != null) {
                obj_fields_prop_union2 = obj_fields_prop_union2_error.message;
            }
            let obj_fields_prop_union3 = null;
            const obj_fields_prop_union3_error = (() => {
                if (typeof obj_fields_prop !== 'boolean') {
                    return new TypeError('Expected "boolean" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
                }
            })();
            if (obj_fields_prop_union3_error != null) {
                obj_fields_prop_union3 = obj_fields_prop_union3_error.message;
            }
            if (obj_fields_prop_union0 && obj_fields_prop_union1 && obj_fields_prop_union2 && obj_fields_prop_union3) {
                let message = 'Object doesn\'t match union (at "' + path_fields_prop + '")';
                message += '\n' + obj_fields_prop_union0.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_fields_prop_union1.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_fields_prop_union2.split('\n').map((line) => '\t' + line).join('\n');
                message += '\n' + obj_fields_prop_union3.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

const RepresentationType$7 = 'LookupValuesRepresentation';
function getTypeCacheKeys$7(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$7,
        mergeable: false
    });
    const input_lookupResults = input.lookupResults;
    const input_lookupResults_keys = ObjectKeys(input_lookupResults);
    const input_lookupResults_length = input_lookupResults_keys.length;
    for (let i = 0; i < input_lookupResults_length; i++) {
        const key = input_lookupResults_keys[i];
        getTypeCacheKeys$W(rootKeySet, luvio, input_lookupResults[key], () => rootKey + "__lookupResults" + "__" + key);
    }
}

function keyBuilder$8(luvio, params) {
    return keyPrefix + '::LookupValuesRepresentation:(' + 'dependentFieldBindings:' + params.queryParams.dependentFieldBindings + ',' + 'page:' + params.queryParams.page + ',' + 'pageSize:' + params.queryParams.pageSize + ',' + 'q:' + params.queryParams.q + ',' + 'searchType:' + params.queryParams.searchType + ',' + 'sourceRecordId:' + params.queryParams.sourceRecordId + ',' + 'targetApiName:' + params.queryParams.targetApiName + ',' + 'fieldApiName:' + params.urlParams.fieldApiName + ',' + 'objectApiName:' + params.urlParams.objectApiName + ',' + (params.body.sourceRecord?.allowSaveOnDuplicate === undefined ? 'sourceRecord.allowSaveOnDuplicate' : 'sourceRecord.allowSaveOnDuplicate:' + params.body.sourceRecord?.allowSaveOnDuplicate) + '::' + (params.body.sourceRecord?.apiName === undefined ? 'sourceRecord.apiName' : 'sourceRecord.apiName:' + params.body.sourceRecord?.apiName) + '::' + stableJSONStringify(params.body.sourceRecord?.fields) + '::' + (params.body.orderBy === undefined ? undefined : ('[' + params.body.orderBy.map(element => 'orderBy.fieldApiName:' + element.fieldApiName + '::' + 'orderBy.isAscending:' + element.isAscending).join(',') + ']')) + ')';
}
function getResponseCacheKeys$7(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$7(storeKeyMap, luvio, response, () => keyBuilder$8(luvio, resourceParams));
}
function createResourceRequest$a(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/lookups/' + config.urlParams.objectApiName + '/' + config.urlParams.fieldApiName + '',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const getLookupRecords_ConfigPropertyMetadata = [
    generateParamConfigMetadata('fieldApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getFieldApiName),
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('dependentFieldBindings', false, 1 /* QueryParameter */, 0 /* String */, true),
    generateParamConfigMetadata('page', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('pageSize', false, 1 /* QueryParameter */, 3 /* Integer */),
    generateParamConfigMetadata('q', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('searchType', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sourceRecordId', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('targetApiName', false, 1 /* QueryParameter */, 0 /* String */),
    generateParamConfigMetadata('sourceRecord', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('orderBy', false, 2 /* Body */, 4 /* Unsupported */, true),
];
function typeCheckConfig$a(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getLookupRecords_ConfigPropertyMetadata);
    const untrustedConfig_sourceRecord = untrustedConfig.sourceRecord;
    const referenceRecordInputRepresentationValidationError = validate$7(untrustedConfig_sourceRecord);
    if (referenceRecordInputRepresentationValidationError === null) {
        config.sourceRecord = untrustedConfig_sourceRecord;
    }
    const untrustedConfig_orderBy = untrustedConfig.orderBy;
    if (ArrayIsArray$1(untrustedConfig_orderBy)) {
        const untrustedConfig_orderBy_array = [];
        for (let i = 0, arrayLength = untrustedConfig_orderBy.length; i < arrayLength; i++) {
            const untrustedConfig_orderBy_item = untrustedConfig_orderBy[i];
            const referenceListOrderedByInfoInputRepresentationValidationError = validate$11(untrustedConfig_orderBy_item);
            if (referenceListOrderedByInfoInputRepresentationValidationError === null) {
                untrustedConfig_orderBy_array.push(untrustedConfig_orderBy_item);
            }
        }
        config.orderBy = untrustedConfig_orderBy_array;
    }
    return config;
}
function validateAdapterConfig$8(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getLookupRecords_ConfigPropertyMetadata);
    const config = typeCheckConfig$a(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const paramNames = {
    displayName: 'getLookupRecords',
    parameters: {
        required: ['fieldApiName'],
        optional: ['requestParams'],
    },
};
function coerceRequestParams(untrusted) {
    if (!untrustedIsObject(untrusted)) {
        return {};
    }
    const coercedConfig = {};
    const requestParams = untrusted.requestParams || {};
    const dependentFieldBindings = requestParams.dependentFieldBindings;
    if (dependentFieldBindings !== undefined) {
        coercedConfig.dependentFieldBindings = dependentFieldBindings;
    }
    const page = requestParams.page;
    if (page !== undefined) {
        coercedConfig.page = page;
    }
    const pageSize = requestParams.pageSize;
    if (pageSize !== undefined) {
        coercedConfig.pageSize = pageSize;
    }
    const q = requestParams.q;
    if (q !== undefined) {
        coercedConfig.q = q;
    }
    const searchType = requestParams.searchType;
    if (searchType !== undefined) {
        coercedConfig.searchType = searchType;
    }
    const sourceRecordId = requestParams.sourceRecordId;
    if (sourceRecordId !== undefined) {
        coercedConfig.sourceRecordId = sourceRecordId;
    }
    const targetApiName = requestParams.targetApiName;
    if (targetApiName !== undefined) {
        coercedConfig.targetApiName = targetApiName;
    }
    const sourceRecord = requestParams.sourceRecord;
    if (sourceRecord !== undefined) {
        coercedConfig.sourceRecord = sourceRecord;
    }
    const orderBy = requestParams.orderBy;
    if (orderBy !== undefined) {
        coercedConfig.orderBy = orderBy;
    }
    return coercedConfig;
}
function coerceConfigWithDefaults$1(untrusted) {
    const config = validateAdapterConfig$8(untrusted, paramNames);
    if (config === null) {
        return config;
    }
    const coercedRequestParams = coerceRequestParams(untrusted);
    const { objectApiName, fieldApiName } = getFieldId(config.fieldApiName);
    return {
        ...config,
        objectApiName,
        fieldApiName,
        ...coercedRequestParams,
    };
}
function removeEtags(recordRep) {
    const { fields } = recordRep;
    delete recordRep.eTag;
    delete recordRep.weakEtag;
    Object.keys(fields).forEach((fieldName) => {
        const { value: nestedValue } = fields[fieldName];
        if (isSpanningRecord(nestedValue)) {
            removeEtags(nestedValue);
        }
    });
}
function buildNetworkSnapshot$8(luvio, config, options) {
    const { objectApiName, fieldApiName } = config;
    const resourceParams = {
        /*
            targetApiName is not set in the config in order to call /lookups/{objectApiName}/{fieldApiName} resource only.
            This is a temporary measure while aligning the representation of lookup resources (W-10320080)
        */
        urlParams: {
            objectApiName,
            fieldApiName,
        },
        queryParams: {
            page: config.page,
            pageSize: config.pageSize,
            q: config.q,
            searchType: config.searchType,
            dependentFieldBindings: config.dependentFieldBindings,
            sourceRecordId: config.sourceRecordId,
            targetApiName: config.targetApiName,
        },
        body: {
            sourceRecord: config.sourceRecord,
            orderBy: config.orderBy,
        },
    };
    const request = createResourceRequest$a(resourceParams);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        return luvio.handleSuccessResponse(() => {
            // TODO [W-7235112]: remove this hack to never ingest lookup responses that
            // avoids issues caused by them not being real RecordRepresentations
            const key = keyBuilder$8(luvio, resourceParams);
            const { body } = response;
            Object.keys(body.lookupResults)
                .map((targetApiName) => body.lookupResults[targetApiName].records)
                .reduce((allRecords, records) => allRecords.concat(records), [])
                .forEach((record) => removeEtags(record));
            deepFreeze(body);
            return Promise.resolve({
                state: 'Fulfilled',
                recordId: key,
                variables: {},
                seenRecords: new StoreKeySet(),
                select: {
                    recordId: key,
                    node: {
                        kind: 'Fragment',
                    },
                    variables: {},
                },
                data: body,
            });
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$7(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            return Promise.resolve(luvio.errorSnapshot(err));
        });
    });
}
function buildCachedSnapshot$2(_context, _storeLookup) {
    return;
}
function buildNetworkSnapshotCachePolicy$3(context, coercedAdapterRequestContext) {
    const { networkPriority, requestCorrelator, eventObservers } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$8(context.luvio, context.config, dispatchOptions);
}
const factory$9 = (luvio) => {
    return (untrustedConfig, requestContext) => {
        const config = coerceConfigWithDefaults$1(untrustedConfig);
        if (config === null) {
            return null;
        }
        const refresh = {
            config,
            resolve: () => buildNetworkSnapshot$8(luvio, config),
        };
        const promiseOrSnapshot = luvio.applyCachePolicy(requestContext || {}, { config, luvio }, buildCachedSnapshot$2, buildNetworkSnapshotCachePolicy$3);
        if (isPromise(promiseOrSnapshot)) {
            return promiseOrSnapshot.then((snapshot) => {
                snapshot.refresh = refresh;
                return snapshot;
            });
        }
        promiseOrSnapshot.refresh = refresh;
        return promiseOrSnapshot;
    };
};

function createResourceRequest$9(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/record-avatars/' + config.urlParams.recordId + '/association',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$5 = 'updateRecordAvatar';
const updateRecordAvatar_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('actionType', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('blueMasterId', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('externalId', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('photoUrl', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('profileName', false, 2 /* Body */, 0 /* String */),
];
const updateRecordAvatar_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$5, updateRecordAvatar_ConfigPropertyMetadata);
function typeCheckConfig$9(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, updateRecordAvatar_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$7(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$9(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const factory$8 = (luvio) => {
    return (untrustedConfig) => {
        const config = validateAdapterConfig$7(untrustedConfig, updateRecordAvatar_ConfigPropertyNames);
        if (config === null) {
            // eslint-disable-next-line @salesforce/lds/no-error-in-production
            throw new Error('updateRecordAvatar invalid configuration');
        }
        const resourceParams = {
            urlParams: {
                recordId: config.recordId,
            },
            body: {
                externalId: config.externalId,
                blueMasterId: config.blueMasterId,
                profileName: config.profileName,
                photoUrl: config.photoUrl,
                actionType: config.actionType,
            },
        };
        const request = createResourceRequest$9(resourceParams);
        return luvio.dispatchResourceRequest(request).then((response) => {
            const { body } = response;
            const key = keyBuilderFromType$f(luvio, body);
            return luvio.handleSuccessResponse(() => {
                let selectors;
                if (body.type === 'Theme') {
                    selectors = select$C;
                    luvio.storeIngest(key, ingest$h, body);
                }
                else if (body.type === 'Photo') {
                    selectors = select$D;
                    luvio.storeIngest(key, ingest$i, body);
                }
                else {
                    // eslint-disable-next-line @salesforce/lds/no-error-in-production
                    throw new Error('Unsupported avatar type');
                }
                // TODO [W-6804405]: support unions on fragments (only supported on links today)
                const snapshot = luvio.storeLookup({
                    recordId: key,
                    node: selectors(),
                    variables: {},
                });
                return luvio.storeBroadcast().then(() => snapshot);
            }, () => {
                const cache = new StoreKeyMap();
                getTypeCacheKeys$n(cache, luvio, body);
                return cache;
            });
        }, (err) => {
            deepFreeze(err);
            throw err;
        });
    };
};

const VERSION$6 = "809ada3563b00c364360826037620d7e";
function validate$6(obj, path = 'RecordCreateDefaultRecordRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_childRelationships = obj.childRelationships;
        const path_childRelationships = path + '.childRelationships';
        if (typeof obj_childRelationships !== 'object' || ArrayIsArray(obj_childRelationships) || obj_childRelationships === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_childRelationships + '" (at "' + path_childRelationships + '")');
        }
        const obj_childRelationships_keys = ObjectKeys(obj_childRelationships);
        for (let i = 0; i < obj_childRelationships_keys.length; i++) {
            const key = obj_childRelationships_keys[i];
            const obj_childRelationships_prop = obj_childRelationships[key];
            const path_childRelationships_prop = path_childRelationships + '["' + key + '"]';
            if (typeof obj_childRelationships_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_childRelationships_prop + '" (at "' + path_childRelationships_prop + '")');
            }
        }
        const obj_eTag = obj.eTag;
        const path_eTag = path + '.eTag';
        if (typeof obj_eTag !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_eTag + '" (at "' + path_eTag + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            if (typeof obj_fields_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
            }
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (obj_id !== null) {
            return new TypeError('Expected "null" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        const obj_lastModifiedById = obj.lastModifiedById;
        const path_lastModifiedById = path + '.lastModifiedById';
        let obj_lastModifiedById_union0 = null;
        const obj_lastModifiedById_union0_error = (() => {
            if (typeof obj_lastModifiedById !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lastModifiedById + '" (at "' + path_lastModifiedById + '")');
            }
        })();
        if (obj_lastModifiedById_union0_error != null) {
            obj_lastModifiedById_union0 = obj_lastModifiedById_union0_error.message;
        }
        let obj_lastModifiedById_union1 = null;
        const obj_lastModifiedById_union1_error = (() => {
            if (obj_lastModifiedById !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lastModifiedById + '" (at "' + path_lastModifiedById + '")');
            }
        })();
        if (obj_lastModifiedById_union1_error != null) {
            obj_lastModifiedById_union1 = obj_lastModifiedById_union1_error.message;
        }
        if (obj_lastModifiedById_union0 && obj_lastModifiedById_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lastModifiedById + '")';
            message += '\n' + obj_lastModifiedById_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lastModifiedById_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_lastModifiedDate = obj.lastModifiedDate;
        const path_lastModifiedDate = path + '.lastModifiedDate';
        let obj_lastModifiedDate_union0 = null;
        const obj_lastModifiedDate_union0_error = (() => {
            if (typeof obj_lastModifiedDate !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lastModifiedDate + '" (at "' + path_lastModifiedDate + '")');
            }
        })();
        if (obj_lastModifiedDate_union0_error != null) {
            obj_lastModifiedDate_union0 = obj_lastModifiedDate_union0_error.message;
        }
        let obj_lastModifiedDate_union1 = null;
        const obj_lastModifiedDate_union1_error = (() => {
            if (obj_lastModifiedDate !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_lastModifiedDate + '" (at "' + path_lastModifiedDate + '")');
            }
        })();
        if (obj_lastModifiedDate_union1_error != null) {
            obj_lastModifiedDate_union1 = obj_lastModifiedDate_union1_error.message;
        }
        if (obj_lastModifiedDate_union0 && obj_lastModifiedDate_union1) {
            let message = 'Object doesn\'t match union (at "' + path_lastModifiedDate + '")';
            message += '\n' + obj_lastModifiedDate_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_lastModifiedDate_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        let obj_recordTypeId_union0 = null;
        const obj_recordTypeId_union0_error = (() => {
            if (typeof obj_recordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union0_error != null) {
            obj_recordTypeId_union0 = obj_recordTypeId_union0_error.message;
        }
        let obj_recordTypeId_union1 = null;
        const obj_recordTypeId_union1_error = (() => {
            if (obj_recordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union1_error != null) {
            obj_recordTypeId_union1 = obj_recordTypeId_union1_error.message;
        }
        if (obj_recordTypeId_union0 && obj_recordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeId + '")';
            message += '\n' + obj_recordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_recordTypeInfo = obj.recordTypeInfo;
        const path_recordTypeInfo = path + '.recordTypeInfo';
        let obj_recordTypeInfo_union0 = null;
        const obj_recordTypeInfo_union0_error = (() => {
            const referencepath_recordTypeInfoValidationError = validate$1Z(obj_recordTypeInfo, path_recordTypeInfo);
            if (referencepath_recordTypeInfoValidationError !== null) {
                let message = 'Object doesn\'t match RecordTypeInfoRepresentation (at "' + path_recordTypeInfo + '")\n';
                message += referencepath_recordTypeInfoValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        })();
        if (obj_recordTypeInfo_union0_error != null) {
            obj_recordTypeInfo_union0 = obj_recordTypeInfo_union0_error.message;
        }
        let obj_recordTypeInfo_union1 = null;
        const obj_recordTypeInfo_union1_error = (() => {
            if (obj_recordTypeInfo !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeInfo + '" (at "' + path_recordTypeInfo + '")');
            }
        })();
        if (obj_recordTypeInfo_union1_error != null) {
            obj_recordTypeInfo_union1 = obj_recordTypeInfo_union1_error.message;
        }
        if (obj_recordTypeInfo_union0 && obj_recordTypeInfo_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeInfo + '")';
            message += '\n' + obj_recordTypeInfo_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeInfo_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_systemModstamp = obj.systemModstamp;
        const path_systemModstamp = path + '.systemModstamp';
        let obj_systemModstamp_union0 = null;
        const obj_systemModstamp_union0_error = (() => {
            if (typeof obj_systemModstamp !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_systemModstamp + '" (at "' + path_systemModstamp + '")');
            }
        })();
        if (obj_systemModstamp_union0_error != null) {
            obj_systemModstamp_union0 = obj_systemModstamp_union0_error.message;
        }
        let obj_systemModstamp_union1 = null;
        const obj_systemModstamp_union1_error = (() => {
            if (obj_systemModstamp !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_systemModstamp + '" (at "' + path_systemModstamp + '")');
            }
        })();
        if (obj_systemModstamp_union1_error != null) {
            obj_systemModstamp_union1 = obj_systemModstamp_union1_error.message;
        }
        if (obj_systemModstamp_union0 && obj_systemModstamp_union1) {
            let message = 'Object doesn\'t match union (at "' + path_systemModstamp + '")';
            message += '\n' + obj_systemModstamp_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_systemModstamp_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_weakEtag = obj.weakEtag;
        const path_weakEtag = path + '.weakEtag';
        if (typeof obj_weakEtag !== 'number' || (typeof obj_weakEtag === 'number' && Math.floor(obj_weakEtag) !== obj_weakEtag)) {
            return new TypeError('Expected "integer" but received "' + typeof obj_weakEtag + '" (at "' + path_weakEtag + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$6 = 'RecordCreateDefaultRecordRepresentation';
function normalize$2(input, existing, path, luvio, store, timestamp) {
    const input_childRelationships = input.childRelationships;
    const input_childRelationships_id = path.fullPath + '__childRelationships';
    const input_childRelationships_keys = Object.keys(input_childRelationships);
    const input_childRelationships_length = input_childRelationships_keys.length;
    for (let i = 0; i < input_childRelationships_length; i++) {
        const key = input_childRelationships_keys[i];
        const input_childRelationships_prop = input_childRelationships[key];
        const input_childRelationships_prop_id = input_childRelationships_id + '__' + key;
        input_childRelationships[key] = ingest$P(input_childRelationships_prop, {
            fullPath: input_childRelationships_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_fields = input.fields;
    const input_fields_id = path.fullPath + '__fields';
    const input_fields_keys = Object.keys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        const input_fields_prop = input_fields[key];
        const input_fields_prop_id = input_fields_id + '__' + key;
        input_fields[key] = ingest$Q(input_fields_prop, {
            fullPath: input_fields_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    return input;
}
function equals$6(existing, incoming) {
    const existing_weakEtag = existing.weakEtag;
    const incoming_weakEtag = incoming.weakEtag;
    if (!(existing_weakEtag === incoming_weakEtag)) {
        return false;
    }
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_eTag = existing.eTag;
    const incoming_eTag = incoming.eTag;
    if (!(existing_eTag === incoming_eTag)) {
        return false;
    }
    const existing_childRelationships = existing.childRelationships;
    const incoming_childRelationships = incoming.childRelationships;
    const equals_childRelationships_props = equalsObject(existing_childRelationships, incoming_childRelationships, (existing_childRelationships_prop, incoming_childRelationships_prop) => {
        if (!(existing_childRelationships_prop.__ref === incoming_childRelationships_prop.__ref)) {
            return false;
        }
    });
    if (equals_childRelationships_props === false) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_props = equalsObject(existing_fields, incoming_fields, (existing_fields_prop, incoming_fields_prop) => {
        if (!(existing_fields_prop.__ref === incoming_fields_prop.__ref)) {
            return false;
        }
    });
    if (equals_fields_props === false) {
        return false;
    }
    const existing_id = existing.id;
    const incoming_id = incoming.id;
    if (!(existing_id === incoming_id)) {
        return false;
    }
    const existing_lastModifiedById = existing.lastModifiedById;
    const incoming_lastModifiedById = incoming.lastModifiedById;
    if (!(existing_lastModifiedById === incoming_lastModifiedById)) {
        return false;
    }
    const existing_lastModifiedDate = existing.lastModifiedDate;
    const incoming_lastModifiedDate = incoming.lastModifiedDate;
    if (!(existing_lastModifiedDate === incoming_lastModifiedDate)) {
        return false;
    }
    const existing_recordTypeId = existing.recordTypeId;
    const incoming_recordTypeId = incoming.recordTypeId;
    if (!(existing_recordTypeId === incoming_recordTypeId)) {
        return false;
    }
    const existing_recordTypeInfo = existing.recordTypeInfo;
    const incoming_recordTypeInfo = incoming.recordTypeInfo;
    if (!(existing_recordTypeInfo === incoming_recordTypeInfo
        || (existing_recordTypeInfo != null &&
            incoming_recordTypeInfo != null &&
            equals$18(existing_recordTypeInfo, incoming_recordTypeInfo)))) {
        return false;
    }
    const existing_systemModstamp = existing.systemModstamp;
    const incoming_systemModstamp = incoming.systemModstamp;
    if (!(existing_systemModstamp === incoming_systemModstamp)) {
        return false;
    }
    return true;
}
const ingest$2 = function RecordCreateDefaultRecordRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$6(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$2, "UiApi", VERSION$6, RepresentationType$6, equals$6);
    return createLink(key);
};
function getTypeCacheKeys$6(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$6,
        mergeable: false
    });
    const input_childRelationships = input.childRelationships;
    const input_childRelationships_keys = ObjectKeys(input_childRelationships);
    const input_childRelationships_length = input_childRelationships_keys.length;
    for (let i = 0; i < input_childRelationships_length; i++) {
        const key = input_childRelationships_keys[i];
        getTypeCacheKeys$W(rootKeySet, luvio, input_childRelationships[key], () => rootKey + "__childRelationships" + "__" + key);
    }
    const input_fields = input.fields;
    const input_fields_keys = ObjectKeys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$Y(rootKeySet, luvio, input_fields[key], () => rootKey + "__fields" + "__" + key);
    }
}

const TTL$4 = 900000;
const VERSION$5 = "894a62b8f5de5535f2483fb2c3abca8e";
function validate$5(obj, path = 'RecordDefaultsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_layout = obj.layout;
        const path_layout = path + '.layout';
        let obj_layout_union0 = null;
        const obj_layout_union0_error = (() => {
            if (typeof obj_layout !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_layout + '" (at "' + path_layout + '")');
            }
        })();
        if (obj_layout_union0_error != null) {
            obj_layout_union0 = obj_layout_union0_error.message;
        }
        let obj_layout_union1 = null;
        const obj_layout_union1_error = (() => {
            if (obj_layout !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_layout + '" (at "' + path_layout + '")');
            }
        })();
        if (obj_layout_union1_error != null) {
            obj_layout_union1 = obj_layout_union1_error.message;
        }
        if (obj_layout_union0 && obj_layout_union1) {
            let message = 'Object doesn\'t match union (at "' + path_layout + '")';
            message += '\n' + obj_layout_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_layout_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_objectInfos = obj.objectInfos;
        const path_objectInfos = path + '.objectInfos';
        if (typeof obj_objectInfos !== 'object' || ArrayIsArray(obj_objectInfos) || obj_objectInfos === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_objectInfos + '" (at "' + path_objectInfos + '")');
        }
        const obj_objectInfos_keys = ObjectKeys(obj_objectInfos);
        for (let i = 0; i < obj_objectInfos_keys.length; i++) {
            const key = obj_objectInfos_keys[i];
            const obj_objectInfos_prop = obj_objectInfos[key];
            const path_objectInfos_prop = path_objectInfos + '["' + key + '"]';
            if (typeof obj_objectInfos_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_objectInfos_prop + '" (at "' + path_objectInfos_prop + '")');
            }
        }
        const obj_record = obj.record;
        const path_record = path + '.record';
        if (typeof obj_record !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_record + '" (at "' + path_record + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$5 = 'RecordDefaultsRepresentation';
function normalize$1(input, existing, path, luvio, store, timestamp) {
    const input_layout = input.layout;
    const input_layout_id = path.fullPath + '__layout';
    if (input_layout !== null && typeof input_layout === 'object') {
        input.layout = ingest$G(input_layout, {
            fullPath: input_layout_id,
            propertyName: 'layout',
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_objectInfos = input.objectInfos;
    const input_objectInfos_id = path.fullPath + '__objectInfos';
    const input_objectInfos_keys = Object.keys(input_objectInfos);
    const input_objectInfos_length = input_objectInfos_keys.length;
    for (let i = 0; i < input_objectInfos_length; i++) {
        const key = input_objectInfos_keys[i];
        const input_objectInfos_prop = input_objectInfos[key];
        const input_objectInfos_prop_id = input_objectInfos_id + '__' + key;
        input_objectInfos[key] = ingest$H(input_objectInfos_prop, {
            fullPath: input_objectInfos_prop_id,
            propertyName: key,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_record = input.record;
    const input_record_id = path.fullPath + '__record';
    input.record = ingest$2(input_record, {
        fullPath: input_record_id,
        propertyName: 'record',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    return input;
}
function equals$5(existing, incoming) {
    const existing_layout = existing.layout;
    const incoming_layout = incoming.layout;
    if (!(existing_layout === incoming_layout
        || (existing_layout != null &&
            incoming_layout != null &&
            existing_layout.__ref != null &&
            incoming_layout.__ref != null &&
            existing_layout.__ref === incoming_layout.__ref))) {
        return false;
    }
    const existing_objectInfos = existing.objectInfos;
    const incoming_objectInfos = incoming.objectInfos;
    const equals_objectInfos_props = equalsObject(existing_objectInfos, incoming_objectInfos, (existing_objectInfos_prop, incoming_objectInfos_prop) => {
        if (!(existing_objectInfos_prop.__ref === incoming_objectInfos_prop.__ref)) {
            return false;
        }
    });
    if (equals_objectInfos_props === false) {
        return false;
    }
    const existing_record = existing.record;
    const incoming_record = incoming.record;
    if (!(existing_record.__ref === incoming_record.__ref)) {
        return false;
    }
    return true;
}
const ingest$1 = function RecordDefaultsRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate$5(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = TTL$4;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize$1, "UiApi", VERSION$5, RepresentationType$5, equals$5);
    return createLink(key);
};
function getTypeCacheKeys$5(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$5,
        mergeable: false
    });
    if (input.layout !== null && typeof input.layout === 'object') {
        getTypeCacheKeys$N(rootKeySet, luvio, input.layout);
    }
    const input_objectInfos = input.objectInfos;
    const input_objectInfos_keys = ObjectKeys(input_objectInfos);
    const input_objectInfos_length = input_objectInfos_keys.length;
    for (let i = 0; i < input_objectInfos_length; i++) {
        const key = input_objectInfos_keys[i];
        getTypeCacheKeys$O(rootKeySet, luvio, input_objectInfos[key]);
    }
    getTypeCacheKeys$6(rootKeySet, luvio, input.record, () => rootKey + "__" + "record");
}

function keyBuilder$7(luvio, params) {
    return keyPrefix + '::RecordDefaultsRepresentation:(' + 'formFactor:' + params.queryParams.formFactor + ',' + 'optionalFields:' + params.queryParams.optionalFields + ',' + 'recordTypeId:' + params.queryParams.recordTypeId + ',' + 'objectApiName:' + params.urlParams.objectApiName + ')';
}
function getResponseCacheKeys$6(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$5(storeKeyMap, luvio, response, () => keyBuilder$7(luvio, resourceParams));
}
function createResourceRequest$8(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/record-defaults/create/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$4 = 'getRecordCreateDefaults';
const getRecordCreateDefaults_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('formFactor', false, 1 /* QueryParameter */, 0 /* String */, false, coerceFormFactor),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */, false, getRecordId18),
];
const getRecordCreateDefaults_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$4, getRecordCreateDefaults_ConfigPropertyMetadata);
const createResourceParams$7 = /*#__PURE__*/ createResourceParams$13(getRecordCreateDefaults_ConfigPropertyMetadata);
function typeCheckConfig$8(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordCreateDefaults_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$6(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordCreateDefaults_ConfigPropertyMetadata);
    const config = typeCheckConfig$8(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const contextId$2 = `${keyPrefix}__${adapterName$4}`;
const layoutSelections = select$1L();
const objectInfoSelections = select$1N();
function buildSelector(resp) {
    const recordSelections = buildSelectionFromRecord(resp.record);
    return [
        {
            kind: 'Link',
            name: 'layout',
            nullable: true,
            fragment: layoutSelections,
        },
        {
            kind: 'Link',
            name: 'objectInfos',
            map: true,
            fragment: objectInfoSelections,
        },
        {
            kind: 'Link',
            name: 'record',
            fragment: {
                kind: 'Fragment',
                private: [],
                selections: recordSelections,
                version: VERSION$6,
            },
        },
    ];
}
function buildSnapshotRefresh$1(luvio, context, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot$7(luvio, context, config),
    };
}
function buildNetworkSnapshot$7(luvio, context, config, options) {
    const params = createResourceParams$7(config);
    const request = createResourceRequest$8(params);
    const key = keyBuilder$7(luvio, params);
    const selectorKey = buildSelectorKey(luvio, config);
    return luvio.dispatchResourceRequest(request, options).then((response) => {
        return luvio.handleSuccessResponse(() => {
            const { body } = response;
            const cacheSelector = {
                recordId: key,
                node: {
                    kind: 'Fragment',
                    private: [],
                    version: VERSION$5,
                    selections: buildSelector(body),
                },
                variables: {},
            };
            context.set(selectorKey, cacheSelector);
            luvio.storeIngest(key, ingest$1, body);
            const snapshot = luvio.storeLookup(cacheSelector, buildSnapshotRefresh$1(luvio, context, config));
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$6(cache, luvio, params, response.body);
            return cache;
        });
    }, (err) => {
        return luvio.handleErrorResponse(() => {
            const errorSnapshot = luvio.errorSnapshot(err, buildSnapshotRefresh$1(luvio, context, config));
            luvio.storeIngestError(key, errorSnapshot);
            return luvio.storeBroadcast().then(() => errorSnapshot);
        });
    });
}
function coerceConfigWithDefaults(untrusted) {
    const config = validateAdapterConfig$6(untrusted, getRecordCreateDefaults_ConfigPropertyNames);
    if (config === null) {
        return null;
    }
    let formFactor = config.formFactor;
    if (formFactor === undefined) {
        if (untrusted.formFactor === undefined) {
            formFactor = FormFactor.Large;
        }
        else {
            return null;
        }
    }
    const recordTypeId = config.recordTypeId === undefined ? MAIN_RECORD_TYPE_ID : config.recordTypeId;
    const optionalFields = config.optionalFields === undefined ? [] : config.optionalFields;
    return {
        ...config,
        formFactor,
        recordTypeId,
        optionalFields,
    };
}
function buildSelectorKey(luvio, config) {
    const params = createResourceParams$7(config);
    const key = keyBuilder$7(luvio, params);
    return `${key}__selector`;
}
function buildCachedSnapshotCachePolicy$2(context, storeLookup) {
    const { luvio, config, cachedSelector, adapterContext } = context;
    return cachedSelector === undefined
        ? undefined
        : storeLookup(cachedSelector, buildSnapshotRefresh$1(luvio, adapterContext, config));
}
function buildNetworkSnapshotCachePolicy$2(context, coercedAdapterRequestContext) {
    const { config, adapterContext, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$7(luvio, adapterContext, config, dispatchOptions);
}
const factory$7 = (luvio) => {
    return luvio.withContext(function UiApi__getRecordCreateDefaults(untrusted, adapterContext, requestContext) {
        const config = coerceConfigWithDefaults(untrusted);
        if (config === null) {
            return null;
        }
        const selectorKey = buildSelectorKey(luvio, config);
        /**
         * getRecordCreateDefaults returns a value that includes a map of ObjectInfos,
         * a layout and a record. The returned record includes fields that are not
         * known to the client. Because we don't know what the return shape will be,
         * we have to store a selector from a previous response and see if we can
         * extract those values back out.
         *
         * store cached selector in the adapter context and if it does not exist
         * we need to fetch it from the network and set it.
         */
        const cachedSelector = adapterContext.get(selectorKey);
        return luvio.applyCachePolicy(requestContext || {}, {
            luvio,
            config,
            adapterContext,
            cachedSelector,
        }, buildCachedSnapshotCachePolicy$2, buildNetworkSnapshotCachePolicy$2);
    }, { contextId: contextId$2 });
};

const TTL$3 = 1000;
const VERSION$4 = "6a63c9ca6dda2e125d94e004f83240d8";
function validate$4(obj, path = 'RecordTemplateCloneRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_cloneSourceId = obj.cloneSourceId;
        const path_cloneSourceId = path + '.cloneSourceId';
        if (typeof obj_cloneSourceId !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_cloneSourceId + '" (at "' + path_cloneSourceId + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            if (typeof obj_fields_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
            }
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        let obj_recordTypeId_union0 = null;
        const obj_recordTypeId_union0_error = (() => {
            if (typeof obj_recordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union0_error != null) {
            obj_recordTypeId_union0 = obj_recordTypeId_union0_error.message;
        }
        let obj_recordTypeId_union1 = null;
        const obj_recordTypeId_union1_error = (() => {
            if (obj_recordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union1_error != null) {
            obj_recordTypeId_union1 = obj_recordTypeId_union1_error.message;
        }
        if (obj_recordTypeId_union0 && obj_recordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeId + '")';
            message += '\n' + obj_recordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$4 = 'RecordTemplateCloneRepresentation';
function keyBuilder$6(luvio, config) {
    return keyPrefix + '::' + RepresentationType$4 + ':' + config.cloneSourceId + ':' + (config.recordTypeId === null ? '' : config.recordTypeId);
}
function keyBuilderFromType$4(luvio, object) {
    const keyParams = {
        cloneSourceId: object.cloneSourceId,
        recordTypeId: object.recordTypeId
    };
    return keyBuilder$6(luvio, keyParams);
}
function dynamicNormalize$3(ingestParams) {
    return function normalize_dynamic(input, existing, path, luvio, store, timestamp) {
        const input_fields = input.fields;
        const input_fields_id = path.fullPath + '__fields';
        const input_fields_keys = Object.keys(input_fields);
        const input_fields_length = input_fields_keys.length;
        for (let i = 0; i < input_fields_length; i++) {
            const key = input_fields_keys[i];
            const input_fields_prop = input_fields[key];
            const input_fields_prop_id = input_fields_id + '__' + key;
            input_fields[key] = ingestParams.fields(input_fields_prop, {
                fullPath: input_fields_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        return input;
    };
}
const select$3 = function RecordTemplateCloneRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$4,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'cloneSourceId',
                kind: 'Scalar'
            },
            {
                name: 'fields',
                kind: 'Link',
                map: true,
                fragment: select$1X()
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            }
        ]
    };
};
const dynamicSelect$3 = function dynamicRecordTemplateCloneRepresentationSelect(params) {
    const fieldsPathSelection = params.fields === undefined ? {
        name: 'fields',
        kind: 'Link',
        map: true,
        fragment: select$1X()
    } : params.fields;
    return {
        kind: 'Fragment',
        version: VERSION$4,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'cloneSourceId',
                kind: 'Scalar'
            },
            fieldsPathSelection,
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$4(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_cloneSourceId = existing.cloneSourceId;
    const incoming_cloneSourceId = incoming.cloneSourceId;
    if (!(existing_cloneSourceId === incoming_cloneSourceId)) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_props = equalsObject(existing_fields, incoming_fields, (existing_fields_prop, incoming_fields_prop) => {
        if (!(existing_fields_prop.__ref === incoming_fields_prop.__ref)) {
            return false;
        }
    });
    if (equals_fields_props === false) {
        return false;
    }
    const existing_recordTypeId = existing.recordTypeId;
    const incoming_recordTypeId = incoming.recordTypeId;
    if (!(existing_recordTypeId === incoming_recordTypeId)) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$4(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$4(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$4,
        mergeable: false
    });
    const input_fields = input.fields;
    const input_fields_keys = ObjectKeys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$Y(rootKeySet, luvio, input_fields[key], () => rootKey + "__fields" + "__" + key);
    }
}
function dynamicIngest$3(ingestParams) {
    return function RecordTemplateCloneRepresentationIngest(input, path, luvio, store, timestamp) {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$4(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        const key = keyBuilderFromType$4(luvio, input);
        const ttlToUse = TTL$3;
        ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, dynamicNormalize$3(ingestParams), "UiApi", VERSION$4, RepresentationType$4, equals$4);
        return createLink(key);
    };
}

const TTL$2 = 1000;
const VERSION$3 = "b352a734f919895e97682703b486b649";
function validate$3(obj, path = 'RecordDefaultsTemplateCloneRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_objectInfos = obj.objectInfos;
        const path_objectInfos = path + '.objectInfos';
        if (typeof obj_objectInfos !== 'object' || ArrayIsArray(obj_objectInfos) || obj_objectInfos === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_objectInfos + '" (at "' + path_objectInfos + '")');
        }
        const obj_objectInfos_keys = ObjectKeys(obj_objectInfos);
        for (let i = 0; i < obj_objectInfos_keys.length; i++) {
            const key = obj_objectInfos_keys[i];
            const obj_objectInfos_prop = obj_objectInfos[key];
            const path_objectInfos_prop = path_objectInfos + '["' + key + '"]';
            if (typeof obj_objectInfos_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_objectInfos_prop + '" (at "' + path_objectInfos_prop + '")');
            }
        }
        const obj_record = obj.record;
        const path_record = path + '.record';
        if (typeof obj_record !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_record + '" (at "' + path_record + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$3 = 'RecordDefaultsTemplateCloneRepresentation';
function keyBuilder$5(luvio, config) {
    return keyPrefix + '::' + RepresentationType$3 + ':' + config.cloneSourceId + ':' + (config.recordTypeId === null ? '' : config.recordTypeId);
}
function keyBuilderFromType$3(luvio, object) {
    const keyParams = {
        cloneSourceId: object.record.cloneSourceId,
        recordTypeId: object.record.recordTypeId
    };
    return keyBuilder$5(luvio, keyParams);
}
function dynamicNormalize$2(ingestParams) {
    return function normalize_dynamic(input, existing, path, luvio, store, timestamp) {
        const input_objectInfos = input.objectInfos;
        const input_objectInfos_id = path.fullPath + '__objectInfos';
        const input_objectInfos_keys = Object.keys(input_objectInfos);
        const input_objectInfos_length = input_objectInfos_keys.length;
        for (let i = 0; i < input_objectInfos_length; i++) {
            const key = input_objectInfos_keys[i];
            const input_objectInfos_prop = input_objectInfos[key];
            const input_objectInfos_prop_id = input_objectInfos_id + '__' + key;
            input_objectInfos[key] = ingestParams.objectInfos(input_objectInfos_prop, {
                fullPath: input_objectInfos_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        const input_record = input.record;
        const input_record_id = path.fullPath + '__record';
        input.record = ingestParams.record(input_record, {
            fullPath: input_record_id,
            propertyName: 'record',
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
        return input;
    };
}
const dynamicSelect$2 = function dynamicRecordDefaultsTemplateCloneRepresentationSelect(params) {
    const objectInfosPathSelection = params.objectInfos === undefined ? {
        name: 'objectInfos',
        kind: 'Link',
        map: true,
        fragment: select$1N()
    } : params.objectInfos;
    const recordPathSelection = params.record === undefined ? {
        name: 'record',
        kind: 'Link',
        fragment: select$3()
    } : params.record;
    return {
        kind: 'Fragment',
        version: VERSION$3,
        private: [],
        selections: [
            objectInfosPathSelection,
            recordPathSelection
        ]
    };
};
function equals$3(existing, incoming) {
    const existing_objectInfos = existing.objectInfos;
    const incoming_objectInfos = incoming.objectInfos;
    const equals_objectInfos_props = equalsObject(existing_objectInfos, incoming_objectInfos, (existing_objectInfos_prop, incoming_objectInfos_prop) => {
        if (!(existing_objectInfos_prop.__ref === incoming_objectInfos_prop.__ref)) {
            return false;
        }
    });
    if (equals_objectInfos_props === false) {
        return false;
    }
    const existing_record = existing.record;
    const incoming_record = incoming.record;
    if (!(existing_record.__ref === incoming_record.__ref)) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$3(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$3(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$3,
        mergeable: false
    });
    const input_objectInfos = input.objectInfos;
    const input_objectInfos_keys = ObjectKeys(input_objectInfos);
    const input_objectInfos_length = input_objectInfos_keys.length;
    for (let i = 0; i < input_objectInfos_length; i++) {
        const key = input_objectInfos_keys[i];
        getTypeCacheKeys$O(rootKeySet, luvio, input_objectInfos[key]);
    }
    getTypeCacheKeys$4(rootKeySet, luvio, input.record);
}
function dynamicIngest$2(ingestParams) {
    return function RecordDefaultsTemplateCloneRepresentationIngest(input, path, luvio, store, timestamp) {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$3(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        const key = keyBuilderFromType$3(luvio, input);
        const ttlToUse = TTL$2;
        ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, dynamicNormalize$2(ingestParams), "UiApi", VERSION$3, RepresentationType$3, equals$3);
        return createLink(key);
    };
}

function createFieldsIngest$3(params) {
    const { fields, optionalFields, trackedFields, recordConflictMap } = params;
    const ingest = dynamicIngest$3({
        fields: createFieldsIngestion(fields, optionalFields, recordConflictMap)
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$5(fields) {
    return dynamicSelect$3({
        fields: createPathSelection('fields', fields)
    });
}

function createFieldsIngest$2(params) {
    const { fields, optionalFields, trackedFields, recordConflictMap } = params;
    const ingest = dynamicIngest$2({
        objectInfos: ingest$H,
        record: createFieldsIngest$3(params)
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$4(fields) {
    return dynamicSelect$2({
        record: {
            kind: 'Link',
            name: 'record',
            fragment: selectFields$5(fields),
        }
    });
}

function createFieldsIngestSuccess$1(params) {
    const { trackedFields } = params;
    const recordConflictMap = {
        conflicts: {},
        serverRequestCount: 1,
    };
    const ingest = createFieldsIngest$2({
        ...params,
        recordConflictMap,
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        resolveConflict(luvio, recordConflictMap);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$3(luvio, params) {
    const optionalFields = params.queryParams.optionalFields || [];
    const fields = [];
    const trie = convertRecordFieldsArrayToTrie(fields, optionalFields);
    return selectFields$4(trie);
}

const select$2 = (luvio, params) => {
    let { optionalFields } = params.queryParams;
    const entry = luvio.getNode(keyBuilder$6(luvio, {
        cloneSourceId: params.urlParams.recordId,
        recordTypeId: params.queryParams.recordTypeId || null,
    }));
    // If we have data in the cache, we know the only fields that are relevant start with that record's objectApiName
    if (entry?.data) {
        const apiName = entry.data.apiName;
        if (optionalFields !== undefined) {
            optionalFields = optionalFields.filter((field) => field.startsWith(`${apiName}.`));
        }
    }
    optionalFields =
        optionalFields === undefined ? ['.CloneSourceId'] : [...optionalFields, '.CloneSourceId'];
    return selectFields$3(luvio, {
        ...params,
        queryParams: {
            ...params.queryParams,
            optionalFields,
        },
    });
};

function getResponseCacheKeys$5(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$3(storeKeyMap, luvio, response);
}
function createResourceRequest$7(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/record-defaults/template/clone/' + config.urlParams.recordId + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName$3 = 'getRecordTemplateClone';
const getRecordTemplateClone_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getRecordTemplateClone_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$3, getRecordTemplateClone_ConfigPropertyMetadata);
const createResourceParams$6 = /*#__PURE__*/ createResourceParams$13(getRecordTemplateClone_ConfigPropertyMetadata);
function typeCheckConfig$7(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordTemplateClone_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$5(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordTemplateClone_ConfigPropertyMetadata);
    const config = typeCheckConfig$7(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const contextId$1 = `${keyPrefix}__${adapterName$3}`;
const DEFAULT_RECORD_TYPE_ID_KEY = 'defaultRecordTypeId';
const RECORD_TEMPLATE_CLONE_ERROR_VERSION = 'RECORD_TEMPLATE_CLONE_ERROR_VERSION_1';
const RECORD_TEMPLATE_CLONE_ERROR_STORE_METADATA_PARAMS = {
    ttl: TTL$2,
    representationName: '',
    namespace: keyPrefix,
    version: RECORD_TEMPLATE_CLONE_ERROR_VERSION,
};
function saveDefaultRecordTypeId(context, objectInfo) {
    context.set(DEFAULT_RECORD_TYPE_ID_KEY, objectInfo.defaultRecordTypeId);
}
function getRecordTypeId$1(adapterConfig, context) {
    const { recordTypeId } = adapterConfig;
    if (recordTypeId !== undefined && recordTypeId !== null) {
        return recordTypeId;
    }
    const contextValue = context.get(DEFAULT_RECORD_TYPE_ID_KEY);
    if (contextValue === null || contextValue === undefined) {
        return undefined;
    }
    return contextValue;
}
const buildNetworkSnapshot$6 = (luvio, context, config, options) => {
    const resourceParams = createResourceParams$6(config);
    const recordTypeId = getRecordTypeId$1(config, context);
    const { recordId } = config;
    const resourceRequest = createResourceRequest$7(resourceParams);
    const coercedRecordTypeId = recordTypeId === undefined ? null : recordTypeId;
    const templateRecordKey = keyBuilder$6(luvio, {
        cloneSourceId: recordId,
        recordTypeId: coercedRecordTypeId,
    });
    const request = recordTypeId === undefined
        ? resourceRequest
        : createResourceRequest$7({
            ...resourceParams,
            queryParams: {
                ...resourceRequest.queryParams,
                optionalFields: getTrackedFields(templateRecordKey, luvio.getNode(templateRecordKey), {
                    maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMiss(),
                    onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
                }, config.optionalFields),
            },
        });
    return luvio
        .dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const { body } = response;
            const key = keyBuilderFromType$3(luvio, body);
            const responseRecordTypeId = body.record.recordTypeId;
            const objectApiName = body.record.apiName;
            // publish metadata for recordTypeId
            saveDefaultRecordTypeId(context, body.objectInfos[objectApiName]);
            const optionalFieldsTrie = convertFieldsToTrie(resourceParams.queryParams.optionalFields, true, objectApiName);
            luvio.storeIngest(key, createFieldsIngestSuccess$1({
                fields: BLANK_RECORD_FIELDS_TRIE,
                optionalFields: optionalFieldsTrie,
                trackedFields: optionalFieldsTrie,
                serverRequestCount: 1,
            }), body);
            const snapshot = buildCachedSnapshot$1(luvio, context, {
                ...config,
                recordTypeId: responseRecordTypeId,
            });
            if (process.env.NODE_ENV !== 'production') {
                if (snapshot.state !== 'Fulfilled') {
                    throw new Error('Invalid network response. Expected network response to result in Fulfilled snapshot');
                }
            }
            return luvio.storeBroadcast().then(() => {
                return snapshot;
            });
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$5(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => {
            const key = keyBuilder$5(luvio, {
                cloneSourceId: config.recordId,
                recordTypeId: config.recordTypeId || null,
            });
            const errorSnapshot = luvio.errorSnapshot(response, {
                config,
                resolve: () => buildNetworkSnapshot$6(luvio, context, config, snapshotRefreshOptions),
            });
            luvio.storeIngestError(key, errorSnapshot, RECORD_TEMPLATE_CLONE_ERROR_STORE_METADATA_PARAMS);
            return Promise.resolve(errorSnapshot);
        });
    });
};
const buildCachedSnapshot$1 = (luvio, context, config) => {
    const resourceParams = createResourceParams$6(config);
    const key = keyBuilder$5(luvio, {
        cloneSourceId: config.recordId,
        recordTypeId: config.recordTypeId || null,
    });
    const selector = {
        recordId: key,
        node: select$2(luvio, resourceParams),
        variables: {},
    };
    return luvio.storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$6(luvio, context, config, snapshotRefreshOptions),
    });
};
function buildNetworkSnapshotCachePolicy$1(context, coercedAdapterRequestContext) {
    const { config, adapterContext, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$6(luvio, adapterContext, config, dispatchOptions);
}
function buildCachedSnapshotCachePolicy$1(context, storeLookup) {
    const { adapterContext, config, luvio, recordTypeId } = context;
    const updatedConfig = {
        ...config,
        recordTypeId,
    };
    const resourceParams = createResourceParams$6(updatedConfig);
    const key = keyBuilder$5(luvio, {
        cloneSourceId: updatedConfig.recordId,
        recordTypeId: updatedConfig.recordTypeId || null,
    });
    const selector = {
        recordId: key,
        node: select$2(luvio, resourceParams),
        variables: {},
    };
    return storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot$6(luvio, adapterContext, updatedConfig, snapshotRefreshOptions),
    });
}
const factory$6 = (luvio) => luvio.withContext(function getRecordTemplateClone_ContextWrapper(untrustedConfig, adapterContext, requestContext) {
    const config = validateAdapterConfig$5(untrustedConfig, getRecordTemplateClone_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    const recordTypeId = getRecordTypeId$1(config, adapterContext);
    return luvio.applyCachePolicy(requestContext || {}, {
        luvio,
        config,
        recordTypeId,
        adapterContext,
    }, buildCachedSnapshotCachePolicy$1, buildNetworkSnapshotCachePolicy$1);
}, { contextId: contextId$1 });

const TTL$1 = 30000;
const VERSION$2 = "665de0fdde39efd6f1098e374117ef58";
function validate$2(obj, path = 'RecordTemplateCreateRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_apiName = obj.apiName;
        const path_apiName = path + '.apiName';
        if (typeof obj_apiName !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_apiName + '" (at "' + path_apiName + '")');
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (typeof obj_fields !== 'object' || ArrayIsArray(obj_fields) || obj_fields === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        const obj_fields_keys = ObjectKeys(obj_fields);
        for (let i = 0; i < obj_fields_keys.length; i++) {
            const key = obj_fields_keys[i];
            const obj_fields_prop = obj_fields[key];
            const path_fields_prop = path_fields + '["' + key + '"]';
            if (typeof obj_fields_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_fields_prop + '" (at "' + path_fields_prop + '")');
            }
        }
        const obj_recordTypeId = obj.recordTypeId;
        const path_recordTypeId = path + '.recordTypeId';
        let obj_recordTypeId_union0 = null;
        const obj_recordTypeId_union0_error = (() => {
            if (typeof obj_recordTypeId !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union0_error != null) {
            obj_recordTypeId_union0 = obj_recordTypeId_union0_error.message;
        }
        let obj_recordTypeId_union1 = null;
        const obj_recordTypeId_union1_error = (() => {
            if (obj_recordTypeId !== null) {
                return new TypeError('Expected "null" but received "' + typeof obj_recordTypeId + '" (at "' + path_recordTypeId + '")');
            }
        })();
        if (obj_recordTypeId_union1_error != null) {
            obj_recordTypeId_union1 = obj_recordTypeId_union1_error.message;
        }
        if (obj_recordTypeId_union0 && obj_recordTypeId_union1) {
            let message = 'Object doesn\'t match union (at "' + path_recordTypeId + '")';
            message += '\n' + obj_recordTypeId_union0.split('\n').map((line) => '\t' + line).join('\n');
            message += '\n' + obj_recordTypeId_union1.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$2 = 'RecordTemplateCreateRepresentation';
function keyBuilder$4(luvio, config) {
    return keyPrefix + '::' + RepresentationType$2 + ':' + config.apiName + ':' + (config.recordTypeId === null ? '' : config.recordTypeId);
}
function keyBuilderFromType$2(luvio, object) {
    const keyParams = {
        apiName: object.apiName,
        recordTypeId: object.recordTypeId
    };
    return keyBuilder$4(luvio, keyParams);
}
function dynamicNormalize$1(ingestParams) {
    return function normalize_dynamic(input, existing, path, luvio, store, timestamp) {
        const input_fields = input.fields;
        const input_fields_id = path.fullPath + '__fields';
        const input_fields_keys = Object.keys(input_fields);
        const input_fields_length = input_fields_keys.length;
        for (let i = 0; i < input_fields_length; i++) {
            const key = input_fields_keys[i];
            const input_fields_prop = input_fields[key];
            const input_fields_prop_id = input_fields_id + '__' + key;
            input_fields[key] = ingestParams.fields(input_fields_prop, {
                fullPath: input_fields_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        return input;
    };
}
const select$1 = function RecordTemplateCreateRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION$2,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            {
                name: 'fields',
                kind: 'Link',
                map: true,
                fragment: select$1X()
            },
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            }
        ]
    };
};
const dynamicSelect$1 = function dynamicRecordTemplateCreateRepresentationSelect(params) {
    const fieldsPathSelection = params.fields === undefined ? {
        name: 'fields',
        kind: 'Link',
        map: true,
        fragment: select$1X()
    } : params.fields;
    return {
        kind: 'Fragment',
        version: VERSION$2,
        private: [],
        selections: [
            {
                name: 'apiName',
                kind: 'Scalar'
            },
            fieldsPathSelection,
            {
                name: 'recordTypeId',
                kind: 'Scalar'
            }
        ]
    };
};
function equals$2(existing, incoming) {
    const existing_apiName = existing.apiName;
    const incoming_apiName = incoming.apiName;
    if (!(existing_apiName === incoming_apiName)) {
        return false;
    }
    const existing_fields = existing.fields;
    const incoming_fields = incoming.fields;
    const equals_fields_props = equalsObject(existing_fields, incoming_fields, (existing_fields_prop, incoming_fields_prop) => {
        if (!(existing_fields_prop.__ref === incoming_fields_prop.__ref)) {
            return false;
        }
    });
    if (equals_fields_props === false) {
        return false;
    }
    const existing_recordTypeId = existing.recordTypeId;
    const incoming_recordTypeId = incoming.recordTypeId;
    if (!(existing_recordTypeId === incoming_recordTypeId)) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$2(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$2(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$2,
        mergeable: false
    });
    const input_fields = input.fields;
    const input_fields_keys = ObjectKeys(input_fields);
    const input_fields_length = input_fields_keys.length;
    for (let i = 0; i < input_fields_length; i++) {
        const key = input_fields_keys[i];
        getTypeCacheKeys$Y(rootKeySet, luvio, input_fields[key], () => rootKey + "__fields" + "__" + key);
    }
}
function dynamicIngest$1(ingestParams) {
    return function RecordTemplateCreateRepresentationIngest(input, path, luvio, store, timestamp) {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$2(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        const key = keyBuilderFromType$2(luvio, input);
        const ttlToUse = TTL$1;
        ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, dynamicNormalize$1(ingestParams), "UiApi", VERSION$2, RepresentationType$2, equals$2);
        return createLink(key);
    };
}

const TTL = 900000;
const VERSION$1 = "30493e7ac0677e35242026bb959c079e";
function validate$1(obj, path = 'RecordDefaultsTemplateCreateRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_objectInfos = obj.objectInfos;
        const path_objectInfos = path + '.objectInfos';
        if (typeof obj_objectInfos !== 'object' || ArrayIsArray(obj_objectInfos) || obj_objectInfos === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_objectInfos + '" (at "' + path_objectInfos + '")');
        }
        const obj_objectInfos_keys = ObjectKeys(obj_objectInfos);
        for (let i = 0; i < obj_objectInfos_keys.length; i++) {
            const key = obj_objectInfos_keys[i];
            const obj_objectInfos_prop = obj_objectInfos[key];
            const path_objectInfos_prop = path_objectInfos + '["' + key + '"]';
            if (typeof obj_objectInfos_prop !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_objectInfos_prop + '" (at "' + path_objectInfos_prop + '")');
            }
        }
        const obj_record = obj.record;
        const path_record = path + '.record';
        if (typeof obj_record !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_record + '" (at "' + path_record + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType$1 = 'RecordDefaultsTemplateCreateRepresentation';
function keyBuilder$3(luvio, config) {
    return keyPrefix + '::' + RepresentationType$1 + ':' + config.objectApiName + ':' + (config.recordTypeId === null ? '' : config.recordTypeId);
}
function keyBuilderFromType$1(luvio, object) {
    const keyParams = {
        objectApiName: object.record.apiName,
        recordTypeId: object.record.recordTypeId
    };
    return keyBuilder$3(luvio, keyParams);
}
function dynamicNormalize(ingestParams) {
    return function normalize_dynamic(input, existing, path, luvio, store, timestamp) {
        const input_objectInfos = input.objectInfos;
        const input_objectInfos_id = path.fullPath + '__objectInfos';
        const input_objectInfos_keys = Object.keys(input_objectInfos);
        const input_objectInfos_length = input_objectInfos_keys.length;
        for (let i = 0; i < input_objectInfos_length; i++) {
            const key = input_objectInfos_keys[i];
            const input_objectInfos_prop = input_objectInfos[key];
            const input_objectInfos_prop_id = input_objectInfos_id + '__' + key;
            input_objectInfos[key] = ingestParams.objectInfos(input_objectInfos_prop, {
                fullPath: input_objectInfos_prop_id,
                propertyName: key,
                parent: {
                    data: input,
                    key: path.fullPath,
                    existing: existing,
                },
                ttl: path.ttl
            }, luvio, store, timestamp);
        }
        const input_record = input.record;
        const input_record_id = path.fullPath + '__record';
        input.record = ingestParams.record(input_record, {
            fullPath: input_record_id,
            propertyName: 'record',
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
        return input;
    };
}
const dynamicSelect = function dynamicRecordDefaultsTemplateCreateRepresentationSelect(params) {
    const objectInfosPathSelection = params.objectInfos === undefined ? {
        name: 'objectInfos',
        kind: 'Link',
        map: true,
        fragment: select$1N()
    } : params.objectInfos;
    const recordPathSelection = params.record === undefined ? {
        name: 'record',
        kind: 'Link',
        fragment: select$1()
    } : params.record;
    return {
        kind: 'Fragment',
        version: VERSION$1,
        private: [],
        selections: [
            objectInfosPathSelection,
            recordPathSelection
        ]
    };
};
function equals$1(existing, incoming) {
    const existing_objectInfos = existing.objectInfos;
    const incoming_objectInfos = incoming.objectInfos;
    const equals_objectInfos_props = equalsObject(existing_objectInfos, incoming_objectInfos, (existing_objectInfos_prop, incoming_objectInfos_prop) => {
        if (!(existing_objectInfos_prop.__ref === incoming_objectInfos_prop.__ref)) {
            return false;
        }
    });
    if (equals_objectInfos_props === false) {
        return false;
    }
    const existing_record = existing.record;
    const incoming_record = incoming.record;
    if (!(existing_record.__ref === incoming_record.__ref)) {
        return false;
    }
    return true;
}
function getTypeCacheKeys$1(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType$1(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType$1,
        mergeable: false
    });
    const input_objectInfos = input.objectInfos;
    const input_objectInfos_keys = ObjectKeys(input_objectInfos);
    const input_objectInfos_length = input_objectInfos_keys.length;
    for (let i = 0; i < input_objectInfos_length; i++) {
        const key = input_objectInfos_keys[i];
        getTypeCacheKeys$O(rootKeySet, luvio, input_objectInfos[key]);
    }
    getTypeCacheKeys$2(rootKeySet, luvio, input.record);
}
function dynamicIngest(ingestParams) {
    return function RecordDefaultsTemplateCreateRepresentationIngest(input, path, luvio, store, timestamp) {
        if (process.env.NODE_ENV !== 'production') {
            const validateError = validate$1(input);
            if (validateError !== null) {
                throw validateError;
            }
        }
        const key = keyBuilderFromType$1(luvio, input);
        const ttlToUse = TTL;
        ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, dynamicNormalize(ingestParams), "UiApi", VERSION$1, RepresentationType$1, equals$1);
        return createLink(key);
    };
}

function createFieldsIngest$1(params) {
    const { fields, optionalFields, trackedFields, recordConflictMap } = params;
    const ingest = dynamicIngest$1({
        fields: createFieldsIngestion(fields, optionalFields, recordConflictMap)
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$2(fields) {
    return dynamicSelect$1({
        fields: createPathSelection('fields', fields)
    });
}

function createFieldsIngest(params) {
    const { fields, optionalFields, trackedFields, recordConflictMap } = params;
    const ingest = dynamicIngest({
        objectInfos: ingest$H,
        record: createFieldsIngest$1(params)
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields$1(fields) {
    return dynamicSelect({
        record: {
            kind: 'Link',
            name: 'record',
            fragment: selectFields$2(fields),
        }
    });
}

function createFieldsIngestSuccess(params) {
    const { trackedFields } = params;
    const recordConflictMap = {
        conflicts: {},
        serverRequestCount: 1,
    };
    const ingest = createFieldsIngest({
        ...params,
        recordConflictMap,
    });
    return (data, path, luvio, store, timestamp) => {
        const link = ingest(data, path, luvio, store, timestamp);
        resolveConflict(luvio, recordConflictMap);
        const recordNode = luvio.getNode(link.__ref);
        markMissingOptionalFields(recordNode, convertTrieToFields(trackedFields));
        return link;
    };
}
function selectFields(luvio, params) {
    const optionalFields = params.queryParams.optionalFields || [];
    const fields = [];
    const trie = convertRecordFieldsArrayToTrie(fields, optionalFields);
    return selectFields$1(trie);
}

function keyBuilder$2(luvio, params) {
    return keyBuilder$3(luvio, {
        objectApiName: params.urlParams.objectApiName,
        recordTypeId: params.queryParams.recordTypeId || null
    });
}
function getResponseCacheKeys$4(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$1(storeKeyMap, luvio, response);
}
function ingestError(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$2(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    const storeMetadataParams = {
        ttl: TTL,
        namespace: keyPrefix,
        version: VERSION$1,
        representationName: RepresentationType$1
    };
    luvio.storeIngestError(key, errorSnapshot, storeMetadataParams);
    return errorSnapshot;
}
function createResourceRequest$6(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/record-defaults/template/create/' + config.urlParams.objectApiName + '',
        method: 'get',
        body: null,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

function adapterFragment(luvio, config) {
    const resourceParams = createResourceParams$5(config);
    return selectFields(luvio, resourceParams);
}

const adapterName$2 = 'getRecordTemplateCreate';
const getRecordTemplateCreate_ConfigPropertyMetadata = [
    generateParamConfigMetadata('objectApiName', true, 0 /* UrlParameter */, 0 /* String */, false, getObjectApiName$1),
    generateParamConfigMetadata('optionalFields', false, 1 /* QueryParameter */, 0 /* String */, true, getFieldApiNamesArray),
    generateParamConfigMetadata('recordTypeId', false, 1 /* QueryParameter */, 0 /* String */),
];
const getRecordTemplateCreate_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$2, getRecordTemplateCreate_ConfigPropertyMetadata);
const createResourceParams$5 = /*#__PURE__*/ createResourceParams$13(getRecordTemplateCreate_ConfigPropertyMetadata);
function typeCheckConfig$6(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, getRecordTemplateCreate_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$4(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, getRecordTemplateCreate_ConfigPropertyMetadata);
    const config = typeCheckConfig$6(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const contextId = `${keyPrefix}__${adapterName$2}`;
function buildSnapshotRefresh(luvio, context, config) {
    return {
        config,
        resolve: () => buildNetworkSnapshot$5(luvio, context, config, snapshotRefreshOptions),
    };
}
function buildRecordTypeIdContextKey(objectApiName) {
    return `DEFAULTS::recordTypeId:${objectApiName}`;
}
function getRecordTypeId(context, adapterConfig) {
    const config = createResourceParams$5(adapterConfig);
    const { recordTypeId } = config.queryParams;
    if (recordTypeId !== undefined && recordTypeId !== null) {
        return recordTypeId;
    }
    const saved = context.get(buildRecordTypeIdContextKey(config.urlParams.objectApiName));
    if (saved === null || saved === undefined) {
        return undefined;
    }
    return saved;
}
function prepareRequest(luvio, context, config) {
    const resourceParams = createResourceParams$5(config);
    const recordTypeId = getRecordTypeId(context, config);
    const { objectApiName } = config;
    const resourceRequest = createResourceRequest$6(resourceParams);
    if (recordTypeId === undefined) {
        return resourceRequest;
    }
    const recordTemplateKey = keyBuilder$4(luvio, {
        apiName: objectApiName,
        recordTypeId: recordTypeId,
    });
    return createResourceRequest$6({
        ...resourceParams,
        queryParams: {
            ...resourceRequest.queryParams,
            optionalFields: getTrackedFields(recordTemplateKey, luvio.getNode(recordTemplateKey), {
                maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMiss(),
                onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
            }, config.optionalFields),
        },
    });
}
function onFetchResponseSuccess(luvio, context, config, request, response, resourceParams) {
    const { urlParams: { objectApiName }, queryParams: { optionalFields }, } = resourceParams;
    const { body } = response;
    const key = keyBuilderFromType$1(luvio, body);
    const responseRecordTypeId = body.record.recordTypeId;
    // publish metadata for recordTypeId
    const recordTypeId = body.objectInfos[objectApiName].defaultRecordTypeId;
    context.set(buildRecordTypeIdContextKey(objectApiName), recordTypeId);
    // mark missing optionalFields
    const templateRecordKey = keyBuilder$4(luvio, {
        apiName: objectApiName,
        recordTypeId: responseRecordTypeId,
    });
    const allTrackedFields = getTrackedFields(templateRecordKey, luvio.getNode(templateRecordKey), {
        maxDepth: configurationForRestAdapters.getTrackedFieldDepthOnCacheMiss(),
        onlyFetchLeafNodeIdAndName: configurationForRestAdapters.getTrackedFieldLeafNodeIdAndNameOnly(),
    }, optionalFields);
    const allTrackedFieldsTrie = convertFieldsToTrie(allTrackedFields, true);
    const ingest = createFieldsIngestSuccess({
        fields: BLANK_RECORD_FIELDS_TRIE,
        optionalFields: allTrackedFieldsTrie,
        trackedFields: allTrackedFieldsTrie,
        serverRequestCount: 1,
    });
    luvio.storeIngest(key, ingest, body);
    const snapshot = buildCachedSnapshot(luvio, context, {
        ...config,
        recordTypeId: responseRecordTypeId,
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected network response to result in Fulfilled snapshot');
        }
    }
    return luvio
        .storeBroadcast()
        .then(() => snapshot);
}
function onFetchResponseError(luvio, context, config, resourceParams, error) {
    const snapshot = ingestError(luvio, resourceParams, error, buildSnapshotRefresh(luvio, context, config));
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$5(luvio, context, config, options) {
    const resourceParams = createResourceParams$5(config);
    const request = prepareRequest(luvio, context, config);
    return luvio
        .dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            return onFetchResponseSuccess(luvio, context, config, request, response, resourceParams);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$4(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => {
            return onFetchResponseError(luvio, context, config, resourceParams, response);
        });
    });
}
function buildCachedSnapshot(luvio, context, config) {
    const resourceParams = createResourceParams$5(config);
    const selector = {
        recordId: keyBuilder$2(luvio, resourceParams),
        node: adapterFragment(luvio, config),
        variables: {},
    };
    return luvio.storeLookup(selector, buildSnapshotRefresh(luvio, context, config));
}
const buildNetworkSnapshotCachePolicy = (context, coercedAdapterRequestContext) => {
    const { config, adapterContext, luvio } = context;
    const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
    const dispatchOptions = {
        resourceRequestContext: {
            requestCorrelator,
            sourceContext,
        },
        eventObservers,
    };
    if (networkPriority !== 'normal') {
        dispatchOptions.overrides = {
            priority: networkPriority,
        };
    }
    return buildNetworkSnapshot$5(luvio, adapterContext, config, dispatchOptions);
};
const buildCachedSnapshotCachePolicy = (context, storeLookup) => {
    const { adapterContext, config, luvio, recordTypeId } = context;
    const updatedConfig = {
        ...config,
        recordTypeId,
    };
    const resourceParams = createResourceParams$5(updatedConfig);
    const selector = {
        recordId: keyBuilder$2(luvio, resourceParams),
        node: adapterFragment(luvio, config),
        variables: {},
    };
    return storeLookup(selector, buildSnapshotRefresh(luvio, adapterContext, config));
};
const factory$5 = (luvio) => {
    return luvio.withContext(function UiApi__getRecordDefaultsTemplateForCreate(untrustedConfig, adapterContext, requestContext) {
        const config = validateAdapterConfig$4(untrustedConfig, getRecordTemplateCreate_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            return null;
        }
        const recordTypeId = getRecordTypeId(adapterContext, config);
        return luvio.applyCachePolicy(requestContext || {}, {
            luvio,
            config,
            recordTypeId,
            adapterContext,
        }, buildCachedSnapshotCachePolicy, buildNetworkSnapshotCachePolicy);
    }, { contextId });
};

function getResponseCacheKeys$3(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$X(storeKeyMap, luvio, response);
}
function createResourceRequest$5(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const createRecord_ConfigPropertyMetadata = [
    generateParamConfigMetadata('handleOwnerChange', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('includeFieldsInBody', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('triggerOtherEmail', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('triggerUserEmail', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('useDefaultRule', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('allowSaveOnDuplicate', false, 2 /* Body */, 1 /* Boolean */),
    generateParamConfigMetadata('apiName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('fields', true, 2 /* Body */, 4 /* Unsupported */),
];
const createResourceParams$4 = /*#__PURE__*/ createResourceParams$13(createRecord_ConfigPropertyMetadata);

function onResponseSuccess(luvio, response, recordIngest, conflictMap) {
    const { body, status } = response;
    if (status === HttpStatusCode.NoContent) {
        const syntheticSnapshot = {
            state: 'Fulfilled',
            data: {},
        };
        return luvio.storeBroadcast().then(() => syntheticSnapshot);
    }
    const selections = buildSelectionFromRecord(body);
    const key = keyBuilder$29(luvio, {
        recordId: body.id,
    });
    luvio.storeIngest(key, recordIngest, body);
    resolveConflict(luvio, conflictMap);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: {
            kind: 'Fragment',
            private: [],
            selections,
            version: VERSION$1g,
        },
        variables: {},
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot$4(luvio, config) {
    const resourceParams = createResourceParams$4(config);
    const request = createResourceRequest$5(resourceParams);
    const fieldTrie = BLANK_RECORD_FIELDS_TRIE;
    const optionalFieldTrie = BLANK_RECORD_FIELDS_TRIE;
    const conflictMap = {
        conflicts: {},
        serverRequestCount: 1,
    };
    const recordIngest = createRecordIngest(fieldTrie, optionalFieldTrie, conflictMap);
    return luvio.dispatchResourceRequest(request).then((response) => {
        return luvio.handleSuccessResponse(() => onResponseSuccess(luvio, response, recordIngest, conflictMap), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$3(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (err) => {
        deepFreeze(err);
        throw err;
    });
}
function createResourceRequest$4(config) {
    const resourceParams = createResourceParams$4(config);
    return createResourceRequest$5(resourceParams);
}
const factory$4 = (luvio) => {
    return function (untrustedConfig) {
        const config = untrustedConfig;
        const draftAdapter = configurationForRestAdapters.getDraftAwareCreateRecordAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, createResourceRequest$4);
        }
        return buildNetworkSnapshot$4(luvio, config);
    };
};

function keyBuilder$1(luvio, params) {
    return keyBuilder$29(luvio, {
        recordId: params.urlParams.recordId
    });
}
function getResponseCacheKeys$2(cacheKeyMap, luvio, resourceParams) {
    const key = keyBuilder$1(luvio, resourceParams);
    cacheKeyMap.set(key, {
        namespace: keyPrefix,
        representationName: RepresentationType$V,
        mergeable: false
    });
}
function evictSuccess(luvio, resourceParams) {
    const key = keyBuilder$1(luvio, resourceParams);
    luvio.storeEvict(key);
}
function createResourceRequest$3(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/' + config.urlParams.recordId + '',
        method: 'delete',
        body: null,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName$1 = 'deleteRecord';
const deleteRecord_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
];
const deleteRecord_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName$1, deleteRecord_ConfigPropertyMetadata);
const createResourceParams$3 = /*#__PURE__*/ createResourceParams$13(deleteRecord_ConfigPropertyMetadata);
function typeCheckConfig$5(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, deleteRecord_ConfigPropertyMetadata);
    return config;
}
function validateAdapterConfig$3(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, deleteRecord_ConfigPropertyMetadata);
    const config = typeCheckConfig$5(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function buildNetworkSnapshot$3(luvio, config, options) {
    const resourceParams = createResourceParams$3(config);
    const request = createResourceRequest$3(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then(() => {
        return luvio.handleSuccessResponse(() => {
            evictSuccess(luvio, resourceParams);
            return luvio.storeBroadcast();
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$2(cache, luvio, resourceParams);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}
const deleteRecordAdapterFactory = (luvio) => {
    return function UiApideleteRecord(untrustedConfig) {
        const config = validateAdapterConfig$3(untrustedConfig, deleteRecord_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            throw new Error(`Invalid config for "${adapterName$1}"`);
        }
        return buildNetworkSnapshot$3(luvio, config);
    };
};

const factory$3 = (luvio) => {
    const deleteRecordAdapterInstance = deleteRecordAdapterFactory(luvio);
    return (recordId) => {
        const config = { recordId };
        const draftAdapter = configurationForRestAdapters.getDraftAwareDeleteRecordAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, (config) => {
                const params = createResourceParams$3(config);
                return createResourceRequest$3(params);
            });
        }
        return deleteRecordAdapterInstance(config);
    };
};

function getResponseCacheKeys$1(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys$X(storeKeyMap, luvio, response);
}
function createResourceRequest$2(config) {
    const headers = {};
    const header_ifUnmodifiedSince = config.headers.ifUnmodifiedSince;
    if (header_ifUnmodifiedSince !== undefined) {
        headers['If-Unmodified-Since'] = header_ifUnmodifiedSince;
    }
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/' + config.urlParams.recordId + '',
        method: 'patch',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: config.queryParams,
        headers,
        priority: 'normal',
    };
}

const adapterName = 'updateRecord';
const updateRecord_ConfigPropertyMetadata = [
    generateParamConfigMetadata('recordId', true, 0 /* UrlParameter */, 0 /* String */, false, getRecordId18),
    generateParamConfigMetadata('handleOwnerChange', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('triggerOtherEmail', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('triggerUserEmail', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('useDefaultRule', false, 1 /* QueryParameter */, 1 /* Boolean */),
    generateParamConfigMetadata('allowSaveOnDuplicate', false, 2 /* Body */, 1 /* Boolean */),
    generateParamConfigMetadata('apiName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('fields', true, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('ifUnmodifiedSince', false, 3 /* Header */, 0 /* String */),
];
const updateRecord_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName, updateRecord_ConfigPropertyMetadata);
const createResourceParams$2 = /*#__PURE__*/ createResourceParams$13(updateRecord_ConfigPropertyMetadata);
function typeCheckConfig$4(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, updateRecord_ConfigPropertyMetadata);
    const untrustedConfig_fields = untrustedConfig.fields;
    if (untrustedIsObject(untrustedConfig_fields)) {
        const untrustedConfig_fields_object = {};
        const untrustedConfig_fields_keys = Object.keys(untrustedConfig_fields);
        for (let i = 0, arrayLength = untrustedConfig_fields_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_fields_keys[i];
            const untrustedConfig_fields_prop = untrustedConfig_fields[key];
            if (typeof untrustedConfig_fields_prop === 'string') {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
            if (typeof untrustedConfig_fields_prop === 'number') {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
            if (untrustedConfig_fields_prop === null) {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
            if (typeof untrustedConfig_fields_prop === 'boolean') {
                if (untrustedConfig_fields_object !== undefined) {
                    untrustedConfig_fields_object[key] = untrustedConfig_fields_prop;
                }
            }
        }
        if (untrustedConfig_fields_object !== undefined && Object.keys(untrustedConfig_fields_object).length >= 0) {
            config.fields = untrustedConfig_fields_object;
        }
    }
    return config;
}
function validateAdapterConfig$2(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const coercedConfig = coerceConfig$1(untrustedConfig, updateRecord_ConfigPropertyMetadata);
    const config = typeCheckConfig$4(coercedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const ISO8601_DATE_REGEX = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d+Z$/;
function getHeaders(clientOptions) {
    const headers = {};
    if (untrustedIsObject(clientOptions)) {
        if (typeof clientOptions.ifUnmodifiedSince === 'string') {
            headers.ifUnmodifiedSince = clientOptions.ifUnmodifiedSince;
            // HTTP standard format date is expected by UI-API
            // https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/If-Unmodified-Since
            // A component built for Connect API must use If-Unmodified-Since
            // dates formatted as ISO 8601, which does not match the HTTP spec.
            // For compatibility, convert the date to match the standard.
            if (headers.ifUnmodifiedSince.match(ISO8601_DATE_REGEX)) {
                const utcString = new Date(headers.ifUnmodifiedSince).toUTCString();
                if (utcString !== 'Invalid Date') {
                    headers.ifUnmodifiedSince = utcString;
                }
            }
        }
    }
    return headers;
}
function buildNetworkSnapshot$2(luvio, config, clientOptions) {
    const { recordId } = config;
    const headers = getHeaders(clientOptions);
    const resourceParams = createResourceParams$2({ ...config, ...headers });
    const request = createResourceRequest$2(resourceParams);
    const fieldTrie = BLANK_RECORD_FIELDS_TRIE;
    const optionalFieldTrie = BLANK_RECORD_FIELDS_TRIE;
    const conflictMap = {
        conflicts: {},
        serverRequestCount: 0, // do not count the update request we're about to make
    };
    const recordIngest = createRecordIngest(fieldTrie, optionalFieldTrie, conflictMap);
    return luvio.dispatchResourceRequest(request).then((response) => {
        return luvio.handleSuccessResponse(() => {
            if (response.status === HttpStatusCode.NoContent) {
                const syntheticSnapshot = {
                    state: 'Fulfilled',
                    data: {},
                };
                luvio.storeEvict(keyBuilder$29(luvio, { recordId }));
                return luvio.storeBroadcast().then(() => syntheticSnapshot);
            }
            const snapshot = ingestRecordResponse(luvio, response, recordId, recordIngest, conflictMap);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys$1(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (err) => {
        deepFreeze(err);
        throw err;
    });
}
const factory$2 = (luvio) => {
    return (untrusted, clientOptions) => {
        let config = null;
        if (untrustedIsObject(untrusted) &&
            untrustedIsObject(untrusted.fields)) {
            config = validateAdapterConfig$2({ recordId: untrusted.fields.Id, ...untrusted }, updateRecord_ConfigPropertyNames);
        }
        // Invalid or incomplete config
        if (config === null) {
            // eslint-disable-next-line @salesforce/lds/no-error-in-production
            throw new Error('Invalid recordInput');
        }
        const draftAdapter = configurationForRestAdapters.getDraftAwareUpdateRecordAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, (config) => {
                const headers = getHeaders(clientOptions);
                const resourceParams = createResourceParams$2({ ...config, ...headers });
                return createResourceRequest$2(resourceParams);
            });
        }
        return buildNetworkSnapshot$2(luvio, config, clientOptions);
    };
};

const VERSION = "5f97eb4f2c3f805ef9d98ba7f0530b3e";
function validate(obj, path = 'ContentDocumentCompositeRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_contentDocument = obj.contentDocument;
        const path_contentDocument = path + '.contentDocument';
        if (typeof obj_contentDocument !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_contentDocument + '" (at "' + path_contentDocument + '")');
        }
        const obj_contentDocumentLinks = obj.contentDocumentLinks;
        const path_contentDocumentLinks = path + '.contentDocumentLinks';
        if (!ArrayIsArray(obj_contentDocumentLinks)) {
            return new TypeError('Expected "array" but received "' + typeof obj_contentDocumentLinks + '" (at "' + path_contentDocumentLinks + '")');
        }
        for (let i = 0; i < obj_contentDocumentLinks.length; i++) {
            const obj_contentDocumentLinks_item = obj_contentDocumentLinks[i];
            const path_contentDocumentLinks_item = path_contentDocumentLinks + '[' + i + ']';
            if (typeof obj_contentDocumentLinks_item !== 'object') {
                return new TypeError('Expected "object" but received "' + typeof obj_contentDocumentLinks_item + '" (at "' + path_contentDocumentLinks_item + '")');
            }
        }
        const obj_contentVersion = obj.contentVersion;
        const path_contentVersion = path + '.contentVersion';
        if (typeof obj_contentVersion !== 'object') {
            return new TypeError('Expected "object" but received "' + typeof obj_contentVersion + '" (at "' + path_contentVersion + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType = 'ContentDocumentCompositeRepresentation';
function keyBuilder(luvio, config) {
    return keyPrefix + '::' + RepresentationType + ':' + config.contentDocumentId;
}
function keyBuilderFromType(luvio, object) {
    const keyParams = {
        contentDocumentId: object.contentDocument.id
    };
    return keyBuilder(luvio, keyParams);
}
function normalize(input, existing, path, luvio, store, timestamp) {
    const input_contentDocument = input.contentDocument;
    const input_contentDocument_id = path.fullPath + '__contentDocument';
    input.contentDocument = ingest$O(input_contentDocument, {
        fullPath: input_contentDocument_id,
        propertyName: 'contentDocument',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    const input_contentDocumentLinks = input.contentDocumentLinks;
    const input_contentDocumentLinks_id = path.fullPath + '__contentDocumentLinks';
    for (let i = 0; i < input_contentDocumentLinks.length; i++) {
        const input_contentDocumentLinks_item = input_contentDocumentLinks[i];
        let input_contentDocumentLinks_item_id = input_contentDocumentLinks_id + '__' + i;
        input_contentDocumentLinks[i] = ingest$O(input_contentDocumentLinks_item, {
            fullPath: input_contentDocumentLinks_item_id,
            propertyName: i,
            parent: {
                data: input,
                key: path.fullPath,
                existing: existing,
            },
            ttl: path.ttl
        }, luvio, store, timestamp);
    }
    const input_contentVersion = input.contentVersion;
    const input_contentVersion_id = path.fullPath + '__contentVersion';
    input.contentVersion = ingest$O(input_contentVersion, {
        fullPath: input_contentVersion_id,
        propertyName: 'contentVersion',
        parent: {
            data: input,
            key: path.fullPath,
            existing: existing,
        },
        ttl: path.ttl
    }, luvio, store, timestamp);
    return input;
}
function equals(existing, incoming) {
    const existing_contentDocument = existing.contentDocument;
    const incoming_contentDocument = incoming.contentDocument;
    if (!(existing_contentDocument.__ref === incoming_contentDocument.__ref)) {
        return false;
    }
    const existing_contentDocumentLinks = existing.contentDocumentLinks;
    const incoming_contentDocumentLinks = incoming.contentDocumentLinks;
    const equals_contentDocumentLinks_items = equalsArray(existing_contentDocumentLinks, incoming_contentDocumentLinks, (existing_contentDocumentLinks_item, incoming_contentDocumentLinks_item) => {
        if (!(existing_contentDocumentLinks_item.__ref === incoming_contentDocumentLinks_item.__ref)) {
            return false;
        }
    });
    if (equals_contentDocumentLinks_items === false) {
        return false;
    }
    const existing_contentVersion = existing.contentVersion;
    const incoming_contentVersion = incoming.contentVersion;
    if (!(existing_contentVersion.__ref === incoming_contentVersion.__ref)) {
        return false;
    }
    return true;
}
const ingest = function ContentDocumentCompositeRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = keyBuilderFromType(luvio, input);
    const ttlToUse = path.ttl !== undefined ? path.ttl : 2592000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize, "UiApi", VERSION, RepresentationType, equals);
    return createLink(key);
};
function getTypeCacheKeys(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = keyBuilderFromType(luvio, input);
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType,
        mergeable: false
    });
    getTypeCacheKeys$X(rootKeySet, luvio, input.contentDocument);
    const input_contentDocumentLinks_length = input.contentDocumentLinks.length;
    for (let i = 0; i < input_contentDocumentLinks_length; i++) {
        getTypeCacheKeys$X(rootKeySet, luvio, input.contentDocumentLinks[i]);
    }
    getTypeCacheKeys$X(rootKeySet, luvio, input.contentVersion);
}

function getResponseCacheKeys(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys(storeKeyMap, luvio, response);
}

function createResourceParams$1(config) {
    const { fileData, title, description, contentDocumentId } = config;
    const body = {
        namedEntries: [
            {
                name: 'fileData',
                value: fileData,
            },
        ],
    };
    if (title !== undefined) {
        body.namedEntries.push({
            name: 'title',
            value: title,
        });
    }
    if (description !== undefined) {
        body.namedEntries.push({
            name: 'description',
            value: description,
        });
    }
    return {
        urlParams: {
            contentDocumentId,
        },
        body,
    };
}
function createResourceRequest$1(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/content-documents/' +
            config.urlParams.contentDocumentId +
            '/content-versions',
        method: 'post',
        body: config.body,
        urlParams: config.urlParams,
        queryParams: {},
        headers,
        priority: 'normal',
    };
}
const select = function ContentDocumentCompositeRepresentationSelect(body) {
    return {
        kind: 'Fragment',
        private: [],
        version: VERSION,
        selections: [
            {
                name: 'contentDocument',
                kind: 'Link',
                fragment: {
                    kind: 'Fragment',
                    private: [],
                    version: VERSION$1g,
                    selections: buildSelectionFromRecord(body.contentDocument),
                },
            },
            {
                name: 'contentDocumentLinks',
                kind: 'Link',
                plural: true,
                fragment: {
                    kind: 'Fragment',
                    private: [],
                    version: VERSION$1g,
                    selections: buildSelectionFromRecord(body.contentDocumentLinks[0] || { fields: {} }),
                },
            },
            {
                name: 'contentVersion',
                kind: 'Link',
                fragment: {
                    kind: 'Fragment',
                    private: [],
                    version: VERSION$1g,
                    selections: buildSelectionFromRecord(body.contentVersion),
                },
            },
        ],
    };
};
function ingestSuccess$1(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType(luvio, body);
    const node = select(body);
    luvio.storeIngest(key, ingest, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node,
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    return snapshot;
}
function buildNetworkSnapshot$1(luvio, config, options) {
    const resourceParams = createResourceParams$1(config);
    const request = createResourceRequest$1(resourceParams);
    return luvio
        .dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess$1(luvio, {}, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys(cache, luvio, {}, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}

function createResourceParams(config) {
    const { fileData, title, description } = config;
    const body = {
        namedEntries: [
            {
                name: 'fileData',
                value: fileData,
            },
        ],
    };
    if (title !== undefined) {
        body.namedEntries.push({
            name: 'title',
            value: title,
        });
    }
    if (description !== undefined) {
        body.namedEntries.push({
            name: 'description',
            value: description,
        });
    }
    return {
        body,
    };
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v64.0',
        basePath: '/ui-api/records/content-documents/content-versions',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}
function ingestSuccess(luvio, resourceParams, response) {
    const { body } = response;
    const key = keyBuilderFromType(luvio, body);
    const node = select(body);
    luvio.storeIngest(key, ingest, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node,
        variables: {},
    });
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    return snapshot;
}
function buildNetworkSnapshot(luvio, config, options) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return luvio
        .dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => {
            const snapshot = ingestSuccess(luvio, {}, response);
            return luvio.storeBroadcast().then(() => snapshot);
        }, () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        deepFreeze(response);
        throw response;
    });
}

const createContentDocumentAndVersion_ConfigPropertyMetadata = [
    generateParamConfigMetadata('description', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('title', false, 2 /* Body */, 0 /* String */),
];
function typeCheckConfig$3(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, createContentDocumentAndVersion_ConfigPropertyMetadata);
    return config;
}

// This override is due to the addition of Blob formatted file data. There is not a convenient way to express this in RAML, so this validation
// must be handrolled
const createContentDocumentAndVersion_ConfigPropertyNames = {
    displayName: 'createContentDocumentAndVersion',
    parameters: {
        required: ['fileData'],
        optional: ['description', 'title'],
    },
};
function typeCheckConfig$2(untrustedConfig) {
    const config = typeCheckConfig$3(untrustedConfig);
    const untrustedConfig_fileData = untrustedConfig.fileData;
    if (untrustedConfig_fileData !== undefined && untrustedConfig_fileData instanceof Object) {
        config.fileData = untrustedConfig_fileData;
    }
    return config;
}
function validateAdapterConfig$1(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig$2(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const factory$1 = (luvio) => {
    return function createContentDocumentAndVersion(untrustedConfig, requestContext) {
        let config = validateAdapterConfig$1(untrustedConfig, createContentDocumentAndVersion_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            // eslint-disable-next-line @salesforce/lds/no-error-in-production
            throw new Error('Invalid config for "createContentDocumentAndVersion"');
        }
        const draftAdapter = configurationForRestAdapters.getDraftAwareCreateContentDocumentAndVersionAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, (config) => {
                const resourceParams = createResourceParams(config);
                return createResourceRequest(resourceParams);
            }, requestContext);
        }
        return buildNetworkSnapshot(luvio, config, createDispatchResourceRequestContext$1(requestContext));
    };
};
function createDispatchResourceRequestContext$1(requestContext) {
    let dispatchOptions = undefined;
    if (requestContext !== undefined) {
        const coercedAdapterRequestContext = coerceAdapterRequestContext(requestContext);
        const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
        dispatchOptions = {
            resourceRequestContext: {
                requestCorrelator,
                sourceContext,
                luvioRequestMethod: undefined,
            },
            eventObservers,
        };
        if (networkPriority !== 'normal') {
            dispatchOptions.overrides = {
                priority: networkPriority,
            };
        }
    }
    return dispatchOptions;
}

const createContentVersion_ConfigPropertyMetadata = [
    generateParamConfigMetadata('contentDocumentId', true, 0 /* UrlParameter */, 0 /* String */),
    generateParamConfigMetadata('description', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('title', false, 2 /* Body */, 0 /* String */),
];
function typeCheckConfig$1(untrustedConfig) {
    const config = {};
    typeCheckConfig$17(untrustedConfig, config, createContentVersion_ConfigPropertyMetadata);
    return config;
}

// This override is due to the addition of Blob formatted file data. There is not a convenient way to express this in RAML, so this validation
// must be handrolled
const createContentVersion_ConfigPropertyNames = {
    displayName: 'createContentVersion',
    parameters: {
        required: ['contentDocumentId', 'fileData'],
        optional: ['description', 'title'],
    },
};
function typeCheckConfig(untrustedConfig) {
    const config = typeCheckConfig$1(untrustedConfig);
    const untrustedConfig_fileData = untrustedConfig.fileData;
    if (untrustedConfig_fileData !== undefined && untrustedConfig_fileData instanceof Object) {
        config.fileData = untrustedConfig_fileData;
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}

const factory = (luvio) => {
    return function createContentVersion(untrustedConfig, requestContext) {
        const config = validateAdapterConfig(untrustedConfig, createContentVersion_ConfigPropertyNames);
        // Invalid or incomplete config
        if (config === null) {
            // eslint-disable-next-line @salesforce/lds/no-error-in-production
            throw new Error('Invalid config for "createContentVersion"');
        }
        const draftAdapter = configurationForRestAdapters.getDraftAwareCreateContentVersionAdapter();
        if (draftAdapter !== undefined) {
            return draftAdapter(config, buildNetworkSnapshot$1, requestContext);
        }
        return buildNetworkSnapshot$1(luvio, config, createDispatchResourceRequestContext(requestContext));
    };
};
function createDispatchResourceRequestContext(requestContext) {
    let dispatchOptions = undefined;
    if (requestContext !== undefined) {
        const coercedAdapterRequestContext = coerceAdapterRequestContext(requestContext);
        const { networkPriority, requestCorrelator, eventObservers, sourceContext } = coercedAdapterRequestContext;
        dispatchOptions = {
            resourceRequestContext: {
                requestCorrelator,
                sourceContext,
                luvioRequestMethod: undefined,
            },
            eventObservers,
        };
        if (networkPriority !== 'normal') {
            dispatchOptions.overrides = {
                priority: networkPriority,
            };
        }
    }
    return dispatchOptions;
}

// TODO [W-11498005]: This should be imported from generated code once key generation is complete
const recordRepresentationKeySchema = ['namespace', 'representationName', 'id'];
class InMemoryRecordRepresentationQueryEvaluator {
    constructor(baseQueryEvaluator) {
        this.baseQueryEvaluator = baseQueryEvaluator;
    }
    queryByKey(keyQuery) {
        return this.baseQueryEvaluator.queryByKey(this.buildKeyQuery(keyQuery), recordRepresentationKeySchema);
    }
    queryWhere(valueQuery, keyQuery) {
        const defaultKeyQuery = {
            namespace: keyPrefix,
            representationName: RepresentationType$V,
            id: Wildcard,
        };
        const actualKeyQuery = keyQuery ? this.buildKeyQuery(keyQuery) : defaultKeyQuery;
        return this.baseQueryEvaluator.queryWhere(actualKeyQuery, recordRepresentationKeySchema, valueQuery);
    }
    buildKeyQuery(keyQuery) {
        // Ensure that all key queries on this class are for record representations
        return {
            id: Wildcard,
            ...keyQuery,
            namespace: keyPrefix,
            representationName: RepresentationType$V,
        };
    }
}

const configuration = {
    ...configurationForRestAdapters,
    ...configurationForGraphQLAdapters,
    ...configurationForOneStoreEnabledAdapters,
};
ensureRegisteredOnce({
    id: '@salesforce/lds-adapters-uiapi',
    configuration: {
        ...configurationForRestAdapters,
        ...configurationForGraphQLAdapters,
        ...configurationForOneStoreEnabledAdapters,
    },
    instrument,
});
function getRecordIngestionOverride() {
    const { getRecordRepresentationIngestionOverride } = configuration;
    return getRecordRepresentationIngestionOverride();
}

let createContentDocumentAndVersion;
let createContentVersion;
let createListInfo;
let createRecord;
let deleteListInfo;
let deleteRecord;
let executeBatchRecordOperations;
let getActionOverrides;
let getAllApps;
let getAppDetails;
let getDuplicateConfiguration;
let getDuplicates;
let getFlexipageFormulaOverrides;
let getGlobalActions;
let getKeywordSearchResults;
let getLayout;
let getLayoutUserState;
let getListInfoByName;
let getListInfosByName;
let getListInfosByObjectName;
let getListObjectInfo;
let getListPreferences;
let getListRecordsByName;
let getListUi;
let getLookupActions;
let getLookupMetadata;
let getLookupRecords;
let getNavItems;
let getObjectCreateActions;
let getObjectInfo;
let getObjectInfos;
let getPathLayout;
let getPicklistValues;
let getPicklistValuesByRecordType;
let getQuickActionDefaults;
let getQuickActionInfo;
let getQuickActionLayout;
let getRecord;
let getRecordActions;
let getRecordAvatars;
let getRecordCreateDefaults;
let getRecordEditActions;
let getRecordTemplateClone;
let getRecordTemplateCreate;
let getRecordUi;
let getRecords;
let getRelatedListActions;
let getRelatedListCount;
let getRelatedListInfo;
let getRelatedListInfoBatch;
let getRelatedListPreferences;
let getRelatedListPreferencesBatch;
let getRelatedListRecordActions;
let getRelatedListRecords;
let getRelatedListRecordsBatch;
let getRelatedListsActions;
let getRelatedListsCount;
let getRelatedListsInfo;
let getSearchFilterMetadata;
let getSearchFilterOptions;
let getSearchResults;
let performQuickAction;
let performUpdateRecordQuickAction;
let updateListInfoByName;
let updateListPreferences;
let updateRecord;
let updateRecordAvatar;
// Imperative GET Adapters
let getActionOverrides_imperative;
let getAllApps_imperative;
let getAppDetails_imperative;
let getDuplicateConfiguration_imperative;
let getDuplicates_imperative;
let getFlexipageFormulaOverrides_imperative;
let getGlobalActions_imperative;
let getKeywordSearchResults_imperative;
let getLayout_imperative;
let getLayoutUserState_imperative;
let getListInfoByName_imperative;
let getListInfosByName_imperative;
let getListInfosByObjectName_imperative;
let getListObjectInfo_imperative;
let getListPreferences_imperative;
let getListRecordsByName_imperative;
let getListUi_imperative;
let getLookupActions_imperative;
let getLookupMetadata_imperative;
let getLookupRecords_imperative;
let getNavItems_imperative;
let getObjectCreateActions_imperative;
let getObjectInfo_imperative;
let getObjectInfos_imperative;
let getPathLayout_imperative;
let getPicklistValues_imperative;
let getPicklistValuesByRecordType_imperative;
let getQuickActionDefaults_imperative;
let getQuickActionInfo_imperative;
let getQuickActionLayout_imperative;
let getRecord_imperative;
let getRecordActions_imperative;
let getRecordAvatars_imperative;
let getRecordCreateDefaults_imperative;
let getRecordEditActions_imperative;
let getRecordTemplateClone_imperative;
let getRecordTemplateCreate_imperative;
let getRecordUi_imperative;
let getRecords_imperative;
let getRelatedListActions_imperative;
let getRelatedListCount_imperative;
let getRelatedListInfo_imperative;
let getRelatedListInfoBatch_imperative;
let getRelatedListPreferences_imperative;
let getRelatedListPreferencesBatch_imperative;
let getRelatedListRecordActions_imperative;
let getRelatedListRecords_imperative;
let getRelatedListRecordsBatch_imperative;
let getRelatedListsActions_imperative;
let getRelatedListsCount_imperative;
let getRelatedListsInfo_imperative;
let getSearchFilterMetadata_imperative;
let getSearchFilterOptions_imperative;
let getSearchResults_imperative;
// Adapter Metadata
const getActionOverridesMetadata = { apiFamily: keyPrefix, name: adapterName$T };
const getAllAppsMetadata = { apiFamily: keyPrefix, name: adapterName$K, ttl: 300000 };
const getAppDetailsMetadata = { apiFamily: keyPrefix, name: adapterName$J, ttl: 300000 };
const getDuplicateConfigurationMetadata = { apiFamily: keyPrefix, name: adapterName$I, ttl: 900000 };
const getDuplicatesMetadata = { apiFamily: keyPrefix, name: adapterName$q, ttl: 30000 };
const getFlexipageFormulaOverridesMetadata = { apiFamily: keyPrefix, name: adapterName$S, ttl: 300000 };
const getGlobalActionsMetadata = { apiFamily: keyPrefix, name: adapterName$X, ttl: 300000 };
const getKeywordSearchResultsMetadata = { apiFamily: keyPrefix, name: adapterName$8, ttl: 200 };
const getLayoutMetadata = { apiFamily: keyPrefix, name: adapterName$H, ttl: 900000 };
const getLayoutUserStateMetadata = { apiFamily: keyPrefix, name: adapterName$G, ttl: 900000 };
const getListInfoByNameMetadata = { apiFamily: keyPrefix, name: adapterName$B, ttl: 900000 };
const getListInfosByNameMetadata = { apiFamily: keyPrefix, name: adapterName$F };
const getListInfosByObjectNameMetadata = { apiFamily: keyPrefix, name: adapterName$E };
const getListObjectInfoMetadata = { apiFamily: keyPrefix, name: adapterName$z, ttl: 900000 };
const getListPreferencesMetadata = { apiFamily: keyPrefix, name: adapterName$y, ttl: 900000 };
const getListRecordsByNameMetadata = { apiFamily: keyPrefix, name: 'getListRecordsByName', ttl: 30000 };
const getListUiMetadata = { apiFamily: keyPrefix, name: 'getListUi', ttl: 900000 };
const getLookupActionsMetadata = { apiFamily: keyPrefix, name: adapterName$V, ttl: 300000 };
const getLookupMetadataMetadata = { apiFamily: keyPrefix, name: adapterName$a, ttl: 30000 };
const getLookupRecordsMetadata = { apiFamily: keyPrefix, name: 'getLookupRecords' };
const getNavItemsMetadata = { apiFamily: keyPrefix, name: adapterName$w, ttl: 120000 };
const getObjectCreateActionsMetadata = { apiFamily: keyPrefix, name: adapterName$U, ttl: 300000 };
const getObjectInfoMetadata = { apiFamily: keyPrefix, name: adapterName$Y, ttl: 900000 };
const getObjectInfosMetadata = { apiFamily: keyPrefix, name: adapterName$u };
const getPathLayoutMetadata = { apiFamily: keyPrefix, name: adapterName$r, ttl: 900000 };
const getPicklistValuesMetadata = { apiFamily: keyPrefix, name: adapterName$s, ttl: 900000 };
const getPicklistValuesByRecordTypeMetadata = { apiFamily: keyPrefix, name: adapterName$t, ttl: 900000 };
const getQuickActionDefaultsMetadata = { apiFamily: keyPrefix, name: adapterName$Q, ttl: 900000 };
const getQuickActionInfoMetadata = { apiFamily: keyPrefix, name: adapterName$R, ttl: 900000 };
const getQuickActionLayoutMetadata = { apiFamily: keyPrefix, name: adapterName$W, ttl: 900000 };
const getRecordMetadata = { apiFamily: keyPrefix, name: 'getRecord', ttl: 30000 };
const getRecordActionsMetadata = { apiFamily: keyPrefix, name: adapterName$P, ttl: 300000 };
const getRecordAvatarsMetadata = { apiFamily: keyPrefix, name: adapterName$p, ttl: 3600000 };
const getRecordCreateDefaultsMetadata = { apiFamily: keyPrefix, name: 'getRecordCreateDefaults', ttl: 900000 };
const getRecordEditActionsMetadata = { apiFamily: keyPrefix, name: adapterName$O, ttl: 300000 };
const getRecordTemplateCloneMetadata = { apiFamily: keyPrefix, name: 'getRecordTemplateClone', ttl: 1000 };
const getRecordTemplateCreateMetadata = { apiFamily: keyPrefix, name: 'getRecordTemplateCreate', ttl: 900000 };
const getRecordUiMetadata = { apiFamily: keyPrefix, name: 'getRecordUi', ttl: 900000 };
const getRecordsMetadata = { apiFamily: keyPrefix, name: adapterName$o };
const getRelatedListActionsMetadata = { apiFamily: keyPrefix, name: adapterName$M, ttl: 300000 };
const getRelatedListCountMetadata = { apiFamily: keyPrefix, name: adapterName$m };
const getRelatedListInfoMetadata = { apiFamily: keyPrefix, name: adapterName$j, ttl: 900000 };
const getRelatedListInfoBatchMetadata = { apiFamily: keyPrefix, name: adapterName$l };
const getRelatedListPreferencesMetadata = { apiFamily: keyPrefix, name: adapterName$g, ttl: 900000 };
const getRelatedListPreferencesBatchMetadata = { apiFamily: keyPrefix, name: adapterName$h };
const getRelatedListRecordActionsMetadata = { apiFamily: keyPrefix, name: adapterName$L, ttl: 300000 };
const getRelatedListRecordsMetadata = { apiFamily: keyPrefix, name: adapterName$d, ttl: 30000 };
const getRelatedListRecordsBatchMetadata = { apiFamily: keyPrefix, name: adapterName$e };
const getRelatedListsActionsMetadata = { apiFamily: keyPrefix, name: adapterName$N };
const getRelatedListsCountMetadata = { apiFamily: keyPrefix, name: adapterName$n };
const getRelatedListsInfoMetadata = { apiFamily: keyPrefix, name: adapterName$k };
const getSearchFilterMetadataMetadata = { apiFamily: keyPrefix, name: adapterName$c, ttl: 30000 };
const getSearchFilterOptionsMetadata = { apiFamily: keyPrefix, name: adapterName$b, ttl: 30000 };
const getSearchResultsMetadata = { apiFamily: keyPrefix, name: adapterName$9, ttl: 200 };
function bindExportsTo(luvio) {
    // LDS adapters
    const getActionOverrides_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getActionOverrides', getActionOverridesAdapterFactory), getActionOverridesMetadata);
    const getAllApps_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getAllApps', getAllAppsAdapterFactory), getAllAppsMetadata);
    const getAppDetails_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getAppDetails', getAppDetailsAdapterFactory), getAppDetailsMetadata);
    const getDuplicateConfiguration_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getDuplicateConfiguration', getDuplicateConfigurationAdapterFactory), getDuplicateConfigurationMetadata);
    const getDuplicates_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getDuplicates', getDuplicatesAdapterFactory), getDuplicatesMetadata);
    const getFlexipageFormulaOverrides_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getFlexipageFormulaOverrides', getFlexipageFormulaOverridesAdapterFactory), getFlexipageFormulaOverridesMetadata);
    const getGlobalActions_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getGlobalActions', getGlobalActionsAdapterFactory), getGlobalActionsMetadata);
    const getKeywordSearchResults_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getKeywordSearchResults', configurationForEnvironmentFactoryOverrides.getKeywordSearchResultsAdapterFactory() ?? getKeywordSearchResultsAdapterFactory), getKeywordSearchResultsMetadata);
    const getLayout_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getLayout', getLayoutAdapterFactory), getLayoutMetadata);
    const getLayoutUserState_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getLayoutUserState', getLayoutUserStateAdapterFactory), getLayoutUserStateMetadata);
    const getListInfoByName_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getListInfoByName', getListInfoByNameAdapterFactory), luvio, 'getListInfoByName'), getListInfoByNameMetadata);
    const getListInfosByName_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getListInfosByName', getListInfosByNameAdapterFactory), getListInfosByNameMetadata);
    const getListInfosByObjectName_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getListInfosByObjectName', getListInfosByObjectNameAdapterFactory), luvio, 'getListInfosByObjectName'), getListInfosByObjectNameMetadata);
    const getListObjectInfo_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getListObjectInfo', getListObjectInfoAdapterFactory), luvio, 'getListObjectInfo'), getListObjectInfoMetadata);
    const getListPreferences_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getListPreferences', getListPreferencesAdapterFactory), getListPreferencesMetadata);
    const getListRecordsByName_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getListRecordsByName', configurationForEnvironmentFactoryOverrides.getListRecordsByNameAdapterFactory() ?? factory$a), luvio, 'getListRecordsByName'), getListRecordsByNameMetadata);
    const getListUi_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getListUi', configurationForEnvironmentFactoryOverrides.getListUiAdapterFactory() ?? factory$h), getListUiMetadata);
    const getLookupActions_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getLookupActions', getLookupActionsAdapterFactory), getLookupActionsMetadata);
    const getLookupMetadata_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getLookupMetadata', getLookupMetadataAdapterFactory), getLookupMetadataMetadata);
    const getLookupRecords_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getLookupRecords', configurationForEnvironmentFactoryOverrides.getLookupRecordsAdapterFactory() ?? factory$9), getLookupRecordsMetadata);
    const getNavItems_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getNavItems', getNavItemsAdapterFactory), getNavItemsMetadata);
    const getObjectCreateActions_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getObjectCreateActions', getObjectCreateActionsAdapterFactory), getObjectCreateActionsMetadata);
    const getObjectInfo_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getObjectInfo', getObjectInfoAdapterFactory), luvio, 'getObjectInfo'), getObjectInfoMetadata);
    const getObjectInfos_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getObjectInfos', getObjectInfosAdapterFactory), luvio, 'getObjectInfos'), getObjectInfosMetadata);
    const getPathLayout_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getPathLayout', getPathLayoutAdapterFactory), getPathLayoutMetadata);
    const getPicklistValues_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getPicklistValues', getPicklistValuesAdapterFactory), getPicklistValuesMetadata);
    const getPicklistValuesByRecordType_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getPicklistValuesByRecordType', getPicklistValuesByRecordTypeAdapterFactory), getPicklistValuesByRecordTypeMetadata);
    const getQuickActionDefaults_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getQuickActionDefaults', configurationForEnvironmentFactoryOverrides.getQuickActionDefaultsAdapterFactory() ?? getQuickActionDefaultsAdapterFactory), getQuickActionDefaultsMetadata);
    const getQuickActionInfo_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getQuickActionInfo', getQuickActionInfoAdapterFactory), getQuickActionInfoMetadata);
    const getQuickActionLayout_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getQuickActionLayout', getQuickActionLayoutAdapterFactory), getQuickActionLayoutMetadata);
    const getRecord_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getRecord', configurationForEnvironmentFactoryOverrides.getRecordAdapterFactory() ?? factory$f), luvio, 'getRecord'), getRecordMetadata);
    const getRecordActions_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getRecordActions', getRecordActionsAdapterFactory), luvio, 'getRecordActions'), getRecordActionsMetadata);
    const getRecordAvatars_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getRecordAvatars', getRecordAvatarsAdapterFactory), luvio, 'getRecordAvatars'), getRecordAvatarsMetadata);
    const getRecordCreateDefaults_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRecordCreateDefaults', configurationForEnvironmentFactoryOverrides.getRecordCreateDefaultsAdapterFactory() ?? factory$7), getRecordCreateDefaultsMetadata);
    const getRecordEditActions_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRecordEditActions', getRecordEditActionsAdapterFactory), getRecordEditActionsMetadata);
    const getRecordTemplateClone_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRecordTemplateClone', configurationForEnvironmentFactoryOverrides.getRecordTemplateCloneAdapterFactory() ?? factory$6), getRecordTemplateCloneMetadata);
    const getRecordTemplateCreate_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRecordTemplateCreate', configurationForEnvironmentFactoryOverrides.getRecordTemplateCreateAdapterFactory() ?? factory$5), getRecordTemplateCreateMetadata);
    const getRecordUi_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRecordUi', configurationForEnvironmentFactoryOverrides.getRecordUiAdapterFactory() ?? factory$g), getRecordUiMetadata);
    const getRecords_ldsAdapter = createInstrumentedAdapter(createLDSAdapterWithPrediction(createLDSAdapter(luvio, 'getRecords', configurationForEnvironmentFactoryOverrides.getRecordsAdapterFactory() ?? getRecordsAdapterFactory), luvio, 'getRecords'), getRecordsMetadata);
    const getRelatedListActions_ldsAdapter = createInstrumentedAdapter(createRelatedListPlusAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListActions', getRelatedListActionsAdapterFactory), luvio, 'getRelatedListActions'), getRelatedListActionsMetadata);
    const getRelatedListCount_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRelatedListCount', getRelatedListCountAdapterFactory), getRelatedListCountMetadata);
    const getRelatedListInfo_ldsAdapter = createInstrumentedAdapter(createRelatedListAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListInfo', getRelatedListInfoAdapterFactory), luvio, 'getRelatedListInfo'), getRelatedListInfoMetadata);
    const getRelatedListInfoBatch_ldsAdapter = createInstrumentedAdapter(createRelatedListAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListInfoBatch', getRelatedListInfoBatchAdapterFactory), luvio, 'getRelatedListInfoBatch'), getRelatedListInfoBatchMetadata);
    const getRelatedListPreferences_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRelatedListPreferences', getRelatedListPreferencesAdapterFactory), getRelatedListPreferencesMetadata);
    const getRelatedListPreferencesBatch_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRelatedListPreferencesBatch', getRelatedListPreferencesBatchAdapterFactory), getRelatedListPreferencesBatchMetadata);
    const getRelatedListRecordActions_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRelatedListRecordActions', getRelatedListRecordActionsAdapterFactory), getRelatedListRecordActionsMetadata);
    const getRelatedListRecords_ldsAdapter = createInstrumentedAdapter(createRelatedListAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListRecords', configurationForEnvironmentFactoryOverrides.getRelatedListRecordsAdapterFactory() ?? getRelatedListRecordsAdapterFactory), luvio, 'getRelatedListRecords'), getRelatedListRecordsMetadata);
    const getRelatedListRecordsBatch_ldsAdapter = createInstrumentedAdapter(createRelatedListAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListRecordsBatch', configurationForEnvironmentFactoryOverrides.getRelatedListRecordsBatchAdapterFactory() ?? getRelatedListRecordsBatchAdapterFactory), luvio, 'getRelatedListRecordsBatch'), getRelatedListRecordsBatchMetadata);
    const getRelatedListsActions_ldsAdapter = createInstrumentedAdapter(createRelatedListAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListsActions', getRelatedListsActionsAdapterFactory), luvio, 'getRelatedListsActions'), getRelatedListsActionsMetadata);
    const getRelatedListsCount_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getRelatedListsCount', getRelatedListsCountAdapterFactory), getRelatedListsCountMetadata);
    const getRelatedListsInfo_ldsAdapter = createInstrumentedAdapter(createRelatedListPlusAdapterWithPrediction(createLDSAdapter(luvio, 'getRelatedListsInfo', getRelatedListsInfoAdapterFactory), luvio, 'getRelatedListsInfo'), getRelatedListsInfoMetadata);
    const getSearchFilterMetadata_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getSearchFilterMetadata', getSearchFilterMetadataAdapterFactory), getSearchFilterMetadataMetadata);
    const getSearchFilterOptions_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getSearchFilterOptions', getSearchFilterOptionsAdapterFactory), getSearchFilterOptionsMetadata);
    const getSearchResults_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getSearchResults', configurationForEnvironmentFactoryOverrides.getSearchResultsAdapterFactory() ?? getSearchResultsAdapterFactory), getSearchResultsMetadata);
    function unwrapSnapshotData(factory) {
        const adapter = factory(luvio);
        return (...config) => adapter(...config).then(snapshot => snapshot.data);
    }
    return {
        // Wire Adapters
        createContentDocumentAndVersion: unwrapSnapshotData(factory$1),
        createContentVersion: unwrapSnapshotData(factory),
        createListInfo: createLDSAdapter(luvio, adapterName$D, createListInfoAdapterFactory),
        createRecord: unwrapSnapshotData(factory$4),
        deleteListInfo: createLDSAdapter(luvio, adapterName$C, deleteListInfoAdapterFactory),
        deleteRecord: createLDSAdapter(luvio, 'deleteRecord', factory$3),
        executeBatchRecordOperations: unwrapSnapshotData(factory$e),
        getActionOverrides: createWireAdapterConstructor(luvio, getActionOverrides_ldsAdapter, getActionOverridesMetadata),
        getAllApps: createWireAdapterConstructor(luvio, getAllApps_ldsAdapter, getAllAppsMetadata),
        getAppDetails: createWireAdapterConstructor(luvio, getAppDetails_ldsAdapter, getAppDetailsMetadata),
        getDuplicateConfiguration: createWireAdapterConstructor(luvio, getDuplicateConfiguration_ldsAdapter, getDuplicateConfigurationMetadata),
        getDuplicates: createWireAdapterConstructor(luvio, getDuplicates_ldsAdapter, getDuplicatesMetadata),
        getFlexipageFormulaOverrides: createWireAdapterConstructor(luvio, getFlexipageFormulaOverrides_ldsAdapter, getFlexipageFormulaOverridesMetadata),
        getGlobalActions: createWireAdapterConstructor(luvio, getGlobalActions_ldsAdapter, getGlobalActionsMetadata),
        getKeywordSearchResults: createWireAdapterConstructor(luvio, getKeywordSearchResults_ldsAdapter, getKeywordSearchResultsMetadata),
        getLayout: createWireAdapterConstructor(luvio, getLayout_ldsAdapter, getLayoutMetadata),
        getLayoutUserState: createWireAdapterConstructor(luvio, getLayoutUserState_ldsAdapter, getLayoutUserStateMetadata),
        getListInfoByName: createWireAdapterConstructor(luvio, getListInfoByName_ldsAdapter, getListInfoByNameMetadata),
        getListInfosByName: createWireAdapterConstructor(luvio, getListInfosByName_ldsAdapter, getListInfosByNameMetadata),
        getListInfosByObjectName: createWireAdapterConstructor(luvio, getListInfosByObjectName_ldsAdapter, getListInfosByObjectNameMetadata),
        getListObjectInfo: createWireAdapterConstructor(luvio, getListObjectInfo_ldsAdapter, getListObjectInfoMetadata),
        getListPreferences: createWireAdapterConstructor(luvio, getListPreferences_ldsAdapter, getListPreferencesMetadata),
        getListRecordsByName: createInfiniteScrollingWireAdapterConstructor(luvio, getListRecordsByName_ldsAdapter, getListRecordsByNameMetadata),
        getListUi: createInfiniteScrollingWireAdapterConstructor(luvio, getListUi_ldsAdapter, getListUiMetadata),
        getLookupActions: createWireAdapterConstructor(luvio, getLookupActions_ldsAdapter, getLookupActionsMetadata),
        getLookupMetadata: createWireAdapterConstructor(luvio, getLookupMetadata_ldsAdapter, getLookupMetadataMetadata),
        getLookupRecords: createWireAdapterConstructor(luvio, getLookupRecords_ldsAdapter, getLookupRecordsMetadata),
        getNavItems: createWireAdapterConstructor(luvio, getNavItems_ldsAdapter, getNavItemsMetadata),
        getObjectCreateActions: createWireAdapterConstructor(luvio, getObjectCreateActions_ldsAdapter, getObjectCreateActionsMetadata),
        getPathLayout: createWireAdapterConstructor(luvio, getPathLayout_ldsAdapter, getPathLayoutMetadata),
        getPicklistValues: createWireAdapterConstructor(luvio, getPicklistValues_ldsAdapter, getPicklistValuesMetadata),
        getPicklistValuesByRecordType: createWireAdapterConstructor(luvio, getPicklistValuesByRecordType_ldsAdapter, getPicklistValuesByRecordTypeMetadata),
        getQuickActionDefaults: createWireAdapterConstructor(luvio, getQuickActionDefaults_ldsAdapter, getQuickActionDefaultsMetadata),
        getQuickActionInfo: createWireAdapterConstructor(luvio, getQuickActionInfo_ldsAdapter, getQuickActionInfoMetadata),
        getQuickActionLayout: createWireAdapterConstructor(luvio, getQuickActionLayout_ldsAdapter, getQuickActionLayoutMetadata),
        getRecord: createWireAdapterConstructor(luvio, getRecord_ldsAdapter, getRecordMetadata),
        getRecordActions: createWireAdapterConstructor(luvio, getRecordActions_ldsAdapter, getRecordActionsMetadata),
        getRecordAvatars: createWireAdapterConstructor(luvio, getRecordAvatars_ldsAdapter, getRecordAvatarsMetadata),
        getRecordCreateDefaults: createWireAdapterConstructor(luvio, getRecordCreateDefaults_ldsAdapter, getRecordCreateDefaultsMetadata),
        getRecordEditActions: createWireAdapterConstructor(luvio, getRecordEditActions_ldsAdapter, getRecordEditActionsMetadata),
        getRecordTemplateClone: createWireAdapterConstructor(luvio, getRecordTemplateClone_ldsAdapter, getRecordTemplateCloneMetadata),
        getRecordTemplateCreate: createWireAdapterConstructor(luvio, getRecordTemplateCreate_ldsAdapter, getRecordTemplateCreateMetadata),
        getRecordUi: createWireAdapterConstructor(luvio, getRecordUi_ldsAdapter, getRecordUiMetadata),
        getRecords: createWireAdapterConstructor(luvio, getRecords_ldsAdapter, getRecordsMetadata),
        getRelatedListActions: createWireAdapterConstructor(luvio, getRelatedListActions_ldsAdapter, getRelatedListActionsMetadata),
        getRelatedListCount: createWireAdapterConstructor(luvio, getRelatedListCount_ldsAdapter, getRelatedListCountMetadata),
        getRelatedListInfo: createWireAdapterConstructor(luvio, getRelatedListInfo_ldsAdapter, getRelatedListInfoMetadata),
        getRelatedListInfoBatch: createWireAdapterConstructor(luvio, getRelatedListInfoBatch_ldsAdapter, getRelatedListInfoBatchMetadata),
        getRelatedListPreferences: createWireAdapterConstructor(luvio, getRelatedListPreferences_ldsAdapter, getRelatedListPreferencesMetadata),
        getRelatedListPreferencesBatch: createWireAdapterConstructor(luvio, getRelatedListPreferencesBatch_ldsAdapter, getRelatedListPreferencesBatchMetadata),
        getRelatedListRecordActions: createWireAdapterConstructor(luvio, getRelatedListRecordActions_ldsAdapter, getRelatedListRecordActionsMetadata),
        getRelatedListRecords: createInfiniteScrollingWireAdapterConstructor(luvio, getRelatedListRecords_ldsAdapter, getRelatedListRecordsMetadata),
        getRelatedListRecordsBatch: createWireAdapterConstructor(luvio, getRelatedListRecordsBatch_ldsAdapter, getRelatedListRecordsBatchMetadata),
        getRelatedListsActions: createWireAdapterConstructor(luvio, getRelatedListsActions_ldsAdapter, getRelatedListsActionsMetadata),
        getRelatedListsCount: createWireAdapterConstructor(luvio, getRelatedListsCount_ldsAdapter, getRelatedListsCountMetadata),
        getRelatedListsInfo: createWireAdapterConstructor(luvio, getRelatedListsInfo_ldsAdapter, getRelatedListsInfoMetadata),
        getSearchFilterMetadata: createWireAdapterConstructor(luvio, getSearchFilterMetadata_ldsAdapter, getSearchFilterMetadataMetadata),
        getSearchFilterOptions: createWireAdapterConstructor(luvio, getSearchFilterOptions_ldsAdapter, getSearchFilterOptionsMetadata),
        getSearchResults: createWireAdapterConstructor(luvio, getSearchResults_ldsAdapter, getSearchResultsMetadata),
        performQuickAction: unwrapSnapshotData(factory$c),
        performUpdateRecordQuickAction: unwrapSnapshotData(factory$d),
        updateListInfoByName: createLDSAdapter(luvio, adapterName$A, updateListInfoByNameAdapterFactory),
        updateListPreferences: createLDSAdapter(luvio, adapterName$x, updateListPreferencesAdapterFactory),
        updateRecord: unwrapSnapshotData(factory$2),
        updateRecordAvatar: unwrapSnapshotData(factory$8),
        // One Store Enabled Adapters
        getObjectInfo: getLuvioOrOneStoreAdapter(createWireAdapterConstructor(luvio, getObjectInfo_ldsAdapter, getObjectInfoMetadata), configurationForOneStoreEnabledAdapters.getGetObjectInfoAdapter()),
        getObjectInfos: getLuvioOrOneStoreAdapter(createWireAdapterConstructor(luvio, getObjectInfos_ldsAdapter, getObjectInfosMetadata), configurationForOneStoreEnabledAdapters.getGetObjectInfosAdapter()),
        // Imperative Adapters
        getActionOverrides_imperative: createImperativeAdapter(luvio, getActionOverrides_ldsAdapter, getActionOverridesMetadata),
        getAllApps_imperative: createImperativeAdapter(luvio, getAllApps_ldsAdapter, getAllAppsMetadata),
        getAppDetails_imperative: createImperativeAdapter(luvio, getAppDetails_ldsAdapter, getAppDetailsMetadata),
        getDuplicateConfiguration_imperative: createImperativeAdapter(luvio, getDuplicateConfiguration_ldsAdapter, getDuplicateConfigurationMetadata),
        getDuplicates_imperative: createImperativeAdapter(luvio, getDuplicates_ldsAdapter, getDuplicatesMetadata),
        getFlexipageFormulaOverrides_imperative: createImperativeAdapter(luvio, getFlexipageFormulaOverrides_ldsAdapter, getFlexipageFormulaOverridesMetadata),
        getGlobalActions_imperative: createImperativeAdapter(luvio, getGlobalActions_ldsAdapter, getGlobalActionsMetadata),
        getKeywordSearchResults_imperative: createImperativeAdapter(luvio, getKeywordSearchResults_ldsAdapter, getKeywordSearchResultsMetadata),
        getLayout_imperative: createImperativeAdapter(luvio, getLayout_ldsAdapter, getLayoutMetadata),
        getLayoutUserState_imperative: createImperativeAdapter(luvio, getLayoutUserState_ldsAdapter, getLayoutUserStateMetadata),
        getListInfoByName_imperative: createImperativeAdapter(luvio, getListInfoByName_ldsAdapter, getListInfoByNameMetadata),
        getListInfosByName_imperative: createImperativeAdapter(luvio, getListInfosByName_ldsAdapter, getListInfosByNameMetadata),
        getListInfosByObjectName_imperative: createImperativeAdapter(luvio, getListInfosByObjectName_ldsAdapter, getListInfosByObjectNameMetadata),
        getListObjectInfo_imperative: createImperativeAdapter(luvio, getListObjectInfo_ldsAdapter, getListObjectInfoMetadata),
        getListPreferences_imperative: createImperativeAdapter(luvio, getListPreferences_ldsAdapter, getListPreferencesMetadata),
        getListRecordsByName_imperative: createImperativeAdapter(luvio, getListRecordsByName_ldsAdapter, getListRecordsByNameMetadata),
        getListUi_imperative: createImperativeAdapter(luvio, getListUi_ldsAdapter, getListUiMetadata),
        getLookupActions_imperative: createImperativeAdapter(luvio, getLookupActions_ldsAdapter, getLookupActionsMetadata),
        getLookupMetadata_imperative: createImperativeAdapter(luvio, getLookupMetadata_ldsAdapter, getLookupMetadataMetadata),
        getLookupRecords_imperative: createImperativeAdapter(luvio, getLookupRecords_ldsAdapter, getLookupRecordsMetadata),
        getNavItems_imperative: createImperativeAdapter(luvio, getNavItems_ldsAdapter, getNavItemsMetadata),
        getObjectCreateActions_imperative: createImperativeAdapter(luvio, getObjectCreateActions_ldsAdapter, getObjectCreateActionsMetadata),
        getObjectInfo_imperative: createImperativeAdapter(luvio, getObjectInfo_ldsAdapter, getObjectInfoMetadata),
        getObjectInfos_imperative: createImperativeAdapter(luvio, getObjectInfos_ldsAdapter, getObjectInfosMetadata),
        getPathLayout_imperative: createImperativeAdapter(luvio, getPathLayout_ldsAdapter, getPathLayoutMetadata),
        getPicklistValues_imperative: createImperativeAdapter(luvio, getPicklistValues_ldsAdapter, getPicklistValuesMetadata),
        getPicklistValuesByRecordType_imperative: createImperativeAdapter(luvio, getPicklistValuesByRecordType_ldsAdapter, getPicklistValuesByRecordTypeMetadata),
        getQuickActionDefaults_imperative: createImperativeAdapter(luvio, getQuickActionDefaults_ldsAdapter, getQuickActionDefaultsMetadata),
        getQuickActionInfo_imperative: createImperativeAdapter(luvio, getQuickActionInfo_ldsAdapter, getQuickActionInfoMetadata),
        getQuickActionLayout_imperative: createImperativeAdapter(luvio, getQuickActionLayout_ldsAdapter, getQuickActionLayoutMetadata),
        getRecord_imperative: createImperativeAdapter(luvio, getRecord_ldsAdapter, getRecordMetadata),
        getRecordActions_imperative: createImperativeAdapter(luvio, getRecordActions_ldsAdapter, getRecordActionsMetadata),
        getRecordAvatars_imperative: createImperativeAdapter(luvio, getRecordAvatars_ldsAdapter, getRecordAvatarsMetadata),
        getRecordCreateDefaults_imperative: createImperativeAdapter(luvio, getRecordCreateDefaults_ldsAdapter, getRecordCreateDefaultsMetadata),
        getRecordEditActions_imperative: createImperativeAdapter(luvio, getRecordEditActions_ldsAdapter, getRecordEditActionsMetadata),
        getRecordTemplateClone_imperative: createImperativeAdapter(luvio, getRecordTemplateClone_ldsAdapter, getRecordTemplateCloneMetadata),
        getRecordTemplateCreate_imperative: createImperativeAdapter(luvio, getRecordTemplateCreate_ldsAdapter, getRecordTemplateCreateMetadata),
        getRecordUi_imperative: createImperativeAdapter(luvio, getRecordUi_ldsAdapter, getRecordUiMetadata),
        getRecords_imperative: createImperativeAdapter(luvio, getRecords_ldsAdapter, getRecordsMetadata),
        getRelatedListActions_imperative: createImperativeAdapter(luvio, getRelatedListActions_ldsAdapter, getRelatedListActionsMetadata),
        getRelatedListCount_imperative: createImperativeAdapter(luvio, getRelatedListCount_ldsAdapter, getRelatedListCountMetadata),
        getRelatedListInfo_imperative: createImperativeAdapter(luvio, getRelatedListInfo_ldsAdapter, getRelatedListInfoMetadata),
        getRelatedListInfoBatch_imperative: createImperativeAdapter(luvio, getRelatedListInfoBatch_ldsAdapter, getRelatedListInfoBatchMetadata),
        getRelatedListPreferences_imperative: createImperativeAdapter(luvio, getRelatedListPreferences_ldsAdapter, getRelatedListPreferencesMetadata),
        getRelatedListPreferencesBatch_imperative: createImperativeAdapter(luvio, getRelatedListPreferencesBatch_ldsAdapter, getRelatedListPreferencesBatchMetadata),
        getRelatedListRecordActions_imperative: createImperativeAdapter(luvio, getRelatedListRecordActions_ldsAdapter, getRelatedListRecordActionsMetadata),
        getRelatedListRecords_imperative: createImperativeAdapter(luvio, getRelatedListRecords_ldsAdapter, getRelatedListRecordsMetadata),
        getRelatedListRecordsBatch_imperative: createImperativeAdapter(luvio, getRelatedListRecordsBatch_ldsAdapter, getRelatedListRecordsBatchMetadata),
        getRelatedListsActions_imperative: createImperativeAdapter(luvio, getRelatedListsActions_ldsAdapter, getRelatedListsActionsMetadata),
        getRelatedListsCount_imperative: createImperativeAdapter(luvio, getRelatedListsCount_ldsAdapter, getRelatedListsCountMetadata),
        getRelatedListsInfo_imperative: createImperativeAdapter(luvio, getRelatedListsInfo_ldsAdapter, getRelatedListsInfoMetadata),
        getSearchFilterMetadata_imperative: createImperativeAdapter(luvio, getSearchFilterMetadata_ldsAdapter, getSearchFilterMetadataMetadata),
        getSearchFilterOptions_imperative: createImperativeAdapter(luvio, getSearchFilterOptions_ldsAdapter, getSearchFilterOptionsMetadata),
        getSearchResults_imperative: createImperativeAdapter(luvio, getSearchResults_ldsAdapter, getSearchResultsMetadata),
    };
}
withDefaultLuvio((luvio) => {
    ({
        createContentDocumentAndVersion,
        createContentVersion,
        createListInfo,
        createRecord,
        deleteListInfo,
        deleteRecord,
        executeBatchRecordOperations,
        getActionOverrides,
        getAllApps,
        getAppDetails,
        getDuplicateConfiguration,
        getDuplicates,
        getFlexipageFormulaOverrides,
        getGlobalActions,
        getKeywordSearchResults,
        getLayout,
        getLayoutUserState,
        getListInfoByName,
        getListInfosByName,
        getListInfosByObjectName,
        getListObjectInfo,
        getListPreferences,
        getListRecordsByName,
        getListUi,
        getLookupActions,
        getLookupMetadata,
        getLookupRecords,
        getNavItems,
        getObjectCreateActions,
        getObjectInfo,
        getObjectInfos,
        getPathLayout,
        getPicklistValues,
        getPicklistValuesByRecordType,
        getQuickActionDefaults,
        getQuickActionInfo,
        getQuickActionLayout,
        getRecord,
        getRecordActions,
        getRecordAvatars,
        getRecordCreateDefaults,
        getRecordEditActions,
        getRecordTemplateClone,
        getRecordTemplateCreate,
        getRecordUi,
        getRecords,
        getRelatedListActions,
        getRelatedListCount,
        getRelatedListInfo,
        getRelatedListInfoBatch,
        getRelatedListPreferences,
        getRelatedListPreferencesBatch,
        getRelatedListRecordActions,
        getRelatedListRecords,
        getRelatedListRecordsBatch,
        getRelatedListsActions,
        getRelatedListsCount,
        getRelatedListsInfo,
        getSearchFilterMetadata,
        getSearchFilterOptions,
        getSearchResults,
        performQuickAction,
        performUpdateRecordQuickAction,
        updateListInfoByName,
        updateListPreferences,
        updateRecord,
        updateRecordAvatar,
        getActionOverrides_imperative,
        getAllApps_imperative,
        getAppDetails_imperative,
        getDuplicateConfiguration_imperative,
        getDuplicates_imperative,
        getFlexipageFormulaOverrides_imperative,
        getGlobalActions_imperative,
        getKeywordSearchResults_imperative,
        getLayout_imperative,
        getLayoutUserState_imperative,
        getListInfoByName_imperative,
        getListInfosByName_imperative,
        getListInfosByObjectName_imperative,
        getListObjectInfo_imperative,
        getListPreferences_imperative,
        getListRecordsByName_imperative,
        getListUi_imperative,
        getLookupActions_imperative,
        getLookupMetadata_imperative,
        getLookupRecords_imperative,
        getNavItems_imperative,
        getObjectCreateActions_imperative,
        getObjectInfo_imperative,
        getObjectInfos_imperative,
        getPathLayout_imperative,
        getPicklistValues_imperative,
        getPicklistValuesByRecordType_imperative,
        getQuickActionDefaults_imperative,
        getQuickActionInfo_imperative,
        getQuickActionLayout_imperative,
        getRecord_imperative,
        getRecordActions_imperative,
        getRecordAvatars_imperative,
        getRecordCreateDefaults_imperative,
        getRecordEditActions_imperative,
        getRecordTemplateClone_imperative,
        getRecordTemplateCreate_imperative,
        getRecordUi_imperative,
        getRecords_imperative,
        getRelatedListActions_imperative,
        getRelatedListCount_imperative,
        getRelatedListInfo_imperative,
        getRelatedListInfoBatch_imperative,
        getRelatedListPreferences_imperative,
        getRelatedListPreferencesBatch_imperative,
        getRelatedListRecordActions_imperative,
        getRelatedListRecords_imperative,
        getRelatedListRecordsBatch_imperative,
        getRelatedListsActions_imperative,
        getRelatedListsCount_imperative,
        getRelatedListsInfo_imperative,
        getSearchFilterMetadata_imperative,
        getSearchFilterOptions_imperative,
        getSearchResults_imperative,
    } = bindExportsTo(luvio));
});

const REFRESH_UIAPI_KEY = 'refreshUiApi';
const refresh = function (data) {
    return refresh$2(data, REFRESH_UIAPI_KEY);
};
/** Custom adapters */
// updateLayoutUserState adapter should always return undefined
let baseUpdateLayoutUserState;
const updateLayoutUserState = (apiName, recordTypeId, layoutType, mode, layoutUserStateInput) => {
    return baseUpdateLayoutUserState(apiName, recordTypeId, layoutType, mode, layoutUserStateInput).then(() => undefined);
};
// In order to export the imperative wire correctly, we need to add some safety checks
// to ensure the config passed is correct
let baseUpdateRelatedListInfo;
const updateRelatedListInfo = (config) => {
    const value = baseUpdateRelatedListInfo(config);
    if (value === null) {
        if (process.env.NODE_ENV !== 'production') {
            throw new Error('Invalid config for updateRelatedListInfo');
        }
        return;
    }
    if ('then' in value) {
        return value.then((snapshot) => snapshot.data);
    }
    if (value.state === 'Error') {
        return Promise.reject(value.error);
    }
    return Promise.resolve(value.data);
};
let baseUpdateRelatedListPreferences;
const updateRelatedListPreferences = (config) => {
    const value = baseUpdateRelatedListPreferences(config);
    if (value === null) {
        if (process.env.NODE_ENV !== 'production') {
            throw new Error('Invalid config for updateRelatedListPreferences');
        }
        return;
    }
    if ('then' in value) {
        return value.then((snapshot) => snapshot.data);
    }
    if (value.state === 'Error') {
        return Promise.reject(value.error);
    }
    return Promise.resolve(value.data);
};
/** SFDC utils */
let getRecordNotifyChange;
let notifyRecordUpdateAvailable;
let notifyListViewSummaryUpdateAvailable;
let notifyListInfoSummaryUpdateAvailable;
let notifyListInfoUpdateAvailable;
let notifyQuickActionDefaultsUpdateAvailable;
let notifyListRecordCollectionUpdateAvailable;
let notifyAllListRecordUpdateAvailable;
let notifyAllListInfoSummaryUpdateAvailable;
withDefaultLuvio((luvio) => {
    bindWireRefresh(luvio);
    baseUpdateLayoutUserState = createLDSAdapter(luvio, 'updateLayoutUserState', factory$b);
    baseUpdateRelatedListInfo = createLDSAdapter(luvio, 'baseUpdateRelatedListInfo', updateRelatedListInfoAdapterFactory);
    baseUpdateRelatedListPreferences = createLDSAdapter(luvio, 'baseUpdateRelatedListPreferences', updateRelatedListPreferencesAdapterFactory);
    getRecordNotifyChange = throttle(60, 60000, createLDSAdapter(luvio, 'getRecordNotifyChange', notifyChangeFactory), {
        allowFunction: instrumentation.getRecordNotifyChangeAllowed,
        dropFunction: instrumentation.getRecordNotifyChangeDropped,
    });
    notifyRecordUpdateAvailable = throttle(60, 60000, createLDSAdapter(luvio, 'notifyRecordUpdateAvailable', notifyUpdateAvailableFactory$5), {
        allowFunction: instrumentation.notifyRecordUpdateAvailableAllowed,
        dropFunction: instrumentation.notifyRecordUpdateAvailableDropped,
    });
    notifyListViewSummaryUpdateAvailable = throttle(60, 60000, createLDSAdapter(luvio, 'notifyListViewSummaryUpdateAvailable', notifyUpdateAvailableFactory$2));
    notifyListInfoSummaryUpdateAvailable = throttle(60, 60000, createLDSAdapter(luvio, 'notifyListInfoSummaryUpdateAvailable', notifyUpdateAvailableFactory$3));
    notifyListInfoUpdateAvailable = throttle(60, 60000, createLDSAdapter(luvio, 'notifyListInfoUpdateAvailable', notifyUpdateAvailableFactory$1));
    notifyListRecordCollectionUpdateAvailable = throttle(60, 60000, createLDSAdapter(luvio, 'notifyListRecordCollectionUpdateAvailable', notifyUpdateAvailableFactory$4));
    notifyQuickActionDefaultsUpdateAvailable = throttle(60, 60000, createLDSAdapter(luvio, 'notifyQuickActionDefaultsUpdateAvailable', notifyUpdateAvailableFactory));
    // Setting up storeWatchers for custom notifyUpdateAvailable endpoints
    setupListRecordCollectionStoreWatcher(luvio);
    setupListSummaryCollectionStoreWatcher(luvio);
    // Custom notifyUpdateAvailable endpoints for partial key support
    notifyAllListRecordUpdateAvailable = throttle(60, 60000, setupNotifyAllListRecordUpdateAvailable(luvio));
    notifyAllListInfoSummaryUpdateAvailable = throttle(60, 60000, setupNotifyAllListInfoSummaryUpdateAvailable(luvio));
});

export { API_NAMESPACE, InMemoryRecordRepresentationQueryEvaluator, MRU, RepresentationType$J as ObjectInfoDirectoryEntryRepresentationType, RepresentationType$O as ObjectInfoRepresentationType, RECORD_FIELDS_KEY_JUNCTION, RECORD_ID_PREFIX, RECORD_REPRESENTATION_NAME, RECORD_VIEW_ENTITY_ID_PREFIX, RECORD_VIEW_ENTITY_REPRESENTATION_NAME, RepresentationType$V as RecordRepresentationRepresentationType, TTL$z as RecordRepresentationTTL, RepresentationType$V as RecordRepresentationType, VERSION$1g as RecordRepresentationVersion, keyPrefix as UiApiNamespace, buildRecordRepKeyFromId, getFieldApiNamesArray as coerceFieldIdArray, getObjectApiName$1 as coerceObjectId, getObjectApiNamesArray as coerceObjectIdArray, configurationForRestAdapters as configuration, createContentDocumentAndVersion, createContentVersion, createIngestRecordWithFields, createLDSAdapterWithPrediction, createListInfo, createRecord, createRelatedListAdapterWithPrediction, createRelatedListPlusAdapterWithPrediction, deleteListInfo, deleteRecord, executeBatchRecordOperations, extractRecordIdFromStoreKey, getActionOverrides, getActionOverrides_imperative, getAllApps, getAllApps_imperative, getAppDetails, getAppDetails_imperative, getDuplicateConfiguration, getDuplicateConfiguration_imperative, getDuplicates, getDuplicates_imperative, getFlexipageFormulaOverrides, getFlexipageFormulaOverrides_imperative, getGlobalActions, getGlobalActions_imperative, getKeywordSearchResults, getKeywordSearchResults_imperative, getLayout, getLayoutUserState, getLayoutUserState_imperative, getLayout_imperative, getListInfoByName, getListInfoByNameAdapterFactory, getListInfoByName_imperative, getListInfosByName, getListInfosByName_imperative, getListInfosByObjectName, getListInfosByObjectNameAdapterFactory, getListInfosByObjectName_imperative, getListObjectInfo, getListObjectInfoAdapterFactory, getListObjectInfo_imperative, getListPreferences, getListPreferences_imperative, getListRecordsByName, factory$a as getListRecordsByNameAdapterFactory, getListRecordsByName_imperative, getListUi, getListUi_imperative, getLookupActions, getLookupActions_imperative, getLookupMetadata, getLookupMetadata_imperative, getLookupRecords, getLookupRecords_imperative, getNavItems, getNavItems_imperative, getObjectCreateActions, getObjectCreateActions_imperative, getObjectInfo, getObjectInfoAdapterFactory, getObjectInfoDirectoryAdapterFactory, getObjectInfo_imperative, getObjectInfos, getObjectInfosAdapterFactory, getObjectInfos_imperative, getPathLayout, getPathLayout_imperative, getPicklistValues, getPicklistValuesByRecordType, getPicklistValuesByRecordType_imperative, getPicklistValues_imperative, getQuickActionDefaults, getQuickActionDefaults_imperative, getQuickActionInfo, getQuickActionInfo_imperative, getQuickActionLayout, getQuickActionLayout_imperative, getRecord, getRecordActions, getRecordActionsAdapterFactory, getRecordActions_imperative, factory$f as getRecordAdapterFactory, getRecordAvatars, getRecordAvatarsAdapterFactory, getRecordAvatars_imperative, getRecordCreateDefaults, getRecordCreateDefaults_imperative, getRecordEditActions, getRecordEditActions_imperative, getRecordId18, getRecordId18Array, getRecordIngestionOverride, getRecordNotifyChange, getRecordTemplateClone, getRecordTemplateClone_imperative, getRecordTemplateCreate, getRecordTemplateCreate_imperative, getRecordUi, getRecordUi_imperative, getRecord_imperative, getRecords, getRecordsAdapterFactory, getRecords_imperative, getRelatedListActions, getRelatedListActionsAdapterFactory, getRelatedListActions_imperative, getRelatedListCount, getRelatedListCount_imperative, getRelatedListInfo, getRelatedListInfoAdapterFactory, getRelatedListInfoBatch, getRelatedListInfoBatchAdapterFactory, getRelatedListInfoBatch_imperative, getRelatedListInfo_imperative, getRelatedListPreferences, getRelatedListPreferencesBatch, getRelatedListPreferencesBatch_imperative, getRelatedListPreferences_imperative, getRelatedListRecordActions, getRelatedListRecordActions_imperative, getRelatedListRecords, getRelatedListRecordsAdapterFactory, getRelatedListRecordsBatch, getRelatedListRecordsBatchAdapterFactory, getRelatedListRecordsBatch_imperative, getRelatedListRecords_imperative, getRelatedListsActions, getRelatedListsActionsAdapterFactory, getRelatedListsActions_imperative, getRelatedListsCount, getRelatedListsCount_imperative, getRelatedListsInfo, getRelatedListsInfoAdapterFactory, getRelatedListsInfo_imperative, getResponseCacheKeys as getResponseCacheKeysContentDocumentCompositeRepresentation, getSearchFilterMetadata, getSearchFilterMetadata_imperative, getSearchFilterOptions, getSearchFilterOptions_imperative, getSearchResults, getSearchResults_imperative, getTypeCacheKeys$X as getTypeCacheKeysRecord, ingest as ingestContentDocumentCompositeRepresentation, ingest$H as ingestObjectInfo, ingest$B as ingestQuickActionExecutionRepresentation, ingest$O as ingestRecord, instrument, isStoreKeyRecordViewEntity, isSupportedEntity, keyBuilder as keyBuilderContentDocumentCompositeRepresentation, keyBuilderFromType as keyBuilderFromTypeContentDocumentCompositeRepresentation, keyBuilderFromType$D as keyBuilderFromTypeRecordRepresentation, keyBuilder$1Y as keyBuilderObjectInfo, keyBuilder$1R as keyBuilderQuickActionExecutionRepresentation, keyBuilder$29 as keyBuilderRecord, notifyAllListInfoSummaryUpdateAvailable, notifyAllListRecordUpdateAvailable, notifyListInfoSummaryUpdateAvailable, notifyListInfoUpdateAvailable, notifyListRecordCollectionUpdateAvailable, notifyListViewSummaryUpdateAvailable, notifyQuickActionDefaultsUpdateAvailable, notifyRecordUpdateAvailable, performQuickAction, performUpdateRecordQuickAction, refresh, registerPrefetcher, updateLayoutUserState, updateListInfoByName, updateListPreferences, updateRecord, updateRecordAvatar, updateRelatedListInfo, updateRelatedListPreferences };
// version: 1.353.1-4693659f9b
